@@ -30,7 +30,7 @@ do i3=0,ngridk(3)-1
       ace=0.d0
       do ist=1,nstsv
         vn=vnorm(ist,jk)
-        if ((vn.gt.0.d0).and.(vn.lt.1.d0)) then
+        if ((vn > 0.d0).and.(vn < 1.d0)) then
           ace=ace+vn*log(vn)+(1.d0-vn)*log(1.d0-vn)
         end if
       end do
@@ -53,7 +53,7 @@ do i3=0,ngridq(3)-1
       ace=0.d0
       do i=1,nbph
         xn=xnorm(i,jq)
-        if (xn.gt.0.d0) then
+        if (xn > 0.d0) then
           ace=ace+xn*log(xn)-(1.d0+xn)*log(1.d0+xn)
         end if
       end do
