@@ -11,7 +11,7 @@ implicit none
 integer idm,is,ias,npc
 real(8) t1
 ! add the global fixed spin moment B-field to the Kohn-Sham field
-if ((abs(fsmtype) == 1).or.(abs(fsmtype) == 3)) then
+if (any(abs(fsmtype) == [1,3,4,6])) then
   do idm=1,ndmag
     t1=bfsmc(idm)
     do ias=1,natmtot
@@ -23,7 +23,7 @@ if ((abs(fsmtype) == 1).or.(abs(fsmtype) == 3)) then
   end do
 end if
 ! add the muffin-tin fields
-if ((abs(fsmtype) == 2).or.(abs(fsmtype) == 3)) then
+if (any(abs(fsmtype) == [2,3,5,6])) then
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
