@@ -67,7 +67,7 @@ real(8), allocatable :: ri(:),wpr(:,:),fr1(:),fr2(:),gr1(:),gr2(:)
 real(8), allocatable :: grho(:),g2rho(:),g3rho(:)
 if (nst < 1) then
   write(*,*)
-  write(*,'("Error(atom): nst < 1 : ",I8)') nst
+  write(*,'("Error(atom): nst < 1 : ",I0)') nst
   write(*,*)
   stop
 end if
@@ -131,14 +131,14 @@ do iscl=1,maxscl
 ! compute the exchange-correlation energy and potential
   if (xcgrad == 1) then
 ! GGA functional
-! |grad rho|
+! |∇ρ|
     call fderiv(1,nr,r,rho,grho)
-! grad^2 rho
+! ∇²ρ
     call fderiv(2,nr,r,rho,g2rho)
     do ir=1,nr
       g2rho(ir)=g2rho(ir)+2.d0*ri(ir)*grho(ir)
     end do
-! approximate (grad rho).(grad |grad rho|)
+! approximate (∇ρ)⋅(∇|∇ρ|)
     do ir=1,nr
       g3rho(ir)=grho(ir)*g2rho(ir)
     end do
@@ -176,7 +176,6 @@ write(*,'("Warning(atom): maximum iterations exceeded")')
 deallocate(vn,vh,ex,ec,vx,vc,vrp)
 deallocate(ri,wpr,fr1,fr2,gr1,gr2)
 if (xcgrad == 1) deallocate(grho,g2rho,g3rho)
-return
 
 contains
 
