@@ -32,10 +32,8 @@ x=v(1); y=v(2); z=v(3)
 t1=sqrt(x**2+y**2+z**2)
 ! return the identity matrix for a zero-length axis
 if (t1 < 1.d-8) then
-  su2(1,1)=1.d0
-  su2(2,1)=0.d0
-  su2(1,2)=0.d0
-  su2(2,2)=1.d0
+  su2(1,1)=1.d0; su2(2,1)=0.d0
+  su2(1,2)=0.d0; su2(2,2)=1.d0
   return
 end if
 ! normalise the vector
