@@ -26,29 +26,53 @@ use modomp
 !BOC
 implicit none
 ! local variables
-integer ik,ist,ispn,is,ia,ias
-integer lmax,lmmax,l,m,lm,iv,nthd
-real(8) emin,emax,sm,t1
+logical tspndg,tlmdg
+integer ik,ist,ispn,idm
+integer is,ia,ias,nthd
+integer l,m,lm,iv
+real(8) emin,emax,sm
+real(8) v(ndmag),t1,t2
 character(256) fname
+complex(8) su2(2,2),z1
 ! allocatable arrays
 real(8), allocatable :: evalfv(:,:)
 ! low precision for band character array saves memory
-real(4), allocatable :: bc(:,:,:,:)
-complex(8), allocatable :: dmat(:,:,:,:,:),apwalm(:,:,:,:,:)
-complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
+real(4), allocatable :: bc(:,:,:,:),elm(:,:)
+complex(8), allocatable :: ulm(:,:,:),dmat(:,:,:,:,:)
+complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
 ! initialise universal variables
 call init0
 call init1
-! maximum angular momentum for band character
-lmax=min(3,lmaxo)
-lmmax=(lmax+1)**2
-if (task == 21) then
-  allocate(bc(0:lmax,natmtot,nstsv,nkpt))
-else if (task == 22) then
-  allocate(bc(lmmax,natmtot,nstsv,nkpt))
-else if (task == 23) then
+! calculate only the diagonal parts of the density matrices by default
+tspndg=.true.
+tlmdg=.true.
+select case(task)
+case(21)
+  allocate(bc(0:lmaxdb,natmtot,nstsv,nkpt))
+case(22)
+  allocate(bc(lmmaxdb,natmtot,nstsv,nkpt))
+! generate unitary matrices which convert the Yₗₘ basis into the irreducible
+! representation basis of the symmetry group at each atomic site
+  if (lmirep) then
+    allocate(elm(lmmaxdb,natmtot),ulm(lmmaxdb,lmmaxdb,natmtot))
+    call genlmirep(elm,ulm)
+! write the eigenvalues of a pseudorandom matrix symmetrised by the site
+! symmetries in the Yₗₘ basis
+    call writeelmirep('.OUT',elm)
+! require full density matrix in (l,m) degrees of freedom
+    tlmdg=.false.
+  end if
+case(23)
+  if (.not.spinpol) goto 10
   allocate(bc(nspinor,natmtot,nstsv,nkpt))
-end if
+! compute the SU(2) operator used for rotating the density matrix to the
+! desired spin-quantisation axis; if axis is not z then the full matrix in
+! spin degrees of freedom is required
+  call sqasu2(sqaxis,tspndg,su2)
+case(24)
+  if (.not.spinpol) goto 10
+  allocate(bc(ndmag,natmtot,nstsv,nkpt))
+end select
 ! read density and potentials from file
 call readstate
 ! Fourier transform Kohn-Sham potential to G-space
@@ -63,19 +87,19 @@ call gensocfr
 call holdthd(nkpt,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(evalfv,evecfv,evecsv) &
-!$OMP PRIVATE(dmat,apwalm,ist,ispn) &
-!$OMP PRIVATE(ias,l,m,lm,sm) &
+!$OMP PRIVATE(dmat,apwalm,ispn,ias,ist) &
+!$OMP PRIVATE(l,m,lm,sm,v,t1,t2,z1) &
 !$OMP NUM_THREADS(nthd)
 allocate(evalfv(nstfv,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 if (task >= 21) then
-  allocate(dmat(lmmax,nspinor,lmmax,nspinor,nstsv))
+  allocate(dmat(lmmaxdb,nspinor,lmmaxdb,nspinor,nstsv))
   allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 end if
 !$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkpt
 !$OMP CRITICAL(bandstr_)
-  write(*,'("Info(bandstr): ",I6," of ",I6," k-points")') ik,nkpt
+  write(*,'("Info(bandstr): ",I0," of ",I0," k-points")') ik,nkpt
 !$OMP END CRITICAL(bandstr_)
 ! solve the first- and second-variational eigenvalue equations
   call eveqn(ik,evalfv,evecfv,evecsv)
@@ -88,14 +112,19 @@ do ik=1,nkpt
     end do
 ! average band character over spin and m for all atoms
     do ias=1,natmtot
-! generate the diagonal of the density matrix
-      call gendmatk(.true.,.true.,0,lmax,ias,nstsv,[0],ngk(:,ik),apwalm,evecfv,&
-       evecsv,lmmax,dmat)
+! generate the density matrix
+      call gendmatk(tspndg,tlmdg,0,lmaxdb,ias,nstsv,[0],ngk(:,ik),apwalm, &
+       evecfv,evecsv,lmmaxdb,dmat)
+! convert (l,m) part to an irreducible representation if required
+      if (.not.tlmdg) call dmatulm(ulm(:,:,ias),dmat)
+! spin rotate the density matrices to desired spin-quantisation axis
+      if (.not.tspndg) call dmatsu2(lmmaxdb,su2,dmat)
       do ist=1,nstsv
-        if (task == 21) then
+        select case(task)
+        case(21)
 ! l character of band
           lm=0
-          do l=0,lmax
+          do l=0,lmaxdb
             sm=0.d0
             do m=-l,l
               lm=lm+1
@@ -103,35 +132,41 @@ do ik=1,nkpt
                 sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
               end do
             end do
-            bc(l,ias,ist,ik)=real(sm)
+            bc(l,ias,ist,ik)=sm
           end do
-        else if (task == 22) then
+        case(22)
 ! (l,m) character of band
-          lm=0
-          do l=0,lmax
-            do m=-l,l
-              lm=lm+1
-              sm=0.d0
-              do ispn=1,nspinor
-                sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
-              end do
-              bc(lm,ias,ist,ik)=real(sm)
+          do lm=1,lmmaxdb
+            sm=0.d0
+            do ispn=1,nspinor
+              sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
             end do
+            bc(lm,ias,ist,ik)=sm
           end do
-        else
+        case(23)
 ! spin character of band
           do ispn=1,nspinor
             sm=0.d0
-            lm=0
-            do l=0,lmax
-              do m=-l,l
-                lm=lm+1
-                sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
-              end do
+            do lm=1,lmmaxdb
+              sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
             end do
-            bc(ispn,ias,ist,ik)=real(sm)
+            bc(ispn,ias,ist,ik)=sm
           end do
-        end if
+        case(24)
+! magnetic moment character of band
+          v(1:ndmag)=0.d0
+          do lm=1,lmmaxdb
+            t1=dble(dmat(lm,1,lm,1,ist))
+            t2=dble(dmat(lm,2,lm,2,ist))
+            v(ndmag)=v(ndmag)+t1-t2
+            if (ncmag) then
+              z1=2.d0*dmat(lm,1,lm,2,ist)
+              v(1)=v(1)+z1%re
+              v(2)=v(2)-z1%im
+            end if
+          end do
+          bc(1:ndmag,ias,ist,ik)=v(1:ndmag)
+        end select
       end do
     end do
   end if
@@ -164,33 +199,39 @@ if (task == 20) then
   write(*,'("Info(bandstr):")')
   write(*,'(" Band structure plot written to BAND.OUT")')
 else
-  do is=1,nspecies
-    do ia=1,natoms(is)
-      ias=idxas(ia,is)
-      write(fname,'("BAND_S",I2.2,"_A",I4.4,".OUT")') is,ia
-      open(50,file=trim(fname),form='FORMATTED',action='WRITE')
-      do ist=1,nstsv
-        do ik=1,nkpt
-          if (task == 21) then
+  do ias=1,natmtot
+    is=idxis(ias)
+    ia=idxia(ias)
+    write(fname,'("BAND_S",I2.2,"_A",I4.4,".OUT")') is,ia
+    open(50,file=trim(fname),form='FORMATTED',action='WRITE')
+    do ist=1,nstsv
+      do ik=1,nkpt
+        select case(task)
+        case(21)
 ! sum band character over l to find total atomic character
-            sm=0.d0
-            do l=0,lmax
-              sm=sm+bc(l,ias,ist,ik)
-            end do
-            write(50,'(2G18.10,5F12.6)') dpp1d(ik),evalsv(ist,ik),sm, &
-             (bc(l,ias,ist,ik),l=0,lmax)
-          else if (task == 22) then
-            write(50,'(2G18.10,16F12.6)') dpp1d(ik),evalsv(ist,ik), &
-             (bc(lm,ias,ist,ik),lm=1,lmmax)
-          else
-            write(50,'(2G18.10,2F12.6)') dpp1d(ik),evalsv(ist,ik), &
-             (bc(ispn,ias,ist,ik),ispn=1,nspinor)
-          end if
-        end do
-        write(50,*)
+          sm=sum(bc(0:lmaxdb,ias,ist,ik))
+          write(50,'(2G18.10,F12.6)',advance='NO') dpp1d(ik),evalsv(ist,ik),sm
+          do l=0,lmaxdb
+            write(50,'(F12.6)',advance='NO') bc(l,ias,ist,ik)
+          end do
+          write(50,*)
+        case(22)
+          write(50,'(2G18.10)',advance='NO') dpp1d(ik),evalsv(ist,ik)
+          do lm=1,lmmaxdb
+            write(50,'(F12.6)',advance='NO') bc(lm,ias,ist,ik)
+          end do
+          write(50,*)
+        case(23)
+          write(50,'(2G18.10,2F12.6)') dpp1d(ik),evalsv(ist,ik), &
+           (bc(ispn,ias,ist,ik),ispn=1,nspinor)
+        case(24)
+          write(50,'(2G18.10,3F12.6)') dpp1d(ik),evalsv(ist,ik), &
+           (bc(idm,ias,ist,ik),idm=1,ndmag)
+        end select
       end do
-      close(50)
+      write(50,*)
     end do
+    close(50)
   end do
   write(*,*)
   write(*,'("Info(bandstr):")')
@@ -198,15 +239,27 @@ else
   write(*,'(" for all species and atoms")')
   write(*,*)
   write(*,'(" Columns in the file are :")')
-  if (task == 21) then
+  select case(task)
+  case(21)
     write(*,'("  distance, eigenvalue, total atomic character, l character &
-     &(l = 0...",I1,")")') lmax
-  else if (task == 22) then
+     &(l = 0...",I0,")")') lmaxdb
+  case(22)
     write(*,'("  distance, eigenvalue, (l,m) character &
-     &(l = 0...",I1,", m = -l...l)")') lmax
-  else
+     &(l = 0...",I0,", m = -l...l)")') lmaxdb
+    if (lmirep) then
+      write(*,*)
+      write(*,'(" Eigenvalues of a random matrix symmetrised with the site")')
+      write(*,'(" symmetries in the Yₗₘ basis written to ELMIREP.OUT for all")')
+      write(*,'(" species and atoms. Degenerate eigenvalues correspond to")')
+      write(*,'(" irreducible representations of each site symmetry group")')
+    end if
+  case(23)
     write(*,'("  distance, eigenvalue, spin-up and spin-down characters")')
-  end if
+    write(*,*)
+    write(*,'(" Spin-quantisation axis : ",3G18.10)') sqaxis(:)
+  case(24)
+    write(*,'("  distance, eigenvalue, moment character")')
+  end select
 end if
 write(*,*)
 write(*,'(" Fermi energy is at zero in plot")')
@@ -221,6 +274,13 @@ close(50)
 write(*,*)
 write(*,'(" Vertex location lines written to BANDLINES.OUT")')
 if (task >= 21) deallocate(bc)
+if ((task == 22).and.lmirep) deallocate(elm,ulm)
+return
+10 continue
+write(*,*)
+write(*,'("Error(bandstr): spin-unpolarised calculation")')
+write(*,*)
+stop
 end subroutine
 !EOC
 
