@@ -68,7 +68,7 @@ if (any(dmomfix(:) /= 0.d0)) then
 end if
 if (any(dbfieldc0(:) /= 0.d0)) then
   bfieldc0(:)=bfieldc0(:)+dbfieldc0(:)
-  if (mp_mpi) write(*,'("Info(batchdv): incremented dbfieldc0")')
+  if (mp_mpi) write(*,'("Info(batchdv): incremented bfieldc0")')
 end if
 if (any(dvqlss(:) /= 0.d0)) then
   vqlss(:)=vqlss(:)+dvqlss(:)
