@@ -13,7 +13,7 @@ integer its,is,ia
 call gentimes
 ! write zero force to file for all time steps
 open(50,file='FORCETOT_TD.OUT',form='FORMATTED')
-do its=1,ntimes
+do its=1,ntimes,ntsforce
   write(50,'(I8,G18.10)') its,times(its)
   do is=1,nspecies
     do ia=1,natoms(is)
