@@ -26,7 +26,7 @@ use modmain
 implicit none
 ! local variables
 integer is,ia,ias
-real(8) v1(3),v2(3),t1
+real(8) v1(3),v2(3),t1,t2
 if ((.not.spinpol).or.(fsmtype == 0)) return
 ! fixed spin direction not valid for collinear magnetism
 if ((.not.ncmag).and.(fsmtype < 0)) return
@@ -48,14 +48,13 @@ if ((abs(fsmtype) == 1).or.(abs(fsmtype) == 3)) then
 ! for fixed direction calculations (Y. Kvashnin and LN)
   if (fsmtype < 0) call r3vo(momfix,bfsmc)
 end if
-if ((abs(fsmtype) == 2).or.(abs(fsmtype) == 3)) then
 ! determine the muffin-tin fields for fixed local moments
+if ((abs(fsmtype) == 2).or.(abs(fsmtype) == 3)) then
   do is=1,nspecies
     do ia=1,natoms(is)
       ias=idxas(ia,is)
 ! if any component is >= 1000 then do not fix the moment
-      t1=sum(abs(mommtfix(:,ia,is)))
-      if (t1 >= 1000.d0) cycle
+      if (any(abs(mommtfix(1:3,ia,is)) >= 1000.d0)) cycle
       if (ncmag) then
         v1(:)=mommt(:,ias)
       else
@@ -73,6 +72,24 @@ if ((abs(fsmtype) == 2).or.(abs(fsmtype) == 3)) then
     end do
   end do
 end if
+! global fixed spin magnitude
+if ((fsmtype == 4).or.(fsmtype == 6)) then
+  t1=taufsm*(momtotm-momfixm)
+  bfsmc(1:ndmag)=bfsmc(1:ndmag)+t1*momtot(1:ndmag)
+end if
+! local fixed spin magnitude
+if ((fsmtype == 5).or.(fsmtype == 6)) then
+  do is=1,nspecies
+    do ia=1,natoms(is)
+      ias=idxas(ia,is)
+      t1=mommtfixm(ia,is)
+      if (t1 < 0.d0) cycle
+      t2=norm2(mommt(1:ndmag,ias))
+      t1=taufsm*(t2-t1)
+      bfsmcmt(1:ndmag,ias)=bfsmcmt(1:ndmag,ias)+t1*mommt(1:ndmag,ias)
+    end do
+  end do
+end if
 end subroutine
 !EOC
 
