@@ -60,13 +60,13 @@ real(8) f00(n),f01(n),f10(n),f11(n)
 real(8) e00(n),e01(n),e10(n),e11(n)
 if ((ngridk(1) < 1).or.(ngridk(2) < 1).or.(ngridk(3) < 1)) then
   write(*,*)
-  write(*,'("Error(brzint): ngridk < 1 : ",3I8)') ngridk
+  write(*,'("Error(brzint): ngridk < 1 :",3(X,I0))') ngridk
   write(*,*)
   stop
 end if
 if ((nsk(1) < 1).or.(nsk(2) < 1).or.(nsk(3) < 1)) then
   write(*,*)
-  write(*,'("Error(brzint): nsk < 1 : ",3I8)') nsk
+  write(*,'("Error(brzint): nsk < 1 :",3(X,I0))') nsk
   write(*,*)
   stop
 end if
