@@ -16,7 +16,7 @@ integer n,igp,nthd
 real(4) t0
 ! automatic arrays
 complex(4) c(ngkmax)
-t0=1.e0/sqrt(omega)
+t0=1.d0/sqrt(omega)
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(c,ispn,jspn,n,igp) &
