@@ -21,7 +21,6 @@ use modtest
 implicit none
 ! local variables
 integer is,ias
-real(8) t1
 ! external functions
 real(8), external :: rfmtint
 ! find the muffin-tin charges
@@ -32,8 +31,7 @@ do ias=1,natmtot
   chgmttot=chgmttot+chgmt(ias)
 end do
 ! find the interstitial charge
-t1=dot_product(rhoir(1:ngtot),cfunir(1:ngtot))
-chgir=t1*omega/dble(ngtot)
+chgir=(omega/ngtot)*dot_product(rhoir(1:ngtot),cfunir(1:ngtot))
 ! total calculated charge
 chgcalc=chgmttot+chgir
 ! write total calculated charge to test file
