@@ -54,7 +54,7 @@ do ip=1,3
    ngvec,jlgqrmt,ylmgq,sfacgq,zrhoir,npmtmax,zvclmt,zvclir)
 ! multiply with density derivative and integrate
   z1=sum(cfunir(1:ngtot)*conjg(zvclir(1:ngtot))*drhoir(1:ngtot))
-  z1=z1*omega/dble(ngtot)
+  z1=z1*(omega/ngtot)
   do ias=1,natmtot
     is=idxis(ias)
     z1=z1+zfmtinp(nrmt(is),nrmti(is),wr2mt(:,is),zvclmt(:,ias),drhomt(:,ias))
@@ -75,7 +75,7 @@ call zpotcoul(iasph,nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg, &
 do ip=1,3
 ! multiply with density gradient and integrate
   z1=sum(cfunir(1:ngtot)*zvclir(1:ngtot)*grhoir(1:ngtot,ip))
-  z1=z1*omega/dble(ngtot)
+  z1=z1*(omega/ngtot)
   do ias=1,natmtot
     is=idxis(ias)
     z1=z1+zfmtinp(nrmt(is),nrmti(is),wr2mt(:,is),grhomt(:,ias,ip),zvclmt(:,ias))
