@@ -131,9 +131,9 @@ do jspn=1,nspnfv
           t1=vgc(l,ig)
           z1=-ffacg(ig,is)*conjg(sfacg(ig,ias))
           z2=t1*(dp(i,j)*z1+h(i,j))
-          dlh(i,j)=zi*z2
+          dlh(i,j)=cmplx(-z2%im,z2%re,8)
           z2=t1*(z1+o(i,j))
-          dlo(i,j)=zi*z2
+          dlo(i,j)=cmplx(-z2%im,z2%re,8)
         end do
       end do
       do j=n+1,nm
@@ -141,9 +141,9 @@ do jspn=1,nspnfv
         do i=1,n
           t1=vgkc(l,i,jspn,ik)
           z1=t1*h(i,j)
-          dlh(i,j)=zi*z1
+          dlh(i,j)=cmplx(-z1%im,z1%re,8)
           z1=t1*o(i,j)
-          dlo(i,j)=zi*z1
+          dlo(i,j)=cmplx(-z1%im,z1%re,8)
         end do
 ! zero the local-orbital-local-orbital contribution
         do i=n+1,j
@@ -159,17 +159,17 @@ do jspn=1,nspnfv
           t1=vgqc(l,ig)
           z1=-ffacgq(ig,is)*conjg(sfacgq(ig,ias))
           z2=t1*(dpq(i,j)*z1+hq(i,j))
-          dlhq(i,j)=zi*z2
+          dlhq(i,j)=cmplx(-z2%im,z2%re,8)
           z2=t1*(z1+oq(i,j))
-          dloq(i,j)=zi*z2
+          dloq(i,j)=cmplx(-z2%im,z2%re,8)
         end do
 ! local-orbital-APW derivative
         t1=-vgkc(l,j,jspn,ik)
         do i=nq+1,nmq
           z1=t1*hq(i,j)
-          dlhq(i,j)=zi*z1
+          dlhq(i,j)=cmplx(-z1%im,z1%re,8)
           z1=t1*oq(i,j)
-          dloq(i,j)=zi*z1
+          dloq(i,j)=cmplx(-z1%im,z1%re,8)
         end do
       end do
       do j=n+1,nm
@@ -177,9 +177,9 @@ do jspn=1,nspnfv
         do i=1,nq
           t1=vgkqc(l,i,jspn,ik)
           z1=t1*hq(i,j)
-          dlhq(i,j)=zi*z1
+          dlhq(i,j)=cmplx(-z1%im,z1%re,8)
           z1=t1*oq(i,j)
-          dloq(i,j)=zi*z1
+          dloq(i,j)=cmplx(-z1%im,z1%re,8)
         end do
 ! zero the local-orbital-local-orbital contribution
         do i=nq+1,nmq
@@ -194,22 +194,22 @@ do jspn=1,nspnfv
           t1=vgc(l,ig)
           if (ias == iasph) then
             z1=-ffacg(ig,is)*conjg(sfacg(ig,ias))
-            dz1=vgc(ipph,ig)*zmi*z1
+            dz1=vgc(ipph,ig)*cmplx(z1%im,-z1%re,8)
           else
             dz1=0.d0
           end if
           z2=t1*(dp(i,j)*dz1+dh(i,j))
-          ddlh(i,j)=zi*z2
+          ddlh(i,j)=cmplx(-z2%im,z2%re,8)
           z2=t1*(dz1+od(i,j))
-          ddlo(i,j)=zi*z2
+          ddlo(i,j)=cmplx(-z2%im,z2%re,8)
         end do
 ! local-orbital-APW derivative
         t1=-vgkc(l,j,jspn,ik)
         do i=n+1,nm
           z1=t1*dh(i,j)
-          ddlh(i,j)=zi*z1
+          ddlh(i,j)=cmplx(-z1%im,z1%re,8)
           z1=t1*od(i,j)
-          ddlo(i,j)=zi*z1
+          ddlo(i,j)=cmplx(-z1%im,z1%re,8)
         end do
       end do
 ! APW-local-orbital derivative
@@ -217,9 +217,9 @@ do jspn=1,nspnfv
         do i=1,n
           t1=vgkc(l,i,jspn,ik)
           z1=t1*dh(i,j)
-          ddlh(i,j)=zi*z1
+          ddlh(i,j)=cmplx(-z1%im,z1%re,8)
           z1=t1*od(i,j)
-          ddlo(i,j)=zi*z1
+          ddlo(i,j)=cmplx(-z1%im,z1%re,8)
         end do
 ! zero the local-orbital-local-orbital derivative
         do i=n+1,nm
