@@ -39,7 +39,7 @@ do l1=0,lmaxapw
               lma=l2**2+1; lmb=lma+2*l2
               z1=z1+sum(gntyyy(lma:lmb,lm3,lm1)*dhaa(lma:lmb,jo,l3,io,l1,ias))
             end do
-            if (abs(dble(z1))+abs(aimag(z1)) > 1.d-12) then
+            if (abs(z1%re)+abs(z1%im) > 1.d-12) then
               call zaxpy(ngp,z1,apwalm(:,jo,lm3),1,y1,1)
             end if
           end do
@@ -56,7 +56,7 @@ do l1=0,lmaxapw
                 lma=l2**2+1; lmb=lma+2*l2
                 z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*haa(lma:lmb,jo,l3,io,l1,ias))
               end do
-              if (abs(dble(z1))+abs(aimag(z1)) > 1.d-12) then
+              if (abs(z1%re)+abs(z1%im) > 1.d-12) then
                 call zaxpy(ngp,z1,dapwalm(:,jo,lm3),1,y1,1)
                 call zaxpy(ngp,z1,apwalm(:,jo,lm3),1,y2,1)
               end if
@@ -71,9 +71,9 @@ do l1=0,lmaxapw
     end do
   end do
 end do
-call zmmab(lmoapw(is),ngpq,ngp,a1,b1,ld,dh)
+call zmctm(lmoapw(is),ngpq,ngp,a1,b1,ld,dh)
 if (ias == iasph) then
-  call zmmab(lmoapw(is),ngpq,ngp,a2,b2,ld,dh)
+  call zmctm(lmoapw(is),ngpq,ngp,a2,b2,ld,dh)
 end if
 end subroutine
 
