@@ -36,7 +36,7 @@ do ilo=1,nlorb(is)
             lma=l2**2+1; lmb=lma+2*l2
             z1=z1+sum(gntyyy(lma:lmb,lm3,lm1)*dhloa(lma:lmb,io,l3,ilo,ias))
           end do
-          if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
+          if (abs(z1%re)+abs(z1%im) > 1.d-12) then
             do i=1,ngpq
               dh(i,j0)=dh(i,j0)+conjg(z1*apwalmq(i,io,lm3))
             end do
@@ -57,7 +57,7 @@ do ilo=1,nlorb(is)
               lma=l2**2+1; lmb=lma+2*l2
               z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*hloa(lma:lmb,io,l3,ilo,ias))
             end do
-            if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
+            if (abs(z1%re)+abs(z1%im) > 1.d-12) then
               do i=1,ngpq
                 dh(i,j0)=dh(i,j0)+conjg(z1*dapwalmq(i,io,lm3))
               end do
