@@ -41,7 +41,7 @@ real(8), external :: sdelta
 call init0
 call init1
 ! read Fermi energy from file
-call readfermi
+call readefm
 ! get the eigenvalues and occupation numbers from file
 call readevalsv
 call readoccsv
@@ -75,7 +75,7 @@ do ioc=1,noptcomp
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(dielectric_)
-    write(*,'("Info(dielectric): ",I6," of ",I6," k-points")') ik,nkptnr
+    write(*,'("Info(dielectric): ",I0," of ",I0," k-points")') ik,nkptnr
 !$OMP END CRITICAL(dielectric_)
 ! equivalent reduced k-point
     jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
@@ -98,7 +98,7 @@ do ioc=1,noptcomp
           if (i == j) then
             if (ist == jst) then
               x=(ei-efermi)/swidth
-              t1=wkptnr*dble(z1)*sdelta(stype,x)/swidth
+              t1=wkptnr*z1%re*sdelta(stype,x)/swidth
               wplas=wplas+t1
             end if
           end if
