@@ -23,7 +23,7 @@ complex(8), allocatable :: pmat(:,:,:),sigma(:,:,:),zv(:,:)
 call init0
 call init1
 ! read Fermi energy from a file
-call readfermi
+call readefm
 ! get the eigenvalues from file
 do ik1=1,nkpt
   call getevalsv(filext,ik1,vkl(:,ik1),evalsv(:,ik1))
@@ -48,8 +48,8 @@ read(140) nmbse_
 if (nmbse /= nmbse_) then
   write(*,*)
   write(*,'("Error(dielectric_bse): differing nmbse")')
-  write(*,'(" current   : ",I6)') nmbse
-  write(*,'(" EVBSE.OUT : ",I6)') nmbse_
+  write(*,'(" current   : ",I0)') nmbse
+  write(*,'(" EVBSE.OUT : ",I0)') nmbse_
   stop
 end if
 read(140) evalbse
@@ -142,7 +142,7 @@ do ioc=1,noptcomp
   write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,ioc)
 end do
 ! write sigma to test file
-call writetest(187,'BSE optical conductivity',nv=nwplot,tol=1.d-3,zva=sigma)
+call writetest(187,'BSE optical conductivity',nv=nwplot,tol=1.d-2,zva=sigma)
 deallocate(w,pmat,sigma,zv)
 ! deallocate global BSE arrays
 deallocate(evalbse,hmlbse)
