@@ -39,7 +39,10 @@ do i=1,3
 ! Fourier transform A(t) numerically to obtain A(ω)
     call zftft(w,wt,3,afieldt(i,1),ew(:,i))
 ! take the time derivative E(t)=-1/c dA(t)/dt analytically to get E(ω)
-    ew(:,i)=t0*zmi*w(:)*ew(:,i)
+    do iw=1,nwplot
+      z1=ew(iw,i)
+      ew(iw,i)=t0*w(iw)*cmplx(z1%im,-z1%re,8)
+    end do
 ! filter the high-frequency components from E(ω) with a Lorentzian convolution
     call zlrzncnv(nwplot,swidth,w,ew(:,i))
   else
@@ -77,13 +80,13 @@ do i=1,3
     do iw=1,nwplot
       z1=jw(iw,i)
       z2=ew(iw,j)
-      t1=abs(dble(z2))+abs(aimag(z2))
+      t1=abs(z2%re)+abs(z2%im)
       if (t1 > 1.d-8) then
         z1=z1/z2
       else
         z1=0.d0
       end if
-      z1=fourpi*zi*z1/(w(iw)+eta)
+      z1=fourpi*cmplx(-z1%im,z1%re,8)/(w(iw)+eta)
       if (i == j) z1=z1+1.d0
       eps(iw)=z1
     end do
