@@ -12,15 +12,13 @@ real(8), intent(in) :: vgpc(3,ngkmax)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 complex(8), intent(out) :: dapwalm(ngkmax,apwordmax,lmmaxapw)
 ! local variables
-integer is,l,lm,io,igp
+integer is,l,lm,io
 ! take derivative with respect to atomic displacement
 is=idxis(ias)
 do l=0,lmaxapw
   do lm=l**2+1,(l+1)**2
     do io=1,apword(l,is)
-      do igp=1,ngp
-        dapwalm(igp,io,lm)=vgpc(ip,igp)*zi*apwalm(igp,io,lm,ias)
-      end do
+      dapwalm(1:ngp,io,lm)=vgpc(ip,1:ngp)*zi*apwalm(1:ngp,io,lm,ias)
     end do
   end do
 end do
