@@ -40,37 +40,37 @@ complex(8) gamma(ld,2,ld,2)
 real(8), external :: trzhmm
 if (l < 0) then
   write(*,*)
-  write(*,'("Error(dmtotm3): l < 0 : ",I8)') l
+  write(*,'("Error(dmtotm3): l < 0 : ",I0)') l
   write(*,*)
   stop
 end if
 if (k < 0) then
   write(*,*)
-  write(*,'("Error(dmtotm3): k < 0 : ",I8)') k
+  write(*,'("Error(dmtotm3): k < 0 : ",I0)') k
   write(*,*)
   stop
 end if
 if (k > 2*l) then
   write(*,*)
-  write(*,'("Error(dmtotm3): k > 2*l : ",2I8)') k,2*l
+  write(*,'("Error(dmtotm3): k > 2*l :",2(X,I0))') k,2*l
   write(*,*)
   stop
 end if
 if ((p < 0).or.(p > 1)) then
   write(*,*)
-  write(*,'("Error(dmtotm3): p should be 0 or 1 : ",I8)') p
+  write(*,'("Error(dmtotm3): p should be 0 or 1 : ",I0)') p
   write(*,*)
   stop
 end if
 if (r < abs(k-p)) then
   write(*,*)
-  write(*,'("Error(dmtotm3): r < |k-p| : ",2I8)') r,abs(k-p)
+  write(*,'("Error(dmtotm3): r < |k-p| :",2(X,I0))') r,abs(k-p)
   write(*,*)
   stop
 end if
 if (r > (k+p)) then
   write(*,*)
-  write(*,'("Error(dmtotm3): r > k+p : ",2I8)') r,k+p
+  write(*,'("Error(dmtotm3): r > k+p :",2(X,I0))') r,k+p
   write(*,*)
   stop
 end if
