@@ -31,7 +31,7 @@ do l=0,lmaxapw
     end do
   end do
 end do
-call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,od)
+call zmctm(lmoapw(is),ngpq,ngp,a,b,ld,od)
 i=0
 do l=0,lmaxapw
   do lm=l**2+1,(l+1)**2
@@ -42,6 +42,6 @@ do l=0,lmaxapw
     end do
   end do
 end do
-call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,od)
+call zmctm(lmoapw(is),ngpq,ngp,a,b,ld,od)
 end subroutine
 
