@@ -11,7 +11,7 @@ implicit none
 integer, intent(in) :: ngp,ngpq
 integer, intent(in) :: igpig(ngkmax),igpqig(ngkmax)
 integer, intent(in) :: ld
-complex(8), intent(inout) :: od(ld,*)
+complex(8), intent(out) :: od(ld,*)
 ! local variables
 integer ig,j1,j2,j3,i,j
 do j=1,ngp
@@ -20,7 +20,7 @@ do j=1,ngp
   do i=1,ngpq
     ig=igpqig(i)
     ig=ivgig(ivg(1,ig)-j1,ivg(2,ig)-j2,ivg(3,ig)-j3)
-    od(i,j)=od(i,j)+dcfunig(ig)
+    od(i,j)=dcfunig(ig)
   end do
 end do
 end subroutine
