@@ -45,78 +45,60 @@ character(*), intent(in) :: fext
 logical, intent(in) :: tocc
 real(8), intent(in) :: occsvp(nstsv,nkpt)
 ! local variables
-logical tsqaz
-integer nsk(3),ik,jk,ist,iw,ld
-integer nsd,ispn,jspn,is,ia,ias
-integer lmmax,l0,l1,l,m,lm,nthd
-real(8) dw,th,sps(2),vl(3),vc(3)
-real(8) v1(3),v2(3),v3(3),t1
-complex(8) su2(2,2),b(2,2),c(2,2)
+logical tspndg,tlmdg
+integer nsk(3),ik,jk,ist,iw
+integer nsd,ispn,sps(2)
+integer is,ia,ias,nthd
+integer l0,l1,l,lm
+real(8) dw,vl(3),vc(3)
+complex(8) su2(2,2),b(2,2)
 character(256) fname
 ! allocatable arrays
 ! low precision for band/spin character array saves memory
 real(4), allocatable :: bc(:,:,:,:,:),sc(:,:,:)
 real(8), allocatable :: w(:),e(:,:,:),f(:,:),g(:)
 real(8), allocatable :: dt(:,:),dp(:,:,:),elm(:,:)
-complex(8), allocatable :: ulm(:,:,:),a(:,:)
-complex(8), allocatable :: dmat(:,:,:,:,:),sdmat(:,:,:)
-complex(8), allocatable :: apwalm(:,:,:,:,:)
-complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
-lmmax=(lmaxdos+1)**2
-ld=lmmax*nspinor
+complex(8), allocatable :: ulm(:,:,:),dmat(:,:,:,:,:),sdmat(:,:,:)
+complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
 if (dosssum) then
   nsd=1
 else
   nsd=nspinor
 end if
 if (dosmsum) then
-  l0=0; l1=lmaxdos
+  l0=0; l1=lmaxdb
 else
-  l0=1; l1=lmmax
+  l0=1; l1=lmmaxdb
 end if
-allocate(bc(lmmax,nspinor,natmtot,nstsv,nkptnr))
+! calculate only the diagonal parts of the density matrices by default
+tspndg=.true.
+tlmdg=.true.
+allocate(bc(lmmaxdb,nspinor,natmtot,nstsv,nkptnr))
 allocate(sc(nspinor,nstsv,nkptnr))
 ! generate unitary matrices which convert the Yₗₘ basis into the irreducible
 ! representation basis of the symmetry group at each atomic site
 if (lmirep) then
-  allocate(elm(lmmax,natmtot))
-  allocate(ulm(lmmax,lmmax,natmtot))
-  call genlmirep(lmaxdos,lmmax,elm,ulm)
+  allocate(elm(lmmaxdb,natmtot),ulm(lmmaxdb,lmmaxdb,natmtot))
+  call genlmirep(elm,ulm)
+! write the eigenvalues of a pseudorandom matrix symmetrised by the site
+! symmetries in the Yₗₘ basis
+  call writeelmirep(fext,elm)
+  tlmdg=.false.
 end if
 ! compute the SU(2) operator used for rotating the density matrix to the
 ! desired spin-quantisation axis
-v1(:)=sqados(:)
-t1=sqrt(v1(1)**2+v1(2)**2+v1(3)**2)
-if (t1 <= epslat) then
-  write(*,*)
-  write(*,'("Error(dos): spin-quantisation axis (sqados) has zero length")')
-  write(*,*)
-  stop
-end if
-v1(:)=v1(:)/t1
-if (v1(3) >= 1.d0-epslat) then
-  tsqaz=.true.
-else
-  tsqaz=.false.
-  v2(1:2)=0.d0
-  v2(3)=1.d0
-  call r3cross(v1,v2,v3)
-! note that the spin-quantisation axis is rotated, so the density matrix should
-! be rotated in the opposite direction
-  th=-acos(v1(3))
-  call axangsu2(v3,th,su2)
-end if
+if (spinpol) call sqasu2(sqaxis,tspndg,su2)
 ! begin parallel loop over k-points
 call holdthd(nkptnr,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(apwalm,evecfv,evecsv,dmat,sdmat,a) &
-!$OMP PRIVATE(jk,ispn,jspn,vl,vc) &
-!$OMP PRIVATE(is,ia,ias,ist,lm,b,c,t1) &
+!$OMP PRIVATE(apwalm,evecfv,evecsv,dmat,sdmat) &
+!$OMP PRIVATE(jk,ispn,vl,vc) &
+!$OMP PRIVATE(ias,is,ist,lm,b) &
 !$OMP NUM_THREADS(nthd)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
-allocate(dmat(lmmax,nspinor,lmmax,nspinor,nstsv))
-allocate(sdmat(nspinor,nspinor,nstsv),a(lmmax,lmmax))
+allocate(dmat(lmmaxdb,nspinor,lmmaxdb,nspinor,nstsv))
+allocate(sdmat(nspinor,nspinor,nstsv))
 !$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkptnr
 ! equivalent reduced k-point
@@ -142,43 +124,20 @@ do ik=1,nkptnr
 ! get the eigenvectors from file for non-reduced k-point
   call getevecfv('.OUT',0,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv('.OUT',0,vkl(:,ik),evecsv)
-  do is=1,nspecies
-    do ia=1,natoms(is)
-      ias=idxas(ia,is)
+  do ias=1,natmtot
+    is=idxis(ias)
 ! generate the density matrix for all states
-      call gendmatk(.false.,.false.,0,lmaxdos,ias,nstsv,[0],ngk(:,ik),apwalm, &
-       evecfv,evecsv,lmmax,dmat)
+    call gendmatk(tspndg,tlmdg,0,lmaxdb,ias,nstsv,[0],ngk(:,ik),apwalm, &
+     evecfv,evecsv,lmmaxdb,dmat)
 ! convert (l,m) part to an irreducible representation if required
-      if (lmirep) then
-        do ist=1,nstsv
-          do ispn=1,nspinor
-            do jspn=1,nspinor
-              call zgemm('N','N',lmmax,lmmax,lmmax,zone,ulm(:,:,ias),lmmax, &
-               dmat(:,ispn,1,jspn,ist),ld,zzero,a,lmmax)
-              call zgemm('N','C',lmmax,lmmax,lmmax,zone,a,lmmax,ulm(:,:,ias), &
-               lmmax,zzero,dmat(:,ispn,1,jspn,ist),ld)
-            end do
-          end do
-        end do
-      end if
+    if (.not.tlmdg) call dmatulm(ulm(:,:,ias),dmat)
 ! spin rotate the density matrices to desired spin-quantisation axis
-      if (spinpol.and.(.not.tsqaz)) then
-        do ist=1,nstsv
-          do lm=1,lmmax
-            b(:,:)=dmat(lm,:,lm,:,ist)
-            call z2mm(su2,b,c)
-            call z2mmct(c,su2,b)
-            dmat(lm,:,lm,:,ist)=b(:,:)
-          end do
-        end do
-      end if
+    if (.not.tspndg) call dmatsu2(lmmaxdb,su2,dmat)
 ! determine the band characters from the density matrix
-      do ist=1,nstsv
-        do ispn=1,nspinor
-          do lm=1,lmmax
-            t1=dble(dmat(lm,ispn,lm,ispn,ist))
-            bc(lm,ispn,ias,ist,ik)=real(t1)
-          end do
+    do ist=1,nstsv
+      do ispn=1,nspinor
+        do lm=1,lmmaxdb
+          bc(lm,ispn,ias,ist,ik)=dmat(lm,ispn,lm,ispn,ist)%re
         end do
       end do
     end do
@@ -186,7 +145,7 @@ do ik=1,nkptnr
 ! compute the spin density matrices of the second-variational states
   call gensdmat(evecsv,sdmat)
 ! spin rotate the density matrices to desired spin-quantisation axis
-  if (spinpol.and.(.not.tsqaz)) then
+  if (.not.tspndg) then
     do ist=1,nstsv
       call z2mm(su2,sdmat(:,:,ist),b)
       call z2mmct(b,su2,sdmat(:,:,ist))
@@ -194,13 +153,12 @@ do ik=1,nkptnr
   end if
   do ist=1,nstsv
     do ispn=1,nspinor
-      t1=dble(sdmat(ispn,ispn,ist))
-      sc(ispn,ist,ik)=real(t1)
+      sc(ispn,ist,ik)=sdmat(ispn,ispn,ist)%re
     end do
   end do
 end do
 !$OMP END DO
-deallocate(apwalm,evecfv,evecsv,dmat,sdmat,a)
+deallocate(apwalm,evecfv,evecsv,dmat,sdmat)
 !$OMP END PARALLEL
 call freethd(nthd)
 allocate(w(nwplot),e(nstsv,nkptnr,nspinor))
@@ -212,9 +170,8 @@ do iw=1,nwplot
 end do
 ! number of subdivisions used for interpolation in the Brillouin zone
 nsk(:)=max(ngrkf/ngridk(:),1)
-! sign for spin in DOS
-sps(1)=1.d0
-sps(2)=-1.d0
+! sign for spin in DOS plot
+sps(1)=1; sps(2)=-1
 !-------------------!
 !     total DOS     !
 !-------------------!
@@ -259,96 +216,79 @@ if (.not.tpdos) goto 10
 !---------------------!
 !     partial DOS     !
 !---------------------!
-do is=1,nspecies
-  do ia=1,natoms(is)
-    ias=idxas(ia,is)
-    dp(:,:,:)=0.d0
-    do ispn=1,nspinor
-      call holdthd(lmaxdos+1,nthd)
+call holdthd(lmaxdb+1,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(f,g,lm,ik,jk,ist) &
+!$OMP PRIVATE(f,g,ias,is,ia,ispn) &
+!$OMP PRIVATE(l,lm,ik,jk,ist) &
 !$OMP NUM_THREADS(nthd)
-      allocate(f(nstsv,nkptnr),g(nwplot))
+allocate(f(nstsv,nkptnr),g(nwplot))
+do ias=1,natmtot
+  is=idxis(ias)
+  ia=idxia(ias)
+!$OMP BARRIER
+!$OMP SINGLE
+  dp(:,:,:)=0.d0
+!$OMP END SINGLE
+  do ispn=1,nspinor
 !$OMP DO SCHEDULE(DYNAMIC)
-      do l=0,lmaxdos
-        do lm=l**2+1,(l+1)**2
-          do ik=1,nkptnr
-            jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
-            do ist=1,nstsv
-              f(ist,ik)=bc(lm,ispn,ias,ist,ik)
-              if (tocc) then
-                f(ist,ik)=f(ist,ik)*occsvp(ist,jk)
-              else
-                f(ist,ik)=f(ist,ik)*occmax
-              end if
-            end do
+    do l=0,lmaxdb
+      do lm=l**2+1,(l+1)**2
+        do ik=1,nkptnr
+          jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
+          do ist=1,nstsv
+            f(ist,ik)=bc(lm,ispn,ias,ist,ik)
+            if (tocc) then
+              f(ist,ik)=f(ist,ik)*occsvp(ist,jk)
+            else
+              f(ist,ik)=f(ist,ik)*occmax
+            end if
           end do
-          call brzint(nswplot,ngridk,nsk,ivkiknr,nwplot,wplot,nstsv,nstsv, &
-           e(:,:,ispn),f,g)
-          if (dosmsum) then
-            if (dosssum) then
-              dp(:,l,1)=dp(:,l,1)+g(:)
-            else
-              dp(:,l,ispn)=dp(:,l,ispn)+g(:)
-            end if
+        end do
+        call brzint(nswplot,ngridk,nsk,ivkiknr,nwplot,wplot,nstsv,nstsv, &
+         e(:,:,ispn),f,g)
+        if (dosmsum) then
+          if (dosssum) then
+            dp(:,l,1)=dp(:,l,1)+g(:)
           else
-            if (dosssum) then
-              dp(:,lm,1)=dp(:,lm,1)+g(:)
-            else
-              dp(:,lm,ispn)=g(:)
-            end if
+            dp(:,l,ispn)=dp(:,l,ispn)+g(:)
           end if
+        else
+          if (dosssum) then
+            dp(:,lm,1)=dp(:,lm,1)+g(:)
+          else
+            dp(:,lm,ispn)=g(:)
+          end if
+        end if
 ! subtract from interstitial DOS
 !$OMP CRITICAL(dos_)
-          if (dosssum) then
-            dt(:,1)=dt(:,1)-g(:)
-          else
-            dt(:,ispn)=dt(:,ispn)-g(:)
-          end if
+        if (dosssum) then
+          dt(:,1)=dt(:,1)-g(:)
+        else
+          dt(:,ispn)=dt(:,ispn)-g(:)
+        end if
 !$OMP END CRITICAL(dos_)
-        end do
       end do
+    end do
 !$OMP END DO
-      deallocate(f,g)
-!$OMP END PARALLEL
-      call freethd(nthd)
-    end do
-! output to file
-    write(fname,'("PDOS_S",I2.2,"_A",I4.4)') is,ia
-    open(50,file=trim(fname)//trim(fext),form='FORMATTED',action='WRITE')
-    do ispn=1,nsd
-      do l=l0,l1
-        do iw=1,nwplot
-          write(50,'(2G18.10)') w(iw),dp(iw,l,ispn)*sps(ispn)
-        end do
-        write(50,*)
-      end do
-    end do
-    close(50)
   end do
-end do
-!------------------------------------------!
-!     irreducible representations file     !
-!------------------------------------------!
-if (lmirep) then
-  open(50,file='ELMIREP'//trim(fext),form='FORMATTED',action='WRITE')
-  do is=1,nspecies
-    do ia=1,natoms(is)
-      ias=idxas(ia,is)
-      write(50,*)
-      write(50,'("Species : ",I4," (",A,"), atom : ",I4)') is, &
-       trim(spsymb(is)),ia
-      do l=0,lmaxdos
-        do m=-l,l
-          lm=l*(l+1)+m+1
-          write(50,'(" l = ",I2,", m = ",I2,", lm= ",I3," : ",G18.10)') l,m, &
-           lm,elm(lm,ias)
-        end do
+! output to file
+!$OMP SINGLE
+  write(fname,'("PDOS_S",I2.2,"_A",I4.4)') is,ia
+  open(50,file=trim(fname)//trim(fext),form='FORMATTED',action='WRITE')
+  do ispn=1,nsd
+    do l=l0,l1
+      do iw=1,nwplot
+        write(50,'(2G18.10)') w(iw),dp(iw,l,ispn)*sps(ispn)
       end do
+      write(50,*)
     end do
   end do
   close(50)
-end if
+!$OMP END SINGLE
+end do
+deallocate(f,g)
+!$OMP END PARALLEL
+call freethd(nthd)
 !--------------------------!
 !     interstitial DOS     !
 !--------------------------!
