@@ -82,9 +82,6 @@ do ist=1,nst
       end if
     end if
 !$OMP END CRITICAL(drhomagk_1)
-
-!****** use lock
-
   end do
 !------------------------------------------------!
 !     interstitial density and magnetisation     !
@@ -118,7 +115,6 @@ do ist=1,nst
 ! end loop over states
 end do
 deallocate(wfmt,wfir,dwfmt,dwfir)
-return
 
 contains
 
@@ -147,7 +143,7 @@ do i=1,n
   z6=z2*z3
   dmag1(i)=dmag1(i)+wo*(z5+z6)
   z5=z5-z6
-  dmag2(i)=dmag2(i)+wo*zmi*z5
+  dmag2(i)=dmag2(i)+wo*cmplx(z5%im,-z5%re,8)
 end do
 end subroutine
 
@@ -166,12 +162,12 @@ complex(8) z1,z2
 do i=1,n
   z1=wf1(i)
   z2=wf2(i)
-  t1=dble(z1)**2+aimag(z1)**2
-  t2=dble(z2)**2+aimag(z2)**2
+  t1=z1%re**2+z1%im**2
+  t2=z2%re**2+z2%im**2
   z1=conjg(z1)*z2
   drho(i)=drho(i)+dwo*(t1+t2)
-  dmag1(i)=dmag1(i)+dwo*2.d0*dble(z1)
-  dmag2(i)=dmag2(i)+dwo*2.d0*aimag(z1)
+  dmag1(i)=dmag1(i)+dwo*2.d0*z1%re
+  dmag2(i)=dmag2(i)+dwo*2.d0*z1%im
   dmag3(i)=dmag3(i)+dwo*(t1-t2)
 end do
 end subroutine
