@@ -26,7 +26,7 @@ do i=1,nbph
   t1=0.d0
   do k=1,nbph
     z1=dot_product(ev(:,i),dq(:,k))
-    t2=dble(z1)**2+aimag(z1)**2
+    t2=z1%re**2+z1%im**2
     if (t2 > t1) then
       j=k
       t1=t2
