@@ -99,7 +99,7 @@ do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-! convert rho from spherical harmonics to spherical coordinates
+! convert ρ from spherical harmonics to spherical coordinates
   call rbsht(nr,nri,rhomt(:,ias),rfmt)
 ! compute the gradient of the density
   call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),rhomt(:,ias),npmtmax,grfmt)
@@ -109,7 +109,7 @@ do ias=1,natmtot
   end do
   do i=1,npmt(is)
     r=abs(rfmt(i))
-! square of gradient of rho
+! compute |∇ρ|²
     t1=grfmt(i,1)**2+grfmt(i,2)**2+grfmt(i,3)**2
 ! D for inhomogeneous density
     t1=(1.d0/2.d0)*(gwf2mt(i,ias)-(1.d0/4.d0)*t1/r)
@@ -126,13 +126,13 @@ end do
 !--------------------------!
 ! Fourier transform density to G-space
 call rzfftifc(3,ngridg,-1,rhoir,zfft1)
-! calculate the square of gradient of rho
+! compute |∇ρ|²
 grfir(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
