@@ -40,12 +40,12 @@ call omp_init
 call mkl_init
 if (mp_mpi) then
   write(*,*)
-  write(*,'("Number of MPI processes : ",I6)') np_mpi
-  write(*,'("Number of OpenMP threads per MPI process : ",I4)') maxthd
-  write(*,'("Total number of threads (MPI x OpenMP) : ",I6)') np_mpi*maxthd
-  write(*,'("Maximum OpenMP nesting level : ",I4)') maxlvl
-  write(*,'("Number of OpenMP threads at first nesting level : ",I4)') maxthd1
-  write(*,'("Number of MKL threads : ",I4)') maxthdmkl
+  write(*,'("Number of MPI processes : ",I0)') np_mpi
+  write(*,'("Number of OpenMP threads per MPI process : ",I0)') maxthd
+  write(*,'("Total number of threads (MPI x OpenMP) : ",I0)') np_mpi*maxthd
+  write(*,'("Maximum OpenMP nesting level : ",I0)') maxlvl
+  write(*,'("Number of OpenMP threads at first nesting level : ",I0)') maxthd1
+  write(*,'("Number of MKL threads : ",I0)') maxthdmkl
 ! check if Elk is already running in this directory
   inquire(file='RUNNING',exist=exist)
   if (exist) then
@@ -99,8 +99,8 @@ do itask=1,ntasks
     if (all(task /= [0,1,2,3,5,15,16,28,29,61,62,63,110,120,121,125,135,136, &
      162,170,180,185,200,201,202,205,208,209,240,241,270,271,300,320,330,331, &
      350,351,352,371,372,373,380,390,420,421,440,460,461,462,463,471,478,600, &
-     610,620,640,680,700,701,720])) then
-      write(*,'("Info(elk): MPI process ",I6," idle for task ",I6)') lp_mpi,task
+     601,610,620,630,640,680,700,701,720,725])) then
+      write(*,'("Info(elk): MPI process ",I0," idle for task ",I0)') lp_mpi,task
       goto 20
     end if
   end if
@@ -119,7 +119,7 @@ do itask=1,ntasks
     call writesf
   case(15,16)
     call writelsj
-  case(20,21,22,23)
+  case(20,21,22,23,24)
     call bandstr
   case(25)
     call effmass
@@ -255,12 +255,14 @@ do itask=1,ntasks
     call testcheck
   case(550)
     call writew90
-  case(600)
+  case(600,601)
     call gwsefm
   case(610)
     call gwspecf
   case(620)
     call gwbandstr
+  case(630)
+    call writegwefm
   case(640)
     call gwdmat
   case(680)
@@ -269,7 +271,7 @@ do itask=1,ntasks
     call gndstulr
   case(710)
     call writedosu
-  case(720)
+  case(720,725)
     call bandstrulr
   case(731,732,733)
     call rhouplot
@@ -279,7 +281,7 @@ do itask=1,ntasks
     call maguplot
   case default
     write(*,*)
-    write(*,'("Error(elk): task not defined : ",I8)') task
+    write(*,'("Error(elk): task not defined : ",I0)') task
     write(*,*)
     stop
   end select
@@ -307,7 +309,7 @@ call mpi_finalize(ierror)
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 10.4.9}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 10.8.1}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -702,12 +704,22 @@ end program
 !   {\tt betamax} & maximum adaptive mixing parameter & real & $0.5$}
 !   Maximum allowed mixing parameter used in routine {\tt mixadapt}.
 !
+!   \block{bfdmag}{
+!   {\tt bfdmag} & {\tt .true.} if the external ${\bf B}$-field diamagnetic
+!    coupling term should be included & logical & {\tt .false.}}
+!   This causes the diamagnetic coupling term
+!   $$ H_{\rm dia}=\frac{B^2 r^2}{8c^2}\big(1-(\hat{\bf B}\cdot
+!    \hat{\bf r})^2\big) $$
+!   to be included in the first-variational Hamiltonian. Note that because this
+!   is a scalar potential, spin-polarisation does not have to be enabled for
+!   this term to have an effect.
+!
 !   \block{bfieldc}{
 !   {\tt bfieldc} & global external magnetic field in Cartesian coordinates &
 !    real(3) & $(0.0,0.0,0.0)$}
 !   This is a constant magnetic field applied throughout the entire unit cell
 !   and enters the second-variational Hamiltonian as
-!   $$ \frac{g_e}{4c}\,\vec{\sigma}\cdot{\bf B}_{\rm ext}, $$
+!   $$ \frac{g_e}{4c}\,\vec{\sigma}\cdot{\bf B}, $$
 !   where $g_e$ is the electron $g$-factor. This field is normally used to break
 !   spin symmetry for spin-polarised calculations and considered to be
 !   infinitesimal with no direct contribution to the total energy. In cases
@@ -718,17 +730,32 @@ end program
 !   {\tt bfcmt} vectors in the {\tt atoms} block. Collinear calculations are
 !   more efficient if the field is applied in the $z$-direction.
 !
-!   \block{bfielduc}{
-!   {\tt bfielduc} & global external magnetic field in Cartesian coordinates &
+!   \block{bfieldcu}{
+!   {\tt bfieldcu} & global external magnetic field in Cartesian coordinates &
 !    real(3) & $(0.0,0.0,0.0)$}
 !   As with {\tt bfieldc} but applied only in the ultracell during an ultra
 !   long-range calculation.
 !
+!   \block{bforb}{
+!   {\tt bforb} & {\tt .true.} if the external ${\bf B}$-field-orbit coupling
+!    term should be included & logical & {\tt .false.}}
+!   This causes the term corresponding to the coupling between an external
+!   magnetic field and the orbit of an electron (orbital paramagnetism)
+!   $$ \hat{H}_{{\bf B}{\rm o}}=\frac{1}{2c}{\bf B}\cdot\hat{\bf L} $$
+!   to be added to the second-variational Hamiltonian. Spin-polarisation is
+!   automatically enabled.
+!
 !   \block{broydpm}{
 !   {\tt broydpm} & Broyden mixing parameters $\alpha$ and $w_0$ & real &
 !    $(0.4,0.15)$}
 !   See {\tt mixtype} and {\tt mixsdb}.
 !
+!   \block{c\_tb09}{
+!   {\tt c\_tb09} & Tran-Blaha constant $c$ & real & -}
+!   Sets the constant $c$ in the Tran-Blaha '09 functional. Normally this is
+!   calculated from the density, but there may be situations where this needs to
+!   be adjusted by hand. See {\it Phys. Rev. Lett.} {\bf 102}, 226401 (2009).
+!
 !   \block{chgexs}{
 !   {\tt chgexs} & excess electronic charge & real & $0.0$}
 !   This controls the amount of charge in the unit cell beyond that required to
@@ -786,7 +813,7 @@ end program
 !    0 & No DFT+$U$ calculation \\
 !    1 & Fully localised limit (FLL) \\
 !    2 & Around mean field (AFM) \\
-!    3 & An interpolation between FLL and AFM \\
+!    3 & An interpolation between FLL and AFM
 !   \end{tabularx}
 !   \vskip 6pt
 !   The type of input parameters is set with the parameter {\tt inpdftu}.
@@ -927,11 +954,22 @@ end program
 !   {\tt lmaxi} and {\tt lmaxo}.
 !
 !   \block{fsmtype}{
-!   {\tt fsmtype} & 0 for no fixed spin moment (FSM), 1 for total FSM, 2 for
-!    local muffin-tin FSM, and 3 for both total and local FSM & integer & 0}
-!   Set to 1, 2 or 3 for fixed spin moment calculations. To fix only the
-!   direction and not the magnitude set to $-1$, $-2$ or $-3$. See also
-!   {\tt momfix}, {\tt mommtfix}, {\tt taufsm} and {\tt spinpol}.
+!   {\tt fsmtype} & fixed spin moment (FSM) type & integer & 0}
+!   The magnetic moment, its direction or magnitude can be fixed both globally
+!   as well as in each muffin-tin individually. The options are as follows:
+!   \vskip 6pt
+!   \begin{tabularx}{\textwidth}[h]{lX}
+!   0 & no FSM \\
+!   1 (-1) & total moment (direction) \\
+!   2 (-2) & individual muffin-tin moments (direction) \\
+!   3 (-3) & total and muffin-tin moments (direction) \\
+!   4 & total moment magnitude \\
+!   5 & individual muffin-tin moment magnitudes \\
+!   6 & total and muffin-tin moment magnitudes
+!   \end{tabularx}
+!   \vskip 6pt
+!   See also {\tt momfix}, {\tt momfixm}, {\tt mommtfix}, {\tt mommtfixm},
+!   {\tt taufsm} and {\tt spinpol}.
 !
 !   \block{ftmtype}{
 !   {\tt ftmtype} & 1 to enable a fixed tensor moment (FTM) calculation,
@@ -1099,13 +1137,21 @@ end program
 !   See {\tt tau0oep}.
 !
 !   \block{maxscl}{
-!   {\tt maxscl } & maximum number of self-consistent loops allowed & integer &
+!   {\tt maxscl} & maximum number of self-consistent loops allowed & integer &
 !    200}
 !   This determines after how many loops the self-consistent cycle will
 !   terminate if the convergence criterion is not met. If {\tt maxscl} is $1$
 !   then the density and potential file, {\tt STATE.OUT}, will {\bf not} be
 !   written to disk at the end of the loop. See {\tt epspot}.
 !
+!   \block{mbwgrf}{
+!   {\tt mbwgrf} & matrix bandwidth of response functions in the
+!    ${\bf G}$-vector basis & integer & $-1$}
+!   Setting this to a positive integer results in response functions and the
+!   screened interaction $W({\bf G},{\bf G}',{\bf q},\omega)$ being treated as a
+!   banded matrix in ${\bf G}$ and ${\bf G}'$ with bandwidth {\tt mbwgrf}.
+!   This can be used to speed up $GW$ calculations.
+!
 !   \block{mixsave}{
 !   {\tt mixsave} & {\tt .true.} if the mixer work array is to be saved during a
 !    ground-state run & logical & {\tt .false.}}
@@ -1139,17 +1185,34 @@ end program
 !   {\tt momfix} & the desired total moment for a FSM calculation &
 !    real(3) & $(0.0,0.0,0.0)$}
 !   Note that all three components must be specified (even for collinear
-!   calculations). See {\tt fsmtype}, {\tt taufsm} and {\tt spinpol}.
+!   calculations). Applies when {\tt fsmtype} is 1(-1) or 3(-3). See
+!   {\tt fsmtype}, {\tt taufsm} and {\tt spinpol}.
+!
+!   \block{momfixm}{
+!   {\tt momfixm} & the desired total moment magnitude for a FSM calculation &
+!    real & $0.0$}
+!   This applies when {\tt fsmtype} is 4 or 6.
 !
 !   \block{mommtfix}{
 !   {\tt is} & species number & integer & 0 \\
 !   {\tt ia} & atom number & integer & 0 \\
-!   {\tt mommtfix} & the desired muffin-tin moment for a FSM calculation &
+!   {\tt mommtfix} & desired muffin-tin moment for a FSM calculation &
 !    real(3) & $(0.0,0.0,0.0)$}
 !   The local muffin-tin moments are specified for a subset of atoms, with the
 !   list terminated with a blank line. Note that all three components must be
-!   specified (even for collinear calculations). See {\tt fsmtype}, {\tt taufsm}
-!   and {\tt spinpol}.
+!   specified (even for collinear calculations). Applies when {\tt fsmtype} is
+!   2(-2) or 3(-3). Note that the moment is not fixed in a particular muffin-tin
+!   when the magnitude of any component of the corresponding {\tt mommtfix} is
+!   $\ge 1000$. See {\tt fsmtype}, {\tt taufsm} and {\tt spinpol}.
+!
+!   \block{mommtfixm}{
+!   {\tt is} & species number & integer & 0 \\
+!   {\tt ia} & atom number & integer & 0 \\
+!   {\tt mommtfixm} & desired muffin-tin moment magnitude for a FSM
+!    calculation & real & $-1$}
+!   This applies when {\tt fsmtype} is 5 or 6. Note that the moment magnitude is
+!   not fixed in a particular muffin-tin when the corresponding {\tt mommtfixm}
+!   is negative.
 !
 !   \block{mrmtav}{
 !   {\tt mrmtav} & order of averaging applied to the muffin-tin radii &
@@ -1186,6 +1249,11 @@ end program
 !    effective mass tensor & integer & 1}
 !   See {\tt deltaem} and {\tt vklem}.
 !
+!   \block{nefvit}{
+!   {\tt nefvit} & number of iterations the iterative eigenvalue solver should
+!    perform per self-consistent loop & integer & 2}
+!   See {\tt tefvit}.
+!
 !   \block{nempty}{
 !   {\tt nempty} & the number of empty states per atom and spin & real & $4.0$ }
 !   Defines the number of eigenstates beyond that required for charge
@@ -1355,7 +1423,10 @@ end program
 !    function & real & $0.0$}
 !   The ultra long-range Poisson equation is solved using the Green's function
 !   $4\pi/|{\bf G}+{\bf Q}|^2$. This is set to zero for all
-!   $|{\bf G}+{\bf Q}| <{\tt q0cut}$ in order to improve stability of the
+!   $|{\bf G}+{\bf Q}|<{\tt q0cut}$ when {\tt q0cut} is positive. For negative
+!   {\tt q0cut}, a Yukawa-type screening of the form
+!   $4\pi/(|{\bf G}+{\bf Q}|^2+{\tt q0cut}^2)$ is employed. Setting this
+!   variable to be small but finite can improve the stability of a
 !   self-consistent calculation.
 !
 !   \block{radkpt}{
@@ -1702,11 +1773,15 @@ end program
 !   610 & Generates the $GW$ spectral function. \\
 !   620 & Generates the $GW$ band structure, i.e. the ${\bf k}$-dependent
 !    spectral function). \\
+!   630 & Writes the $GW$ Fermi energy to {\tt GWEFERMI.OUT} \\
 !   640 & Determines the $GW$ density matrix in terms of natural orbitals and
 !    occupation numbers. The files {\tt EVECSV.OUT} and {\tt OCCSV.OUT} are
 !    overwritten by these and can then be used for other calculations. \\
 !   700/1 & Ultra long-range ground-state calculation. Task 701 is for
 !    restarting from the potential in {\tt STATE\_ULR.OUT}. \\
+!   720/5 & Ultra long-range band structure and spectral function. Task 720 is
+!    for the central $k$-point (i.e. $\kappa=0$), while task 725 averages over
+!    all $\kappa$-points.\\
 !   731/2/3 & 1/2/3D plot of the ultra long-range density. \\
 !   741/2/3 & 1/2/3D plot of the ultra long-range Kohn-Sham potential. \\
 !   771/2/3 & 1/2/3D plot of the ultra long-range magnetisation.
@@ -1792,18 +1867,28 @@ end program
 !    corresponding decomposition of DFT+$U$ energy should be calculated
 !    at every loop of the self-consistent cycle & logical & {\tt .false.}}
 !   This variable is useful to check the convergence of the tensor moments in
-!   DFT+$U$ caculations. Alternatively, with {\tt task} equal to 400, one can
+!   DFT+$U$ calculations. Alternatively, with {\tt task} equal to 400, one can
 !   calculate the tensor moments and corresponding DFT+$U$ energy contributions
 !   from a given density matrix and set of Slater parameters at the end of the
 !   self-consistent cycle.
 !
+!   \block{trdbfcr}{
+!   {\tt trdbfcr} & set to {\tt .true.} if the ultra long-range, real-space
+!    external magnetic field in Cartesian coordinates should be read in from
+!    {\tt BFCR.OUT} & logical & {\tt .false.}}
+!
+!   \block{trdvclr}{
+!   {\tt trdvclr} & set to {\tt .true.} if the ultra long-range, real-space
+!    external Coulomb potential should be read in from {\tt VCLR.OUT} &
+!    logical & {\tt .false.}}
+!
 !   \block{tsediag}{
 !   {\tt tsediag} & set to {\tt .true.} if the self-energy matrix should be
-!    treated as diagonal & logical & {\tt .true.}}
+!    treated as diagonal & logical & {\tt .false.}}
 !   When this variable is {\tt .true.}, the self-energy used in a $GW$
 !   calculation $\Sigma_{ij}({\bf k},\omega)$ is taken to be diagonal in the
 !   Kohn-Sham state indices $i$ and $j$. When {\tt tsediag} is {\tt .false.},
-!   the entire matrix is used. See also {\tt twdiag}.
+!   the entire matrix is used.
 !
 !   \block{tshift}{
 !   {\tt tshift} & set to {\tt .true.} if the crystal can be shifted so that the
@@ -1815,13 +1900,6 @@ end program
 !    $1000.0$}
 !   See also {\tt dtimes}.
 !
-!   \block{twdiag}{
-!   {\tt twdiag} & set to {\tt .true.} if the screened interaction matrix should
-!    be treated as diagonal & logical & {\tt .false.}}
-!   When this variable is {\tt .true.}, the screened interaction used in a $GW$
-!   calculation $W({\bf G},{\bf G}',{\bf q},\omega)$ is taken to be diagonal in
-!   the plane wave indices ${\bf G}$ and ${\bf G}'$. See also {\tt tsediag}.
-!
 !   \block{vhmat}{
 !   {\tt vhmat(1)} & matrix row 1 & real(3) & $(1.0,0.0,0.0)$ \\
 !   \hline
@@ -1931,7 +2009,7 @@ end program
 !    {\it Phys. Rev. B} {\bf 72}, 085108 (2005) \\
 !   100 & Libxc functionals; the second and third values of {\tt xctype} define
 !    the exchange and correlation functionals in the Libxc library,
-!    respectively \\
+!    respectively
 !   \end{tabularx}
 !
 !   \section{Contributing to Elk}
@@ -1976,8 +2054,8 @@ end program
 !    example:
 !    \begin{verbatim}
 !     write(*,*)
-!     write(*,'("Error(readinput): natoms < 1 : ",I8)') natoms(is)
-!     write(*,'(" for species ",I4)') is
+!     write(*,'("Error(readinput): natoms < 1 : ",I0)') natoms(is)
+!     write(*,'(" for species ",I0)') is
 !     write(*,*)
 !     stop
 !    \end{verbatim}
