@@ -15,10 +15,8 @@ real(8) vgqc(3),gqc
 real(8) vkql(3),v(3)
 real(8) q,wd,dw,w,t1
 ! allocatable arrays
-real(8), allocatable :: jlgqr(:,:),ddcs(:)
-real(8), allocatable :: e(:,:,:),f(:,:,:)
-complex(8), allocatable :: ylmgq(:),sfacgq(:)
-complex(8), allocatable :: expmt(:,:),emat(:,:)
+real(8), allocatable :: jlgqr(:,:),ddcs(:),e(:,:,:),f(:,:,:)
+complex(8), allocatable :: ylmgq(:),sfacgq(:),expmt(:,:),emat(:,:)
 ! initialise universal variables
 call init0
 call init1
@@ -29,7 +27,7 @@ v(:)=abs(v(:)-nint(v(:)))
 if ((v(1) > epslat).or.(v(2) > epslat).or.(v(3) > epslat)) then
   write(*,*)
   write(*,'("Error(elnes): q-vector incommensurate with k-point grid")')
-  write(*,'(" ngridk : ",3I6)') ngridk
+  write(*,'(" ngridk :",3(X,I0))') ngridk
   write(*,'(" vecql : ",3G18.10)') vecql
   write(*,*)
   stop
@@ -67,7 +65,7 @@ allocate(emat(nstsv,nstsv))
 !$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkptnr
 !$OMP CRITICAL(elnes_)
-  write(*,'("Info(elnes): ",I6," of ",I6," k-points")') ik,nkptnr
+  write(*,'("Info(elnes): ",I0," of ",I0," k-points")') ik,nkptnr
 !$OMP END CRITICAL(elnes_)
 ! equivalent reduced k-point
   jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
