@@ -7,12 +7,9 @@ subroutine emdplot
 use modmain
 use modpw
 implicit none
-! local variables
-real(8) t1
 ! allocatable arrays
 real(4), allocatable :: emds(:,:)
-t1=sum(abs(vkloff(:)))
-if (t1 > epslat) then
+if (any(abs(vkloff(:)) > epslat)) then
   write(*,*)
   write(*,'("Error(emdplot): use vkloff = 0 for the ground-state run")')
   write(*,*)
