@@ -164,9 +164,9 @@ if (dftu /= 0) then
     end do
   end do
 end if
-!----------------------------!
-!     sum of eigenvalues     !
-!----------------------------!
+!-------------------------------------!
+!     sum of occupied eigenvalues     !
+!-------------------------------------!
 ! core eigenvalues
 evalsum=0.d0
 do ias=1,natmtot
@@ -198,7 +198,7 @@ if (task == 5) then
      nstsv)
     do ist=1,nstsv
       z1=zdotc(nstsv,evecsv(:,ist),1,c(:,ist),1)
-      engykn=engykn+w*occsv(ist,ik)*dble(z1)
+      engykn=engykn+w*occsv(ist,ik)*z1%re
     end do
   end do
   deallocate(evecsv,kmat,c)
@@ -220,14 +220,14 @@ else
     n2=(lmmaxdm*nspinor)**2
     do ias=1,natmtot
       z1=zdotc(n2,dmatmt(:,:,:,:,ias),1,vmftm(:,:,:,:,ias),1)
-      sm=sm+dble(z1)
+      sm=sm+z1%re
     end do
   end if
   engykn=evalsum-engyvcl-engyvxc-sm
   deallocate(rfmt)
 end if
 ! remove vector potential energy term if required
-if (tafield) then
+if (tafield.and.tlast) then
   engykn=engykn+(0.5d0/solsc)*dot_product(afieldc(:),jtot(:))
 end if
 ! remove spin-dependent vector potential energy term if required
