@@ -14,30 +14,20 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer ns,ist,it,j
+integer ns,ist,it,i,j
 integer is,ias,nthd
-integer lwork,info
-real(8) rmax,t1
+integer nb,lwork,info
+real(8) t1
 real(8) ts1,ts0
 ! allocatable arrays
+integer, allocatable :: idx(:)
 real(8), allocatable :: w(:),rwork(:)
 complex(8), allocatable :: h(:,:),o(:,:),hv(:,:),ov(:,:)
 complex(8), allocatable :: u(:,:),hu(:,:),ou(:,:)
 complex(8), allocatable :: hs(:,:),os(:,:),work(:)
 ! external functions
+integer, external :: ilaenv
 real(8), external :: ddot
-ns=2*nstfv
-if (iscl >= 2) then
-! read in the eigenvalues/vectors from file
-  call getevalfv(filext,0,vpl,evalfv)
-  call getevecfv(filext,0,vpl,vgpl,evecfv)
-else
-! initialise the eigenvectors to canonical basis vectors
-  evecfv(1:nmatp,1:nstfv)=0.d0
-  do ist=1,nstfv
-    evecfv(ist,ist)=1.d0
-  end do
-end if
 ! compute Hamiltonian and overlap matrices
 call timesec(ts0)
 allocate(h(nmatp,nmatp),o(nmatp,nmatp))
@@ -74,22 +64,39 @@ call freethd(nthd)
 call timesec(ts1)
 !$OMP ATOMIC
 timemat=timemat+ts1-ts0
+if (trdstate.or.(iscl >= 2)) then
+! read in the eigenvectors from file if available
+  call getevecfv(filext,0,vpl,vgpl,evecfv)
+else
+! initialise the eigenvalues/vectors using the diagonal elements of H
+  allocate(idx(nmatp),w(nmatp))
+  do i=1,nmatp
+    w(i)=h(i,i)
+  end do
+  call sortidx(nmatp,w,idx)
+  evecfv(1:nmatp,1:nstfv)=0.d0
+  do ist=1,nstfv
+    evecfv(idx(ist),ist)=1.d0
+  end do
+  deallocate(idx,w)
+end if
 call timesec(ts0)
+ns=2*nstfv
 allocate(w(ns),rwork(3*ns))
 allocate(hv(nmatp,nstfv),ov(nmatp,nstfv))
 allocate(u(nmatp,nstfv),hu(nmatp,nstfv),ou(nmatp,nstfv))
 allocate(hs(ns,ns),os(ns,ns))
-lwork=2*ns
+! find the optimal blocksize for allocating the work array
+nb=ilaenv(1,'ZHETRD','U',nmatp,-1,-1,-1)
+nb=max(nb,1)
+lwork=(nb+1)*ns
 allocate(work(lwork))
 call holdthd(nstfv,nthd)
 ! iteration loop
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(it,ist,t1) &
 !$OMP NUM_THREADS(nthd)
-do it=1,maxitefv
-!$OMP SINGLE
-  rmax=0.d0
-!$OMP END SINGLE
+do it=1,nefvit
 !$OMP DO SCHEDULE(DYNAMIC)
   do ist=1,nstfv
 ! operate with O on the current eigenvector
@@ -104,28 +111,13 @@ do it=1,maxitefv
 ! operate with H on the current eigenvector
     call zhemv('U',nmatp,zone,h,nmatp,evecfv(:,ist),1,zzero,hv(:,ist),1)
 ! estimate the eigenvalue
-    t1=ddot(2*nmatp,evecfv(:,ist),1,hv(:,ist),1)
-    if ((iscl <= 1).and.(it == 1)) then
-      evalfv(ist)=t1
-    else
-      evalfv(ist)=(1.d0-befvit)*evalfv(ist)+befvit*t1
-    end if
-! compute the residual |u> = (H - eO)|v>
+    evalfv(ist)=ddot(2*nmatp,evecfv(:,ist),1,hv(:,ist),1)
+! compute the residual |u⟩ = (H - eO)|v⟩
     call zcopy(nmatp,hv(:,ist),1,u(:,ist),1)
     t1=-evalfv(ist)
     u(1:nmatp,ist)=u(1:nmatp,ist)+t1*ov(1:nmatp,ist)
 ! apply the overlap matrix to the residual
     call zhemv('U',nmatp,zone,o,nmatp,u(:,ist),1,zzero,ou(:,ist),1)
-! compute the overlap of the residual with itself
-    t1=ddot(2*nmatp,u(:,ist),1,ou(:,ist),1)
-!$OMP ATOMIC
-    rmax=max(rmax,t1)
-! normalise the residual
-    if (t1 > 0.d0) then
-      t1=1.d0/sqrt(t1)
-      call zdscal(nmatp,t1,u(:,ist),1)
-      call zdscal(nmatp,t1,ou(:,ist),1)
-    end if
 ! apply the Hamiltonian matrix to the residual
     call zhemv('U',nmatp,zone,h,nmatp,u(:,ist),1,zzero,hu(:,ist),1)
   end do
@@ -170,11 +162,6 @@ do it=1,maxitefv
     call zcopy(nmatp,ov(:,ist),1,evecfv(:,ist),1)
   end do
 !$OMP END DO
-! check for convergence
-!$OMP SINGLE
-  rmax=sqrt(abs(rmax)/dble(nmatp))
-!$OMP END SINGLE
-  if ((it >= minitefv).and.(rmax < epsefvit)) exit
 ! end iteration loop
 end do
 !$OMP END PARALLEL
