@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine eveqnss(ngp,igpig,apwalm,evalfv,evecfv,evalsvp,evecsv)
+subroutine eveqnss(ngp,igpig,apwalm,evalfv,evecfv,evalsv_,evecsv)
 use modmain
 use moddftu
 use modomp
@@ -13,11 +13,11 @@ integer, intent(in) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv)
 real(8), intent(in) :: evalfv(nstfv,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv)
-real(8), intent(out) :: evalsvp(nstsv)
+real(8), intent(out) :: evalsv_(nstsv)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
 integer ld,ist,jst,ispn,is,ias
-integer nrc,nrci,nrco,i,j
+integer nrc,nrci,nrco,nj,i,j
 integer l,lm,nm,npc,npc2,npci
 integer n1,n12,n2,n22,igp,nthd
 real(8) ts0,ts1
@@ -26,13 +26,12 @@ complex(8) zq
 complex(8) wfmt2(npcmtmax,nspnfv),wfmt4(npcmtmax)
 complex(8) wfmt31(npcmtmax),wfmt32(npcmtmax),wfmt33(npcmtmax)
 complex(4) wfmt5(npcmtmax),wfgp1(ngkmax),wfgp2(ngkmax),wfgp3(ngkmax)
-complex(4) wfir1(ngtc,nspnfv),wfir2(ngtc)
+complex(4) wfir1(ngtc,nspnfv),wfir2(ngtc),y(nstfv)
 ! allocatable arrays
 complex(4), allocatable :: wfmt0(:,:,:),wfgp0(:,:,:)
 complex(8), allocatable :: wfmt1(:,:,:)
 ! external functions
 real(4), external :: sdot
-complex(4), external :: cdotc
 if (.not.spinpol) then
   write(*,*)
   write(*,'("Error(eveqnss): spin-unpolarised calculation")')
@@ -41,9 +40,8 @@ if (.not.spinpol) then
 end if
 call timesec(ts0)
 ld=lmmaxdm*nspinor
-call holdthd(nstfv,nthd)
 ! zero the second-variational Hamiltonian (stored in the eigenvector array)
-evecsv(:,:)=0.d0
+evecsv(1:nstsv,1:nstsv)=0.d0
 ! set the diagonal elements equal to the first-variational eigenvalues
 do ispn=1,nspinor
   do ist=1,nstfv
@@ -51,16 +49,19 @@ do ispn=1,nspinor
     evecsv(i,i)=evalfv(ist,ispn)
   end do
 end do
+call holdthd(nstfv,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
+!$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3,y) &
+!$OMP PRIVATE(ias,is,nrc,nrci,nrco,npc,npc2,npci) &
+!$OMP PRIVATE(zq,ispn,ist,jst,l,nm,lm,i,j,nj,igp) &
+!$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
+!$OMP SINGLE
 allocate(wfmt0(npcmtmax,nstfv,nspnfv),wfmt1(npcmtmax,nstfv,nspnfv))
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
-!$OMP PRIVATE(ias,is,nrc,nrci,nrco) &
-!$OMP PRIVATE(npc,npc2,npci,zq,ispn) &
-!$OMP PRIVATE(ist,jst,l,nm,lm,i,j) &
-!$OMP NUM_THREADS(nthd)
+!$OMP END SINGLE
 do ias=1,natmtot
   is=idxis(ias)
   nrc=nrcmt(is)
@@ -127,41 +128,37 @@ do ias=1,natmtot
       end do
     end if
 ! add to second-variational Hamiltonian matrix
+    nj=jst-1
 ! upper diagonal block
     wfmt5(1:npc)=wfmt31(1:npc)
-    do ist=1,jst-1
-      evecsv(ist,jst)=evecsv(ist,jst)+cdotc(npc,wfmt0(:,ist,1),1,wfmt5,1)
-    end do
+    call cgemv('C',npc,nj,cone,wfmt0,npcmtmax,wfmt5,1,czero,y,1)
+    evecsv(1:nj,jst)=evecsv(1:nj,jst)+y(1:nj)
     evecsv(jst,jst)=evecsv(jst,jst)+sdot(npc2,wfmt0(:,jst,1),1,wfmt5,1)
     j=jst+nstfv
 ! lower diagonal block
     wfmt5(1:npc)=wfmt32(1:npc)
-    do ist=1,jst-1
-      i=ist+nstfv
-      evecsv(i,j)=evecsv(i,j)+cdotc(npc,wfmt0(:,ist,2),1,wfmt5,1)
-    end do
+    call cgemv('C',npc,nj,cone,wfmt0(:,:,2),npcmtmax,wfmt5,1,czero,y,1)
+    evecsv(nstfv+1:nstfv+nj,j)=evecsv(nstfv+1:nstfv+nj,j)+y(1:nj)
     evecsv(j,j)=evecsv(j,j)+sdot(npc2,wfmt0(:,jst,2),1,wfmt5,1)
 ! off-diagonal block
     wfmt5(1:npc)=wfmt33(1:npc)
-    do ist=1,nstfv
-      evecsv(ist,j)=evecsv(ist,j)+cdotc(npc,wfmt0(:,ist,1),1,wfmt5,1)
-    end do
+    call cgemv('C',npc,nstfv,cone,wfmt0,npcmtmax,wfmt5,1,czero,y,1)
+    evecsv(1:nstfv,j)=evecsv(1:nstfv,j)+y(1:nstfv)
   end do
 !$OMP END DO
 ! end loop over atoms
 end do
-!$OMP END PARALLEL
+!$OMP SINGLE
 deallocate(wfmt0,wfmt1)
+!$OMP END SINGLE
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
-allocate(wfgp0(ngkmax,nstfv,nspnfv))
+!$OMP SINGLE
 n1=ngp(1); n12=n1*2
 n2=ngp(2); n22=n2*2
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3) &
-!$OMP PRIVATE(ist,jst,ispn,igp,i,j) &
-!$OMP NUM_THREADS(nthd)
+allocate(wfgp0(ngkmax,nstfv,nspnfv))
+!$OMP END SINGLE
 ! make single-precision copy of wavefunction
 !$OMP DO SCHEDULE(DYNAMIC)
   do ist=1,nstfv
@@ -198,29 +195,28 @@ do jst=1,nstfv
     wfgp3(igp)=wfir2(igfc(igpig(igp,1)))
   end do
 ! add to second-variational Hamiltonian matrix
+  nj=jst-1
 ! upper diagonal block
-  do ist=1,jst-1
-    evecsv(ist,jst)=evecsv(ist,jst)+cdotc(n1,wfgp0(:,ist,1),1,wfgp1,1)
-  end do
+  call cgemv('C',n1,nj,cone,wfgp0,ngkmax,wfgp1,1,czero,y,1)
+  evecsv(1:nj,jst)=evecsv(1:nj,jst)+y(1:nj)
   evecsv(jst,jst)=evecsv(jst,jst)+sdot(n12,wfgp0(:,jst,1),1,wfgp1,1)
 ! lower diagonal block
   j=jst+nstfv
-  do ist=1,jst-1
-    i=ist+nstfv
-    evecsv(i,j)=evecsv(i,j)+cdotc(n2,wfgp0(:,ist,2),1,wfgp2,1)
-  end do
+  call cgemv('C',n2,nj,cone,wfgp0(:,:,2),ngkmax,wfgp2,1,czero,y,1)
+  evecsv(nstfv+1:nstfv+nj,j)=evecsv(nstfv+1:nstfv+nj,j)+y(1:nj)
   evecsv(j,j)=evecsv(j,j)+sdot(n22,wfgp0(:,jst,2),1,wfgp2,1)
 ! off-diagonal block
-  do ist=1,nstfv
-    evecsv(ist,j)=evecsv(ist,j)+cdotc(n1,wfgp0(:,ist,1),1,wfgp3,1)
-  end do
+  call cgemv('C',n1,nstfv,cone,wfgp0,ngkmax,wfgp3,1,czero,y,1)
+  evecsv(1:nstfv,j)=evecsv(1:nstfv,j)+y(1:nstfv)
 end do
 !$OMP END DO
-!$OMP END PARALLEL
+!$OMP SINGLE
 deallocate(wfgp0)
+!$OMP END SINGLE
+!$OMP END PARALLEL
 call freethd(nthd)
 ! diagonalise the second-variational Hamiltonian
-call eveqnzh(nstsv,nstsv,evecsv,evalsvp)
+call eveqnzh(nstsv,nstsv,evecsv,evalsv_)
 call timesec(ts1)
 !$OMP ATOMIC
 timesv=timesv+ts1-ts0
