@@ -4,7 +4,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine eveqnsv(ngp,igpig,vgpc,apwalm,evalfv,evecfv,evalsvp,evecsv)
+subroutine eveqnsv(ngp,igpig,vgpc,apwalm,evalfv,evecfv,evalsv_,evecsv)
 use modmain
 use moddftu
 use modomp
@@ -15,15 +15,15 @@ real(8), intent(in) :: vgpc(3,ngkmax)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 real(8), intent(in) :: evalfv(nstfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv)
-real(8), intent(out) :: evalsvp(nstsv)
+real(8), intent(out) :: evalsv_(nstsv)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
 logical todsb,socz
 integer ld,ist,jst,ispn,is,ias
 integer nrc,nrci,nrco,irco,irc
 integer l,lm,nm,npc,npc2,npci,ipco
-integer ngp2,igp,i0,i,j,nthd
-real(8) ca,a(3),asp(3,3),t1
+integer ngp2,igp,i0,i,j,nj,nthd
+real(8) ca,cb,a(3),asp(3,3),b(3),t1
 real(8) ts0,ts1
 complex(8) z1,z2,z3
 complex(4) c1
@@ -31,16 +31,15 @@ complex(4) c1
 complex(8) wfmt2(npcmtmax),wfmt4(npcmtmax,3)
 complex(8) wfmt31(npcmtmax),wfmt32(npcmtmax),wfmt33(npcmtmax)
 complex(4) wfmt5(npcmtmax),wfgp1(ngkmax),wfgp2(ngkmax),wfgp3(ngkmax)
-complex(4) wfir1(ngtc),wfir2(ngtc)
+complex(4) wfir1(ngtc),wfir2(ngtc),y(nstfv)
 ! allocatable arrays
 complex(4), allocatable :: wfmt0(:,:),wfgp0(:,:)
 complex(8), allocatable :: wfmt1(:,:)
 ! external functions
 real(4), external :: sdot
-complex(4), external :: cdotc
 ! no calculation of second-variational eigenvectors
 if (.not.tevecsv) then
-  evalsvp(1:nstsv)=evalfv(1:nstsv)
+  evalsv_(1:nstsv)=evalfv(1:nstsv)
   evecsv(1:nstsv,1:nstsv)=0.d0
   do i=1,nstsv
     evecsv(i,i)=1.d0
@@ -52,12 +51,13 @@ call timesec(ts0)
 ca=-1.d0/solsc
 if (tafield) a(1:3)=ca*afieldc(1:3)
 if (tafsp) asp(1:3,1:3)=ca*afspc(1:3,1:3)
+! coupling constant of the external field (g_e/4c)
+cb=gfacte/(4.d0*solsc)
 ! check if the off-diagonal spin block of the Hamiltonian is required
 todsb=(spinpol.and.(ncmag.or.spinorb))
 ! special case of spin-orbit coupling and collinear magnetism
 socz=(spinorb.and.cmagz)
 ld=lmmaxdm*nspinor
-call holdthd(nstfv,nthd)
 ! zero the second-variational Hamiltonian (stored in the eigenvector array)
 evecsv(1:nstsv,1:nstsv)=0.d0
 ! set the diagonal elements equal to the first-variational eigenvalues
@@ -67,16 +67,20 @@ do ispn=1,nspinor
     evecsv(i,i)=evalfv(ist)
   end do
 end do
+call holdthd(nstfv,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
+!$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3,y) &
+!$OMP PRIVATE(ias,is,nrc,nrci,nrco,irco,npc,npc2) &
+!$OMP PRIVATE(npci,ipco,b,ist,jst,irc,t1,i0,i,j) &
+!$OMP PRIVATE(z1,z2,z3,l,nm,lm,nj,igp,c1) &
+!$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
+!$OMP SINGLE
 allocate(wfmt0(npcmtmax,nstfv),wfmt1(npcmtmax,nstfv))
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
-!$OMP PRIVATE(ias,is,nrc,nrci,nrco,irco) &
-!$OMP PRIVATE(npc,npc2,npci,ipco,ist,jst,irc) &
-!$OMP PRIVATE(t1,i0,i,j,l,nm,lm,z1,z2,z3) &
-!$OMP NUM_THREADS(nthd)
+!$OMP END SINGLE
 ! begin loop over atoms
 do ias=1,natmtot
   is=idxis(ias)
@@ -88,6 +92,16 @@ do ias=1,natmtot
   npc2=npc*2
   npci=npcmti(is)
   ipco=npci+1
+! B-field-orbit coupling
+  if (bforb) then
+    if (tbdip) then
+! external plus average muffin-tin dipole field
+      b(1:3)=cb*(bfieldc(1:3)+bdmta(1:3,ias))
+    else
+! external field only
+      b(1:3)=cb*bfieldc(1:3)
+    end if
+  end if
 ! compute the first-variational wavefunctions
 !$OMP DO SCHEDULE(DYNAMIC)
   do ist=1,nstfv
@@ -114,32 +128,43 @@ do ias=1,natmtot
         call zfsht(nrc,nrci,wfmt32,wfmt33)
       end if
       wfmt32(1:npc)=-wfmt31(1:npc)
-! apply spin-orbit coupling if required
-      if (spinorb) then
+! apply spin-orbit or B-field-orbit coupling if required
+      if (spinorb.or.bforb) then
         call lopzflmn(lmaxi,nrci,lmmaxi,wfmt1(1,jst),wfmt4,wfmt4(1,2), &
          wfmt4(1,3))
         call lopzflmn(lmaxo,nrco,lmmaxo,wfmt1(ipco,jst),wfmt4(ipco,1), &
          wfmt4(ipco,2),wfmt4(ipco,3))
+! spin-orbit coupling
+        if (spinorb) then
 ! inner part of muffin-tin
-        do irc=1,nrci
-          t1=socfr(irc,ias)
-          i0=lmmaxi*(irc-1)
-          do i=i0+1,i0+lmmaxi
-            wfmt31(i)=wfmt31(i)+t1*wfmt4(i,3)
-            wfmt32(i)=wfmt32(i)-t1*wfmt4(i,3)
-            wfmt33(i)=wfmt33(i)+t1*(wfmt4(i,1)+zmi*wfmt4(i,2))
+          do irc=1,nrci
+            t1=socfr(irc,ias)
+            i0=lmmaxi*(irc-1)
+            do i=i0+1,i0+lmmaxi
+              wfmt31(i)=wfmt31(i)+t1*wfmt4(i,3)
+              wfmt32(i)=wfmt32(i)-t1*wfmt4(i,3)
+              wfmt33(i)=wfmt33(i)+t1*(wfmt4(i,1)-zi*wfmt4(i,2))
+            end do
           end do
-        end do
 ! outer part of muffin-tin
-        do irc=irco,nrc
-          t1=socfr(irc,ias)
-          i0=npci+lmmaxo*(irc-irco)
-          do i=i0+1,i0+lmmaxo
-            wfmt31(i)=wfmt31(i)+t1*wfmt4(i,3)
-            wfmt32(i)=wfmt32(i)-t1*wfmt4(i,3)
-            wfmt33(i)=wfmt33(i)+t1*(wfmt4(i,1)+zmi*wfmt4(i,2))
+          do irc=irco,nrc
+            t1=socfr(irc,ias)
+            i0=npci+lmmaxo*(irc-irco)
+            do i=i0+1,i0+lmmaxo
+              wfmt31(i)=wfmt31(i)+t1*wfmt4(i,3)
+              wfmt32(i)=wfmt32(i)-t1*wfmt4(i,3)
+              wfmt33(i)=wfmt33(i)+t1*(wfmt4(i,1)-zi*wfmt4(i,2))
+            end do
           end do
-        end do
+        end if
+! B-field-orbit coupling
+        if (bforb) then
+          do i=1,npc
+            z1=b(1)*wfmt4(i,1)+b(2)*wfmt4(i,2)+b(3)*wfmt4(i,3)
+            wfmt31(i)=wfmt31(i)+z1
+            wfmt32(i)=wfmt32(i)+z1
+          end do
+        end if
       end if
     else
       wfmt31(1:npc)=0.d0
@@ -182,7 +207,8 @@ do ias=1,natmtot
        npcmtmax,wfmt4)
       if (tafield) then
         do i=1,npc
-          z1=zmi*(a(1)*wfmt4(i,1)+a(2)*wfmt4(i,2)+a(3)*wfmt4(i,3))
+          z1=a(1)*wfmt4(i,1)+a(2)*wfmt4(i,2)+a(3)*wfmt4(i,3)
+          z1=cmplx(z1%im,-z1%re,8)
           wfmt31(i)=wfmt31(i)+z1
           if (spinpol) wfmt32(i)=wfmt32(i)+z1
         end do
@@ -190,39 +216,37 @@ do ias=1,natmtot
 ! apply spin-dependent vector potential if required
       if (tafsp) then
         do i=1,npc
-          z3=zmi*(asp(1,3)*wfmt4(i,1)+asp(2,3)*wfmt4(i,2)+asp(3,3)*wfmt4(i,3))
+          z3=asp(1,3)*wfmt4(i,1)+asp(2,3)*wfmt4(i,2)+asp(3,3)*wfmt4(i,3)
+          z3=cmplx(z3%im,-z3%re,8)
           wfmt31(i)=wfmt31(i)+z3
           wfmt32(i)=wfmt32(i)-z3
           if (ncmag) then
             z1=asp(1,1)*wfmt4(i,1)+asp(2,1)*wfmt4(i,2)+asp(3,1)*wfmt4(i,3)
             z2=asp(1,2)*wfmt4(i,1)+asp(2,2)*wfmt4(i,2)+asp(3,2)*wfmt4(i,3)
-            wfmt33(i)=wfmt33(i)+zmi*z1-z2
+            wfmt33(i)=wfmt33(i)+cmplx(z1%im,-z1%re,8)-z2
           end if
         end do
       end if
     end if
 ! add to second-variational Hamiltonian matrix
+    nj=jst-1
 ! upper diagonal block
     wfmt5(1:npc)=wfmt31(1:npc)
-    do ist=1,jst-1
-      evecsv(ist,jst)=evecsv(ist,jst)+cdotc(npc,wfmt0(:,ist),1,wfmt5,1)
-    end do
+    call cgemv('C',npc,nj,cone,wfmt0,npcmtmax,wfmt5,1,czero,y,1)
+    evecsv(1:nj,jst)=evecsv(1:nj,jst)+y(1:nj)
     evecsv(jst,jst)=evecsv(jst,jst)+sdot(npc2,wfmt0(:,jst),1,wfmt5,1)
     if (spinpol) then
       j=jst+nstfv
 ! lower diagonal block
       wfmt5(1:npc)=wfmt32(1:npc)
-      do ist=1,jst-1
-        i=ist+nstfv
-        evecsv(i,j)=evecsv(i,j)+cdotc(npc,wfmt0(:,ist),1,wfmt5,1)
-      end do
+      call cgemv('C',npc,nj,cone,wfmt0,npcmtmax,wfmt5,1,czero,y,1)
+      evecsv(nstfv+1:nstfv+nj,j)=evecsv(nstfv+1:nstfv+nj,j)+y(1:nj)
       evecsv(j,j)=evecsv(j,j)+sdot(npc2,wfmt0(:,jst),1,wfmt5,1)
 ! off-diagonal block
       if (todsb) then
         wfmt5(1:npc)=wfmt33(1:npc)
-        do ist=1,nstfv
-          evecsv(ist,j)=evecsv(ist,j)+cdotc(npc,wfmt0(:,ist),1,wfmt5,1)
-        end do
+        call cgemv('C',npc,nstfv,cone,wfmt0,npcmtmax,wfmt5,1,czero,y,1)
+        evecsv(1:nstfv,j)=evecsv(1:nstfv,j)+y(1:nstfv)
       end if
     end if
 ! end loop over states
@@ -230,19 +254,18 @@ do ias=1,natmtot
 !$OMP END DO
 ! end loop over atoms
 end do
-!$OMP END PARALLEL
+!$OMP SINGLE
 deallocate(wfmt0,wfmt1)
+!$OMP END SINGLE
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
 if (spinpol.or.tafield) then
+!$OMP SINGLE
   if (socz) todsb=.false.
   ngp2=ngp*2
   allocate(wfgp0(ngp,nstfv))
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3) &
-!$OMP PRIVATE(ist,jst,igp,t1,c1,i,j) &
-!$OMP NUM_THREADS(nthd)
+!$OMP END SINGLE
 ! make single-precision copy of wavefunction
 !$OMP DO SCHEDULE(DYNAMIC)
   do ist=1,nstfv
@@ -311,7 +334,7 @@ if (spinpol.or.tafield) then
         else if (j == 2) then
           do igp=1,ngp
             c1=wfir1(igfc(igpig(igp)))
-            wfgp3(igp)=wfgp3(igp)+cmi*c1
+            wfgp3(igp)=wfgp3(igp)+cmplx(c1%im,-c1%re,4)
           end do
         else
           do igp=1,ngp
@@ -323,43 +346,42 @@ if (spinpol.or.tafield) then
       end do
     end if
 ! add to second-variational Hamiltonian matrix
+    nj=jst-1
 ! upper diagonal block
-    do ist=1,jst-1
-      evecsv(ist,jst)=evecsv(ist,jst)+cdotc(ngp,wfgp0(:,ist),1,wfgp1,1)
-    end do
+    call cgemv('C',ngp,nj,cone,wfgp0,ngp,wfgp1,1,czero,y,1)
+    evecsv(1:nj,jst)=evecsv(1:nj,jst)+y(1:nj)
     evecsv(jst,jst)=evecsv(jst,jst)+sdot(ngp2,wfgp0(:,jst),1,wfgp1,1)
     if (spinpol) then
       j=jst+nstfv
 ! lower diagonal block
-      do ist=1,jst-1
-        i=ist+nstfv
-        evecsv(i,j)=evecsv(i,j)+cdotc(ngp,wfgp0(:,ist),1,wfgp2,1)
-      end do
+      call cgemv('C',ngp,nj,cone,wfgp0,ngp,wfgp2,1,czero,y,1)
+      evecsv(nstfv+1:nstfv+nj,j)=evecsv(nstfv+1:nstfv+nj,j)+y(1:nj)
       evecsv(j,j)=evecsv(j,j)+sdot(ngp2,wfgp0(:,jst),1,wfgp2,1)
 ! off-diagonal block
       if (todsb) then
-        do ist=1,nstfv
-          evecsv(ist,j)=evecsv(ist,j)+cdotc(ngp,wfgp0(:,ist),1,wfgp3,1)
-        end do
+        call cgemv('C',ngp,nstfv,cone,wfgp0,ngp,wfgp3,1,czero,y,1)
+        evecsv(1:nstfv,j)=evecsv(1:nstfv,j)+y(1:nstfv)
       end if
     end if
 ! end loop over states
   end do
 !$OMP END DO
-!$OMP END PARALLEL
+!$OMP SINGLE
   deallocate(wfgp0)
+!$OMP END SINGLE
 end if
+!$OMP END PARALLEL
 call freethd(nthd)
 if (ncmag.or.spinorb.or.(.not.spinpol)) then
 ! spins are coupled; or spin-unpolarised: full diagonalisation
-  call eveqnzh(nstsv,nstsv,evecsv,evalsvp)
+  call eveqnzh(nstsv,nstsv,evecsv,evalsv_)
 else
 ! spins not coupled: block diagonalise H
-  call eveqnzh(nstfv,nstsv,evecsv,evalsvp)
+  call eveqnzh(nstfv,nstsv,evecsv,evalsv_)
   evecsv(nstfv+1:nstsv,1:nstfv)=0.d0
   evecsv(1:nstfv,nstfv+1:nstsv)=0.d0
   i=nstfv+1
-  call eveqnzh(nstfv,nstsv,evecsv(i,i),evalsvp(i))
+  call eveqnzh(nstfv,nstsv,evecsv(i,i),evalsv_(i))
 end if
 call timesec(ts1)
 !$OMP ATOMIC
