@@ -31,7 +31,7 @@ do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(exxengy_)
-  write(*,'("Info(exxengy): ",I6," of ",I6," k-points")') ik,nkpt
+  write(*,'("Info(exxengy): ",I0," of ",I0," k-points")') ik,nkpt
 !$OMP END CRITICAL(exxengy_)
   call exxengyk(ik)
 end do
@@ -66,7 +66,7 @@ do is=1,nspecies
                 call cpotclmt(nrc,nrci,nrcmtmax,rlcmt(:,:,is),wprcmt(:,:,is), &
                  crhomt,cvclmt)
                 z1=zcfmtinp(nrc,nrci,wr2cmt(:,is),crhomt,cvclmt)
-                engyx=engyx-0.5d0*dble(z1)
+                engyx=engyx-0.5d0*z1%re
               end do
 ! end loop over ist
             end if
@@ -78,7 +78,6 @@ do is=1,nspecies
 ! end loops over atoms and species
   end do
 end do
-return
 
 contains
 
