@@ -112,15 +112,14 @@ do ik=1,nkptnr
        gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,crhoir,npcmtmax,cvclmt,cvclir)
       cvclir(1:ngtc)=cvclir(1:ngtc)*cfrc(1:ngtc)
       z1=zcfinp(crhomt,crhoir,cvclmt,cvclir)
-      ex=ex-0.5d0*occmax*wkpt(ikp)*wqptnr*dble(z1)
+      ex=ex-0.5d0*occmax*wkpt(ikp)*wqptnr*z1%re
     end do
   end do
 ! end loop over non-reduced k-point set
 end do
 deallocate(vgqc,gqc,gclgq,jlgqrmt)
-deallocate(evecfv,evecsv)
-deallocate(apwalm,ylmgq,sfacgq)
-deallocate(wfmt2,wfir2)
+deallocate(apwalm,evecfv,evecsv)
+deallocate(ylmgq,sfacgq,wfmt2,wfir2)
 !-----------------------------------------!
 !    valence-core-valence contribution    !
 !-----------------------------------------!
@@ -150,7 +149,7 @@ do is=1,nspecies
             call cpotclmt(nrc,nrci,nrcmtmax,rlcmt(:,:,is),wprcmt(:,:,is), &
              crhomt(:,ias),cvclmt(:,ias))
             z1=zcfmtinp(nrc,nrci,wr2cmt(:,is),crhomt(:,ias),cvclmt(:,ias))
-            ex=ex-occmax*wkpt(ikp)*dble(z1)
+            ex=ex-occmax*wkpt(ikp)*z1%re
           end do
 ! end loop over m
         end do
@@ -166,7 +165,6 @@ engyx=engyx+ex
 !$OMP END CRITICAL(exxengyk_)
 deallocate(wfmt1,wfir1,wfcr)
 deallocate(crhomt,crhoir,cvclmt,cvclir)
-return
 
 contains
 
