@@ -39,7 +39,7 @@ real(8), intent(in) :: vgc(3,ngv),gkmax
 integer, intent(out) :: ngkmax
 ! local variables
 integer ispn,ik,n,ig
-real(8) v1,v2,v3,w1,w2,w3,t0,t1
+real(8) v1,v2,v3,t0,t1
 t0=gkmax**2+1.d-6
 ngkmax=0
 do ispn=1,nspnfv
@@ -62,13 +62,10 @@ do ispn=1,nspnfv
     end if
     n=0
     do ig=1,ngv
-      w1=vgc(1,ig)+v1
-      w2=vgc(2,ig)+v2
-      w3=vgc(3,ig)+v3
-      t1=w1**2+w2**2+w3**2
+      t1=(vgc(1,ig)+v1)**2+(vgc(2,ig)+v2)**2+(vgc(3,ig)+v3)**2
       if (t1 < t0) n=n+1
     end do
-    ngkmax=max(ngkmax,n)
+    if (n > ngkmax) ngkmax=n
   end do
 end do
 end subroutine
