@@ -29,7 +29,6 @@ use modtest
 !
 ! !REVISION HISTORY:
 !   Created April 2007 (JKD)
-!   Modified for trimvg=.false., November 2023 (JKD)
 !EOP
 !BOC
 implicit none
@@ -48,6 +47,8 @@ if (allocated(ieqatom)) deallocate(ieqatom)
 allocate(ieqatom(natmmax,nspecies,maxsymcrys))
 if (allocated(eqatoms)) deallocate(eqatoms)
 allocate(eqatoms(natmmax,natmmax,nspecies))
+if (allocated(tfeqat)) deallocate(tfeqat)
+allocate(tfeqat(natmmax,nspecies))
 ! find the smallest set of atoms
 is0=1
 do is=1,nspecies
@@ -148,6 +149,13 @@ do isym=1,nsymcrys
     exit
   end if
 end do
+! flag the first equivalent atom for each species
+do is=1,nspecies
+  do ia=1,natoms(is)
+    ja=findloc(eqatoms(1:ia,ia,is),.true.,1)
+    tfeqat(ia,is)=(ia == ja)
+  end do
+end do
 if (tshift) then
   if (tsyminv) then
 ! if inversion exists then shift basis so that inversion center is at origin
@@ -186,11 +194,7 @@ do isym=1,nsymcrys
   call r3mv(avec,vtlsymc(:,isym),vtcsymc(:,isym))
 ! set flag for zero translation vector
   t1=abs(vtlsymc(1,isym))+abs(vtlsymc(2,isym))+abs(vtlsymc(3,isym))
-  if (t1 < epslat) then
-    tv0symc(isym)=.true.
-  else
-    tv0symc(isym)=.false.
-  end if
+  tv0symc(isym)=(t1 < epslat)
 end do
 ! check inversion does not include a translation
 if (tsyminv) then
