@@ -107,9 +107,9 @@ do jspn=1,nspnfv
           t1=vgc(l,ig)
           z1=-ffacg(ig,is)*conjg(sfacg(ig,ias))
           z2=t1*(dp(i,j)*z1+h(i,j))
-          dlh(i,j)=zi*z2
+          dlh(i,j)=cmplx(-z2%im,z2%re,8)
           z2=t1*(z1+o(i,j))
-          dlo(i,j)=zi*z2
+          dlo(i,j)=cmplx(-z2%im,z2%re,8)
         end do
       end do
 ! APW-local-orbital contribution
@@ -117,9 +117,9 @@ do jspn=1,nspnfv
         do i=1,n
           t1=vgkc(l,i,jspn,ik)
           z1=t1*h(i,j)
-          dlh(i,j)=zi*z1
+          dlh(i,j)=cmplx(-z1%im,z1%re,8)
           z1=t1*o(i,j)
-          dlo(i,j)=zi*z1
+          dlo(i,j)=cmplx(-z1%im,z1%re,8)
         end do
       end do
 ! compute the force matrix elements in the first-variational basis
@@ -149,7 +149,7 @@ do jspn=1,nspnfv
             i=(ispn-1)*nstfv+1
             call zgemv('N',nstfv,nstfv,zone,ffv,nstfv,evecsv(i,j),1,zzero,y,1)
             z1=zdotc(nstfv,evecsv(i,j),1,y,1)
-            sm=sm+occsv(j,ik)*dble(z1)
+            sm=sm+occsv(j,ik)*z1%re
           end do
         end do
       else
