@@ -25,7 +25,7 @@ integer, intent(in) :: x,y
 integer a,b,c
 if ((x < 1).or.(y < 1)) then
   write(*,*)
-  write(*,'("Error(gcd): x < 1 or y < 1 : ",2I8)') x,y
+  write(*,'("Error(gcd): x < 1 or y < 1 :",2(X,I0))') x,y
   write(*,*)
   stop
 end if
