@@ -36,7 +36,7 @@ real(8) av0(3),t0,d,w,phi,rc
 real(8) ft,ppd,s,t
 real(8) av(3),s0,sv(3)
 real(8) t1,t2,t3,t4
-! conversion factor of power density to W/cm^2
+! conversion factor of power density to W/cm²
 real(8), parameter :: cpd=ha_si/(t_si*(100.d0*br_si)**2)
 ! generate the time step grid
 call gentimes
@@ -175,7 +175,7 @@ end do
 !---------------!
 do i=1,nstep
 ! vector amplitude
-  av(1:3)=step(1:3,i)
+  av0(1:3)=step(1:3,i)
 ! step start time
   t0=step(4,i)-1.d-14
 ! step stop time
@@ -183,12 +183,13 @@ do i=1,nstep
 ! write information to TD_INFO.OUT
   write(50,*)
   write(50,'("Step : ",I6)') i
-  write(50,'(" vector amplitude : ",3G18.10)') av(:)
+  write(50,'(" vector amplitude : ",3G18.10)') av0(:)
   write(50,'(" step start and stop times : ",2G18.10)') t0,t1
   if (tafspt) then
     s0=step(6,i)
     sv(1:3)=step(7:9,i)
-    write(50,'(" spin components for σ_0, σ_x, σ_y, σ_z : ")')
+    av(1:3)=s0*av0(1:3)
+    write(50,'(" spin components for σ_0, σ_x, σ_y, σ_z :")')
     write(50,'(4G18.10)') s0,sv(:)
   end if
 ! loop over time steps
@@ -196,12 +197,12 @@ do i=1,nstep
     t=times(its)
     if (t > t1) exit
     if (t >= t0) then
-      afieldt(1:3,its)=afieldt(1:3,its)+av(1:3)
       if (tafspt) then
         do j=1,3
-          afspt(1:3,j,its)=afspt(1:3,j,its)+av(1:3)*sv(j)
+          afspt(1:3,j,its)=afspt(1:3,j,its)+av0(1:3)*sv(j)
         end do
       end if
+      afieldt(1:3,its)=afieldt(1:3,its)+av(1:3)
     end if
   end do
 end do
