@@ -57,9 +57,9 @@ do ias=1,natmtot
   nrs=nrsp(is)
 ! Kohn-Sham magnetic field for spin-polarised core
   if (spincore) then
-! compute the averaged direction of the exchange-correlation magnetic field
+! compute the averaged direction of the magnetisation
     do idm=1,ndmag
-      v(idm)=rfmtint(nr,nri,wr2mt(:,is),bxcmt(:,ias,idm))
+      v(idm)=rfmtint(nr,nri,wr2mt(:,is),magmt(:,ias,idm))
     end do
 ! normalise
     if (ncmag) then
@@ -85,9 +85,9 @@ do ias=1,natmtot
 ! spin-up and -down potentials for polarised core
     if (spincore) then
       if (ispn == 1) then
-        vr(1:nr)=vr(1:nr)-br(1:nr)
-      else
         vr(1:nr)=vr(1:nr)+br(1:nr)
+      else
+        vr(1:nr)=vr(1:nr)-br(1:nr)
       end if
     end if
 ! append the Kohn-Sham potential from the atomic calculation for r > R_MT
