@@ -23,15 +23,15 @@ do i=1,ntmfix
   is=itmfix(1,i)
   if (is > nspecies) then
     write(*,*)
-    write(*,'("Error(gendmftm): invalid species number : ",I8)') is
+    write(*,'("Error(gendmftm): invalid species number : ",I0)') is
     write(*,*)
     stop
   end if
   ia=itmfix(2,i)
   if (ia > natoms(is)) then
     write(*,*)
-    write(*,'("Error(gendmftm): invalid atom number : ",I8)') ia
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(gendmftm): invalid atom number : ",I0)') ia
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
@@ -39,8 +39,8 @@ do i=1,ntmfix
   l=itmfix(3,i)
   if (l > lmaxdm) then
     write(*,*)
-    write(*,'("Error(gendmftm): l > lmaxdm ",2I8)') l,lmaxdm
-    write(*,'(" for species ",I4," and atom ",I4)') is,ia
+    write(*,'("Error(gendmftm): l > lmaxdm :",2(X,I0))') l,lmaxdm
+    write(*,'(" for species ",I0," and atom ",I0)') is,ia
     write(*,*)
     stop
   end if
@@ -51,8 +51,8 @@ do i=1,ntmfix
   t=itmfix(7,i)
   if (abs(t) > lmmaxdm) then
     write(*,*)
-    write(*,'("Error(gendmftm): invalid t : ",I8)') t
-    write(*,'(" for tensor moment entry ",I3)') i
+    write(*,'("Error(gendmftm): invalid t : ",I0)') t
+    write(*,'(" for tensor moment entry ",I0)') i
     write(*,*)
     stop
   end if
