@@ -24,11 +24,10 @@ implicit none
 integer, intent(in) :: idu
 ! local variables
 integer is,ia,ias
-integer nr,nri,ir,nn,l
+integer nr,nri,nn,l
 real(8) t1
 ! automatic arrays
-real(8) vr(nrmtmax),fr(nrmtmax)
-real(8) p0(nrmtmax),p1(nrmtmax),q0(nrmtmax),q1(nrmtmax)
+real(8) vr(nrmtmax),p0(nrmtmax),p1(nrmtmax),q0(nrmtmax),q1(nrmtmax)
 is=isldu(1,idu)
 l=isldu(2,idu)
 nr=nrmt(is)
@@ -39,24 +38,23 @@ do ia=1,natoms(is)
   vr(1:nr)=vr(1:nr)*y00
 ! integrate the radial Schrodinger equation
   call rschrodint(solsc,l,efdu(l,ias),nr,rlmt(:,1,is),vr,nn,p0,p1,q0,q1)
+! divide the radial wavefunction by r
+  p0(1:nr)=p0(1:nr)*rlmt(1:nr,-1,is)
 ! normalise radial functions
-  fr(1:nr)=p0(1:nr)**2
-  t1=dot_product(wrmt(1:nr,is),fr(1:nr))
+  t1=sum(wr2mt(1:nr,is)*p0(1:nr)**2)
   if (t1 < 1.d-20) then
     write(*,*)
     write(*,'("Error(genfdufr): degenerate radial functions")')
-    write(*,'(" for species ",I4)') is
-    write(*,'(" atom ",I4)') ia
-    write(*,'(" and angular momentum ",I4)') l
+    write(*,'(" for species ",I0)') is
+    write(*,'(" atom ",I0)') ia
+    write(*,'(" and angular momentum ",I0)') l
     write(*,*)
     stop
   end if
   t1=1.d0/sqrt(abs(t1))
   p0(1:nr)=t1*p0(1:nr)
-! divide by r and store in global array
-  do ir=1,nr
-    fdufr(ir,l,ias)=p0(ir)/rsp(ir,is)
-  end do
+! store in global array
+  fdufr(1:nr,l,ias)=p0(1:nr)
 end do
 end subroutine
 !EOC
