@@ -19,9 +19,9 @@ if (treg) then
   t1=sqrt(vqc(1,iq)**2+vqc(2,iq)**2+vqc(3,iq)**2)
   do ig=1,ngq
     t2=gqc(ig)
-    if (abs(t1-t2) < epslat) then
+    if (abs(t1-t2) < 1.d-12) then
       gclgq(ig)=gclq(iq)
-    else if (t2 > epslat) then
+    else if (t2 > 1.d-12) then
       gclgq(ig)=fourpi/t2**2
     else
       gclgq(ig)=0.d0
@@ -31,7 +31,7 @@ else
 ! no regularisation
   do ig=1,ngq
     t1=gqc(ig)
-    if (t1 > epslat) then
+    if (t1 > 1.d-12) then
       gclgq(ig)=fourpi/t1**2
     else
       gclgq(ig)=0.d0
