@@ -12,15 +12,14 @@ implicit none
 integer, intent(in) :: ik0
 complex(8), intent(out) :: h(nstulr,nstulr)
 ! local variables
-integer ik,ist,jst,ispn,idm,nthd
+integer ik,ikk,ist,jst,ispn,idm
 integer ikpa,jkpa,iq,ifq,ngk0,igk
-integer i1,i2,i3,j1,j2,j3,i,j
+integer i1,i2,i3,j1,j2,j3,i,j,nthd
 ! automatic arrays
 complex(8) zvir(ngtc),zbir(ngtc,ndmag),vmat(nstsv,nstsv)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(4), allocatable :: wfmt(:,:,:,:),wfir(:,:,:),wfgk(:,:,:)
-complex(8), allocatable :: hdb(:,:,:)
 ! central k-point
 ik=(ik0-1)*nkpa+1
 ! number of G+k-vectors for central k-point
@@ -59,8 +58,8 @@ call freethd(nthd)
 call holdthd(nfqrz,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(zvir,zbir,vmat) &
-!$OMP PRIVATE(iq,idm,ikpa,jkpa,j1,j2,j3) &
-!$OMP PRIVATE(jst,i,j,i1,i2,i3) &
+!$OMP PRIVATE(iq,idm,ikpa,jkpa,jst) &
+!$OMP PRIVATE(i1,i2,i3,j1,j2,j3,i,j) &
 !$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ifq=1,nfqrz
@@ -87,14 +86,14 @@ do ifq=1,nfqrz
         i=(ikpa-1)*nstsv+1
         i1=ivq(1,ikpa)-j1; i2=ivq(2,ikpa)-j2; i3=ivq(3,ikpa)-j3
         if (ivqiq(i1,i2,i3) == iq) then
-! copy matrix elements for kappa_i - kappa_j in Q-point set
+! copy matrix elements for κ_i - κ_j in Q-point set
           h(i:i+nstsv-1,j)=vmat(1:nstsv,jst)
         else if (ivqiq(-i1,-i2,-i3) == iq) then
 ! otherwise use conjugate transpose
           h(i:i+nstsv-1,j)=conjg(vmat(jst,1:nstsv))
         end if
       end do
-! copy only the upper triangular part for Q=0
+! copy only the upper triangular part for Q = 0
       if (ifq == 1) then
         i=(jkpa-1)*nstsv+1
         h(i:i+jst-1,j)=vmat(1:jst,jst)
@@ -104,21 +103,15 @@ do ifq=1,nfqrz
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-deallocate(wfmt,wfir,wfgk)
-! add the second-variational eigenvalues of k+kappa to the diagonal but in the
-! basis of the states at k
-do ist=1,nstsv
-  h(ist,ist)=h(ist,ist)+evalsv(ist,ik)
-end do
-allocate(hdb(nstsv,nstsv,2:nkpa))
-call hdbulrk(ik0,hdb)
-do ikpa=2,nkpa
-  i=(ikpa-1)*nstsv+1
-  do jst=1,nstsv
-    j=i+jst-1
-    h(i:i+jst-1,j)=h(i:i+jst-1,j)+hdb(1:jst,jst,ikpa)
+! add the second-variational eigenvalues of k+κ to the diagonal
+do ikpa=1,nkpa
+  ikk=(ik0-1)*nkpa+ikpa
+  i=(ikpa-1)*nstsv
+  do ist=1,nstsv
+    j=i+ist
+    h(j,j)=h(j,j)+evalsv(ist,ikk)
   end do
 end do
-deallocate(hdb)
+deallocate(wfmt,wfir,wfgk)
 end subroutine
 
