@@ -15,7 +15,7 @@ do i=1,nvxbse
   ist=istxbse(i)
   if ((ist < 1).or.(ist > nstsv)) then
     write(*,*)
-    write(*,'("Error(genidxbse): extra valence state out of range : ",I8)') ist
+    write(*,'("Error(genidxbse): extra valence state out of range : ",I0)') ist
     write(*,*)
     stop
   end if
@@ -24,7 +24,7 @@ do j=1,ncxbse
   jst=jstxbse(j)
   if ((jst < 1).or.(jst > nstsv)) then
     write(*,*)
-    write(*,'("Error(genidxbse): extra conduction state out of range : ",I8)') &
+    write(*,'("Error(genidxbse): extra conduction state out of range : ",I0)') &
      jst
     write(*,*)
     stop
@@ -37,7 +37,7 @@ ncbse=ncbse0+ncxbse
 if ((nvbse < 1).or.(ncbse < 1)) then
   write(*,*)
   write(*,'("Error(genidxbse): invalid number of valence or conduction &
-   &transition states : ",2I8)') nvbse,ncbse
+   &transition states :",2(X,I0))') nvbse,ncbse
   write(*,*)
   stop
 end if
@@ -100,16 +100,16 @@ do ik=1,nkptnr
     if (evalsv(ist,jk) > efermi) then
       write(*,*)
       write(*,'("Error(genidxbse): extra valence state above Fermi energy : ",&
-       &I6)') ist
-      write(*,'(" for k-point ",I8)') jk
+       &I0)') ist
+      write(*,'(" for k-point ",I0)') jk
       write(*,*)
       stop
     end if
     do k=1,nvbse0+i-1
       if (ist == istbse(k,ik)) then
         write(*,*)
-        write(*,'("Error(genidxbse): redundant extra valence state : ",I6)') ist
-        write(*,'(" for k-point ",I8)') jk
+        write(*,'("Error(genidxbse): redundant extra valence state : ",I0)') ist
+        write(*,'(" for k-point ",I0)') jk
         write(*,*)
         stop
       end if
@@ -121,8 +121,8 @@ do ik=1,nkptnr
     if (evalsv(jst,jk) < efermi) then
       write(*,*)
       write(*,'("Error(genidxbse): extra conduction state below Fermi &
-       &energy : ",I6)') jst
-      write(*,'(" for k-point ",I8)') jk
+       &energy : ",I0)') jst
+      write(*,'(" for k-point ",I0)') jk
       write(*,*)
       stop
     end if
@@ -130,8 +130,8 @@ do ik=1,nkptnr
       if (jst == jstbse(k,ik)) then
         write(*,*)
         write(*,'("Error(genidxbse): redundant extra conduction state : ",&
-         &I6)') jst
-        write(*,'(" for k-point ",I8)') jk
+         &I0)') jst
+        write(*,'(" for k-point ",I0)') jk
         write(*,*)
         stop
       end if
