@@ -20,7 +20,7 @@ use modmain
 !BOC
 implicit none
 ! local variables
-integer is,ias,i,ilo,l,m,lm
+integer is,ias,i,ilo,l,lm
 ! allocate global local-orbital index
 if (allocated(idxlo)) deallocate(idxlo)
 allocate(idxlo(lolmmax,nlomax,natmtot))
@@ -29,9 +29,8 @@ do ias=1,natmtot
   is=idxis(ias)
   do ilo=1,nlorb(is)
     l=lorbl(ilo,is)
-    do m=-l,l
+    do lm=l**2+1,(l+1)**2
       i=i+1
-      lm=l*(l+1)+m+1
       idxlo(lm,ilo,ias)=i
     end do
   end do
