@@ -8,27 +8,29 @@ use modmain
 use modtdhfc
 implicit none
 ! local variables
-integer ik,nst,nmax,ist
+integer ik,jk,nst,ist
 ! determine the maximum number of states within energy window over all k-points
-nmax=0
+nmaxthc=0
 do ik=1,nkpt
   nst=0
   do ist=1,nstsv
     if (abs(evalsv(ist,ik)-efermi) < ecutthc) nst=nst+1
   end do
-  nmax=max(nmax,nst)
+  nmaxthc=max(nmaxthc,nst)
 end do
-if (nmax == 0) then
+if (nmaxthc == 0) then
   write(*,*)
   write(*,'("Error(genidxthc): no states within energy window ecutthc")')
   write(*,*)
   stop
 end if
 ! allocate global arrays
-if (allocated(nstthc)) deallocate(nstthc)
-allocate(nstthc(nkpt))
+if (allocated(nthck)) deallocate(nthck)
+allocate(nthck(nkpt))
 if (allocated(idxthc)) deallocate(idxthc)
-allocate(idxthc(nmax,nkpt))
+allocate(idxthc(nmaxthc,nkpt))
+if (allocated(ithc)) deallocate(ithc)
+allocate(ithc(nmaxthc,nkptnr))
 ! determine the number of and index to used states
 do ik=1,nkpt
   nst=0
@@ -38,7 +40,16 @@ do ik=1,nkpt
       idxthc(nst,ik)=ist
     end if
   end do
-  nstthc(ik)=nst
+  nthck(ik)=nst
+end do
+! calculate the index to and total number of TDHFC states
+nthc=0
+do ik=1,nkptnr
+  jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
+  do ist=1,nthck(jk)
+    nthc=nthc+1
+    ithc(ist,ik)=nthc
+  end do
 end do
 end subroutine
 
