@@ -3,13 +3,12 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine genjprk(ik,lock)
+subroutine genjprk(ik,jrmt_,jrir_)
 use modmain
-use modomp
 implicit none
 ! arguments
 integer, intent(in) :: ik
-integer(omp_lock_kind), intent(inout) :: lock(natmtot)
+real(8), intent(inout) :: jrmt_(npcmtmax,natmtot,3),jrir_(ngtc,3)
 ! local variables
 integer ispn,jspn,nst,ist,jst
 integer is,ia,ias,nrc,nrci,npc
@@ -21,8 +20,7 @@ real(8) rfmt(npcmtmax)
 complex(8) gwfmt(npcmtmax,3),zfmt1(npcmtmax),zfmt2(npcmtmax)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
-complex(8), allocatable :: zfft1(:),zfft2(:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:),zfft1(:),zfft2(:)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 ! find the matching coefficients
@@ -69,9 +67,7 @@ do ist=1,nst
           call zbsht(nrc,nrci,gwfmt(:,i),zfmt2)
 ! compute the partial current density
           rfmt(1:npc)=aimag(zfmt1(1:npc)*zfmt2(1:npc))
-          call omp_set_lock(lock(ias))
-          jrmt(1:npc,ias,i)=jrmt(1:npc,ias,i)+wo*rfmt(1:npc)
-          call omp_unset_lock(lock(ias))
+          jrmt_(1:npc,ias,i)=jrmt_(1:npc,ias,i)+wo*rfmt(1:npc)
         end do
       end do
     end do
@@ -103,9 +99,7 @@ do ist=1,nst
         zfft2(ifg)=vgkc(i,igk,jspn,ik)*zi*wfgk(igk,ispn,ist)
       end do
       call zfftifc(3,ngdgc,1,zfft2)
-!$OMP CRITICAL(currentk_)
-      jrir(1:ngtc,i)=jrir(1:ngtc,i)+wo*aimag(zfft1(1:ngtc)*zfft2(1:ngtc))
-!$OMP END CRITICAL(currentk_)
+      jrir_(1:ngtc,i)=jrir_(1:ngtc,i)+wo*aimag(zfft1(1:ngtc)*zfft2(1:ngtc))
     end do
   end do
 end do
