@@ -34,6 +34,8 @@ real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:),bir(:,:)
 allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (spinpol) then
   allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
+else
+  allocate(bmt(1,1,1),bir(1,1))
 end if
 ! generate the Kohn-Sham potential and magnetic field in spherical coordinates
 ! and multiply by the radial integration weights; also multiply the interstitial
@@ -51,14 +53,13 @@ do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(genkmat_)
-  write(*,'("Info(genkmat): ",I6," of ",I6," k-points")') ik,nkpt
+  write(*,'("Info(genkmat): ",I0," of ",I0," k-points")') ik,nkpt
 !$OMP END CRITICAL(genkmat_)
   call putkmat(tfv,tvclcr,ik,vmt,vir,bmt,bir)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-deallocate(vmt,vir)
-if (spinpol) deallocate(bmt,bir)
+deallocate(vmt,vir,bmt,bir)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
