@@ -9,7 +9,7 @@ use modulr
 implicit none
 ! local variables
 integer i1,i2,i3,j1,j2,j3
-integer ikpa,ik0,ik
+integer ik0,ik,ikpa,nk,i
 integer n1,iq,ifq,ir
 real(8) v(3)
 ! allocatable arrays
@@ -24,11 +24,18 @@ nfqrz=n1*ngridq(2)*ngridq(3)
 ! integer grid intervals for the Q-points
 intq(1,1:3)=ngridq(1:3)/2-ngridq(1:3)+1
 intq(2,1:3)=ngridq(1:3)/2
-! kappa-point grid should be half the Q-point grid
-ngridkpa(1:3)=(ngridq(1:3)+1)/2
-! number of kappa-points
+! κ-point grid should be half the Q-point grid unless specified
+do i=1,3
+  nk=(ngridq(i)+1)/2
+  if (ngridkpa(i) > 0) then
+    ngridkpa(i)=min(ngridkpa(i),nk)
+  else
+    ngridkpa(i)=nk
+  end if
+end do
+! number of κ-points
 nkpa=ngridkpa(1)*ngridkpa(2)*ngridkpa(3)
-! integer grid intervals for the kappa-points
+! integer grid intervals for the κ-points
 intkpa(1,1:3)=ngridkpa(1:3)/2-ngridkpa(1:3)+1
 intkpa(2,1:3)=ngridkpa(1:3)/2
 ! allocate global Q-point arrays
@@ -46,7 +53,7 @@ if (allocated(vql)) deallocate(vql)
 allocate(vql(3,nqpt))
 if (allocated(vqc)) deallocate(vqc)
 allocate(vqc(3,nqpt))
-! store the kappa-points as the first nkpa entries in the Q-point arrays
+! store the κ-points as the first nkpa entries in the Q-point arrays
 iq=0
 do i1=intkpa(1,1),intkpa(2,1)
   do i2=intkpa(1,2),intkpa(2,2)
@@ -135,7 +142,7 @@ do i3=0,ngridq(3)-1
   end do
 end do
 ! allocate the k-point weight array for band structure calculation
-if (task == 720) then
+if (any(task == [720,725])) then
   if (allocated(wkpt)) deallocate(wkpt)
   allocate(wkpt(nkpt))
   wkpt(1:nkpt)=1.d0
@@ -145,7 +152,7 @@ allocate(vkl0(3,nkpt),vkc0(3,nkpt),wkpt0(nkpt))
 vkl0(1:3,1:nkpt)=vkl(1:3,1:nkpt)
 vkc0(1:3,1:nkpt)=vkc(1:3,1:nkpt)
 wkpt0(1:nkpt)=wkpt(1:nkpt)
-! number of k+kappa-points
+! number of k+κ-points
 nkpt0=nkpt
 nkpt=nkpt0*nkpa
 ! deallocate and reallocate k-point and weight arrays
