@@ -43,9 +43,8 @@ complex(8), intent(in) :: wfgp(ngkmax,nspinor,nstsv)
 complex(8), intent(out) :: pmat(nstsv,nstsv,3)
 ! local variables
 integer ist,jst,ispn,jspn
-integer is,ia,ias
-integer nrc,nrci,npc
-integer igp,ifg,i
+integer is,ia,ias,nrc,nrci,npc
+integer ld1,ld2,igp,ifg,i
 real(8) cso
 complex(8) z1,z2,z11,z12,z21,z22,z31,z32
 ! automatic arrays
@@ -53,10 +52,11 @@ real(8) rfmt(npcmtmax)
 complex(8) gwfmt(npcmtmax,3,nspinor),gvmt(npcmtmax,3)
 complex(8) zfmt1(npcmtmax,nspinor),zfmt2(npcmtmax,3,nspinor)
 complex(8) gwfir(ngtc,3),z(ngkmax)
-! external functions
-complex(8), external :: zdotc
 ! coefficient of spin-orbit coupling
 cso=1.d0/(4.d0*solsc**2)
+! leading dimensions
+ld1=npcmtmax*natmtot*nspinor
+ld2=ngkmax*nspinor
 ! zero the momentum matrix elements array
 pmat(1:nstsv,1:nstsv,1:3)=0.d0
 !---------------------------------!
@@ -92,17 +92,17 @@ do is=1,nspecies
         end do
 ! compute i σ ⨯ (∇ V(r)) φ(r)
         do i=1,npc
-          z1=zi*zfmt1(i,1)
-          z2=zi*zfmt1(i,2)
+          z1=cmplx(-zfmt1(i,1)%im,zfmt1(i,1)%re,8)
+          z2=cmplx(-zfmt1(i,2)%im,zfmt1(i,2)%re,8)
           z11=gvmt(i,1)*z1; z12=gvmt(i,1)*z2
           z21=gvmt(i,2)*z1; z22=gvmt(i,2)*z2
           z31=gvmt(i,3)*z1; z32=gvmt(i,3)*z2
-          zfmt2(i,1,1)=zmi*z32-z21
-          zfmt2(i,1,2)=zi*z31+z22
+          zfmt2(i,1,1)=cmplx(z32%im,-z32%re,8)-z21
+          zfmt2(i,1,2)=cmplx(-z31%im,z31%re,8)+z22
           zfmt2(i,2,1)=z11-z32
           zfmt2(i,2,2)=-z12-z31
-          zfmt2(i,3,1)=zi*z12+z22
-          zfmt2(i,3,2)=zmi*z11+z21
+          zfmt2(i,3,1)=cmplx(-z12%im,z12%re,8)+z22
+          zfmt2(i,3,2)=cmplx(z11%im,-z11%re,8)+z21
         end do
 ! convert to spherical harmonics and add to wavefunction gradient
         do ispn=1,nspinor
@@ -117,10 +117,8 @@ do is=1,nspecies
 ! apply the radial integral weights
           call zfmtwr(nrc,nrci,wr2cmt(:,is),gwfmt(:,i,ispn))
 ! compute the overlaps
-          do ist=1,jst
-            pmat(ist,jst,i)=pmat(ist,jst,i)+zdotc(npc,wfmt(:,ias,ispn,ist),1, &
-             gwfmt(:,i,ispn),1)
-          end do
+          call zgemv('C',npc,jst,zone,wfmt(1,ias,ispn,1),ld1,gwfmt(1,i,ispn),1,&
+           zone,pmat(1,jst,i),1)
         end do
       end do
     end do
@@ -137,7 +135,8 @@ do jst=1,nstsv
     do igp=1,ngp(jspn)
       ifg=igfc(igpig(igp,jspn))
       z1=wfgp(igp,ispn,jst)
-      gwfir(ifg,1:3)=vgpc(1:3,igp,jspn)*zi*z1
+      z1=cmplx(-z1%im,z1%re,8)
+      gwfir(ifg,1:3)=vgpc(1:3,igp,jspn)*z1
     end do
     do i=1,3
 ! Fourier transform to real-space
@@ -153,9 +152,8 @@ do jst=1,nstsv
         ifg=igfc(igpig(igp,jspn))
         z(igp)=gwfir(ifg,i)
       end do
-      do ist=1,jst
-        pmat(ist,jst,i)=pmat(ist,jst,i)+zdotc(ngp(jspn),wfgp(:,ispn,ist),1,z,1)
-      end do
+      call zgemv('C',ngp(jspn),jst,zone,wfgp(1,ispn,1),ld2,z,1,zone, &
+       pmat(1,jst,i),1)
     end do
   end do
 end do
@@ -163,7 +161,8 @@ end do
 do i=1,3
   do jst=1,nstsv
     do ist=1,jst-1
-      z1=zmi*pmat(ist,jst,i)
+      z1=pmat(ist,jst,i)
+      z1=cmplx(z1%im,-z1%re,8)
       pmat(ist,jst,i)=z1
       pmat(jst,ist,i)=conjg(z1)
     end do
