@@ -36,9 +36,8 @@ end do
 if (allocated(rmtl)) deallocate(rmtl)
 allocate(rmtl(0:lmaxo+3,nspecies))
 do is=1,nspecies
-  rmtl(0,is)=1.d0
-  do l=1,lmaxo+3
-    rmtl(l,is)=rmtl(l-1,is)*rmt(is)
+  do l=0,lmaxo+3
+    rmtl(l,is)=rmt(is)**l
   end do
 end do
 ! generate the radial meshes
@@ -46,8 +45,6 @@ if (allocated(rsp)) deallocate(rsp)
 allocate(rsp(nrspmax,nspecies))
 if (allocated(rlmt)) deallocate(rlmt)
 allocate(rlmt(nrmtmax,-lmaxo-1:lmaxo+2,nspecies))
-if (allocated(wrmt)) deallocate(wrmt)
-allocate(wrmt(nrmtmax,nspecies))
 if (allocated(wr2mt)) deallocate(wr2mt)
 allocate(wr2mt(nrmtmax,nspecies))
 if (allocated(wprmt)) deallocate(wprmt)
@@ -62,19 +59,13 @@ do is=1,nspecies
   end do
 ! calculate rˡ on the fine radial mesh
   nr=nrmt(is)
-  rlmt(1:nr,-1,is)=1.d0/rsp(1:nr,is)
-  rlmt(1:nr,0,is)=1.d0
-  rlmt(1:nr,1,is)=rsp(1:nr,is)
-  do l=-2,-lmaxo-1,-1
-    rlmt(1:nr,l,is)=rlmt(1:nr,l+1,is)*rlmt(1:nr,-1,is)
-  end do
-  do l=2,lmaxo+2
-    rlmt(1:nr,l,is)=rlmt(1:nr,l-1,is)*rlmt(1:nr,1,is)
+  do l=-lmaxo-1,lmaxo+2
+    rlmt(1:nr,l,is)=rsp(1:nr,is)**l
   end do
 ! determine the weights for spline integration on the fine radial mesh
-  call wsplint(nr,rsp(:,is),wrmt(:,is))
-! multiply by r² and store in separate array
-  wr2mt(1:nr,is)=wrmt(1:nr,is)*rlmt(1:nr,2,is)
+  call wsplint(nr,rsp(:,is),wr2mt(:,is))
+! multiply by r²
+  wr2mt(1:nr,is)=wr2mt(1:nr,is)*rlmt(1:nr,2,is)
 ! determine the weights for partial integration on fine radial mesh
   call wsplintp(nr,rsp(:,is),wprmt(:,:,is))
 ! determine the weights for the spline coefficients
@@ -83,7 +74,7 @@ end do
 ! determine the fraction of the muffin-tin radius which defines the inner part
 if (fracinr < 0.d0) fracinr=sqrt(dble(lmmaxi)/dble(lmmaxo))
 ! set up the coarse radial meshes and find the inner part of the muffin-tin
-! where rho is calculated with lmaxi
+! where the maximum angular momentum is lmaxi
 if (allocated(rcmt)) deallocate(rcmt)
 allocate(rcmt(nrcmtmax,nspecies))
 if (allocated(rlcmt)) deallocate(rlcmt)
