@@ -56,7 +56,7 @@ do ias=1,natmtot
     do i=1,np
 ! compute |m|
       magm(i)=sqrt(mag(i,1)**2+mag(i,2)**2+mag(i,3)**2)
-! compute rhoup=(rho+|m|)/2 and rhodn=(rho-|m|)/2
+! compute ρ↑=(ρ+|m|)/2 and ρ↓=(ρ-|m|)/2
       rhoup(i)=0.5d0*(rho(i)+magm(i))
       rhodn(i)=0.5d0*(rho(i)-magm(i))
 ! unit vector m/|m|
@@ -72,7 +72,7 @@ do ias=1,natmtot
     do i=1,np
 ! compute |m| = |m_z|
       magm(i)=abs(mag(i,1))
-! compute rhoup=(rho+|m|)/2 and rhodn=(rho-|m|)/2
+! compute ρ↑=(ρ+|m|)/2 and ρ↓=(ρ-|m|)/2
       rhoup(i)=0.5d0*(rho(i)+magm(i))
       rhodn(i)=0.5d0*(rho(i)-magm(i))
 ! unit vector m/|m|
@@ -147,7 +147,6 @@ deallocate(rho,mag,bxc,fxc)
 deallocate(rhoup,rhodn)
 deallocate(magu,magm,bxcp)
 deallocate(fxcuu,fxcud,fxcdd)
-return
 
 contains
 
