@@ -10,12 +10,10 @@ use modomp
 implicit none
 ! local variables
 integer ik,ispn,is,ias
-integer np,npi,npc,n,nthd
-! automatic arrays
-integer(omp_lock_kind) lock(natmtot)
+integer np,npc,n,nthd
 ! allocatable arrays
-real(8), allocatable :: rfmt(:,:),rfir(:)
-real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
+real(8), allocatable :: taumt_(:,:,:),tauir_(:,:)
+real(8), allocatable :: rfmt(:,:),rfir(:),rvfmt(:,:,:),rvfir(:,:)
 ! tau cannot be computed if wavefunctions do not exist
 if (iscl < 1) then
   taumt(:,:,:)=0.d0
@@ -23,32 +21,39 @@ if (iscl < 1) then
   return
 end if
 ! set the kinetic energy density to zero on the coarse grids
-do ispn=1,nspinor
-  do ias=1,natmtot
-    is=idxis(ias)
-    taumt(1:npcmt(is),ias,ispn)=0.d0
-  end do
-end do
-tauir(1:ngtc,1:nspinor)=0.d0
-! initialise the OpenMP locks
-do ias=1,natmtot
-  call omp_init_lock(lock(ias))
-end do
+allocate(taumt_(npcmtmax,natmtot,nspinor),tauir_(ngtc,nspinor))
+taumt_(:,:,:)=0.d0
+tauir_(:,:)=0.d0
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP SCHEDULE(DYNAMIC) &
+!$OMP REDUCTION(+:taumt_,tauir_) &
+!$OMP SCHEDULE(STATIC) &
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
-  call gentauk(ik,lock)
+  call gentauk(ik,taumt_,tauir_)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-! destroy the OpenMP locks
-do ias=1,natmtot
-  call omp_destroy_lock(lock(ias))
+! add tau from each process and redistribute
+if (np_mpi > 1) then
+  n=npcmtmax*natmtot*nspinor
+  call mpi_allreduce(mpi_in_place,taumt_,n,mpi_double_precision,mpi_sum,mpicom,&
+   ierror)
+  n=ngtc*nspinor
+  call mpi_allreduce(mpi_in_place,tauir_,n,mpi_double_precision,mpi_sum,mpicom,&
+   ierror)
+end if
+! copy tau to the global arrays
+do ispn=1,nspinor
+  do ias=1,natmtot
+    is=idxis(ias)
+    taumt(1:npcmt(is),ias,ispn)=taumt_(1:npcmt(is),ias,ispn)
+  end do
 end do
+tauir(1:ngtc,1:nspinor)=tauir_(1:ngtc,1:nspinor)
+deallocate(taumt_,tauir_)
 ! convert taumt to spherical harmonics
 do ispn=1,nspinor
   do ias=1,natmtot
@@ -56,12 +61,11 @@ do ispn=1,nspinor
     call rfshtip(nrcmt(is),nrcmti(is),taumt(:,ias,ispn))
   end do
 end do
-allocate(rfmt(npcmtmax,natmtot))
 ! symmetrise tau
 if (spinpol) then
 ! spin-polarised case: convert to scalar-vector form
-  allocate(rvfmt(npcmtmax,natmtot,ndmag))
-  allocate(rvfir(ngtc,ndmag),rfir(ngtc))
+  allocate(rfmt(npcmtmax,natmtot),rfir(ngtc))
+  allocate(rvfmt(npcmtmax,natmtot,ndmag),rvfir(ngtc,ndmag))
   do ias=1,natmtot
     is=idxis(ias)
     npc=npcmt(is)
@@ -84,7 +88,7 @@ if (spinpol) then
   end do
   tauir(1:ngtc,1)=0.5d0*(rfir(1:ngtc)+rvfir(1:ngtc,ndmag))
   tauir(1:ngtc,2)=0.5d0*(rfir(1:ngtc)-rvfir(1:ngtc,ndmag))
-  deallocate(rvfmt,rvfir,rfir)
+  deallocate(rfmt,rfir,rvfmt,rvfir)
 else
 ! spin-unpolarised case
   call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,nfgrzc,igfc,igrzfc,npmtmax, &
@@ -98,30 +102,17 @@ end do
 do ispn=1,nspinor
   call rfirctof(tauir(:,ispn),tauir(:,ispn))
 end do
-! add tau from each process and redistribute
-if (np_mpi > 1) then
-  n=npmtmax*natmtot*nspinor
-  call mpi_allreduce(mpi_in_place,taumt,n,mpi_double_precision,mpi_sum,mpicom, &
-   ierror)
-  n=ngtot*nspinor
-  call mpi_allreduce(mpi_in_place,tauir,n,mpi_double_precision,mpi_sum,mpicom, &
-   ierror)
-end if
 ! generate the core kinetic energy density
 call gentaucr
 do ispn=1,nspinor
   do ias=1,natmtot
     is=idxis(ias)
     np=npmt(is)
-    npi=npmti(is)
 ! add the core contribution
     taumt(1:np,ias,ispn)=taumt(1:np,ias,ispn)+taucr(1:np,ias,ispn)
 ! improve stability by smoothing tau
     call rfmtsm(msmgmt,nrmt(is),nrmti(is),taumt(:,ias,ispn))
   end do
 end do
-deallocate(rfmt)
-! synchronise MPI processes
-call mpi_barrier(mpicom,ierror)
 end subroutine
 
