@@ -3,17 +3,17 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine gentauk(ik,lock)
+subroutine gentauk(ik,taumt_,tauir_)
 use modmain
 use modomp
 implicit none
 ! arguments
 integer, intent(in) :: ik
-integer(omp_lock_kind), intent(inout) :: lock(natmtot)
+real(8), intent(inout) :: taumt_(npcmtmax,natmtot,nspinor),tauir_(ngtc,nspinor)
 ! local variables
 integer ispn,jspn,nst,ist,jst
 integer is,ias,nrc,nrci
-integer npc,igk,ifg,i
+integer npc,igk,ifg,i,nthd
 real(8) wo
 ! automatic arrays
 integer idx(nstsv)
@@ -44,18 +44,26 @@ allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfgp(ngkmax,nspinor,nst))
 call genwfsv(.true.,.true.,nst,idx,ngdgc,igfc,ngk(:,ik),igkig(:,:,ik),apwalm, &
  evecfv,evecsv,wfmt,ngkmax,wfgp)
 deallocate(apwalm,evecfv,evecsv)
+call holdthd(nspinor*natmtot+1,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(gzfmt,zfmt,zfft) &
+!$OMP PRIVATE(ispn,jspn,ias,is) &
+!$OMP PRIVATE(nrc,nrci,npc,ist,jst) &
+!$OMP PRIVATE(wo,i,igk,ifg) &
+!$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-do ist=1,nst
-  jst=idx(ist)
-  wo=0.5d0*wkpt(ik)*occsv(jst,ik)
-  do ispn=1,nspinor
-    do ias=1,natmtot
-      is=idxis(ias)
-      nrc=nrcmt(is)
-      nrci=nrcmti(is)
-      npc=npcmt(is)
+!$OMP DO COLLAPSE(2) SCHEDULE(DYNAMIC)
+do ispn=1,nspinor
+  do ias=1,natmtot
+    is=idxis(ias)
+    nrc=nrcmt(is)
+    nrci=nrcmti(is)
+    npc=npcmt(is)
+    do ist=1,nst
+      jst=idx(ist)
+      wo=0.5d0*wkpt(ik)*occsv(jst,ik)
 ! compute the gradient of the wavefunction
       call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is), &
        wfmt(:,ias,ispn,ist),npcmtmax,gzfmt)
@@ -63,18 +71,17 @@ do ist=1,nst
 ! convert gradient to spherical coordinates
         call zbsht(nrc,nrci,gzfmt(:,i),zfmt)
 ! add to total in muffin-tin
-        call omp_set_lock(lock(ias))
-        taumt(1:npc,ias,ispn)=taumt(1:npc,ias,ispn) &
+        taumt_(1:npc,ias,ispn)=taumt_(1:npc,ias,ispn) &
          +wo*(dble(zfmt(1:npc))**2+aimag(zfmt(1:npc))**2)
-        call omp_unset_lock(lock(ias))
       end do
     end do
   end do
 end do
-deallocate(wfmt)
+!$OMP END DO NOWAIT
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
+!$OMP SINGLE
 do ist=1,nst
   jst=idx(ist)
   wo=0.5d0*wkpt(ik)*occsv(jst,ik)/omega
@@ -87,13 +94,14 @@ do ist=1,nst
         zfft(ifg)=vgkc(i,igk,jspn,ik)*zi*wfgp(igk,ispn,ist)
       end do
       call zfftifc(3,ngdgc,1,zfft)
-!$OMP CRITICAL(gentauk_)
-      tauir(1:ngtc,ispn)=tauir(1:ngtc,ispn) &
+      tauir_(1:ngtc,ispn)=tauir_(1:ngtc,ispn) &
        +wo*(dble(zfft(1:ngtc))**2+aimag(zfft(1:ngtc))**2)
-!$OMP END CRITICAL(gentauk_)
     end do
   end do
 end do
-deallocate(wfgp)
+!$OMP END SINGLE
+!$OMP END PARALLEL
+call freethd(nthd)
+deallocate(wfmt,wfgp)
 end subroutine
 
