@@ -19,40 +19,38 @@ integer, intent(in) :: ld
 complex(4), intent(in) :: wfgp(ld,nspinor,nstsv)
 complex(8), intent(out) :: vbmat(nstsv,nstsv)
 ! local variables
-integer ist,jst,ispn,jspn
+integer ist,jst,nj,ispn,jspn
 integer is,ias,nrc,nrci,nrco
 integer npc,npc2,ipco
-integer n,igp,nthd
+integer ld1,ld2,n,igp,nthd
 ! automatic arrays
-complex(4) wfmt1(npcmtmax,2),wfmt2(npcmtmax,2)
+complex(4) wfmt1(npcmtmax,2),wfmt2(npcmtmax,2),y(nstsv)
 complex(4) wfir1(ngtc,nspinor),wfir2(ngtc,nspinor),c(ngkmax)
 ! external functions
 real(4), external :: sdot
-complex(4), external :: cdotc
+ld1=npcmtmax*natmtot*nspinor
+ld2=ld*nspinor
 ! zero the upper triangular matrix elements
 do jst=1,nstsv
   vbmat(1:jst,jst)=0.d0
 end do
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfmt2,wfir1,wfir2,c) &
-!$OMP PRIVATE(ist,jst,ias,is,nrc) &
-!$OMP PRIVATE(nrci,nrco,npc,npc2) &
-!$OMP PRIVATE(ipco,ispn,jspn,igp,n) &
+!$OMP PRIVATE(wfmt1,wfmt2,wfir1,wfir2,y,c) &
+!$OMP PRIVATE(jst,nj,ias,is,npc,npc2) &
+!$OMP PRIVATE(nrc,nrci,nrco,ipco) &
+!$OMP PRIVATE(ispn,jspn,igp,n) &
 !$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
 !$OMP DO SCHEDULE(DYNAMIC)
 do jst=1,nstsv
+  nj=jst-1
   do ias=1,natmtot
     is=idxis(ias)
-    nrc=nrcmt(is)
-    nrci=nrcmti(is)
-    nrco=nrc-nrci
     npc=npcmt(is)
     npc2=npc*2
-    ipco=npcmti(is)+1
 ! apply local potential and magnetic field to spinor wavefunction
     if (ncmag) then
 ! non-collinear case
@@ -66,6 +64,10 @@ do jst=1,nstsv
 ! apply muffin-tin DFT+U potential matrix if required
     if (dftu /= 0) then
       if (any(tvmmt(0:lmaxdm,ias))) then
+        nrc=nrcmt(is)
+        nrci=nrcmti(is)
+        nrco=nrc-nrci
+        ipco=npcmti(is)+1
 ! multiply wavefunction by radial integration weights
         wfmt2(1:npc,1)=wfmt(1:npc,ias,1,jst)
         wfmt2(1:npc,2)=wfmt(1:npc,ias,2,jst)
@@ -92,11 +94,9 @@ do jst=1,nstsv
       end if
     end if
 ! compute the inner products
-    do ist=1,jst-1
-      vbmat(ist,jst)=vbmat(ist,jst) &
-       +cdotc(npc,wfmt(1,ias,1,ist),1,wfmt1(1,1),1) &
-       +cdotc(npc,wfmt(1,ias,2,ist),1,wfmt1(1,2),1)
-    end do
+    call cgemv('C',npc,nj,cone,wfmt(1,ias,1,1),ld1,wfmt1(1,1),1,czero,y,1)
+    call cgemv('C',npc,nj,cone,wfmt(1,ias,2,1),ld1,wfmt1(1,2),1,cone,y,1)
+    vbmat(1:nj,jst)=vbmat(1:nj,jst)+y(1:nj)
     vbmat(jst,jst)=vbmat(jst,jst) &
      +sdot(npc2,wfmt(1,ias,1,jst),1,wfmt1(1,1),1) &
      +sdot(npc2,wfmt(1,ias,2,jst),1,wfmt1(1,2),1)
@@ -108,6 +108,7 @@ end do
 !---------------------------!
 !$OMP DO SCHEDULE(DYNAMIC)
 do jst=1,nstsv
+  nj=jst-1
 ! Fourier transform wavefunction to real-space
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
@@ -133,9 +134,8 @@ do jst=1,nstsv
     do igp=1,n
       c(igp)=wfir2(igfc(igpig(igp,jspn)),ispn)
     end do
-    do ist=1,jst-1
-      vbmat(ist,jst)=vbmat(ist,jst)+cdotc(n,wfgp(1,ispn,ist),1,c,1)
-    end do
+    call cgemv('C',n,nj,cone,wfgp(1,ispn,1),ld2,c,1,czero,y,1)
+    vbmat(1:nj,jst)=vbmat(1:nj,jst)+y(1:nj)
     vbmat(jst,jst)=vbmat(jst,jst)+sdot(2*n,wfgp(1,ispn,jst),1,c,1)
   end do
 end do
@@ -148,7 +148,6 @@ do ist=1,nstsv
     vbmat(ist,jst)=conjg(vbmat(jst,ist))
   end do
 end do
-return
 
 contains
 
