@@ -11,19 +11,18 @@ implicit none
 logical, intent(in) :: t3hw
 integer, intent(in) :: ik
 integer(omp_lock_kind), intent(inout) :: lock(nwrf)
-real(8), intent(in) :: vqpl(3),gclgq(ngrf)
-real(8), intent(in) :: jlgqr(njcmax,nspecies,ngrf)
-complex(8), intent(in) :: ylmgq(lmmaxo,ngrf)
-complex(8), intent(in) :: sfacgq(ngrf,natmtot)
+real(8), intent(in) :: vqpl(3),gclgq(ngrf),jlgqr(njcmax,nspecies,ngrf)
+complex(8), intent(in) :: ylmgq(lmmaxo,ngrf),sfacgq(ngrf,natmtot)
 integer, intent(in) :: nm
-complex(8), intent(inout) :: vchi0(nm,nm,nwrf)
+complex(4), intent(inout) :: vchi0(nm,nm,nwrf)
 ! local variables
 logical tq0
-integer isym,jk,jkq,iw
+integer isym,jk,jkq,iw,nthd
 integer nst,nstq,ist,jst,kst,lst
-integer nm2,ig,jg,i,j,nthd
+integer nm2,ig0,ig1,ig,jg,i,j
 real(8) vkql(3),ei,ej,eij,t1
 complex(8) a(3,3),z1
+complex(4) c1
 ! automatic arrays
 integer idx(nstsv),idxq(nstsv)
 integer ngp(nspnfv),ngpq(nspnfv)
@@ -31,8 +30,8 @@ integer ngp(nspnfv),ngpq(nspnfv)
 integer, allocatable :: igpig(:,:),igpqig(:,:)
 complex(4), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
 complex(4), allocatable :: wfmtq(:,:,:,:),wfirq(:,:,:)
-complex(4), allocatable :: crhomt(:,:),crhoir(:)
-complex(8), allocatable :: zrhoig(:),pmat(:,:,:),zw(:),b(:,:)
+complex(4), allocatable :: crhomt(:,:),crhoir(:),cw(:),b(:,:)
+complex(8), allocatable :: zrhoig(:),pmat(:,:,:)
 ! check if q = 0
 tq0=.false.
 if (sum(abs(vqpl(:))) < epslat) tq0=.true.
@@ -76,12 +75,12 @@ end if
 nm2=nm**2
 call holdthd(nst,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(crhomt,crhoir,zrhoig,zw,b) &
-!$OMP PRIVATE(jst,kst,lst,ei,ej,eij,t1) &
-!$OMP PRIVATE(iw,ig,jg,z1,i,j,a) &
+!$OMP PRIVATE(crhomt,crhoir,zrhoig,cw,b) &
+!$OMP PRIVATE(jst,kst,lst,ei,ej,eij,t1,iw) &
+!$OMP PRIVATE(ig,jg,z1,c1,ig0,ig1,i,j,a) &
 !$OMP NUM_THREADS(nthd)
 allocate(crhomt(npcmtmax,natmtot),crhoir(ngtc))
-allocate(zrhoig(ngrf),zw(nwrf))
+allocate(zrhoig(ngrf),cw(nwrf))
 if (tq0.and.t3hw) then
   allocate(b(-1:ngrf,-1:ngrf))
 else
@@ -99,7 +98,7 @@ do ist=1,nst
     eij=ei-ej
 ! frequency-dependent part in response function formula for all frequencies
     do iw=1,nwrf
-      zw(iw)=t1/(eij+wrf(iw))
+      cw(iw)=t1/(eij+wrf(iw))
     end do
 ! compute the complex density in G+q-space
     call gencrho(.true.,.true.,ngtc,wfmt(:,:,:,ist),wfir(:,:,ist), &
@@ -118,7 +117,7 @@ do ist=1,nst
 ! case of q = 0
     if (tq0) then
       if (t3hw) then
-        b(-1:1,-1:1)=0.d0
+        b(-1:1,-1:1)=0.e0
 ! calculate 3 x ngrf wings of matrix
         t1=-sqrt(fourpi)/eij
         do i=-1,1
@@ -140,15 +139,29 @@ do ist=1,nst
       end if
     end if
 ! add to body and wings of the response function
-    do iw=1,nwrf
-      call omp_set_lock(lock(iw))
-      call zaxpy(nm2,zw(iw),b,1,vchi0(1,1,iw),1)
-      call omp_unset_lock(lock(iw))
-    end do
-! calculate 3 x 3 head
+    if (t3hw.or.(mbwgrf < 0)) then
+! full matrix
+      do iw=1,nwrf
+        call omp_set_lock(lock(iw))
+        call caxpy(nm2,cw(iw),b,1,vchi0(1,1,iw),1)
+        call omp_unset_lock(lock(iw))
+      end do
+    else
+! treat matrix as banded
+      do iw=1,nwrf
+        call omp_set_lock(lock(iw))
+        c1=cw(iw)
+        do jg=1,ngrf
+          ig0=max(jg-mbwgrf,1); ig1=min(jg+mbwgrf,ngrf)
+          vchi0(ig0:ig1,jg,iw)=vchi0(ig0:ig1,jg,iw)+c1*b(ig0:ig1,jg)
+        end do
+        call omp_unset_lock(lock(iw))
+      end do
+    end if
+! calculate 3 x 3 head with alternative formula to improve numerical accuracy
     if (tq0.and.t3hw) then
       t1=-fourpi/eij
-      zw(1:nwrf)=zw(1:nwrf)/wrf(1:nwrf)
+      cw(1:nwrf)=cw(1:nwrf)/wrf(1:nwrf)
       do j=1,3
         do i=1,3
           a(i,j)=t1*pmat(kst,lst,i)*conjg(pmat(kst,lst,j))
@@ -157,7 +170,7 @@ do ist=1,nst
 ! add to the head of the response function
       do iw=1,nwrf
         call omp_set_lock(lock(iw))
-        vchi0(1:3,1:3,iw)=vchi0(1:3,1:3,iw)+a(1:3,1:3)*zw(iw)
+        vchi0(1:3,1:3,iw)=vchi0(1:3,1:3,iw)+cw(iw)*a(1:3,1:3)
         call omp_unset_lock(lock(iw))
       end do
     end if
@@ -166,7 +179,7 @@ do ist=1,nst
 ! end loop over ist
 end do
 !$OMP END DO
-deallocate(crhomt,crhoir,zrhoig,zw,b)
+deallocate(crhomt,crhoir,zrhoig,cw,b)
 !$OMP END PARALLEL
 call freethd(nthd)
 deallocate(wfmt,wfir,wfmtq,wfirq)
