@@ -58,7 +58,7 @@ case(210,211)
   end do
 case default
   write(*,*)
-  write(*,'("Error(genvfxc): fxctype not defined : ",3I8)') fxctype
+  write(*,'("Error(genvfxc): fxctype not defined :",3(X,I0))') fxctype
   write(*,*)
   stop
 end select
