@@ -13,9 +13,8 @@ implicit none
 real(8), intent(in) :: vmt(npmtmax,natmtot),vir(ngtot)
 complex(8), intent(out) :: vmat(nstsv,nstsv,nkpt)
 ! local variables
-integer ik,ispn
-integer is,ias,nrc,nrci
-integer n,lp,nthd
+integer ik,ispn,is,ias
+integer nrc,nrci,n,lp,nthd
 ! automatic arrays
 real(8) vmtc(npcmtmax,natmtot),virc(ngtc)
 ! allocatable arrays
