@@ -18,46 +18,49 @@ integer, intent(in) :: ld
 complex(4), intent(in) :: wfgp(ld,nspinor,nstsv)
 complex(8), intent(out) :: vmat(nstsv,nstsv)
 ! local variables
-integer ist,jst,ispn,jspn
+integer ist,jst,nj,ispn,jspn
 integer is,ias,nrc,nrci,nrco
 integer npc,npc2,ipco
-integer n,igp,nthd
+integer ld1,ld2,n,igp,nthd
 ! automatic arrays
 complex(4) wfmt1(npcmtmax),wfmt2(npcmtmax)
-complex(4) wfir(ngtc),c(ngkmax)
+complex(4) wfir(ngtc),c(ngkmax),y(nstsv)
 ! external functions
 real(4), external :: sdot
-complex(4), external :: cdotc
+ld1=npcmtmax*natmtot*nspinor
+ld2=ld*nspinor
 ! zero the upper triangular matrix elements
 do jst=1,nstsv
   vmat(1:jst,jst)=0.d0
 end do
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfmt2,wfir,c) &
-!$OMP PRIVATE(ist,jst,ispn,jspn) &
-!$OMP PRIVATE(ias,is,nrc,nrci,nrco) &
-!$OMP PRIVATE(npc,npc2,ipco,n,igp) &
+!$OMP PRIVATE(wfmt1,wfmt2,wfir,c,y) &
+!$OMP PRIVATE(jst,nj,ispn,jspn) &
+!$OMP PRIVATE(ias,is,npc,npc2,nrc) &
+!$OMP PRIVATE(nrci,nrco,ipco,n,igp) &
 !$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
 !$OMP DO SCHEDULE(DYNAMIC)
 do jst=1,nstsv
+  nj=jst-1
   do ispn=1,nspinor
     do ias=1,natmtot
       is=idxis(ias)
-      nrc=nrcmt(is)
-      nrci=nrcmti(is)
-      nrco=nrc-nrci
       npc=npcmt(is)
       npc2=npc*2
-      ipco=npcmti(is)+1
+! apply local potential to wavefunction
       wfmt1(1:npc)=vmt(1:npc,ias)*wfmt(1:npc,ias,ispn,jst)
 ! apply muffin-tin DFT+U potential matrix if required (note that this should be
 ! used only in the spin-unpolarised case)
       if (dftu /= 0) then
         if (any(tvmmt(0:lmaxdm,ias))) then
+          nrc=nrcmt(is)
+          nrci=nrcmti(is)
+          nrco=nrc-nrci
+          ipco=npcmti(is)+1
           call cgemm('N','N',lmmaxi,nrci,lmmaxi,cone,vmatmti(1,1,1,1,ias), &
            lmmaxi,wfmt(1,ias,ispn,jst),lmmaxi,czero,wfmt2,lmmaxi)
           call cgemm('N','N',lmmaxo,nrco,lmmaxo,cone,vmatmto(1,1,1,1,ias), &
@@ -67,9 +70,8 @@ do jst=1,nstsv
         end if
       end if
 ! compute the inner products
-      do ist=1,jst-1
-        vmat(ist,jst)=vmat(ist,jst)+cdotc(npc,wfmt(1,ias,ispn,ist),1,wfmt1,1)
-      end do
+      call cgemv('C',npc,nj,cone,wfmt(1,ias,ispn,1),ld1,wfmt1,1,czero,y,1)
+      vmat(1:nj,jst)=vmat(1:nj,jst)+y(1:nj)
       vmat(jst,jst)=vmat(jst,jst)+sdot(npc2,wfmt(1,ias,ispn,jst),1,wfmt1,1)
     end do
   end do
@@ -80,6 +82,7 @@ end do
 !---------------------------!
 !$OMP DO SCHEDULE(DYNAMIC)
 do jst=1,nstsv
+  nj=jst-1
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
     n=ngp(jspn)
@@ -97,9 +100,8 @@ do jst=1,nstsv
       c(igp)=wfir(igfc(igpig(igp,jspn)))
     end do
 ! compute the inner products
-    do ist=1,jst-1
-      vmat(ist,jst)=vmat(ist,jst)+cdotc(n,wfgp(1,ispn,ist),1,c,1)
-    end do
+    call cgemv('C',n,nj,cone,wfgp(1,ispn,1),ld2,c,1,czero,y,1)
+    vmat(1:nj,jst)=vmat(1:nj,jst)+y(1:nj)
     vmat(jst,jst)=vmat(jst,jst)+sdot(n*2,wfgp(1,ispn,jst),1,c,1)
   end do
 end do
