@@ -22,19 +22,22 @@ integer is,ias,ldmt,nthd
 if (nst < 1) return
 ! muffin-tin wavefunction
 ldmt=npcmtmax*natmtot
-call holdthd(natmtot,nthd)
-!$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(is) &
-!$OMP SCHEDULE(DYNAMIC) &
+call holdthd(natmtot+1,nthd)
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(ias,is) &
 !$OMP NUM_THREADS(nthd)
+!$OMP DO SCHEDULE(DYNAMIC)
 do ias=1,natmtot
   is=idxis(ias)
   call wfmtsv_sp(tsh,is,ias,nst,idx,ngp,apwalm,evecfv,evecsv,ldmt, &
    wfmt(1,ias,1,1))
 end do
-!$OMP END PARALLEL DO
-call freethd(nthd)
+!$OMP END DO NOWAIT
 ! interstitial wavefunction
+!$OMP SINGLE
 call wfirsv_sp(tgp,nst,idx,ngridg_,igfft_,ngp,igpig,evecfv,evecsv,ld,wfir)
+!$OMP END SINGLE
+!$OMP END PARALLEL
+call freethd(nthd)
 end subroutine
 
