@@ -19,18 +19,19 @@ complex(4), intent(in) :: wfir(ngtc,nspinor,nstsv)
 complex(4), intent(in) :: wfgp(ngp,nspinor,nstsv)
 complex(8), intent(out) :: vbmat(nstsv,nstsv)
 ! local variables
-integer ist,jst,ispn,nthd
-integer is,ias,npc,igp
+integer jst,ispn,nthd
+integer is,ias,npc
+integer ld1,ld2,igp
 ! automatic arrays
-complex(4) wfmt1(npcmtmax,nspinor),wfir1(ngtc,nspinor),c(ngp)
-! external functions
-complex(4), external :: cdotc
+complex(4) wfmt1(npcmtmax,nspinor),wfir1(ngtc,nspinor),y(nstsv),c(ngp)
+ld1=npcmtmax*natmtot*nspinor
+ld2=ngp*nspinor
 ! zero the matrix elements
 vbmat(1:nstsv,1:nstsv)=0.d0
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfir1,c) &
-!$OMP PRIVATE(ist,jst,ias,is) &
+!$OMP PRIVATE(wfmt1,wfir1,y,c) &
+!$OMP PRIVATE(jst,ias,is) &
 !$OMP PRIVATE(npc,ispn,igp) &
 !$OMP NUM_THREADS(nthd)
 !-------------------------!
@@ -52,11 +53,9 @@ do jst=1,nstsv
        wfmt(:,ias,2,jst),wfmt1,wfmt1(:,2))
     end if
 ! compute the inner products
-    do ist=1,nstsv
-      vbmat(ist,jst)=vbmat(ist,jst) &
-       +cdotc(npc,wfmt(:,ias,1,ist),1,wfmt1,1) &
-       +cdotc(npc,wfmt(:,ias,2,ist),1,wfmt1(:,2),1)
-    end do
+    call cgemv('C',npc,nstsv,cone,wfmt(1,ias,1,1),ld1,wfmt1(1,1),1,czero,y,1)
+    call cgemv('C',npc,nstsv,cone,wfmt(1,ias,2,1),ld1,wfmt1(1,2),1,cone,y,1)
+    vbmat(1:nstsv,jst)=vbmat(1:nstsv,jst)+y(1:nstsv)
   end do
 end do
 !$OMP END DO
@@ -80,15 +79,13 @@ do jst=1,nstsv
     do igp=1,ngp
       c(igp)=wfir1(igfc(igpig(igp)),ispn)
     end do
-    do ist=1,nstsv
-      vbmat(ist,jst)=vbmat(ist,jst)+cdotc(ngp,wfgp(:,ispn,ist),1,c,1)
-    end do
+    call cgemv('C',ngp,nstsv,cone,wfgp(1,ispn,1),ld2,c,1,czero,y,1)
+    vbmat(1:nstsv,jst)=vbmat(1:nstsv,jst)+y(1:nstsv)
   end do
 end do
 !$OMP END DO
 !$OMP END PARALLEL
 call freethd(nthd)
-return
 
 contains
 
@@ -103,7 +100,7 @@ complex(4), intent(out) :: wf21(n),wf22(n)
 integer i
 complex(8) z1
 do i=1,n
-  z1=zi*zb2(i)
+  z1=cmplx(-zb2(i)%im,zb2(i)%re,8)
   wf21(i)=(zv(i)+zb3(i))*wf11(i)+(zb1(i)-z1)*wf12(i)
   wf22(i)=(zv(i)-zb3(i))*wf12(i)+(zb1(i)+z1)*wf11(i)
 end do
