@@ -17,19 +17,20 @@ complex(4), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
 complex(4), intent(in) :: wfir(ngtc,nspinor,nstsv),wfgp(ngp,nspinor,nstsv)
 complex(8), intent(out) :: vmat(nstsv,nstsv)
 ! local variables
-integer ist,jst,ispn,nthd
-integer is,ias,npc,igp
+integer jst,ispn,nthd
+integer is,ias,npc
+integer ld1,ld2,igp
 ! automatic arrays
-complex(4) wfmt1(npcmtmax),wfir1(ngtc),c(ngp)
-! external functions
-complex(4), external :: cdotc
+complex(4) wfmt1(npcmtmax),wfir1(ngtc),y(nstsv),c(ngp)
+ld1=npcmtmax*natmtot*nspinor
+ld2=ngp*nspinor
 ! zero the matrix elements
 vmat(1:nstsv,1:nstsv)=0.d0
 call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfir1,c) &
-!$OMP PRIVATE(ist,jst,ispn) &
-!$OMP PRIVATE(ias,is,npc,igp) &
+!$OMP PRIVATE(wfmt1,wfir1,y,c) &
+!$OMP PRIVATE(jst,ispn,ias) &
+!$OMP PRIVATE(is,npc,igp) &
 !$OMP NUM_THREADS(nthd)
 !-------------------------!
 !     muffin-tin part     !
@@ -43,9 +44,8 @@ do jst=1,nstsv
 ! apply complex potential to wavefunction
       wfmt1(1:npc)=zvmt(1:npc,ias)*wfmt(1:npc,ias,ispn,jst)
 ! compute the inner products
-      do ist=1,nstsv
-        vmat(ist,jst)=vmat(ist,jst)+cdotc(npc,wfmt(:,ias,ispn,ist),1,wfmt1,1)
-      end do
+      call cgemv('C',npc,nstsv,cone,wfmt(1,ias,ispn,1),ld1,wfmt1,1,czero,y,1)
+      vmat(1:nstsv,jst)=vmat(1:nstsv,jst)+y(1:nstsv)
     end do
   end do
 end do
@@ -63,10 +63,8 @@ do jst=1,nstsv
     do igp=1,ngp
       c(igp)=wfir1(igfc(igpig(igp)))
     end do
-    do ist=1,nstsv
-! compute inner product
-      vmat(ist,jst)=vmat(ist,jst)+cdotc(ngp,wfgp(:,ispn,ist),1,c,1)
-    end do
+    call cgemv('C',ngp,nstsv,cone,wfgp(1,ispn,1),ld2,c,1,czero,y,1)
+    vmat(1:nstsv,jst)=vmat(1:nstsv,jst)+y(1:nstsv)
   end do
 end do
 !$OMP END DO
