@@ -38,7 +38,7 @@ close(240)
 t1=abs(vql(1,iq)-vql_(1))+abs(vql(2,iq)-vql_(2))+abs(vql(3,iq)-vql_(3))
 if (t1 > epslat) then
   write(*,*)
-  write(*,'("Error(getephmat): differing vectors for q-point ",I8)') iq
+  write(*,'("Error(getephmat): differing vectors for q-point ",I0)') iq
   write(*,'(" current    : ",3G18.10)') vql(:,iq)
   write(*,'(" EPHMAT.OUT : ",3G18.10)') vql_
   write(*,*)
@@ -47,7 +47,7 @@ end if
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1 > epslat) then
   write(*,*)
-  write(*,'("Error(getephmat): differing vectors for k-point ",I8)') ik
+  write(*,'("Error(getephmat): differing vectors for k-point ",I0)') ik
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
   write(*,'(" EPHMAT.OUT : ",3G18.10)') vkl_
   write(*,*)
@@ -55,19 +55,17 @@ if (t1 > epslat) then
 end if
 if (nstsv /= nstsv_) then
   write(*,*)
-  write(*,'("Error(getephmat): differing nstsv for q-point, k-point ",2I8)') &
-   iq,ik
-  write(*,'(" current    : ",I8)') nstsv
-  write(*,'(" EPHMAT.OUT : ",I8)') nstsv_
+  write(*,'("Error(getephmat): differing nstsv for (q,k)-point",2(X,I0))') iq,ik
+  write(*,'(" current    : ",I0)') nstsv
+  write(*,'(" EPHMAT.OUT : ",I0)') nstsv_
   write(*,*)
   stop
 end if
 if (nbph /= nbph_) then
   write(*,*)
-  write(*,'("Error(getephmat): differing nbph for q-point, k-point ",2I8)') &
-   iq,ik
-  write(*,'(" current    : ",I8)') nbph
-  write(*,'(" EPHMAT.OUT : ",I8)') nbph_
+  write(*,'("Error(getephmat): differing nbph for (q,k)-point",2(X,I0))') iq,ik
+  write(*,'(" current    : ",I0)') nbph
+  write(*,'(" EPHMAT.OUT : ",I0)') nbph_
   write(*,*)
   stop
 end if
