@@ -35,9 +35,9 @@ real(8), intent(in) :: vpl(3),vgpl(3,ngkmax,nspnfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv,nspnfv)
 ! local variables
 logical tgs
-integer isym,lspl,ilspl
-integer jspn,ilo,l,lm,i,j
-integer ik,ist,igp,igk,ig
+integer isym,lspl,ilspl,i,j
+integer jspn,ist,ilo,l,lm
+integer ik,ngk_,igp,igk,ig
 integer is,ia,ja,ias,jas
 integer recl,nmatmax_,nstfv_,nspnfv_
 real(8) vkl_(3),v(3)
@@ -73,7 +73,7 @@ close(202)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1 > epslat) then
   write(*,*)
-  write(*,'("Error(getevecfv): differing vectors for k-point ",I8)') ik
+  write(*,'("Error(getevecfv): differing vectors for k-point ",I0)') ik
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
   write(*,'(" EVECFV.OUT : ",3G18.10)') vkl_
   write(*,*)
@@ -81,25 +81,25 @@ if (t1 > epslat) then
 end if
 if (nmatmax /= nmatmax_) then
   write(*,*)
-  write(*,'("Error(getevecfv): differing nmatmax for k-point ",I8)') ik
-  write(*,'(" current    : ",I8)') nmatmax
-  write(*,'(" EVECFV.OUT : ",I8)') nmatmax_
+  write(*,'("Error(getevecfv): differing nmatmax for k-point ",I0)') ik
+  write(*,'(" current    : ",I0)') nmatmax
+  write(*,'(" EVECFV.OUT : ",I0)') nmatmax_
   write(*,*)
   stop
 end if
 if (nstfv /= nstfv_) then
   write(*,*)
-  write(*,'("Error(getevecfv): differing nstfv for k-point ",I8)') ik
-  write(*,'(" current    : ",I8)') nstfv
-  write(*,'(" EVECFV.OUT : ",I8)') nstfv_
+  write(*,'("Error(getevecfv): differing nstfv for k-point ",I0)') ik
+  write(*,'(" current    : ",I0)') nstfv
+  write(*,'(" EVECFV.OUT : ",I0)') nstfv_
   write(*,*)
   stop
 end if
 if (nspnfv /= nspnfv_) then
   write(*,*)
-  write(*,'("Error(getevecfv): differing nspnfv for k-point ",I8)') ik
-  write(*,'(" current    : ",I8)') nspnfv
-  write(*,'(" EVECFV.OUT : ",I8)') nspnfv_
+  write(*,'("Error(getevecfv): differing nspnfv for k-point ",I0)') ik
+  write(*,'(" current    : ",I0)') nspnfv
+  write(*,'(" EVECFV.OUT : ",I0)') nspnfv_
   write(*,*)
   stop
 end if
@@ -119,17 +119,18 @@ si(1:3,1:3)=dble(symlat(1:3,1:3,ilspl))
 !-----------------------------------------------!
 ! loop over the first-variational spins
 do jspn=1,nspnfv
+  ngk_=ngk(jspn,ik)
   if (tv0symc(isym)) then
 ! translation vector is zero
     do ist=1,nstfv
-      do igk=1,ngk(jspn,ik)
+      do igk=1,ngk_
         evecfv_(igk,ist)=evecfv(igk,ist,jspn)
       end do
     end do
   else
 ! non-zero translation vector gives a phase factor
-    v(:)=vtcsymc(:,isym)
-    do igk=1,ngk(jspn,ik)
+    v(1:3)=vtcsymc(1:3,isym)
+    do igk=1,ngk_
       ig=igkig(igk,jspn,ik)
       t1=vgc(1,ig)*v(1)+vgc(2,ig)*v(2)+vgc(3,ig)*v(3)
       z1=cmplx(cos(t1),-sin(t1),8)
@@ -137,27 +138,25 @@ do jspn=1,nspnfv
     end do
   end if
 ! apply spatial rotation operation (passive transformation)
-  done(1:ngk(jspn,ik))=.false.
+  done(1:ngk_)=.false.
   i=1
-  do igk=1,ngk(jspn,ik)
+  do igk=1,ngk_
     call r3mtv(si,vgkl(:,igk,jspn,ik),v)
-    do igp=i,ngk(jspn,ik)
+    j=0
+    do igp=i,ngk_
       if (done(igp)) cycle
+      if (j == 0) j=igp
       t1=abs(v(1)-vgpl(1,igp,jspn)) &
         +abs(v(2)-vgpl(2,igp,jspn)) &
         +abs(v(3)-vgpl(3,igp,jspn))
       if (t1 < epslat) then
         evecfv(igp,1:nstfv,jspn)=evecfv_(igk,1:nstfv)
         done(igp)=.true.
+        if (igp == j) j=j+1
         exit
       end if
     end do
-    do igp=i,ngk(jspn,ik)
-      if (.not.done(igp)) then
-        i=igp
-        exit
-      end if
-    end do
+    if (j > 0) i=j
   end do
 end do
 !---------------------------------------------------------!
@@ -168,8 +167,9 @@ if (nlotot > 0) then
   call r3mtv(si,vkl(:,ik),v)
 ! loop over the first-variational spins
   do jspn=1,nspnfv
+    ngk_=ngk(jspn,ik)
 ! make a copy of the local-orbital coefficients
-    do i=ngk(jspn,ik)+1,nmat(jspn,ik)
+    do i=ngk_+1,nmat(jspn,ik)
       evecfv_(i,1:nstfv)=evecfv(i,1:nstfv,jspn)
     end do
     do is=1,nspecies
@@ -187,8 +187,8 @@ if (nlotot > 0) then
         do ilo=1,nlorb(is)
           l=lorbl(ilo,is)
           lm=l**2+1
-          i=ngk(jspn,ik)+idxlo(lm,ilo,ias)
-          j=ngk(jspn,ik)+idxlo(lm,ilo,jas)
+          i=ngk_+idxlo(lm,ilo,ias)
+          j=ngk_+idxlo(lm,ilo,jas)
           call rotzflm(symlatc(:,:,lspl),l,l,lolmmax,nstfv,nmatmax, &
            evecfv_(j,1),evecfv(i,1,jspn))
           evecfv(i:i+2*l,1:nstfv,jspn)=z1*evecfv(i:i+2*l,1:nstfv,jspn)
