@@ -28,12 +28,12 @@ complex(8), allocatable :: zfft1(:),zfft2(:)
 allocate(gvrho(ngtot,3),rfir(ngtot))
 allocate(zfft1(nfgrz),zfft2(nfgrz))
 call rzfftifc(3,ngridg,-1,rho,zfft1)
-! |grad rho|
+! |∇ρ|
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
@@ -41,7 +41,7 @@ do i=1,3
   call rzfftifc(3,ngridg,1,gvrho(:,i),zfft2)
 end do
 grho(:)=sqrt(gvrho(:,1)**2+gvrho(:,2)**2+gvrho(:,3)**2)
-! grad^2 rho
+! ∇²ρ
 do ifg=1,nfgrz
   ig=igrzf(ifg)
   if (ig <= ngvc) then
@@ -51,13 +51,13 @@ do ifg=1,nfgrz
   end if
 end do
 call rzfftifc(3,ngridg,1,g2rho,zfft2)
-! (grad rho).(grad |grad rho|)
+! (∇ρ)⋅(∇|∇ρ|)
 call rzfftifc(3,ngridg,-1,grho,zfft1)
 g3rho(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir,zfft2)
   g3rho(:)=g3rho(:)+gvrho(:,i)*rfir(:)
