@@ -27,7 +27,7 @@ complex(8), allocatable :: zfft1(:),zfft2(:)
 allocate(zfft1(nfgrz),zfft2(nfgrz))
 ! Fourier transform density to G-space
 call rzfftifc(3,ngridg,-1,rho,zfft1)
-! grad^2 rho
+! ∇²ρ
 do ifg=1,nfgrz
   ig=igrzf(ifg)
   if (ig <= ngvc) then
@@ -37,20 +37,20 @@ do ifg=1,nfgrz
   end if
 end do
 call rzfftifc(3,ngridg,1,g2rho,zfft2)
-! grad rho
+! ∇ρ
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
   end do
   call rzfftifc(3,ngridg,1,gvrho(:,i),zfft2)
 end do
-! (grad rho)^2
-grho2(:)=gvrho(:,1)**2+gvrho(:,2)**2+gvrho(:,3)**2
+! (∇ρ)²
+grho2(1:ngtot)=gvrho(1:ngtot,1)**2+gvrho(1:ngtot,2)**2+gvrho(1:ngtot,3)**2
 deallocate(zfft1,zfft2)
 end subroutine
 !EOC
