@@ -31,14 +31,14 @@ allocate(zfft1(nfgrz),zfft2(nfgrz))
 !------------------!
 !     exchange     !
 !------------------!
-! compute grad dxdgr2
+! compute ∇ dxdgr2
 call rzfftifc(3,ngridg,-1,dxdgr2,zfft1)
-! (grad dxdgr2).(grad rho)
+! (∇ dxdgr2)⋅(∇ρ)
 rfir1(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   rfir1(:)=rfir1(:)+rfir2(:)*gvrho(:,i)
@@ -47,14 +47,14 @@ vx(:)=vx(:)-2.d0*(rfir1(:)+dxdgr2(:)*g2rho(:))
 !---------------------!
 !     correlation     !
 !---------------------!
-! compute grad dcdgr2
+! compute ∇ dcdgr2
 call rzfftifc(3,ngridg,-1,dcdgr2,zfft1)
-! (grad dcdgr2).(grad rho)
+! (∇ dcdgr2)⋅(∇ρ)
 rfir1(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft2)
   rfir1(:)=rfir1(:)+rfir2(:)*gvrho(:,i)
