@@ -27,7 +27,7 @@ do i=1,3
   call rzfftifc(3,ngridg,-1,rfir2,zfft)
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft(ifg)=vgc(i,ig)*zi*zfft(ifg)
+    zfft(ifg)=vgc(i,ig)*cmplx(-zfft(ifg)%im,zfft(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft)
   vx(:)=vx(:)-2.d0*rfir2(:)
@@ -42,7 +42,7 @@ do i=1,3
   call rzfftifc(3,ngridg,-1,rfir2,zfft)
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft(ifg)=vgc(i,ig)*zi*zfft(ifg)
+    zfft(ifg)=vgc(i,ig)*cmplx(-zfft(ifg)%im,zfft(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir2,zfft)
   vc(:)=vc(:)-2.d0*rfir2(:)
