@@ -47,16 +47,16 @@ real(8), allocatable :: gvup(:,:),gvdn(:,:),rfir(:)
 complex(8), allocatable :: zfft1(:),zfft2(:)
 allocate(gvup(ngtot,3),gvdn(ngtot,3),rfir(ngtot))
 allocate(zfft1(nfgrz),zfft2(nfgrz))
-!----------------!
-!     rho up     !
-!----------------!
+!------------!
+!     ρ↑     !
+!------------!
 call rzfftifc(3,ngridg,-1,rhoup,zfft1)
-! |grad rhoup|
+! |∇ρ↑|
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
@@ -64,7 +64,7 @@ do i=1,3
   call rzfftifc(3,ngridg,1,gvup(:,i),zfft2)
 end do
 gup(:)=sqrt(gvup(:,1)**2+gvup(:,2)**2+gvup(:,3)**2)
-! grad^2 rhoup
+! ∇²ρ↑
 do ifg=1,nfgrz
   ig=igrzf(ifg)
   if (ig <= ngvc) then
@@ -74,27 +74,27 @@ do ifg=1,nfgrz
   end if
 end do
 call rzfftifc(3,ngridg,1,g2up,zfft2)
-! (grad rhoup).(grad |grad rhoup|)
+! (∇ρ↑)⋅(∇|∇ρ↑|)
 call rzfftifc(3,ngridg,-1,gup,zfft1)
 g3up(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir,zfft2)
   g3up(:)=g3up(:)+gvup(:,i)*rfir(:)
 end do
-!------------------!
-!     rho down     !
-!------------------!
+!------------!
+!     ρ↓     !
+!------------!
 call rzfftifc(3,ngridg,-1,rhodn,zfft1)
-! |grad rhodn|
+! |∇ρ↓|
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
@@ -102,7 +102,7 @@ do i=1,3
   call rzfftifc(3,ngridg,1,gvdn(:,i),zfft2)
 end do
 gdn(:)=sqrt(gvdn(:,1)**2+gvdn(:,2)**2+gvdn(:,3)**2)
-! grad^2 rhodn
+! ∇²ρ↓
 do ifg=1,nfgrz
   ig=igrzf(ifg)
   if (ig <= ngvc) then
@@ -112,31 +112,31 @@ do ifg=1,nfgrz
   end if
 end do
 call rzfftifc(3,ngridg,1,g2dn,zfft2)
-! (grad rhodn).(grad |grad rhodn|)
+! (∇ρ↓)⋅(∇|∇ρ↓|)
 call rzfftifc(3,ngridg,-1,gdn,zfft1)
 g3dn(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir,zfft2)
   g3dn(:)=g3dn(:)+gvdn(:,i)*rfir(:)
 end do
-!-------------!
-!     rho     !
-!-------------!
-! |grad rho|
+!-----------!
+!     ρ     !
+!-----------!
+! |∇ρ|
 grho(:)=sqrt((gvup(:,1)+gvdn(:,1))**2 &
             +(gvup(:,2)+gvdn(:,2))**2 &
             +(gvup(:,3)+gvdn(:,3))**2)
-! (grad rho).(grad |grad rho|)
+! (∇ρ)⋅(∇|∇ρ|)
 call rzfftifc(3,ngridg,-1,grho,zfft1)
 g3rho(:)=0.d0
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
-    zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
   end do
   call rzfftifc(3,ngridg,1,rfir,zfft2)
   g3rho(:)=g3rho(:)+(gvup(:,i)+gvdn(:,i))*rfir(:)
