@@ -32,11 +32,11 @@ integer ig,ifg,i
 ! allocatable arrays
 complex(8), allocatable :: zfft1(:),zfft2(:)
 allocate(zfft1(nfgrz),zfft2(nfgrz))
-!----------------!
-!     rho up     !
-!----------------!
+!------------!
+!     ρ↑     !
+!------------!
 call rzfftifc(3,ngridg,-1,rhoup,zfft1)
-! compute grad^2 rhoup
+! compute ∇²ρ↑
 do ifg=1,nfgrz
   ig=igrzf(ifg)
   if (ig <= ngvc) then
@@ -46,25 +46,25 @@ do ifg=1,nfgrz
   end if
 end do
 call rzfftifc(3,ngridg,1,g2up,zfft2)
-! grad rhoup
+! ∇ρ↑
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
   end do
   call rzfftifc(3,ngridg,1,gvup(:,i),zfft2)
 end do
-! (grad rhoup)^2
+! (∇ρ↑)²
 gup2(:)=gvup(:,1)**2+gvup(:,2)**2+gvup(:,3)**2
-!------------------!
-!     rho down     !
-!------------------!
+!------------!
+!     ρ↓     !
+!------------!
 call rzfftifc(3,ngridg,-1,rhodn,zfft1)
-! compute grad^2 rhodn
+! compute ∇²ρ↓
 do ifg=1,nfgrz
   ig=igrzf(ifg)
   if (ig <= ngvc) then
@@ -74,21 +74,21 @@ do ifg=1,nfgrz
   end if
 end do
 call rzfftifc(3,ngridg,1,g2dn,zfft2)
-! grad rhodn
+! ∇ρ↓
 do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvc) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
   end do
   call rzfftifc(3,ngridg,1,gvdn(:,i),zfft2)
 end do
-! (grad rhodn)^2
+! (∇ρ↓)²
 gdn2(:)=gvdn(:,1)**2+gvdn(:,2)**2+gvdn(:,3)**2
-! (grad rhoup).(grad rhodn)
+! (∇ρ↑)⋅(∇ρ↓)
 gupdn(:)=gvup(:,1)*gvdn(:,1)+gvup(:,2)*gvdn(:,2)+gvup(:,3)*gvdn(:,3)
 deallocate(zfft1,zfft2)
 end subroutine
