@@ -10,6 +10,7 @@ subroutine gndstate
 ! !USES:
 use modmain
 use moddftu
+use modxcifc
 use modulr
 use modgw
 use modmpi
@@ -106,14 +107,14 @@ end if
 if (mp_mpi) flush(60)
 call genvsig
 ! size of mixing vector
-nmix=size(vsbs)
+nmix=size(vmixer)
 ! determine the size of the mixer work array
 nwork=-1
-call mixerifc(mixtype,nmix,vsbs,dv,nwork,vsbs)
+call mixerifc(mixtype,nmix,vmixer,dv,nwork,vmixer)
 allocate(work(nwork))
 ! initialise the mixer
 iscl=0
-call mixerifc(mixtype,nmix,vsbs,dv,nwork,work)
+call mixerifc(mixtype,nmix,vmixer,dv,nwork,work)
 if (mixsave.and.trdstate) then
 ! read in starting loop and mixer work array from file if required
   call readmix(iscl0,nwork,work)
@@ -144,7 +145,7 @@ do iscl=iscl0,maxscl
     if (maxscl > 1) then
       write(*,*)
       write(*,'("Warning(gndstate): failed to reach self-consistency after ", &
-       &I4," loops")') iscl
+       &I0," loops")') iscl
     end if
     tlast=.true.
   end if
@@ -177,7 +178,7 @@ do iscl=iscl0,maxscl
 ! write eigenvalues to file
     call writeeval
 ! write the Fermi energy to file
-    call writefermi
+    call writeefm
   end if
 ! synchronise MPI processes
   call mpi_barrier(mpicom,ierror)
@@ -206,10 +207,12 @@ do iscl=iscl0,maxscl
       if (tmwrite) call writetm3
     end if
   end if
-! compute the Kohn-Sham potential and magnetic field
-  call potks(.true.)
-! mix the old effective potential and field with the new
-  call mixerifc(mixtype,nmix,vsbs,dv,nwork,work)
+! compute the Kohn-Sham potential and magnetic field before potential mixing
+  if (.not.mixrho) call potks(.true.)
+! mix the old density/magnetisation or potential/field with the new
+  call mixerifc(mixtype,nmix,vmixer,dv,nwork,work)
+! compute the Kohn-Sham potential and magnetic field after density mixing
+  if (mixrho) call potks(.true.)
 ! calculate and add the fixed spin moment effective field (after mixing)
   call bfieldfsm
   call addbfsm
@@ -239,7 +242,7 @@ do iscl=iscl0,maxscl
     write(60,'("Estimated direct band gap   : ",G18.10)') bandgap(2)
     write(60,'(" at k-point ",I6)') ikgap(3)
 ! write total energy to TOTENERGY.OUT
-    write(61,'(G22.12)') engytot
+    write(61,'(G24.14)') engytot
     flush(61)
 ! write DOS at Fermi energy to FERMIDOS.OUT
     write(62,'(G18.10)') fermidos
@@ -256,12 +259,17 @@ do iscl=iscl0,maxscl
       flush(68)
     end if
 ! write estimated Kohn-Sham indirect band gap
-    write(64,'(G22.12)') bandgap(1)
+    write(64,'(G24.14)') bandgap(1)
     flush(64)
 ! output effective fields for fixed spin moment calculations
     if (fsmtype /= 0) call writefsm(60)
 ! write the average electric field in each muffin-tin
     if (tefield) call writeefield(60)
+! write the Tran-Blaha functional constant
+    if (xctype(2) == XC_MGGA_X_TB09) then
+      write(60,*)
+      write(60,'("Tran-Blaha ''09 constant c : ",G18.10)') c_tb09
+    end if
 ! check for existence of the WRITE file
     call checkwrite(twrite)
 ! check self-consistent loop number modulo nwrite
