@@ -66,7 +66,7 @@ do iscl=1,maxscl
     write(str,'("Loop number : ",I0)') iscl
     call writebox(60,trim(str))
     flush(60)
-    write(*,'("Info(gndsteph): self-consistent loop number : ",I4)') iscl
+    write(*,'("Info(gndsteph): self-consistent loop number : ",I0)') iscl
   end if
   if (iscl >= maxscl) then
     if (mp_mpi) then
@@ -87,13 +87,13 @@ do iscl=1,maxscl
 ! write the phononic eigenvalues to file
     call writeevalwx
 ! write the Fermi energy to file
-    call writefermi
+    call writeefm
     write(60,*)
     write(60,'("Energies :")')
-    write(60,'(" Fermi",T30,": ",G22.12)') efermi
-    write(60,'(" electronic change",T30,": ",G22.12)') dengye
-    write(60,'(" phononic change",T30,": ",G22.12)') dengyph
-    write(60,'(" sum of changes",T30,": ",G22.12)') dengy
+    write(60,'(" Fermi",T30,": ",G24.14)') efermi
+    write(60,'(" electronic change",T30,": ",G24.14)') dengye
+    write(60,'(" phononic change",T30,": ",G24.14)') dengyph
+    write(60,'(" sum of changes",T30,": ",G24.14)') dengy
     write(60,*)
     write(60,'("Estimated indirect band gap : ",G18.10)') bandgap(1)
     write(60,'(" from k-point ",I6," to k-point ",I6)') ikgap(1),ikgap(2)
@@ -104,7 +104,7 @@ do iscl=1,maxscl
     write(60,*)
     write(60,'("Electron-phonon scaling factor : ",G18.10)') ephscf(1)
 ! write estimated indirect band gap
-    write(64,'(G22.12)') bandgap(1)
+    write(64,'(G24.14)') bandgap(1)
     flush(64)
 ! write the fermionic anomalous correlation entropy
     write(67,'(G18.10)') face
