@@ -38,14 +38,14 @@ reducek=0
 ! initialise global variables
 call init0
 call init1
-! write the kappa-points to file
+! write the κ-points to file
 call writekpa
-! write the k+kappa-points to file
+! write the k+κ-points to file
 call writekpts
 ! read the regular Kohn-Sham potential from file
 call readstate
 ! generate the first- and second-variational eigenvectors and eigenvalues for
-! the k+kappa-point set
+! the k+κ-point set
 call genvsig
 call gencore
 call linengy
@@ -64,6 +64,8 @@ else
 end if
 ! initialise the external Coulomb potential
 call vclqinit
+! initialise the external magnetic field if required
+if (spinpol) call bfcqinit
 ! size of mixing vector (complex array)
 nmix=2*size(vsbsq)
 ! determine the size of the mixer work array
@@ -100,7 +102,7 @@ do iscl=1,maxscl
       write(60,'("Reached self-consistent loops maximum")')
     end if
     write(*,*)
-    write(*,'("Warning(gndstulr): failed to reach self-consistency after ",I4,&
+    write(*,'("Warning(gndstulr): failed to reach self-consistency after ",I0,&
      &" loops")') iscl
     tlast=.true.
   end if
@@ -109,12 +111,7 @@ do iscl=1,maxscl
 ! apply required local operations to the potential and magnetic field
   call vblocalu
 ! zero the density and magnetisation
-  rhormt(:,:,:)=0.d0
-  rhorir(:,:)=0.d0
-  if (spinpol) then
-    magrmt(:,:,:,:)=0.d0
-    magrir(:,:,:)=0.d0
-  end if
+  rhmgr(:)=0.d0
 ! loop over original k-points
   call holdthd(nkpt0/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
@@ -143,20 +140,9 @@ do iscl=1,maxscl
       call mpi_bcast(evalu(:,ik0),nstulr,mpi_double_precision,lp,mpicom,ierror)
     end do
 ! add densities from each process and redistribute
-    n=npcmtmax*natmtot*nqpt
-    call mpi_allreduce(mpi_in_place,rhormt,n,mpi_double_precision,mpi_sum, &
+    n=size(rhmgr)
+    call mpi_allreduce(mpi_in_place,rhmgr,n,mpi_double_precision,mpi_sum, &
      mpicom,ierror)
-    n=ngtc*nqpt
-    call mpi_allreduce(mpi_in_place,rhorir,n,mpi_double_precision,mpi_sum, &
-     mpicom,ierror)
-    if (spinpol) then
-      n=npcmtmax*natmtot*ndmag*nqpt
-      call mpi_allreduce(mpi_in_place,magrmt,n,mpi_double_precision,mpi_sum, &
-       mpicom,ierror)
-      n=ngtc*ndmag*nqpt
-      call mpi_allreduce(mpi_in_place,magrir,n,mpi_double_precision,mpi_sum, &
-       mpicom,ierror)
-    end if
   end if
 ! find the occupation numbers and Fermi energy
   call occupyulr
@@ -178,6 +164,8 @@ do iscl=1,maxscl
 ! calculate and add the fixed spin moment effective field (after mixing)
   call bfieldfsm
   call addbfsmu
+! compute the energy components
+  call energyulr
   if (mp_mpi) then
 ! write eigenvalues to file
     call writeevalu
