@@ -37,7 +37,7 @@ do i=1,3
   do ifg=1,nfgrz
     ig=igrzf(ifg)
     if (ig <= ngvec) then
-      zfft2(ifg)=vgc(i,ig)*zi*zfft1(ifg)
+      zfft2(ifg)=vgc(i,ig)*cmplx(-zfft1(ifg)%im,zfft1(ifg)%re,8)
     else
       zfft2(ifg)=0.d0
     end if
