@@ -38,8 +38,9 @@ integer, intent(in) :: ld
 real(8), intent(out) :: grfmt(ld,3)
 ! local variables
 integer i
-! automatic arrays
-complex(8) zfmt(ld),gzfmt(ld,3)
+! allocatable arrays
+complex(8), allocatable :: zfmt(:),gzfmt(:,:)
+allocate(zfmt(ld),gzfmt(ld,3))
 ! convert real to complex spherical harmonic expansion
 call rtozfmt(nr,nri,rfmt,zfmt)
 ! compute the gradient
@@ -50,6 +51,7 @@ do i=1,3
 ! improve stability by smoothing the gradient
   call rfmtsm(msmgmt,nr,nri,grfmt(:,i))
 end do
+deallocate(zfmt,gzfmt)
 end subroutine
 !EOC
 
