@@ -20,8 +20,7 @@ integer idx(nstsv)
 complex(8) gwfmt(npcmtmax,3),zfmt(npcmtmax)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:),evecsv(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
-complex(8), allocatable :: zfft(:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:),zfft(:)
 ! find the matching coefficients
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
@@ -43,7 +42,7 @@ end do
 allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfgk(ngkmax,nspinor,nst))
 call genwfsv(.true.,.true.,nst,idx,ngdgc,igfc,ngk(:,ik),igkig(:,:,ik),apwalm, &
  evecfv,evecsv,wfmt,ngkmax,wfgk)
-deallocate(apwalm)
+deallocate(apwalm,evecfv,evecsv)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
@@ -87,7 +86,7 @@ do ist=1,nst
       do igk=1,ngk(jspn,ik)
         ifg=igfc(igkig(igk,jspn,ik))
         z1=wfgk(igk,ispn,ist)
-        zfft(ifg)=vgkc(i,igk,jspn,ik)*zi*z1
+        zfft(ifg)=vgkc(i,igk,jspn,ik)*cmplx(-z1%im,z1%re,8)
       end do
       call zfftifc(3,ngdgc,1,zfft)
       gwf2ir(1:ngtc)=gwf2ir(1:ngtc) &
