@@ -36,7 +36,7 @@ call zfftifc(3,ngridg,-1,zfft)
 do i=1,3
   do ig=1,ngvec
     ifg=igfft(ig)
-    gzfir(ifg,i)=vgc(i,ig)*zi*zfft(ifg)
+    gzfir(ifg,i)=vgc(i,ig)*cmplx(-zfft(ifg)%im,zfft(ifg)%re,8)
   end do
   gzfir(igfft(ngvec+1:ngtot),i)=0.d0
   call zfftifc(3,ngridg,1,gzfir(:,i))
