@@ -201,7 +201,8 @@ do ir=1,nri
     i=i+1
     z1=gzfmt(i,1)
     gzfmt(i,1)=c1*(z1-gzfmt(i,2))
-    gzfmt(i,2)=c1*(z1+gzfmt(i,2))*zmi
+    z1=c1*(z1+gzfmt(i,2))
+    gzfmt(i,2)=cmplx(z1%im,-z1%re,8)
   end do
 end do
 do ir=iro,nr
@@ -209,7 +210,8 @@ do ir=iro,nr
     i=i+1
     z1=gzfmt(i,1)
     gzfmt(i,1)=c1*(z1-gzfmt(i,2))
-    gzfmt(i,2)=c1*(z1+gzfmt(i,2))*zmi
+    z1=c1*(z1+gzfmt(i,2))
+    gzfmt(i,2)=cmplx(z1%im,-z1%re,8)
   end do
 end do
 end subroutine
