@@ -12,8 +12,7 @@ implicit none
 ! local variables
 integer ik,lp,nthd
 ! allocatable arrays
-real(8), allocatable :: vmt(:,:),vir(:)
-real(8), allocatable :: bmt(:,:,:),bir(:,:)
+real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:),bir(:,:)
 complex(8), allocatable :: se(:,:,:)
 ! generate the momentum matrix elements
 call genpmat
@@ -23,6 +22,8 @@ call epsinv
 allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (spinpol) then
   allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
+else
+  allocate(bmt(1,1,1),bir(1,1))
 end if
 call gwlocal(vmt,vir,bmt,bir)
 ! synchronise MPI processes
@@ -39,7 +40,7 @@ do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(gwrhomag_)
-  write(*,'("Info(gwrhomag): ",I6," of ",I6," k-points")') ik,nkpt
+  write(*,'("Info(gwrhomag): ",I0," of ",I0," k-points")') ik,nkpt
 !$OMP END CRITICAL(gwrhomag_)
 ! determine the self-energy at the fermionic frequencies for current k-point
   call gwsefmk(ik,vmt,vir,bmt,bir,se)
@@ -50,8 +51,7 @@ end do
 deallocate(se)
 !$OMP END PARALLEL
 call freethd(nthd)
-deallocate(vmt,vir)
-if (spinpol) deallocate(bmt,bir)
+deallocate(vmt,vir,bmt,bir)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 ! determine the GW Fermi energy
