@@ -12,8 +12,7 @@ implicit none
 ! local variables
 integer ik,nthd
 ! allocatable arrays
-real(8), allocatable :: vmt(:,:),vir(:)
-real(8), allocatable :: bmt(:,:,:),bir(:,:)
+real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:),bir(:,:)
 complex(8), allocatable :: se(:,:,:)
 ! initialise universal variables
 call init0
@@ -37,12 +36,14 @@ do ik=1,nkpt
 end do
 ! write the momentum matrix elements in the second-variational basis to file
 call genpmat
-! generate the inverse dielectric function and write to file
-call epsinv
+! generate the inverse dielectric function and write to file if required
+if (task /= 601) call epsinv
 ! compute the matrix elements of -V_xc and -B_xc
 allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (spinpol) then
   allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
+else
+  allocate(bmt(1,1,1),bir(1,1))
 end if
 call gwlocal(vmt,vir,bmt,bir)
 if (mp_mpi) write(*,*)
@@ -59,7 +60,7 @@ do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(gwsefm_)
-  write(*,'("Info(gwsefm): ",I6," of ",I6," k-points")') ik,nkpt
+  write(*,'("Info(gwsefm): ",I0," of ",I0," k-points")') ik,nkpt
 !$OMP END CRITICAL(gwsefm_)
 ! determine the self-energy at the fermionic frequencies for current k-point
   call gwsefmk(ik,vmt,vir,bmt,bir,se)
@@ -75,7 +76,6 @@ if (mp_mpi) then
   write(*,'("Info(gwsefm): GW self-energy at the fermionic frequencies &
    &written to GWSEFM.OUT")')
 end if
-deallocate(vmt,vir)
-if (spinpol) deallocate(bmt,bir)
+deallocate(vmt,vir,bmt,bir)
 end subroutine
 
