@@ -12,7 +12,7 @@ use modtest
 implicit none
 ! local variables
 integer ik,iw,nthd
-real(8) dw,w
+real(8) dw
 ! allocatable arrays
 real(8), allocatable :: wr(:),sft(:),sf(:)
 complex(8), allocatable :: se(:,:,:)
@@ -22,7 +22,7 @@ call init1
 call init2
 call init3
 ! read Fermi energy from file
-call readfermi
+call readefm
 ! get the eigenvalues and occupation numbers from file
 do ik=1,nkpt
   call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
@@ -51,7 +51,7 @@ do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(gwspecf_1)
-  write(*,'("Info(gwspecf): ",I6," of ",I6," k-points")') ik,nkpt
+  write(*,'("Info(gwspecf): ",I0," of ",I0," k-points")') ik,nkpt
 !$OMP END CRITICAL(gwspecf_1)
 ! get the self-energy at the fermionic frequencies from file
   call getgwsefm(ik,se)
@@ -59,7 +59,7 @@ do ik=1,nkpt
   call dysonr(ik,wr,se,sf)
 ! write the spectral function to file
 !$OMP CRITICAL(gwspecf_2)
-  call writegwsf(ik,sf)
+  call writegwsf(ik,wr,sf)
 !$OMP END CRITICAL(gwspecf_2)
 ! add to the total spectral function
 !$OMP CRITICAL(gwspecf_3)
@@ -78,10 +78,8 @@ end if
 ! write the total spectral function to file (MPI master process only)
 if (mp_mpi) then
   open(50,file='GWTSF.OUT',form='FORMATTED')
-  dw=(wplot(2)-wplot(1))/dble(nwplot)
   do iw=1,nwplot
-    w=dw*dble(iw-1)+wplot(1)
-    write(50,'(2G18.10)') w,sft(iw)
+    write(50,'(2G18.10)') wr(iw),sft(iw)
   end do
   close(50)
   write(*,*)
