@@ -53,7 +53,7 @@ d3=d2*t3
 d4=d3*t3
 ! determine the coefficients a1, a2 and a4
 a1=(d3*(ge(2)-ge(3))+c3*(ge(4)-ge(1)))*t1*t2
-a1=zi*a1
+a1=cmplx(-a1%im,a1%re,8)
 z1=ge(2)+ge(3)
 z2=ge(1)+ge(4)
 t3=t1**2
