@@ -13,8 +13,7 @@ integer ik,lp,nthd
 real(8) etp,de
 character(64) str
 ! allocatable arrays
-real(8), allocatable :: vmt(:,:),vir(:)
-real(8), allocatable :: bmt(:,:,:),bir(:,:)
+real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:),bir(:,:)
 complex(8), allocatable :: evecsv(:,:)
 ! initialise universal variables
 call init0
@@ -42,6 +41,8 @@ call genkmat(.true.,.true.)
 allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (hybrid.and.spinpol) then
   allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
+else
+  allocate(bmt(1,1,1),bir(1,1))
 end if
 ! only the MPI master process should write files
 if (mp_mpi) then
@@ -74,7 +75,7 @@ do iscl=1,maxscl
     write(str,'("Loop number : ",I0)') iscl
     call writebox(60,trim(str))
     flush(60)
-    write(*,'("Info(hartfock): self-consistent loop number : ",I4)') iscl
+    write(*,'("Info(hartfock): self-consistent loop number : ",I0)') iscl
   end if
   if (iscl >= maxscl) then
     if (mp_mpi) then
@@ -126,7 +127,7 @@ do iscl=1,maxscl
 ! write out the eigenvalues and occupation numbers
     call writeeval
 ! write the Fermi energy to file
-    call writefermi
+    call writeefm
   end if
 ! generate the density and magnetisation
   call rhomag
@@ -144,7 +145,7 @@ do iscl=1,maxscl
     write(60,'("Estimated direct band gap   : ",G18.10)') bandgap(2)
     write(60,'(" at k-point ",I6)') ikgap(3)
 ! write total energy to TOTENERGY.OUT
-    write(61,'(G22.12)') engytot
+    write(61,'(G24.14)') engytot
     flush(61)
 ! write DOS at Fermi energy to FERMIDOS.OUT
     write(62,'(G18.10)') fermidos
@@ -161,7 +162,7 @@ do iscl=1,maxscl
       flush(68)
     end if
 ! write estimated Hartree-Fock indirect band gap
-    write(64,'(G22.12)') bandgap(1)
+    write(64,'(G24.14)') bandgap(1)
     flush(64)
   end if
   if (tlast) goto 10
@@ -225,7 +226,6 @@ if (mp_mpi) then
 ! close the DTOTENERGY.OUT file
   close(66)
 end if
-deallocate(vmt,vir)
-if (hybrid.and.spinpol) deallocate(bmt,bir)
+deallocate(vmt,vir,bmt,bir)
 end subroutine
 
