@@ -34,7 +34,7 @@ do l1=0,lmaxapw
               lma=l2**2+1; lmb=lma+2*l2
               z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*haa(lma:lmb,jo,l3,io,l1,ias))
             end do
-            if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
+            if (abs(z1%re)+abs(z1%im) > 1.d-12) then
               call zaxpy(ngp,z1,apwalm(:,jo,lm3),1,y,1)
             end if
           end do
@@ -45,6 +45,6 @@ do l1=0,lmaxapw
     end do
   end do
 end do
-call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,hq)
+call zmctm(lmoapw(is),ngpq,ngp,a,b,ld,hq)
 end subroutine
 
