@@ -30,7 +30,7 @@ do ilo=1,nlorb(is)
             z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*hloa(lma:lmb,io,l3,ilo,ias))
           end do
 ! note that what is actually computed is the Hermitian conjugate of <lo|H|APW>
-          if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
+          if (abs(z1%re)+abs(z1%im) > 1.d-12) then
             h(1:ngp,j)=h(1:ngp,j)+conjg(z1*apwalm(1:ngp,io,lm3))
           end if
         end do
