@@ -35,7 +35,7 @@ integer, intent(in) :: ld
 complex(8), intent(out) :: h(ld,*)
 ! local variables
 integer j1,j2,j3,ig,i,j
-real(8) v1,v2,v3,t1
+real(8) v1,v2,v3
 do j=1,ngp
   ig=igpig(j)
   j1=ivg(1,ig); j2=ivg(2,ig); j3=ivg(3,ig)
@@ -43,8 +43,7 @@ do j=1,ngp
   do i=1,j
     ig=igpig(i)
     ig=ivgig(ivg(1,ig)-j1,ivg(2,ig)-j2,ivg(3,ig)-j3)
-    t1=vgpc(1,i)*v1+vgpc(2,i)*v2+vgpc(3,i)*v3
-    h(i,j)=vsig(ig)+t1*cfunig(ig)
+    h(i,j)=vsig(ig)+(vgpc(1,i)*v1+vgpc(2,i)*v2+vgpc(3,i)*v3)*cfunig(ig)
   end do
 end do
 end subroutine
