@@ -18,7 +18,7 @@ do jlo=1,nlorb(is)
   l3=lorbl(jlo,is)
   do lm3=l3**2+1,(l3+1)**2
     j=ngp+idxlo(lm3,jlo,ias)
-    do ilo=1,nlorb(is)
+    do ilo=1,jlo
       l1=lorbl(ilo,is)
       if (mod(l1+l3,2) == 0) then; l0=0; else; l0=1; end if
       do lm1=l1**2+1,(l1+1)**2
