@@ -30,8 +30,8 @@ use modomp
 implicit none
 ! local variables
 logical hybrid_
-integer is,ia,ias,idu
-integer ist,nr,l,n,i
+integer is,ia,ias,npc
+integer idu,ist,nr,l,n,i
 integer xcspin_
 real(8) hybridc_,t1
 real(8) ts0,ts1
@@ -53,7 +53,7 @@ call timesec(ts0)
 !------------------------------------!
 if (lmaxo > lmaxapw) then
   write(*,*)
-  write(*,'("Error(init0): lmaxo > lmaxapw : ",2I8)') lmaxo,lmaxapw
+  write(*,'("Error(init0): lmaxo > lmaxapw :",2(X,I0))') lmaxo,lmaxapw
   write(*,*)
   stop
 end if
@@ -61,13 +61,15 @@ lmaxi=min(lmaxi,lmaxo)
 lmmaxapw=(lmaxapw+1)**2
 lmmaxi=(lmaxi+1)**2
 lmmaxo=(lmaxo+1)**2
-! check DOS lmax is within range
-lmaxdos=min(lmaxdos,lmaxo)
+! check DOS and band structure angular momentum maximum is within range
+lmaxdb=min(lmaxdb,lmaxo)
+lmmaxdb=(lmaxdb+1)**2
 ! write to VARIABLES.OUT
 if (wrtvars) then
   call writevars('lmaxapw',iv=lmaxapw)
   call writevars('lmaxi',iv=lmaxi)
   call writevars('lmaxo',iv=lmaxo)
+  call writevars('lmaxdb',iv=lmaxdb)
 end if
 
 !------------------------------------!
@@ -106,7 +108,7 @@ if (spinsprl) then
   spinorb=.false.
   if (any(task == [5,51,52,53,61,62,63,700,701])) then
     write(*,*)
-    write(*,'("Error(init0): spin-spirals do not work with task ",I4)') task
+    write(*,'("Error(init0): spin-spirals do not work with task ",I0)') task
     write(*,*)
     stop
   end if
@@ -126,9 +128,9 @@ if (spinsprl) then
 end if
 ! de-phasing required only for spin-spirals
 if (.not.spinsprl) ssdph=.false.
-! spin-orbit coupling, fixed spin moment, spin spirals or spin-polarised cores
-! requires a spin-polarised calculation
-if ((spinorb).or.(fsmtype /= 0).or.(spinsprl).or.(spincore)) spinpol=.true.
+! spin-orbit coupling, B-field-orbit coupling, fixed spin moment, spin spirals
+! or spin-polarised cores requires a spin-polarised calculation
+if (spinorb.or.bforb.or.(fsmtype /= 0).or.spinsprl.or.spincore) spinpol=.true.
 ! number of spinor components and maximum allowed occupancy
 if (spinpol) then
   nspinor=2
@@ -153,7 +155,7 @@ tevecsv=.false.
 ! spin-polarised calculations require second-variational eigenvectors
 if (spinpol) tevecsv=.true.
 ! Hartree-Fock/RDMFT/TDDFT/GW/ULR requires second-variational eigenvectors
-if (any(task == [5,10,170,300,460,461,462,463,600,620,700,701,720]).or. &
+if (any(task == [5,10,170,300,460,461,462,463,600,601,620,700,701,720,725]).or.&
  ksgwrho) then
   tevecsv=.true.
 end if
@@ -187,7 +189,7 @@ if (spinpol) then
 ! spin-orbit coupling is non-collinear in general
   if (spinorb) ndmag=3
 ! source-free fields and spin-spirals must be non-collinear
-  if ((nosource).or.(spinsprl)) then
+  if (nosource.or.spinsprl) then
     ndmag=3
     cmagz=.false.
   end if
@@ -199,7 +201,7 @@ end if
 ! set the non-collinear flag
 ncmag=(ndmag == 3)
 ! check for meta-GGA with non-collinearity
-if (any(xcgrad == [3,4,5]).and.ncmag) then
+if (any(xcgrad == [3,4,5,6]).and.ncmag) then
   write(*,*)
   write(*,'("Error(init0): meta-GGA is not valid for non-collinear magnetism")')
   write(*,*)
@@ -221,10 +223,12 @@ if (fsmtype /= 0) then
   if (allocated(bfsmcmt)) deallocate(bfsmcmt)
   allocate(bfsmcmt(3,natmtot))
   bfsmcmt(:,:)=0.d0
-  if (mp_mpi.and.(mixtype /= 1)) then
-    write(*,'("Info(init0): mixtype changed to 1 for FSM calculation")')
+  if (mixtype > 1) then
+    mixtype=1
+    if (mp_mpi) then
+      write(*,'("Info(init0): mixtype changed to 1 for FSM calculation")')
+    end if
   end if
-  mixtype=1
 end if
 ! number of independent spin components of the f_xc spin tensor
 if (spinpol) then
@@ -239,14 +243,6 @@ end if
 ! set the magnetic fields to the initial values
 bfieldc(:)=bfieldc0(:)
 bfcmt(:,:,:)=bfcmt0(:,:,:)
-! if reducebf < 1 then reduce the external magnetic fields immediately for
-! non-self-consistent calculations or resumptions
-if (reducebf < 1.d0-1.d-4) then
-  if (all(task /= [0,1,2,3,5,28,200,201,350,351])) then
-    bfieldc(:)=0.d0
-    bfcmt(:,:,:)=0.d0
-  end if
-end if
 if (tmwrite.or.(ftmtype /= 0).or.(task == 400)) then
   if (.not.spinorb) then
     write(*,*)
@@ -259,6 +255,15 @@ if (tmwrite.or.(ftmtype /= 0).or.(task == 400)) then
 end if
 ! generate the fixed tensor moment density matrices if required
 if (ftmtype /= 0) call gendmftm
+! if reducebf < 1 then reduce the external magnetic fields and tensor moments
+! immediately for non-self-consistent calculations
+if (reducebf < 1.d0-1.d-4) then
+  if (all(task /= [0,1,2,3,28,200,201,208,350,351,380,420,421,440])) then
+    bfieldc(:)=0.d0
+    bfcmt(:,:,:)=0.d0
+    if (ftmtype < 0) dmftm(:,:,:,:,:)=0.d0
+  end if
+end if
 ! write to VARIABLES.OUT
 if (wrtvars) then
   call writevars('nspinor',iv=nspinor)
@@ -312,7 +317,7 @@ if (any(abs(efieldc(:)) > epslat)) then
 ! electric field vector in lattice coordinates
   call r3mv(ainv,efieldc,efieldl)
 ! potential at maximum distance
-  vmaxefc=dmaxefc*norm2(efieldc(:))
+  vmaxefc=dmaxefc*norm2(efieldc(1:3))
 ! allocate array for average electric field in each muffin-tin
   if (allocated(efcmt)) deallocate(efcmt)
   allocate(efcmt(3,natmtot))
@@ -381,6 +386,18 @@ do is=1,nspecies
   npcmt(is)=npcmti(is)+lmmaxo*(nrcmt(is)-nrcmti(is))
   npcmtmax=max(npcmtmax,npcmt(is))
 end do
+! index to first muffin-tin point in packed array over all atoms
+if (allocated(ipcmt)) deallocate(ipcmt)
+allocate(ipcmt(natmtot))
+ipcmt(1)=1
+npc=npcmt(1)
+npcmttot=npc
+do ias=2,natmtot
+  is=idxis(ias)
+  ipcmt(ias)=ipcmt(ias)+npc
+  npc=npcmt(is)
+  npcmttot=npcmttot+npc
+end do
 
 !--------------------------------------!
 !     charges and number of states     !
@@ -457,7 +474,7 @@ case(1:)
     gkmax=rgkmax/rmt(isgkmax)
   else
     write(*,*)
-    write(*,'("Error(init0): isgkmax > nspecies : ",2I8)') isgkmax,nspecies
+    write(*,'("Error(init0): isgkmax > nspecies :",2(X,I0))') isgkmax,nspecies
     write(*,*)
     stop
   end if
@@ -561,19 +578,21 @@ allocate(rhocr(nrmtmax,natmtot,nspncr))
 !-------------------------------------------------------------!
 !     charge density, potentials and exchange-correlation     !
 !-------------------------------------------------------------!
-! allocate charge density arrays
-if (allocated(rhomt)) deallocate(rhomt)
-allocate(rhomt(npmtmax,natmtot))
-if (allocated(rhoir)) deallocate(rhoir)
-allocate(rhoir(ngtot))
-! allocate magnetisation arrays
-if (allocated(magmt)) deallocate(magmt)
-if (allocated(magir)) deallocate(magir)
+! combined target array for density and magnetisation
+if (allocated(rhmg)) deallocate(rhmg)
+n=npmtmax*natmtot+ngtot
+if (spinpol) n=n*(1+ndmag)
+allocate(rhmg(n))
+! associate pointer arrays with target
+rhomt(1:npmtmax,1:natmtot) => rhmg(1:)
+i=size(rhomt)+1
+rhoir(1:ngtot) => rhmg(i:)
 if (spinpol) then
-  allocate(magmt(npmtmax,natmtot,ndmag))
-  allocate(magir(ngtot,ndmag))
+  i=i+size(rhoir)
+  magmt(1:npmtmax,1:natmtot,1:ndmag) => rhmg(i:)
+  i=i+size(magmt)
+  magir(1:ngtot,1:ndmag) => rhmg(i:)
 end if
-! check if the current density j(r) should be calculated
 if (any(task == [371,372,373]).or.tafield.or.tdjr1d.or.tdjr2d.or.tdjr3d) then
   tjr=.true.
 end if
@@ -608,25 +627,28 @@ if (allocated(bxcmt)) deallocate(bxcmt)
 if (allocated(bxcir)) deallocate(bxcir)
 if (allocated(bdmt)) deallocate(bdmt)
 if (allocated(bdir)) deallocate(bdir)
+if (allocated(bdmta)) deallocate(bdmta)
 if (spinpol) then
   allocate(bxcmt(npmtmax,natmtot,ndmag),bxcir(ngtot,ndmag))
-  if (tbdip) allocate(bdmt(npmtmax,natmtot,ndmag),bdir(ngtot,ndmag))
+  if (tbdip) then
+    allocate(bdmt(npmtmax,natmtot,ndmag),bdir(ngtot,ndmag))
+    allocate(bdmta(ndmag,natmtot))
+    bdmta(1:ndmag,1:natmtot)=0.d0
+  end if
 end if
 ! combined target array for Kohn-Sham potential and magnetic field
 if (allocated(vsbs)) deallocate(vsbs)
 n=npmtmax*natmtot+ngtc
 if (spinpol) n=n+(npcmtmax*natmtot+ngtc)*ndmag
 allocate(vsbs(n))
-! zero the array
-vsbs(1:n)=0.d0
 ! associate pointer arrays with target
 vsmt(1:npmtmax,1:natmtot) => vsbs(1:)
-i=npmtmax*natmtot+1
+i=size(vsmt)+1
 vsirc(1:ngtc) => vsbs(i:)
 if (spinpol) then
-  i=i+ngtc
+  i=i+size(vsirc)
   bsmt(1:npcmtmax,1:natmtot,1:ndmag) => vsbs(i:)
-  i=i+npcmtmax*natmtot*ndmag
+  i=i+size(bsmt)
   bsirc(1:ngtc,1:ndmag) => vsbs(i:)
 ! allocate the Kohn-Sham magnetic field on the intersitial grid
   if (allocated(bsir)) deallocate(bsir)
@@ -644,7 +666,7 @@ if (allocated(tauir)) deallocate(tauir)
 if (allocated(taucr)) deallocate(taucr)
 if (allocated(wxcmt)) deallocate(wxcmt)
 if (allocated(wxcir)) deallocate(wxcir)
-if (any(xcgrad == [3,4,5])) then
+if (any(xcgrad == [3,4,5,6])) then
   allocate(taumt(npmtmax,natmtot,nspinor),tauir(ngtot,nspinor))
   allocate(taucr(npmtmax,natmtot,nspinor))
   allocate(wxcmt(npmtmax,natmtot),wxcir(ngtot))
@@ -677,6 +699,14 @@ if (ssdph) then
     zqss(ias)=cmplx(cos(t1),sin(t1),8)
   end do
 end if
+! mixing vector: either density/magnetisation or potential/magnetic field
+if (mixrho) then
+  vmixer => rhmg
+else
+  vmixer => vsbs
+end if
+! zero the mixing vector
+vmixer(:)=0.d0
 
 !-------------------------!
 !     force variables     !
@@ -717,9 +747,9 @@ if ((dftu /= 0).or.(ftmtype /= 0)) then
   tevecsv=.true.
 end if
 if (dftu /= 0) then
-  if (any(task == [5,300,600,610,620,640])) then
+  if (any(task == [5,300,600,601,610,620,630,640])) then
     write(*,*)
-    write(*,'("Error(init0): DFT+U does not work with task ",I8)') task
+    write(*,'("Error(init0): DFT+U does not work with task ",I0)') task
     write(*,*)
     stop
   end if
@@ -731,7 +761,7 @@ if (dftu /= 0) then
     is=isldu(1,idu)
     if (is > nspecies) then
       write(*,*)
-      write(*,'("Error(init0): invalid species number : ",I8)') is
+      write(*,'("Error(init0): invalid species number : ",I0)') is
       write(*,*)
       stop
     end if
