@@ -74,7 +74,7 @@ else
     end if
   end do
 end if
-if (any(task == [20,21,22,23,720])) then
+if (any(task == [20,21,22,23,24,720,725])) then
 ! generate k-points along a path for band structure plots
   call plotpt1d(bvec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
   nkpt=npp1d
@@ -163,10 +163,10 @@ else
     call writevars('wkpt',nv=nkpt,rva=wkpt)
   end if
 end if
-if (any(task == [700,701,710,720,731,732,733,741,742,743,771,772,773])) then
+if (any(task == [700,701,710,720,725,731,732,733,741,742,743,771,772,773])) then
 ! generate ultracell reciprocal lattice vectors if required
   call reciplat(avecu,bvecu,omegau,omegabzu)
-! generate the kappa, k+kappa and Q-points if required
+! generate the κ, k+κ and Q-points if required
   call genkpakq
 end if
 ! write the k-points to test file
@@ -175,7 +175,7 @@ call writetest(910,'k-points (Cartesian)',nv=3*nkpt,tol=1.d-8,rva=vkc)
 !---------------------!
 !     G+k-vectors     !
 !---------------------!
-if ((xctype(1) < 0).or.tddos.or.any(task == [5,10,205,300,600,620]).or. &
+if ((xctype(1) < 0).or.tddos.or.any(task == [5,10,205,300,600,601,620]).or. &
  ksgwrho) then
   nppt=nkptnr
 else
@@ -234,7 +234,6 @@ end if
 !---------------------------------!
 apwordmax=0
 lorbordmax=0
-nlomax=0
 lolmax=0
 do is=1,nspecies
   lmoapw(is)=0
@@ -245,8 +244,6 @@ do is=1,nspecies
     lmoapw(is)=lmoapw(is)+(2*l1+1)*apword(l1,is)
     if (l1 == lmaxo) nlmwf(is)=lmoapw(is)
   end do
-! find the maximum number of local-orbitals
-  nlomax=max(nlomax,nlorb(is))
 ! find the maximum local-orbital order and angular momentum
   n=0
   do ilo=1,nlorb(is)
@@ -286,6 +283,17 @@ if (allocated(apwdfr)) deallocate(apwdfr)
 allocate(apwdfr(apwordmax,0:lmaxapw,natmtot))
 if (allocated(lofr)) deallocate(lofr)
 allocate(lofr(nrmtmax,2,nlomax,natmtot))
+! store single-precision radial functions if required
+if (any(task == [5,180,185,240,241,300,320,330,331,460,461,462,463,478,600,601,&
+ 620,680,700,701,720,725]).or.(xctype(1) < 0).or.ksgwrho) then
+  if (allocated(apwfr_sp)) deallocate(apwfr_sp)
+  allocate(apwfr_sp(nrcmtmax,apwordmax,0:lmaxapw,natmtot))
+  if (allocated(lofr_sp)) deallocate(lofr_sp)
+  allocate(lofr_sp(nrcmtmax,nlomax,natmtot))
+  tfr_sp=.true.
+else
+  tfr_sp=.false.
+end if
 
 !-------------------------!
 !     DFT+U variables     !
