@@ -45,7 +45,7 @@ if (any(task == [320,330,331])) then
   if ((fxctype(1) == 210).or.(fxctype(1) == 211)) then
     wrf(1)=cmplx(0.d0,swidth,8)
   end if
-else if (any(task == [600,610,620,640]).or.ksgwrho) then
+else if (any(task == [600,601,610,620,630,640]).or.ksgwrho) then
 ! GW Matsubara frequencies
   call genwgw
 else
