@@ -121,15 +121,18 @@ end if
 !     phonon density functional perturbation theory variables     !
 !-----------------------------------------------------------------!
 if (task == 205) then
-  if (allocated(drhomt)) deallocate(drhomt)
-  allocate(drhomt(npmtmax,natmtot+1))
-  if (allocated(drhoir)) deallocate(drhoir)
-  allocate(drhoir(ngtot))
-  if (allocated(dmagmt)) deallocate(dmagmt)
-  if (allocated(dmagir)) deallocate(dmagir)
+  if (allocated(drhmg)) deallocate(drhmg)
+  n=npmtmax*(natmtot+1)+ngtot
+  if (spinpol) n=n*(1+ndmag)
+  allocate(drhmg(n))
+  drhomt(1:npmtmax,1:natmtot+1) => drhmg(1:)
+  i=size(drhomt)+1
+  drhoir(1:ngtot) => drhmg(i:)
   if (spinpol) then
-    allocate(dmagmt(npmtmax,natmtot,ndmag))
-    allocate(dmagir(ngtot,ndmag))
+    i=i+size(drhoir)
+    dmagmt(1:npmtmax,1:natmtot+1,1:ndmag) => drhmg(i:)
+    i=i+size(dmagmt)
+    dmagir(1:ngtot,1:ndmag) => drhmg(i:)
   end if
   if (allocated(dvclmt)) deallocate(dvclmt)
   allocate(dvclmt(npmtmax,natmtot))
@@ -146,12 +149,12 @@ if (task == 205) then
   dvsbs(:)=0.d0
 ! associate pointer arrays with target
   dvsmt(1:npmtmax,1:natmtot) => dvsbs(1:)
-  i=npmtmax*natmtot+1
+  i=size(dvsmt)+1
   dvsig(1:ngvc) => dvsbs(i:)
   if (spinpol) then
-    i=i+ngvc
+    i=i+size(dvsig)
     dbsmt(1:npcmtmax,1:natmtot,1:ndmag) => dvsbs(i:)
-    i=i+npcmtmax*natmtot*ndmag
+    i=i+size(dbsmt)
     dbsir(1:ngtot,1:ndmag) => dvsbs(i:)
   end if
   if (allocated(dvsir)) deallocate(dvsir)
