@@ -25,7 +25,7 @@ call init0
 call init1
 if (num_bands > nstsv) then
   write(*,*)
-  write(*,'("Error(initw90): num_bands > nstsv : ",2I8)') num_bands,nstsv
+  write(*,'("Error(initw90): num_bands > nstsv :",2(X,I0))') num_bands,nstsv
   write(*,*)
   stop
 end if
@@ -43,7 +43,7 @@ do i=1,num_bands
   ist=idxw90(i)
   if ((ist < 1).or.(ist > nstsv)) then
     write(*,*)
-    write(*,'("Error(initw90): state index out of range : ",I8)') ist
+    write(*,'("Error(initw90): state index out of range : ",I0)') ist
     write(*,*)
     stop
   end if
