@@ -35,7 +35,7 @@ real(8), parameter :: ctf=(3.d0/10.d0)*(3.d0*pi**2)**(2.d0/3.d0)
 ! von Weizsacker coefficient
 real(8), parameter :: cvw=1.d0/72.d0
 real(8) ri,t1,t2
-if ((rho.lt.1.d-20).or.(grho2.lt.0.d0)) then
+if ((rho < 1.d-20).or.(grho2 < 0.d0)) then
   dtdr=0.d0
   dtdgr2=0.d0
   return
