@@ -6,6 +6,7 @@
 module libxcifc
 
 use xc_f03_lib_m
+use xc_f03_funcs_m
 
 ! libxc version number
 integer libxcv(3)
@@ -17,15 +18,16 @@ contains
 !BOP
 ! !ROUTINE: xcifc_libxc
 ! !INTERFACE:
-subroutine xcifc_libxc(xctype,n,tempa,rho,rhoup,rhodn,g2rho,g2up,g2dn,grho2, &
- gup2,gdn2,gupdn,tau,tauup,taudn,ex,ec,vx,vc,vxup,vxdn,vcup,vcdn,dxdgr2,dxdgu2,&
- dxdgd2,dxdgud,dcdgr2,dcdgu2,dcdgd2,dcdgud,dxdg2r,dxdg2u,dxdg2d,dcdg2r,dcdg2u, &
- dcdg2d,wx,wxup,wxdn,wc,wcup,wcdn)
+subroutine xcifc_libxc(xctype,n,c_tb09,tempa,rho,rhoup,rhodn,g2rho,g2up,g2dn, &
+ grho2,gup2,gdn2,gupdn,tau,tauup,taudn,ex,ec,vx,vc,vxup,vxdn,vcup,vcdn,dxdgr2, &
+ dxdgu2,dxdgd2,dxdgud,dcdgr2,dcdgu2,dcdgd2,dcdgud,dxdg2r,dxdg2u,dxdg2d,dcdg2r, &
+ dcdg2u,dcdg2d,wx,wxup,wxdn,wc,wcup,wcdn)
 ! !USES:
 use, intrinsic :: iso_c_binding
 ! !INPUT/OUTPUT PARAMETERS:
 !   xctype : type of exchange-correlation functional (in,integer(3))
 !   n      : number of density points (in,integer)
+!   c_tb09 : Tran-Blaha '09 constant c (in,real,optional)
 !   tempa  : temperature in atomic units (in,real,optional)
 !   rho    : spin-unpolarised charge density (in,real(n),optional)
 !   rhoup  : spin-up charge density (in,real(n),optional)
@@ -87,7 +89,7 @@ implicit none
 ! mandatory arguments
 integer, intent(in) :: xctype(3),n
 ! optional arguments
-real(8), optional, intent(in) :: tempa
+real(8), optional, intent(in) :: c_tb09,tempa
 real(8), optional, intent(in) :: rho(n),rhoup(n),rhodn(n)
 real(8), optional, intent(in) :: g2rho(n),g2up(n),g2dn(n)
 real(8), optional, intent(in) :: grho2(n),gup2(n),gdn2(n),gupdn(n)
@@ -121,7 +123,7 @@ if (xctype(2) /= 0) then
   if (xctype(2) == xctype(3)) then
     write(*,*)
     write(*,'("Error(libxcifc): Libxc exchange and correlation functionals")')
-    write(*,'(" are the same : ",2I8)') xctype(2:3)
+    write(*,'(" are the same :",2(X,I0))') xctype(2:3)
     write(*,*)
     stop
   end if
@@ -142,7 +144,7 @@ do k=2,3
 !-------------------------!
 ! set temperature for free energy functional
       if ((id == XC_LDA_XC_KSDT).or.(id == XC_LDA_XC_GDSMFB)) then
-        call xc_f03_func_set_ext_params(p,[tempa])
+        call xc_f03_func_set_ext_params_name(p,'T',tempa)
       end if
       if (k == 2) then
 ! exchange or a kinetic energy functional
@@ -246,13 +248,18 @@ do k=2,3
 !------------------------------!
 !     meta-GGA functionals     !
 !------------------------------!
+! set Tran-Blaha '09 constants if required
+      if ((id.eq.XC_MGGA_X_TB09).and.(present(c_tb09))) then
+        call xc_f03_func_set_ext_params_name(p,'c',c_tb09)
+      end if
       if (k == 2) then
-! exchange or a kinetic energy functional
         if (present(rho)) then
           if (present(ex)) then
+! exchange energy functional
             call xc_f03_mgga_exc_vxc(p,np,rho,grho2,g2rho,tau,ex,vx,dxdgr2, &
              dxdg2r,wx)
           else
+! exchange potential-only or kinetic energy functional
             call xc_f03_mgga_vxc(p,np,rho,grho2,g2rho,tau,vx,dxdgr2,dxdg2r,wx)
           end if
         else
@@ -317,7 +324,7 @@ do k=2,3
       end if
     case default
       write(*,*)
-      write(*,'("Error(libxcifc): unsupported Libxc functional family : ",I8)')&
+      write(*,'("Error(libxcifc): unsupported Libxc functional family : ",I0)')&
        fmly
       write(*,*)
       stop
@@ -419,7 +426,7 @@ do k=2,3
     end if
   case default
     write(*,*)
-    write(*,'("Error(libxcifc): unsupported Libxc functional family : ",I8)') &
+    write(*,'("Error(libxcifc): unsupported Libxc functional family : ",I0)') &
      fmly
     write(*,'(" for calculating f_xc")')
     write(*,*)
@@ -474,16 +481,12 @@ do k=2,3
     write(*,*)
     stop
   end if
-  if (k == 3) then
-    if ((xcgrad >= 0).and.(g /= xcgrad)) then
-      write(*,*)
-      write(*,'("Error(libxcifc): inconsistent exchange and correlation &
-       &gradient types")')
-      write(*,*)
-      stop
-    end if
+  if ((xcgrad > 0).and.(g > 0).and.(g /= xcgrad)) then
+    write(*,*)
+    write(*,'("Warning(libxcifc): inconsistent exchange and correlation &
+     &gradient types")')
   end if
-  xcgrad=g
+  if (xcgrad <= 0) xcgrad=g
 !----------------------------!
 !     hybrid functionals     !
 !----------------------------!
@@ -521,11 +524,7 @@ implicit none
 type(xc_f03_func_t), intent(in) :: p
 ! local variables
 type(xc_f03_func_info_t) info
-type(xc_f03_func_t) pa
-integer fmly,flg,knd
-integer naux,i
-! allocatable arrays
-integer, allocatable :: ida(:)
+integer fmly,knd,flg
 info=xc_f03_func_get_info(p)
 fmly=xc_f03_func_info_get_family(info)
 select case(fmly)
@@ -536,37 +535,25 @@ case(XC_FAMILY_GGA,XC_FAMILY_HYB_GGA)
 ! GGA gradients required
   grad=2
 case(XC_FAMILY_MGGA)
-  flg=xc_f03_func_info_get_flags(info)
-  if (iand(flg,XC_FLAGS_NEEDS_LAPLACIAN) == 0) then
-! tau and no Laplacian
-    grad=4
-  else
-! tau and Laplacian
-    grad=5
-  end if
-! check if tau is not required
   knd=xc_f03_func_info_get_kind(info)
-  if (knd == XC_KINETIC) then
-! this is a kinetic energy functional so tau is not required
+  flg=xc_f03_func_info_get_flags(info)
+  if ((knd == XC_KINETIC).or.(iand(flg,XC_FLAGS_NEEDS_TAU) == 0)) then
+! this is either a kinetic energy functional or a fully deorbitalised
+! exchange-correlation functional and does not require tau
     grad=3
   else
-! this is an exchange and/or correlation functional
-    naux=xc_f03_num_aux_funcs(p)
-    allocate(ida(naux))
-    call xc_f03_aux_func_ids(p,ida)
-    do i=1,naux
-      call xc_f03_func_init(pa,ida(i),XC_UNPOLARIZED)
-      info=xc_f03_func_get_info(pa)
-      knd=xc_f03_func_info_get_kind(info)
-      call xc_f03_func_end(pa)
-      if (knd == XC_KINETIC) then
-! this is a deorbitalised functional and does not require tau
-        grad=3
-        exit
-      end if
-    end do
-    deallocate(ida)
+! meta-GGA energy functional requiring tau
+    if (iand(flg,XC_FLAGS_NEEDS_LAPLACIAN) == 0) then
+! tau and no Laplacian
+      grad=4
+    else
+! tau and Laplacian
+      grad=5
+    end if
   end if
+! potential-only meta-GGA functional
+  if ((iand(flg,XC_FLAGS_HAVE_VXC) /= 0).and. &
+   (iand(flg,XC_FLAGS_HAVE_EXC) == 0)) grad=6
 case default
   grad=-1
 end select
