@@ -8,18 +8,19 @@
 module libxcifc
 
 integer libxcv(3)
+integer, parameter :: XC_MGGA_X_TB09=208
 
 contains
 
-subroutine xcifc_libxc(xctype,n,tempa,rho,rhoup,rhodn,g2rho,g2up,g2dn,grho2, &
- gup2,gdn2,gupdn,tau,tauup,taudn,ex,ec,vx,vc,vxup,vxdn,vcup,vcdn,dxdgr2,dxdgu2,&
- dxdgd2,dxdgud,dcdgr2,dcdgu2,dcdgd2,dcdgud,dxdg2r,dxdg2u,dxdg2d,dcdg2r,dcdg2u, &
- dcdg2d,wx,wxup,wxdn,wc,wcup,wcdn)
+subroutine xcifc_libxc(xctype,n,c_tb09,tempa,rho,rhoup,rhodn,g2rho,g2up,g2dn, &
+ grho2,gup2,gdn2,gupdn,tau,tauup,taudn,ex,ec,vx,vc,vxup,vxdn,vcup,vcdn,dxdgr2, &
+ dxdgu2,dxdgd2,dxdgud,dcdgr2,dcdgu2,dcdgd2,dcdgud,dxdg2r,dxdg2u,dxdg2d,dcdg2r, &
+ dcdg2u,dcdg2d,wx,wxup,wxdn,wc,wcup,wcdn)
 implicit none
 ! mandatory arguments
 integer, intent(in) :: xctype(3),n
 ! optional arguments
-real(8), optional :: tempa
+real(8), optional :: c_tb09,tempa
 real(8), optional :: rho(n),rhoup(n),rhodn(n)
 real(8), optional :: g2rho(n),g2up(n),g2dn(n)
 real(8), optional :: grho2(n),gup2(n),gdn2(n),gupdn(n)
@@ -56,8 +57,7 @@ implicit none
 ! arguments
 integer xctype(3)
 character(264) xcdescr
-integer xcspin
-integer xcgrad
+integer xcspin,xcgrad
 logical hybrid
 real(8) hybridc
 write(*,*)
