@@ -36,7 +36,6 @@ complex(8), intent(out) :: zlflm(ld,3)
 ! local variables
 integer l,m,lm
 real(8) t1
-complex(8), parameter :: zi=(0.d0,1.d0),zmi=(0.d0,-1.d0)
 complex(8) z1
 lm=0
 do l=0,lmax
@@ -50,13 +49,13 @@ do l=0,lmax
       t1=0.5d0*sqrt(dble((l-m)*(l+m+1)))
       z1=t1*zflm(lm)
       zlflm(lm+1,1)=z1
-      zlflm(lm+1,2)=zmi*z1
+      zlflm(lm+1,2)=cmplx(z1%im,-z1%re,8)
     end if
     if (m > -l) then
       t1=0.5d0*sqrt(dble((l+m)*(l-m+1)))
       z1=t1*zflm(lm)
       zlflm(lm-1,1)=zlflm(lm-1,1)+z1
-      zlflm(lm-1,2)=zlflm(lm-1,2)+zi*z1
+      zlflm(lm-1,2)=zlflm(lm-1,2)+cmplx(-z1%im,z1%re,8)
     end if
     if (m /= 0) then
       zlflm(lm,3)=dble(m)*zflm(lm)
