@@ -12,7 +12,6 @@ complex(8), intent(out) :: zlflm1(ld,n),zlflm2(ld,n),zlflm3(ld,n)
 ! local variables
 integer l,m,lm,i
 real(8) t1
-complex(8), parameter :: zi=(0.d0,1.d0),zmi=(0.d0,-1.d0)
 complex(8) z1
 lm=0
 do l=0,lmax
@@ -27,7 +26,7 @@ do l=0,lmax
       do i=1,n
         z1=t1*zflm(lm,i)
         zlflm1(lm+1,i)=z1
-        zlflm2(lm+1,i)=zmi*z1
+        zlflm2(lm+1,i)=cmplx(z1%im,-z1%re,8)
       end do
     end if
     if (m > -l) then
@@ -35,7 +34,7 @@ do l=0,lmax
       do i=1,n
         z1=t1*zflm(lm,i)
         zlflm1(lm-1,i)=zlflm1(lm-1,i)+z1
-        zlflm2(lm-1,i)=zlflm2(lm-1,i)+zi*z1
+        zlflm2(lm-1,i)=zlflm2(lm-1,i)+cmplx(-z1%im,z1%re,8)
       end do
     end if
     if (m /= 0) then
