@@ -7,7 +7,7 @@ subroutine maginit
 use modmain
 implicit none
 ! local variables
-integer idm,is,ia,ias,np
+integer idm,is,ia,ias,np,i
 ! magnetisation as fraction of density
 real(8), parameter :: fmr=0.15d0
 real(8) v(3),t1
@@ -24,7 +24,9 @@ do ias=1,natmtot
     if (.not.ncmag) v(1)=v(3)
     do idm=1,ndmag
       t1=v(idm)
-      magmt(1:np,ias,idm)=t1*rhomt(1:np,ias)
+      do i=1,np
+        magmt(i,ias,idm)=t1*rhomt(i,ias)
+      end do
     end do
   else
     magmt(1:np,ias,1:ndmag)=0.d0
@@ -39,7 +41,9 @@ if (t1 > 1.d-8) then
   if (.not.ncmag) v(1)=v(3)
   do idm=1,ndmag
     t1=v(idm)
-    magir(1:ngtot,idm)=t1*rhoir(1:ngtot)
+    do i=1,ngtot
+      magir(i,idm)=t1*rhoir(i)
+    end do
   end do
 else
   magir(1:ngtot,1:ndmag)=0.d0
