@@ -75,8 +75,8 @@ if (mp_mpi) then
     write(50,'("Magnetoelectric tensor components dPᵢ/dBⱼ, i=1...3")')
     write(50,'(" lattice coordinates : ",3G18.10)') felt(:,j)
     call r3mv(avec,felt(:,j),vc)
-    write(50,'(" Cartesian coordinates : ",3G18.10)') vc(:)
-    write(50,'("  length : ",G18.10)') norm2(vc(:))
+    write(50,'(" Cartesian coordinates : ",3G18.10)') vc
+    write(50,'("  length : ",G18.10)') norm2(vc(1:3))
   end do
   close(50)
   write(*,*)
