@@ -37,7 +37,7 @@ case(3)
    work(4*n+1),work((4+mixsdb)*n+1),work((4+2*mixsdb)*n+1),dv)
 case default
   write(*,*)
-  write(*,'("Error(mixerifc): mtype not defined : ",I8)') mtype
+  write(*,'("Error(mixerifc): mtype not defined : ",I0)') mtype
   write(*,*)
   stop
 end select
@@ -57,7 +57,7 @@ case(3)
   mixdescr='Broyden mixing, J. Phys. A: Math. Gen. 17, L317 (1984)'
 case default
   write(*,*)
-  write(*,'("Error(getmixdata): mixtype not defined : ",I8)') mtype
+  write(*,'("Error(getmixdata): mtype not defined : ",I0)') mtype
   write(*,*)
   stop
 end select
