@@ -84,8 +84,9 @@ complex(8), allocatable :: vmftm(:,:,:,:,:)
 real(8) tauftm
 ! tensor moments at t=0 of a TDDFT+U calculations
 real(8), allocatable :: wkpr0(:,:)
-! tm3old is .true. if the tensor moments should be in the old complex convention
-logical tm3old
+! tm3vdl is .true. if the tensor moments should be in the complex convention of
+! G. van der Laan and B. T. Thoole, J. Phys.: Condens. Matter 7, 9947 (1995)
+logical tm3vdl
 
 end module
 
