@@ -20,7 +20,7 @@ real(8), optional, intent(out) :: fxc(n),fxcuu(n),fxcud(n),fxcdd(n)
 real(8), allocatable :: ra(:,:)
 if (n < 1) then
   write(*,*)
-  write(*,'("Error(fxcifc): n < 1 : ",I8)') n
+  write(*,'("Error(fxcifc): n < 1 : ",I0)') n
   write(*,*)
   stop
 end if
@@ -67,16 +67,15 @@ case(100)
   end if
 case default
   write(*,*)
-  write(*,'("Error(fxcifc): response function unavailable for fxctype ",3I8)') &
-   fxctype
+  write(*,'("Error(fxcifc): response function unavailable for fxctype",&
+   &3(X,I0))') fxctype
   write(*,*)
   stop
 end select
 return
 10 continue
 write(*,*)
-write(*,'("Error(fxcifc): missing arguments for exchange-correlation type ",&
- &3I6)') fxctype(:)
+write(*,'("Error(fxcifc): missing arguments for fxctype",3(X,I0))') fxctype
 write(*,*)
 stop
 end subroutine
