@@ -23,8 +23,6 @@ integer nwbs
 real(8), allocatable :: wgw(:)
 ! complex fermionic frequencies
 complex(8), allocatable :: wfm(:)
-! twdiag is .true. if the screened interaction W is taken to be diagonal
-logical twdiag
 ! tsediag is .true. if the GW self-energy is taken to be diagonal
 logical tsediag
 ! type of analytic continuation to be used for determining the self-energy on
