@@ -87,6 +87,12 @@ real(8) rnucl(maxspecies)
 real(8) volnucl(maxspecies)
 ! number of radial mesh points to nuclear radius
 integer nrnucl(maxspecies)
+! Thomson radius
+real(8) rtmsn(maxspecies)
+! Thomson volume
+real(8) voltmsn(maxspecies)
+! number of radial mesh points to Thomson radius
+integer nrtmsn(maxspecies)
 ! nuclear Coulomb potential
 real(8), allocatable :: vcln(:,:)
 ! species electronic charge
@@ -157,7 +163,7 @@ real(8) rmt(maxspecies),rmt0(maxspecies)
 ! trmt0 is .true. if the original muffin-tin radii rmt0 are to be retained
 ! between tasks
 logical trmt0
-! (R_mt)^l for l up to lmaxo+3
+! (R_mt)ˡ for l up to lmaxo+3
 real(8), allocatable :: rmtl(:,:)
 ! total muffin-tin volume
 real(8) omegamt
@@ -173,8 +179,6 @@ real(8), allocatable :: rcmt(:,:)
 real(8), allocatable :: rlmt(:,:,:)
 ! r^l on coarse radial mesh
 real(8), allocatable :: rlcmt(:,:,:)
-! weights for spline integration on fine radial mesh
-real(8), allocatable :: wrmt(:,:)
 ! weights for spline integration on fine radial mesh multiplied by r²
 real(8), allocatable :: wr2mt(:,:)
 ! weights for spline partial integration on fine radial mesh
@@ -191,15 +195,15 @@ real(8), allocatable :: wcrcmt(:,:,:)
 integer, parameter :: maxlapw=30
 ! maximum angular momentum for augmented plane waves
 integer lmaxapw,dlmaxapw
-! (lmaxapw+1)^2
+! (lmaxapw+1)²
 integer lmmaxapw
 ! maximum angular momentum on the outer part of the muffin-tin
 integer lmaxo,dlmaxo
-! (lmaxo+1)^2
+! (lmaxo+1)²
 integer lmmaxo
 ! maximum angular momentum on the inner part of the muffin-tin
 integer lmaxi,lmaxi0
-! (lmaxi+1)^2
+! (lmaxi+1)²
 integer lmmaxi
 ! fraction of muffin-tin radius which constitutes the inner part
 real(8) fracinr
@@ -210,6 +214,10 @@ integer npmti(maxspecies),npmt(maxspecies)
 integer npcmti(maxspecies),npcmt(maxspecies)
 ! maximum number of points over all packed muffin-tins
 integer npmtmax,npcmtmax
+! total number of muffin-tin points for all atoms
+integer npcmttot
+! index to first muffin-tin point in packed array for all atoms
+integer, allocatable :: ipcmt(:)
 ! smoothing order used when calculating gradients in the muffin-tin
 integer msmgmt
 
@@ -222,6 +230,10 @@ logical spinpol,spinpol0
 logical spinorb,spinorb0
 ! scale factor of spin-orbit coupling term in Hamiltonian
 real(8) socscf
+! bforb is .true. for external B-field-orbit coupling
+logical bforb
+! bfdmag is .true. for external B-field diamagnetic coupling
+logical bfdmag
 ! dimension of magnetisation and magnetic vector fields (1 or 3)
 integer ndmag
 ! ncmag is .true. if the magnetisation is non-collinear, i.e. when ndmag = 3
@@ -233,13 +245,20 @@ logical cmagz,cmagz0
 !  1 (-1) : total moment (direction)
 !  2 (-2) : individual muffin-tin moments (direction)
 !  3 (-3) : total and muffin-tin moments (direction)
+!  4      : total moment magnitude
+!  5      : individual muffin-tin moment magnitudes
+!  6      : total and muffin-tin moment magnitudes
 integer fsmtype,fsmtype0
 ! fixed total spin magnetic moment
 real(8) momfix(3),momfix0(3),dmomfix(3)
+! fixed total spin magnetic moment magnitude
+real(8) momfixm
 ! fixed spin moment global effective field in Cartesian coordinates
 real(8) bfsmc(3)
 ! muffin-tin fixed spin moments
 real(8) mommtfix(3,maxatoms,maxspecies),mommtfix0(3,maxatoms,maxspecies)
+! muffin-tin fixed spin moment magnitudes
+real(8) mommtfixm(maxatoms,maxspecies)
 ! muffin-tin fixed spin moment effective fields in Cartesian coordinates
 real(8), allocatable :: bfsmcmt(:,:)
 ! fixed spin moment field step size
@@ -573,12 +592,13 @@ character(264) xcdescr
 integer xcspin
 ! exchange-correlation functional density gradient requirement
 !  0 : no gradients
-!  1 : gradients required for GGA with no post-processing: |grad rho|,
-!      grad^2 rho, (grad rho).(grad |grad rho|)
-!  2 : gradients required for GGA with post-processing: |grad rho|^2
-!  3 : as 2 but with the laplacian, grad^2 rho
-!  4 : as 2 but with the kinetic energy density, tau
-!  5 : as 4 but with the laplacian, grad^2 rho
+!  1 : gradients required for GGA with no post-processing: |∇ρ|, ∇²ρ,
+!      (∇ρ)⋅(∇|∇ρ|)
+!  2 : gradients required for GGA with post-processing: |∇ρ|²
+!  3 : as 2 but with the laplacian, ∇²ρ
+!  4 : as 2 but with the kinetic energy density, τ
+!  5 : as 4 but with the laplacian, ∇²ρ
+!  6 : as 4 but for potential-only meta-GGA functionals
 integer xcgrad
 ! small constant used to stabilise non-collinear GGA
 real(8) dncgga
@@ -588,12 +608,14 @@ integer ktype(3)
 character(264) kdescr
 ! kinetic energy density gradient requirement (see xcgrad)
 integer kgrad
+! combined target array for rhomt, rhoir, magmt and magir
+real(8), allocatable, target :: rhmg(:)
 ! muffin-tin and interstitial charge density
-real(8), allocatable :: rhomt(:,:),rhoir(:)
+real(8), pointer, contiguous :: rhomt(:,:),rhoir(:)
+! muffin-tin and interstitial magnetisation vector field
+real(8), pointer, contiguous :: magmt(:,:,:),magir(:,:)
 ! trhonorm is .true. if the density is to be normalised after every iteration
 logical trhonorm
-! muffin-tin and interstitial magnetisation vector field
-real(8), allocatable :: magmt(:,:,:),magir(:,:)
 ! tjr is .true. if the current density j(r) is to be calculated
 logical tjr,tjr0
 ! muffin-tin and interstitial gauge-invariant current density vector field
@@ -614,6 +636,8 @@ real(8), allocatable :: vxcmt(:,:),vxcir(:)
 real(8), allocatable :: bxcmt(:,:,:),bxcir(:,:)
 ! muffin-tin and interstitial magnetic dipole field
 real(8), allocatable :: bdmt(:,:,:),bdir(:,:)
+! average dipole field in each muffin-tin
+real(8), allocatable :: bdmta(:,:)
 ! tbdip is .true. if the spin and current dipole fields are to be added to the
 ! Kohn-Sham magnetic field
 logical tbdip
@@ -650,10 +674,19 @@ real(8), allocatable :: taumt(:,:,:),tauir(:,:)
 real(8), allocatable :: taucr(:,:,:)
 ! meta-GGA exchange-correlation potential
 real(8), allocatable :: wxcmt(:,:),wxcir(:)
+! Tran-Blaha '09 constant c [Phys. Rev. Lett. 102, 226401 (2009)]
+real(8) c_tb09
+! tc_tb09 is .true. if the Tran-Blaha constant has been read in
+logical tc_tb09
 ! if trdstate is .true. the density and potential can be read from STATE.OUT
 logical :: trdstate=.false.
 ! temperature in degrees Kelvin
 real(8) tempk
+! if mixrho is .true. then the (density, magnetisation) is mixed, otherwise the
+! (potential, magnetic field)
+logical mixrho
+! mixing vector: either (density, magnetisation) or (potential, magnetic field)
+real(8), pointer, contiguous :: vmixer(:)
 
 !--------------------------!
 !     mixing variables     !
@@ -739,7 +772,9 @@ integer apwdm(maxapword,0:maxlapw,maxspecies)
 logical apwve(maxapword,0:maxlapw,maxspecies)
 ! APW radial functions
 real(8), allocatable :: apwfr(:,:,:,:,:)
-! derivate of radial functions at the muffin-tin surface multiplied by R_MT²/2
+! single-precision APW radial functions
+real(4), allocatable :: apwfr_sp(:,:,:,:)
+! derivative of radial functions at the muffin-tin surface multiplied by R_MT²/2
 real(8), allocatable :: apwdfr(:,:,:)
 ! maximum number of local-orbitals
 integer, parameter :: maxlorb=200
@@ -761,12 +796,14 @@ integer lorbordmax
 integer lorbl(maxlorb,maxspecies)
 ! maximum lorbl over all species
 integer lolmax
-! (lolmax+1)^2
+! (lolmax+1)²
 integer lolmmax
 ! energy step size used for local-orbital numerical derivatives
 real(8) delorb
 ! local-orbital initial energies
 real(8) lorbe0(maxlorbord,maxlorb,maxspecies)
+! index which arranges the local-orbitals in ascending order of energy
+integer idxelo(maxlorb,maxspecies)
 ! local-orbital energies
 real(8), allocatable :: lorbe(:,:,:)
 ! local-orbital derivative order
@@ -775,6 +812,10 @@ integer lorbdm(maxlorbord,maxlorb,maxspecies)
 logical lorbve(maxlorbord,maxlorb,maxspecies)
 ! local-orbital radial functions
 real(8), allocatable :: lofr(:,:,:,:)
+! single-precision local-orbital radial functions
+real(4), allocatable :: lofr_sp(:,:,:)
+! tfr_sp is .true. if the single-precision radial functions are to be stored
+logical tfr_sp
 ! band energy search tolerance
 real(8) epsband
 ! maximum allowed change in energy during band energy search; enforced only if
@@ -782,11 +823,14 @@ real(8) epsband
 real(8) demaxbnd
 ! minimum default linearisation energy over all APWs and local-orbitals
 real(8) e0min
-! if autolinengy is .true. then the fixed linearisation energies are set to the
+! if autolinengy is .true. then the fixed linearisation energy is set to the
 ! Fermi energy minus dlefe
 logical autolinengy
-! difference between linearisation and Fermi energies when autolinengy is .true.
+! difference between the fixed linearisation energy and Fermi energy
 real(8) dlefe
+! if autodlefe is .true. then dlefe is determined automatically from the energy
+! eigenvalues moment below the Fermi energy
+logical autodlefe
 ! lorbcnd is .true. if conduction state local-orbitals should be added
 logical lorbcnd
 ! conduction state local-orbital order
@@ -797,6 +841,8 @@ integer nxoapwlo
 integer nxlo
 ! number of (l,m) components used for generating the muffin-tin wavefunctions
 integer nlmwf(maxspecies)
+! tolerance to select eigenvector components which contribute to a wavefunction
+real(8), parameter :: epswf=1.d-12
 
 !-------------------------------------------!
 !     overlap and Hamiltonian variables     !
@@ -825,12 +871,8 @@ logical tefvr
 ! tefvit is .true. if the first-variational eigenvalue equation is to be solved
 ! iteratively
 logical tefvit
-! minimum and maximum allowed number of eigenvalue equation iterations
-integer minitefv,maxitefv
-! eigenvalue mixing parameter for iterative solver
-real(8) befvit
-! iterative solver convergence tolerance
-real(8) epsefvit
+! number of eigenvalue equation iterations for iterative solver
+integer nefvit
 
 !--------------------------------------------!
 !     eigenvalue and occupancy variables     !
@@ -903,7 +945,7 @@ integer nspncr
 !--------------------------!
 !     energy variables     !
 !--------------------------!
-! eigenvalue sum
+! core, valence and total occupied eigenvalue sum
 real(8) evalsum
 ! electron kinetic energy
 real(8) engykn
@@ -1022,9 +1064,9 @@ real(8) epsforce
 ! stress tensor convergence tolerance
 real(8) epsstress
 
-!----------------------------------------------------------!
-!     density of states, optics and response variables     !
-!----------------------------------------------------------!
+!--------------------------------------------------------------------------!
+!     density of states, band structure, optics and response variables     !
+!--------------------------------------------------------------------------!
 ! number of energy intervals in the DOS/optics function plot
 integer nwplot
 ! fine k-point grid size for integration of functions in the Brillouin zone
@@ -1033,8 +1075,8 @@ integer ngrkf
 integer nswplot
 ! energy interval for DOS/optics function plot
 real(8) wplot(2)
-! maximum angular momentum for the partial DOS plot
-integer lmaxdos
+! maximum angular momentum for the partial DOS plot and band structure
+integer lmaxdb,lmmaxdb
 ! dosocc is .true. if the DOS is to be weighted by the occupancy
 logical dosocc
 ! tpdos is .true. if the partial DOS should be calculated
@@ -1053,10 +1095,10 @@ logical intraband
 ! irreducible representations of the site symmetries
 logical lmirep
 ! spin-quantisation axis in Cartesian coordinates used when plotting the
-! spin-resolved DOS (z-axis by default)
-real(8) sqados(3)
+! spin-resolved DOS and band structure (z-axis by default)
+real(8) sqaxis(3)
 ! q-vector in lattice and Cartesian coordinates for calculating the matrix
-! elements < i,k+q | exp(iq.r) | j,k >
+! elements ⟨i,k+q| exp(iq⋅r) |j,k⟩
 real(8) vecql(3),vecqc(3)
 ! maximum initial-state energy allowed in ELNES transitions
 real(8) emaxelnes
@@ -1118,6 +1160,8 @@ real(8) gmaxrf
 real(8) emaxrf
 ! number of G-vectors for response functions
 integer ngrf
+! matrix bandwidth of response functions in the G-vector basis
+integer mbwgrf
 ! number of response function frequencies
 integer nwrf
 ! complex response function frequencies
@@ -1186,14 +1230,12 @@ real(8) timefor
 real(8), parameter :: pi=3.1415926535897932385d0
 real(8), parameter :: twopi=6.2831853071795864769d0
 real(8), parameter :: fourpi=12.566370614359172954d0
-! spherical harmonic Y₀₀ and its inverse
+! spherical harmonic Y₀₀ = 1/√4π and its inverse
 real(8), parameter :: y00=0.28209479177387814347d0
 real(8), parameter :: y00i=3.54490770181103205460d0
 ! complex constants
-complex(4), parameter :: czero=(0.e0,0.e0),cone=(1.e0,0.e0)
-complex(4), parameter :: ci=(0.e0,1.e0),cmi=(0.e0,-1.e0)
-complex(8), parameter :: zzero=(0.d0,0.d0),zone=(1.d0,0.d0)
-complex(8), parameter :: zi=(0.d0,1.d0),zmi=(0.d0,-1.d0)
+complex(4), parameter :: czero=(0.e0,0.e0), cone=(1.e0,0.e0)
+complex(8), parameter :: zzero=(0.d0,0.d0), zone=(1.d0,0.d0), zi=(0.d0,1.d0)
 ! Pauli spin matrices:
 ! σ_x = ⎛0  1⎞   σ_y = ⎛0 -i⎞   σ_z = ⎛1  0⎞
 !       ⎝1  0⎠         ⎝i  0⎠         ⎝0 -1⎠
@@ -1242,7 +1284,7 @@ real(8), parameter :: amu=amu_si/em_si
 !     miscellaneous variables     !
 !---------------------------------!
 ! code version
-integer, parameter :: version(3)=[10,4,9]
+integer, parameter :: version(3)=[10,8,1]
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
