@@ -64,7 +64,7 @@ real(8), allocatable :: vgqc(:,:)
 real(8), allocatable :: gqc(:)
 ! regularised Coulomb Green's function in G+q-space
 real(8), allocatable :: gclgq(:)
-! spherical Bessel functions j_l(|G+q|R_mt)
+! spherical Bessel functions jₗ(|G+q|Rₘₜ)
 real(8), allocatable :: jlgqrmt(:,:,:)
 ! spherical harmonics for G+q-vectors
 complex(8), allocatable :: ylmgq(:,:)
@@ -94,10 +94,12 @@ complex(8), allocatable :: sfacgkq(:,:,:,:)
 !----------------------------------------------------------!
 !     density functional perturbation theory variables     !
 !----------------------------------------------------------!
+! combined target array for drhomt, drhoir, dmagmt and dmagir
+complex(8), allocatable, target :: drhmg(:)
 ! density derivative
-complex(8), allocatable :: drhomt(:,:),drhoir(:)
+complex(8), pointer, contiguous :: drhomt(:,:),drhoir(:)
 ! magnetisation derivative
-complex(8), allocatable :: dmagmt(:,:,:),dmagir(:,:)
+complex(8), pointer, contiguous :: dmagmt(:,:,:),dmagir(:,:)
 ! Coulomb potential derivative
 complex(8), allocatable :: dvclmt(:,:),dvclir(:)
 ! gradient of vsmt for the displaced muffin-tin
