@@ -38,7 +38,7 @@ integer(8) i1,i5
 i=modulo(i+1,6_8)
 i1=modulo(i-1,6_8)
 i5=modulo(i-5,6_8)
-rndstate(i)=int(mod(a1*rndstate(i1)+a5*rndstate(i5),m))
+rndstate(i)=mod(a1*rndstate(i1)+a5*rndstate(i5),m)
 randomu=dble(rndstate(i))/dble(m)
 !$OMP END CRITICAL(randomu_)
 end function
