@@ -7,14 +7,16 @@ module modtdhfc
 
 ! energy cut-off for TDHFC states around the Fermi energy
 real(8) ecutthc
-! total number of states
+! maximum number of states within energy window over all k-points
+integer nmaxthc
+! total number of TDHFC states
 integer nthc
-! maximum number of states used per k-point
-integer nthcpk
 ! number of states for each k-point
-integer, allocatable :: nstthc(:)
+integer, allocatable :: nthck(:)
 ! index to used states for each k-point
 integer, allocatable :: idxthc(:,:)
+! index from state and k-point to TDHFC states
+integer, allocatable :: ithc(:,:)
 
 end module
 
