@@ -32,11 +32,11 @@ if (.not.test) return
 if (.not.mp_mpi) return
 if ((id < 0).or.(id > 999)) then
   write(*,*)
-  write(*,'("Error(writetest): id out of range : ",I8)') id
+  write(*,'("Error(writetest): id out of range : ",I0)') id
   write(*,*)
   stop
 end if
-if ((present(iva)).or.(present(rva)).or.(present(zva))) then
+if (present(iva).or.present(rva).or.present(zva)) then
   if (.not.present(nv)) then
     write(*,*)
     write(*,'("Error(writetest): missing argument nv")')
@@ -45,13 +45,13 @@ if ((present(iva)).or.(present(rva)).or.(present(zva))) then
   else
     if (nv < 1) then
       write(*,*)
-      write(*,'("Error(writetest): nv < 1 : ",I8)') nv
+      write(*,'("Error(writetest): nv < 1 : ",I0)') nv
       write(*,*)
       stop
     end if
   end if
 end if
-if ((present(rv)).or.(present(rva)).or.(present(zv)).or.(present(zva))) then
+if (present(rv).or.present(rva).or.present(zv).or.present(zva)) then
   if (.not.present(tol)) then
     write(*,*)
     write(*,'("Error(writetest): missing argument tol")')
@@ -68,12 +68,12 @@ if (present(iv)) then
   write(90,'(2I8)') 1,iv
 else if (present(rv)) then
   write(90,'(2I8)') 2,1
-  write(90,'(G22.12)') tol
-  write(90,'(I8,G22.12)') 1,rv
+  write(90,'(G24.14)') tol
+  write(90,'(I8,G24.14)') 1,rv
 else if (present(zv)) then
   write(90,'(2I8)') 3,1
-  write(90,'(G22.12)') tol
-  write(90,'(I8,2G22.12)') 1,dble(zv),aimag(zv)
+  write(90,'(G24.14)') tol
+  write(90,'(I8,2G24.14)') 1,dble(zv),aimag(zv)
 else if (present(iva)) then
   write(90,'(2I8)') 1,nv
   do j=1,nv
@@ -81,15 +81,15 @@ else if (present(iva)) then
   end do
 else if (present(rva)) then
   write(90,'(2I8)') 2,nv
-  write(90,'(G22.12)') tol
+  write(90,'(G24.14)') tol
   do j=1,nv
-    write(90,'(I8,G22.12)') j,rva(j)
+    write(90,'(I8,G24.14)') j,rva(j)
   end do
 else if (present(zva)) then
   write(90,'(2I8)') 3,nv
-  write(90,'(G22.12)') tol
+  write(90,'(G24.14)') tol
   do j=1,nv
-    write(90,'(I8,2G22.12)') j,dble(zva(j)),aimag(zva(j))
+    write(90,'(I8,2G24.14)') j,dble(zva(j)),aimag(zva(j))
   end do
 end if
 close(90)
