@@ -16,11 +16,11 @@ real(8) bvecu(3,3)
 real(8) omegau,omegabzu
 ! original number of k-points
 integer nkpt0
-! kappa-point grid sizes
+! κ-point grid sizes
 integer ngridkpa(3)
-! integer grid intervals for the kappa-points
+! integer grid intervals for the κ-points
 integer intkpa(2,3)
-! number of kappa-points
+! number of κ-points
 integer nkpa
 ! R-vectors in Cartesian coordinates spanning the ultracell
 real(8), allocatable :: vrcu(:,:)
@@ -34,23 +34,22 @@ real(8) q0cut
 real(8), allocatable :: vgqc(:,:,:)
 ! |G+Q| for all G+Q-vectors
 real(8), allocatable :: gqc(:,:)
-! Coulomb Green's function in G+Q-space = 4 pi / |G+Q|^2
+! Coulomb Green's function in G+Q-space = 4π / |G+Q|²
 real(8), allocatable :: gclgq(:,:)
-! spherical Bessel functions j_l(|G+Q|R_mt)
+! spherical Bessel functions jₗ(|G+Q|Rₘₜ)
 real(8), allocatable :: jlgqrmt(:,:,:,:)
 ! spherical harmonics of the G+Q-vectors
 complex(8), allocatable :: ylmgq(:,:,:)
 ! structure factors for the G+Q-vectors
 complex(8), allocatable :: sfacgq(:,:,:)
-! phase factor functions exp(iQ.r) in each muffin-tin
-complex(8), allocatable :: expqmt(:,:,:)
 
 !---------------------------------------------------!
 !     ultra long-range densities and potentials     !
 !---------------------------------------------------!
 ! R-dependent density and magnetisation
-real(8), allocatable :: rhormt(:,:,:),rhorir(:,:)
-real(8), allocatable :: magrmt(:,:,:,:),magrir(:,:,:)
+real(8), allocatable, target :: rhmgr(:)
+real(8), pointer, contiguous :: rhormt(:,:,:),rhorir(:,:)
+real(8), pointer, contiguous :: magrmt(:,:,:,:),magrir(:,:,:)
 ! muffin-tin charges each R-vector
 real(8), allocatable :: chgmtru(:,:)
 ! muffin-tin, interstitial and total moments for each R-vector
@@ -63,14 +62,17 @@ complex(8), allocatable :: magqmt(:,:,:,:),magqir(:,:,:)
 logical trdvclr
 ! Q-dependent external Coulomb potential (FFT ordering)
 complex(8), allocatable :: vclq(:)
+! trdbfcr is .true. if the real-space external magnetic field in Cartesian
+! coordinates should be read in from file
+logical trdbfcr
 ! Q-dependent external magnetic field
 complex(8), allocatable :: bfcq(:,:)
 ! Q-dependent external muffin-tin magnetic fields
 complex(8), allocatable :: bfcmtq(:,:,:)
 ! global external magnetic field in Cartesian coordinates
-real(8) bfielduc(3)
+real(8) bfieldcu(3)
 ! electric field vector in Cartesian coordinates
-real(8) efielduc(3)
+real(8) efieldcu(3)
 ! if tbdipu is .true. then the spin dipole-dipole interaction is included
 logical tbdipu
 ! Q-dependent magnetic dipole field
