@@ -23,7 +23,7 @@ complex(8), optional, intent(in) :: zv,zva(*)
 character(*), optional, intent(in) :: sv,sva(*)
 ! local variables
 integer i
-if ((present(iva)).or.(present(rva)).or.(present(zva)).or.(present(sva))) then
+if (present(iva).or.present(rva).or.present(zva).or.present(sva)) then
   if (.not.present(nv)) then
     write(*,*)
     write(*,'("Error(writevars): missing argument nv")')
@@ -32,13 +32,13 @@ if ((present(iva)).or.(present(rva)).or.(present(zva)).or.(present(sva))) then
   else
     if (nv < 0) then
       write(*,*)
-      write(*,'("Error(writevars): nv < 0 : ",I8)') nv
+      write(*,'("Error(writevars): nv < 0 : ",I0)') nv
       write(*,*)
       stop
     end if
   end if
 end if
-open(95,file='VARIABLES.OUT',position='APPEND',form='FORMATTED',action='WRITE')
+open(95,file='VARIABLES.OUT',form='FORMATTED',action='WRITE',position='APPEND')
 write(95,*)
 write(95,'(A)',advance='NO') trim(vname)
 if (present(n1)) write(95,'(I8)',advance='NO') n1
@@ -53,10 +53,10 @@ if (present(iv)) then
   write(95,'(I8)') iv
 else if (present(rv)) then
   write(95,'(2I8)') 2,1
-  write(95,'(G22.12)') rv
+  write(95,'(G24.14)') rv
 else if (present(zv)) then
   write(95,'(2I8)') 3,1
-  write(95,'(2G22.12)') dble(zv),aimag(zv)
+  write(95,'(2G24.14)') dble(zv),aimag(zv)
 else if (present(sv)) then
   write(95,'(2I8)') 4,1
   write(95,'(A)') trim(sv)
@@ -68,12 +68,12 @@ else if (present(iva)) then
 else if (present(rva)) then
   write(95,'(2I8)') 2,nv
   do i=1,nv
-    write(95,'(G22.12)') rva(i)
+    write(95,'(G24.14)') rva(i)
   end do
 else if (present(zva)) then
   write(95,'(2I8)') 3,nv
   do i=1,nv
-    write(95,'(2G22.12)') dble(zva(i)),aimag(zva(i))
+    write(95,'(2G24.14)') dble(zva(i)),aimag(zva(i))
   end do
 else if (present(sva)) then
   write(95,'(2I8)') 4,nv
