@@ -22,6 +22,8 @@ integer num_bands
 integer, allocatable :: idxw90(:)
 ! number of iterations for the minimisation of omega
 integer num_iter
+! number of iterations for disentanglement
+integer dis_num_iter
 ! trial step for the line search minimisation
 real(8) trial_step
 ! maximum number of nearest neighbours per k-point
@@ -32,6 +34,9 @@ integer nntot
 integer, allocatable :: nnlist(:,:)
 ! G-vector offset for each nearest neighbour
 integer, allocatable :: nncell(:,:,:)
+! wrtunk is .true. if the UNKkkkkk.s files are to be written in order to
+! enable real-space wavefunction plotting
+logical wrtunk
 
 end module
 
