@@ -12,14 +12,15 @@ contains
 !BOP
 ! !ROUTINE: xcifc
 ! !INTERFACE:
-subroutine xcifc(xctype,n,tempa,rho,rhoup,rhodn,grho,gup,gdn,g2rho,g2up,g2dn, &
- g3rho,g3up,g3dn,grho2,gup2,gdn2,gupdn,tau,tauup,taudn,ex,ec,vx,vc,vxup,vxdn, &
- vcup,vcdn,dxdgr2,dxdgu2,dxdgd2,dxdgud,dcdgr2,dcdgu2,dcdgd2,dcdgud,dxdg2r, &
+subroutine xcifc(xctype,n,c_tb09,tempa,rho,rhoup,rhodn,grho,gup,gdn,g2rho,g2up,&
+ g2dn,g3rho,g3up,g3dn,grho2,gup2,gdn2,gupdn,tau,tauup,taudn,ex,ec,vx,vc,vxup, &
+ vxdn,vcup,vcdn,dxdgr2,dxdgu2,dxdgd2,dxdgud,dcdgr2,dcdgu2,dcdgd2,dcdgud,dxdg2r,&
  dxdg2u,dxdg2d,dcdg2r,dcdg2u,dcdg2d,wx,wxup,wxdn,wc,wcup,wcdn,dtdr,dtdru,dtdrd,&
  dtdgr2,dtdgu2,dtdgd2,dtdg2r,dtdg2u,dtdg2d)
 ! !INPUT/OUTPUT PARAMETERS:
 !   xctype : type of exchange-correlation functional (in,integer(3))
 !   n      : number of density points (in,integer)
+!   c_tb09 : Tran-Blaha '09 constant c (in,real,optional)
 !   tempa  : temperature in atomic units (in,real,optional)
 !   rho    : spin-unpolarised charge density (in,real(n),optional)
 !   rhoup  : spin-up charge density (in,real(n),optional)
@@ -99,7 +100,7 @@ implicit none
 ! mandatory arguments
 integer, intent(in) :: xctype(3),n
 ! optional arguments
-real(8), optional, intent(in) :: tempa
+real(8), optional, intent(in) :: c_tb09,tempa
 real(8), optional, intent(in) :: rho(n),rhoup(n),rhodn(n)
 real(8), optional, intent(in) :: grho(n),gup(n),gdn(n)
 real(8), optional, intent(in) :: g2rho(n),g2up(n),g2dn(n)
@@ -123,7 +124,7 @@ real(8) kappa,mu,beta
 real(8), allocatable :: ra(:,:)
 if (n < 1) then
   write(*,*)
-  write(*,'("Error(xcifc): n < 1 : ",I8)') n
+  write(*,'("Error(xcifc): n < 1 : ",I0)') n
   write(*,*)
   stop
 end if
@@ -297,20 +298,30 @@ case(100)
 ! libxc library functionals
   if (present(rhoup).and.present(rhodn).and.present(g2up).and.present(g2dn) &
    .and.present(gup2).and.present(gdn2).and.present(gupdn).and.present(tauup) &
-   .and.present(taudn).and.present(ex).and.present(ec).and.present(vxup) &
-   .and.present(vxdn).and.present(vcup).and.present(vcdn).and.present(dxdgu2) &
-   .and.present(dxdgd2).and.present(dxdgud).and.present(dcdgu2) &
-   .and.present(dcdgd2).and.present(dcdgud).and.present(dxdg2u) &
-   .and.present(dxdg2d).and.present(dcdg2u).and.present(dcdg2d) &
-   .and.present(wxup).and.present(wxdn).and.present(wcup) &
-   .and.present(wcdn)) then
+   .and.present(taudn).and.present(vxup).and.present(vxdn).and.present(vcup) &
+   .and.present(vcdn).and.present(dxdgu2).and.present(dxdgd2) &
+   .and.present(dxdgud).and.present(dcdgu2).and.present(dcdgd2) &
+   .and.present(dcdgud).and.present(dxdg2u).and.present(dxdg2d) &
+   .and.present(dcdg2u).and.present(dcdg2d).and.present(wxup).and.present(wxdn)&
+   .and.present(wcup).and.present(wcdn)) then
 ! spin-polarised meta-GGA
-    call xcifc_libxc(xctype,n,rhoup=rhoup,rhodn=rhodn,g2up=g2up,g2dn=g2dn, &
-     gup2=gup2,gdn2=gdn2,gupdn=gupdn,tauup=tauup,taudn=taudn,ex=ex,ec=ec, &
-     vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn,dxdgu2=dxdgu2,dxdgd2=dxdgd2, &
-     dxdgud=dxdgud,dcdgu2=dcdgu2,dcdgd2=dcdgd2,dcdgud=dcdgud,dxdg2u=dxdg2u, &
-     dxdg2d=dxdg2d,dcdg2u=dcdg2u,dcdg2d=dcdg2d,wxup=wxup,wxdn=wxdn,wcup=wcup, &
-     wcdn=wcdn)
+    if (present(ex).and.present(ec)) then
+! energy functional
+      call xcifc_libxc(xctype,n,rhoup=rhoup,rhodn=rhodn,g2up=g2up,g2dn=g2dn, &
+       gup2=gup2,gdn2=gdn2,gupdn=gupdn,tauup=tauup,taudn=taudn,ex=ex,ec=ec, &
+       vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn,dxdgu2=dxdgu2,dxdgd2=dxdgd2, &
+       dxdgud=dxdgud,dcdgu2=dcdgu2,dcdgd2=dcdgd2,dcdgud=dcdgud,dxdg2u=dxdg2u, &
+       dxdg2d=dxdg2d,dcdg2u=dcdg2u,dcdg2d=dcdg2d,wxup=wxup,wxdn=wxdn,wcup=wcup,&
+       wcdn=wcdn)
+    else
+! potential-only functional
+      call xcifc_libxc(xctype,n,c_tb09=c_tb09,rhoup=rhoup,rhodn=rhodn, &
+       g2up=g2up,g2dn=g2dn,gup2=gup2,gdn2=gdn2,gupdn=gupdn,tauup=tauup, &
+       taudn=taudn,vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn,dxdgu2=dxdgu2, &
+       dxdgd2=dxdgd2,dxdgud=dxdgud,dcdgu2=dcdgu2,dcdgd2=dcdgd2,dcdgud=dcdgud, &
+       dxdg2u=dxdg2u,dxdg2d=dxdg2d,dcdg2u=dcdg2u,dcdg2d=dcdg2d,wxup=wxup, &
+       wxdn=wxdn,wcup=wcup,wcdn=wcdn)
+    end if
   else if (present(rhoup).and.present(rhodn).and.present(gup2) &
    .and.present(gdn2).and.present(gupdn).and.present(ex).and.present(ec) &
    .and.present(vxup).and.present(vxdn).and.present(vcup).and.present(vcdn) &
@@ -326,7 +337,7 @@ case(100)
    .and.present(taudn).and.present(dtdru).and.present(dtdrd) &
    .and.present(dtdg2u).and.present(dtdg2d).and.present(dtdgu2) &
    .and.present(dtdgd2).and.present(wxup).and.present(wxdn)) then
-! spin-polarised LSDA, GGA or meta-GGA kinetic energy functional
+! spin-polarised kinetic energy functional
     call xcifc_libxc(xctype,n,rhoup=rhoup,rhodn=rhodn,g2up=g2up,g2dn=g2dn, &
      gup2=gup2,gdn2=gdn2,tauup=tauup,taudn=taudn,vxup=dtdru,vxdn=dtdrd, &
      dxdg2u=dtdg2u,dxdg2d=dtdg2d,dxdgu2=dtdgu2,dxdgd2=dtdgd2,wxup=wxup, &
@@ -338,13 +349,20 @@ case(100)
     call xcifc_libxc(xctype,n,tempa=tempa,rhoup=rhoup,rhodn=rhodn,ex=ex,ec=ec, &
      vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn)
   else if (present(rho).and.present(g2rho).and.present(grho2).and.present(tau) &
-   .and.present(ex).and.present(ec).and.present(vx).and.present(vc) &
-   .and.present(dxdgr2).and.present(dcdgr2).and.present(dxdg2r) &
-   .and.present(dcdg2r).and.present(wx).and.present(wc)) then
+   .and.present(vx).and.present(vc).and.present(dxdgr2).and.present(dcdgr2) &
+   .and.present(dxdg2r).and.present(dcdg2r).and.present(wx).and.present(wc))then
 ! spin-unpolarised meta-GGA
-    call xcifc_libxc(xctype,n,rho=rho,g2rho=g2rho,grho2=grho2,tau=tau,ex=ex, &
-     ec=ec,vx=vx,vc=vc,dxdgr2=dxdgr2,dcdgr2=dcdgr2,dxdg2r=dxdg2r, &
-     dcdg2r=dcdg2r,wx=wx,wc=wc)
+    if (present(ex).and.present(ec)) then
+! energy functional
+      call xcifc_libxc(xctype,n,rho=rho,g2rho=g2rho,grho2=grho2,tau=tau,ex=ex, &
+       ec=ec,vx=vx,vc=vc,dxdgr2=dxdgr2,dcdgr2=dcdgr2,dxdg2r=dxdg2r, &
+       dcdg2r=dcdg2r,wx=wx,wc=wc)
+    else
+! potential-only functional
+      call xcifc_libxc(xctype,n,c_tb09=c_tb09,rho=rho,g2rho=g2rho,grho2=grho2, &
+       tau=tau,vx=vx,vc=vc,dxdgr2=dxdgr2,dcdgr2=dcdgr2,dxdg2r=dxdg2r, &
+       dcdg2r=dcdg2r,wx=wx,wc=wc)
+    end if
   else if (present(rho).and.present(grho2).and.present(ex).and.present(ec) &
    .and.present(vx).and.present(vc).and.present(dxdgr2) &
    .and.present(dcdgr2)) then
@@ -354,7 +372,7 @@ case(100)
   else if (present(rho).and.present(g2rho).and.present(grho2).and.present(tau) &
    .and.present(dtdr).and.present(dtdgr2).and.present(dtdg2r) &
    .and.present(wx)) then
-! spin-unpolarised LDA, GGA or meta-GGA kinetic energy functional
+! spin-unpolarised kinetic energy functional
     call xcifc_libxc(xctype,n,rho=rho,g2rho=g2rho,grho2=grho2,tau=tau,vx=dtdr, &
      dxdgr2=dtdgr2,dxdg2r=dtdg2r,wx=wx)
   else if (present(rho).and.present(ex).and.present(ec).and.present(vx) &
@@ -366,7 +384,7 @@ case(100)
   end if
 case default
   write(*,*)
-  write(*,'("Error(xcifc): xctype not defined : ",I8)') xctype(1)
+  write(*,'("Error(xcifc): xctype not defined : ",I0)') xctype(1)
   write(*,*)
   stop
 end select
@@ -379,8 +397,8 @@ end if
 return
 10 continue
 write(*,*)
-write(*,'("Error(xcifc): missing arguments for exchange-correlation type ",&
- &3I6)') xctype(:)
+write(*,'("Error(xcifc): missing arguments for exchange-correlation type",&
+ &3(X,I0))') xctype(:)
 write(*,*)
 stop
 end subroutine
@@ -476,7 +494,7 @@ case(100)
   call xcdata_libxc(xctype,xcdescr,xcspin,xcgrad,hybrid,hybridc)
 case default
   write(*,*)
-  write(*,'("Error(getxcdata): xctype not defined : ",I8)') xctype(1)
+  write(*,'("Error(getxcdata): xctype not defined : ",I0)') xctype(1)
   write(*,*)
   stop
 end select
