@@ -60,7 +60,7 @@ do iw=1,nwplot
   if (w(iw) > 0.d0) then
     z1=cmplx(sig1(iw,1),sig2(iw,1),8)
     z2=cmplx(sig1(iw,2),sig2(iw,2),8)
-    z3=z1*sqrt(1.d0+fourpi*zi*z1/w(iw))
+    z3=z1*sqrt(1.d0+fourpi*cmplx(-z1%im,z1%re,8)/w(iw))
     if (abs(z3) > 1.d-8) then
       kerr(iw)=-z2/z3
     else
