@@ -21,17 +21,8 @@ use modtest
 implicit none
 ! local variables
 integer idm,is,ias
-real(8) t1
 ! external functions
 real(8), external :: rfmtint
-if (.not.spinpol) then
-  mommt(:,:)=0.d0
-  mommttot(:)=0.d0
-  momir(:)=0.d0
-  momtot(:)=0.d0
-  momtotm=0.d0
-  return
-end if
 ! find the muffin-tin moments
 mommttot(:)=0.d0
 do idm=1,ndmag
@@ -43,8 +34,7 @@ do idm=1,ndmag
 end do
 ! find the interstitial and total moments
 do idm=1,ndmag
-  t1=dot_product(magir(1:ngtot,idm),cfunir(1:ngtot))
-  momir(idm)=t1*omega/dble(ngtot)
+  momir(idm)=(omega/ngtot)*dot_product(magir(1:ngtot,idm),cfunir(1:ngtot))
   momtot(idm)=mommttot(idm)+momir(idm)
 end do
 ! total moment magnitude
