@@ -27,9 +27,9 @@ use modtest
 implicit none
 ! local variables
 integer idm,is,ia,ias
-integer nr,nri,nrn
-real(8) mc(3),bc(3),bd(3)
-real(8) rho0,rhon,rhoa
+integer nr,nri,nrn,nrt
+real(8) r0,rn,rna,rt,rta
+real(8) mn(3),mt(3),bn(3),bt(3)
 real(8) cb,t1
 ! allocatable arrays
 real(8), allocatable :: fr(:)
@@ -63,6 +63,7 @@ do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
   nrn=nrnucl(is)
+  nrt=nrtmsn(is)
 ! loop over atoms
   do ia=1,natoms(is)
     ias=idxas(ia,is)
@@ -74,21 +75,34 @@ do is=1,nspecies
       write(50,*)
       write(50,'(" approximate nuclear radius : ",G18.10)') rnucl(is)
       write(50,'(" number of mesh points to nuclear radius : ",I6)') nrn
+      write(50,'(" Thomson radius : ",G18.10)') rtmsn(is)
+      write(50,'(" number of mesh points to Thomson radius : ",I6)') nrt
     end if
 !--------------------------------!
 !     contact charge density     !
 !--------------------------------!
 ! extract the l = m = 0 component of the muffin-tin density
     call rfmtlm(1,nr,nri,rhomt(:,ias),fr)
-    rho0=fr(1)*y00
-    rhon=fr(nrn)*y00
+! density at nuclear center
+    r0=fr(1)*y00
+! density at nuclear surface
+    rn=fr(nrn)*y00
+! average density in nuclear volume
     t1=dot_product(wr2mt(1:nrn,is),fr(1:nrn))
-    rhoa=fourpi*y00*t1/volnucl(is)
+    rna=fourpi*y00*t1/volnucl(is)
+! density at Thomson radius
+    rt=fr(nrt)*y00
+! average density in Thomson volume
+    t1=dot_product(wr2mt(1:nrt,is),fr(1:nrt))
+    rta=fourpi*y00*t1/voltmsn(is)
     if (mp_mpi) then
       write(50,*)
-      write(50,'(" density at nuclear center      : ",G18.10)') rho0
-      write(50,'(" density at nuclear surface     : ",G18.10)') rhon
-      write(50,'(" average contact charge density : ",G18.10)') rhoa
+      write(50,'(" Contact density :")')
+      write(50,'("  at nuclear center         : ",G18.10)') r0
+      write(50,'("  at nuclear surface        : ",G18.10)') rn
+      write(50,'("  average in nuclear volume : ",G18.10)') rna
+      write(50,'("  at Thomson radius         : ",G18.10)') rt
+      write(50,'("  average in Thomson volume : ",G18.10)') rta
     end if
 !----------------------------------!
 !     magnetic hyperfine field     !
@@ -98,36 +112,60 @@ do is=1,nspecies
       do idm=1,ndmag
 ! extract the l = m = 0 component of the muffin-tin magnetisation
         call rfmtlm(1,nr,nri,magmt(:,ias,idm),fr)
+! average magnetisation in nuclear volume
         t1=dot_product(wr2mt(1:nrn,is),fr(1:nrn))
-        mc(idm)=fourpi*y00*t1/volnucl(is)
+        mn(idm)=fourpi*y00*t1/volnucl(is)
+! average in Thomson volume
+        t1=dot_product(wr2mt(1:nrt,is),fr(1:nrt))
+        mt(idm)=fourpi*y00*t1/voltmsn(is)
       end do
       t1=8.d0*pi*cb/(3.d0*solsc)
-      bc(1:ndmag)=t1*mc(1:ndmag)
+      bn(1:ndmag)=t1*mn(1:ndmag)
+      bt(1:ndmag)=t1*mt(1:ndmag)
       if (mp_mpi) then
         write(50,*)
-        write(50,'(" contact magnetic moment (mu_B) : ",3G18.10)') mc(1:ndmag)
-        write(50,'(" contact field : ",3G18.10)') bc(1:ndmag)
-        write(50,'("  tesla : ",3G18.10)') b_si*bc(1:ndmag)
+        write(50,'(" Contact average in nuclear volume :")')
+        write(50,'("  moment (mu_B) : ",3G18.10)') mn(1:ndmag)
+        write(50,'("  magnetic field : ",3G18.10)') bn(1:ndmag)
+        write(50,'("   tesla : ",3G18.10)') b_si*bn(1:ndmag)
+        write(50,*)
+        write(50,'(" Contact average in Thomson volume :")')
+        write(50,'("  moment (mu_B) : ",3G18.10)') mt(1:ndmag)
+        write(50,'("  magnetic field : ",3G18.10)') bt(1:ndmag)
+        write(50,'("   tesla : ",3G18.10)') b_si*bt(1:ndmag)
       end if
 ! spin and orbital dipole term
       if (tbdip) then
 ! extract the l = m = 0 component of the dipole field
         do idm=1,3
           call rfmtlm(1,nr,nri,bdmt(:,ias,idm),fr)
+! average dipole field in nuclear volume
           t1=dot_product(wr2mt(1:nrn,is),fr(1:nrn))
-          bd(idm)=fourpi*y00*t1/(volnucl(is)*solsc)
+          bn(idm)=fourpi*y00*t1/(volnucl(is)*solsc)
+! average in Thomson volume
+          t1=dot_product(wr2mt(1:nrt,is),fr(1:nrt))
+          bt(idm)=fourpi*y00*t1/(voltmsn(is)*solsc)
         end do
         if (mp_mpi) then
           write(50,*)
+          write(50,'(" Average dipole field in nuclear volume :")')
           if (tjr) then
-            write(50,'(" spin and orbital dipole field : ",3G18.10)') bd
+            write(50,'("  spin and orbital : ",3G18.10)') bn
           else
-            write(50,'(" spin dipole field : ",3G18.10)') bd
+            write(50,'("  spin : ",3G18.10)') bn
           end if
-          write(50,'("  tesla : ",3G18.10)') b_si*bd
+          write(50,'("   tesla : ",3G18.10)') b_si*bn
+          write(50,*)
+          write(50,'(" Average dipole field in Thomson volume :")')
+          if (tjr) then
+            write(50,'("  spin and orbital : ",3G18.10)') bt
+          else
+            write(50,'("  spin : ",3G18.10)') bt
+          end if
+          write(50,'("   tesla : ",3G18.10)') b_si*bt
         end if
 ! write to test file if required
-        call writetest(110,'hyperfine field',nv=3,tol=1.d-4,rva=bd)
+        call writetest(110,'hyperfine field',nv=3,tol=1.d-4,rva=bn)
       end if
     end if
   end do
