@@ -21,7 +21,7 @@ call init0
 call init1
 call init2
 ! read Fermi energy from file
-call readfermi
+call readefm
 ! get the eigenvalues from file
 do ik=1,nkpt
   call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
@@ -38,7 +38,7 @@ call holdthd(nqpt,nthd)
 !$OMP NUM_THREADS(nthd)
 do iq=1,nqpt
 !$OMP CRITICAL(nesting_)
-  write(*,'("Info(nesting): ",I6," of ",I6," q-points")') iq,nqpt
+  write(*,'("Info(nesting): ",I0," of ",I0," q-points")') iq,nqpt
 !$OMP END CRITICAL(nesting_)
   sm1=0.d0
   do ik=1,nkptnr
