@@ -48,7 +48,7 @@ complex(8), allocatable :: chi2w(:),eta2w(:),sigma2w(:)
 call init0
 call init1
 ! read Fermi energy from file
-call readfermi
+call readefm
 ! read the eigenvalues and occupation numbers from file
 call readevalsv
 call readoccsv
@@ -88,7 +88,7 @@ do ioc=1,noptcomp
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(nonlinopt_)
-    write(*,'("Info(nonlinopt): ",I6," of ",I6," k-points")') ik,nkptnr
+    write(*,'("Info(nonlinopt): ",I0," of ",I0," k-points")') ik,nkptnr
 !$OMP END CRITICAL(nonlinopt_)
 ! equivalent reduced k-point
     jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
@@ -116,7 +116,7 @@ do ioc=1,noptcomp
           t1=e(m,n)
           if (abs(t1) > swidth) then
             z1=r(m,n,i)/t1
-            r(m,n,i)=zmi*z1
+            r(m,n,i)=cmplx(z1%im,-z1%re,8)
           else
             r(m,n,i)=0.d0
           end if
@@ -186,12 +186,12 @@ do ioc=1,noptcomp
           if (abs(t1) > swidth) then
             t1=1.d0/t1**2
             z1=r(n,m,a)*(d(m,n,b)*r(m,n,c)+d(m,n,c)*r(m,n,b))
-            z1=zmi*z1
+            z1=cmplx(z1%im,-z1%re,8)
             z1=4.d0*f(n,m)*t1*z1
             ce2(m,n)=ce2(m,n)+z1
 ! Eq. (B16b)
             z1=r(n,m,a)*(r(m,n,b)*d(m,n,c)+r(m,n,c)*d(m,n,b))
-            z1=zi*z1
+            z1=cmplx(-z1%im,z1%re,8)
             z1=0.25d0*f(n,m)*t1*z1
             cs1(m,n)=cs1(m,n)+z1
           end if
