@@ -12,7 +12,9 @@ use modmain
 use modtest
 ! !DESCRIPTION:
 !   Finds the Fermi energy and sets the occupation numbers for the
-!   second-variational states using the routine {\tt fermi}.
+!   second-variational states using the routine {\tt fermi}. Also determines
+!   the density of states at the Fermi surface as well as the direct and
+!   indirect band gaps.
 !
 ! !REVISION HISTORY:
 !   Created February 2004 (JKD)
@@ -45,7 +47,7 @@ if (e0 < e0min) then
   write(*,*)
   write(*,'("Warning(occupy): minimum eigenvalue less than minimum &
    &linearisation energy : ",2G18.10)') e0,e0min
-  write(*,'(" for s.c. loop ",I5)') iscl
+  write(*,'(" for s.c. loop ",I0)') iscl
 end if
 t0=1.d0/swidth
 ! determine the Fermi energy using the bisection method
@@ -75,6 +77,10 @@ end do
 write(*,*)
 write(*,'("Warning(occupy): could not find Fermi energy")')
 10 continue
+if (any(abs(occsv(nstsv,1:nkpt)) > epsocc)) then
+  write(*,*)
+  write(*,'("Warning(occupy): not enough empty states for s.c. loop ",I0)') iscl
+end if
 ! find the density of states at the Fermi surface in units of
 ! states/Hartree/unit cell
 fermidos=0.d0
@@ -84,11 +90,6 @@ do ik=1,nkpt
     x=(evalsv(ist,ik)-efermi)*t0
     fermidos=fermidos+w*sdelta(stype,x)
   end do
-  if (abs(occsv(nstsv,ik)) > epsocc) then
-    write(*,*)
-    write(*,'("Warning(occupy): not enough empty states for k-point ",I6)') ik
-    write(*,'(" and s.c. loop ",I5)') iscl
-  end if
 end do
 fermidos=fermidos*occmax*t0
 ! write Fermi density of states to test file
@@ -124,6 +125,9 @@ do ik=1,nkpt
 end do
 bandgap(1)=ei1-ei0
 bandgap(2)=de
+! automatically find the difference between the fixed linearisation and Fermi
+! energies if required
+if (autodlefe) call finddlefe
 ! write band gap to test file
 call writetest(510,'estimated indirect band gap',tol=2.d-2,rv=bandgap(1))
 end subroutine
