@@ -10,8 +10,7 @@ implicit none
 ! local variables
 integer, parameter :: maxit=1000
 integer ik0,ik,ist,it
-real(8) e0,e1,e
-real(8) chg,x,t1
+real(8) e0,e1,e,chg,x,t0
 ! external functions
 real(8), external :: stheta
 ! find minimum and maximum eigenvalues
@@ -28,9 +27,9 @@ if (e0 < e0min) then
   write(*,*)
   write(*,'("Warning(occupyulr): minimum eigenvalue less than minimum &
    &linearisation energy : ",2G18.10)') e0,e0min
-  write(*,'(" for s.c. loop ",I5)') iscl
+  write(*,'(" for s.c. loop ",I0)') iscl
 end if
-t1=1.d0/swidth
+t0=1.d0/swidth
 ! determine the Fermi energy using the bisection method
 do it=1,maxit
   efermi=0.5d0*(e0+e1)
@@ -43,7 +42,7 @@ do it=1,maxit
       if (e < e0min) then
         occulr(ist,ik0)=0.d0
       else
-        x=(efermi-e)*t1
+        x=(efermi-e)*t0
         occulr(ist,ik0)=occmax*stheta(stype,x)
         chg=chg+wkpt(ik)*occulr(ist,ik0)
       end if
