@@ -175,8 +175,8 @@ real(8), intent(out) :: rv(n)
 ! local variables
 integer i
 real(8) a,b
-a=dble(z)
-b=-aimag(z)
+a=z%re
+b=-z%im
 if (abs(a) > 1.d-12) then
   if (abs(b) > 1.d-12) then
     do i=1,n
