@@ -27,10 +27,10 @@ do l=0,lmaxapw
 end do
 if (tor) then
 ! matrix O is real
-  call rzmmaau(lmoapw(is),ngp,a,ld,o)
+  call rzmctmu(lmoapw(is),ngp,a,a,ld,o)
 else
 ! matrix O is complex
-  call zmmaau(lmoapw(is),ngp,a,ld,o)
+  call zmctmu(lmoapw(is),ngp,a,a,ld,o)
 end if
 end subroutine
 
