@@ -11,16 +11,15 @@ integer, intent(in) :: is,ias,ngp,ld
 complex(8), intent(out) :: o(ld,*)
 ! local variables
 integer ilo,jlo,l,lm,i,j
-do ilo=1,nlorb(is)
-  l=lorbl(ilo,is)
-  do jlo=1,nlorb(is)
-    if (lorbl(jlo,is) == l) then
-      do lm=l**2+1,(l+1)**2
-        i=ngp+idxlo(lm,ilo,ias)
-        j=ngp+idxlo(lm,jlo,ias)
-        if (i <= j) o(i,j)=ololo(ilo,jlo,ias)
-      end do
-    end if
+do jlo=1,nlorb(is)
+  l=lorbl(jlo,is)
+  do ilo=1,jlo
+    if (lorbl(ilo,is) /= l) cycle
+    do lm=l**2+1,(l+1)**2
+      i=ngp+idxlo(lm,ilo,ias)
+      j=ngp+idxlo(lm,jlo,ias)
+      o(i,j)=ololo(ilo,jlo,ias)
+    end do
   end do
 end do
 end subroutine
