@@ -45,8 +45,7 @@ do i=2,ni
   i1=mod(i-1,2)
   do j=i,ni
     z1=(zi(j)-zi(i-1))*g(i0,j)
-    t1=abs(dble(z1))+abs(aimag(z1))
-    if (t1 > 1.d-14) then
+    if (abs(z1%re)+abs(z1%im) > 1.d-14) then
       g(i1,j)=(g(i0,i-1)-g(i0,j))/z1
     else
       g(i1,j)=0.d0
@@ -71,14 +70,14 @@ do i=1,no
     b0=b1
     b1=z2
 ! check for overflow and rescale
-    if ((abs(dble(a1)) > 1.d100).or.(abs(aimag(a1)) > 1.d100)) then
+    if ((abs(a1%re) > 1.d100).or.(abs(a1%im) > 1.d100)) then
       t1=1.d0/abs(a1)
       a0=a0*t1
       b0=b0*t1
       a1=a1*t1
       b1=b1*t1
     end if
-    if ((abs(dble(b1)) > 1.d100).or.(abs(aimag(b1)) > 1.d100)) then
+    if ((abs(b1%re) > 1.d100).or.(abs(b1%im) > 1.d100)) then
       t1=1.d0/abs(b1)
       a0=a0*t1
       b0=b0*t1
@@ -86,8 +85,7 @@ do i=1,no
       b1=b1*t1
     end if
   end do
-  t1=abs(dble(b1))+abs(aimag(b1))
-  if (t1 >= 1.d-14) then
+  if (abs(b1%re)+abs(b1%im) > 1.d-14) then
     uo(i)=a1/b1
   else
     uo(i)=0.d0
