@@ -12,7 +12,7 @@ use modomp
 use moddelf
 implicit none
 ! local variables
-integer ik,jk,iv(3),jspn,idm
+integer ik,jk,jspn,idm
 integer is,ia,ias,ip,nthd
 integer nmix,nwork,n,lp
 ! use Broyden mixing only
@@ -31,20 +31,10 @@ call init0
 call init1
 call init2
 call init4
-! check k-point grid is commensurate with q-point grid
-iv(:)=mod(ngridk(:),ngridq(:))
-if ((iv(1) /= 0).or.(iv(2) /= 0).or.(iv(3) /= 0)) then
-  write(*,*)
-  write(*,'("Error(phonon): k-point grid incommensurate with q-point grid")')
-  write(*,'(" ngridk : ",3I6)') ngridk
-  write(*,'(" ngridq : ",3I6)') ngridq
-  write(*,*)
-  stop
-end if
 if (lmaxi < 2) then
   write(*,*)
   write(*,'("Error(phonon): lmaxi too small for calculating DFPT phonons : ",&
-   &I4)') lmaxi
+   &I0)') lmaxi
   write(*,'(" Run the ground-state calculation again with lmaxi >= 2")')
   write(*,*)
   stop
@@ -111,13 +101,9 @@ call gengclgq(.false.,iqph,ngvec,gqc,gclgq)
 call gendcfun
 ! generate the gradient of the Kohn-Sham potential
 call gengvsmt
+! zero the density derivative
+drhmg(:)=0.d0
 ! initialise the potential derivative
-drhomt(:,:)=0.d0
-drhoir(:)=0.d0
-if (spinpol) then
-  dmagmt(:,:,:)=0.d0
-  dmagir(:,:)=0.d0
-end if
 call dpotks
 call gendvsig
 ! initialise the mixer
@@ -230,19 +216,9 @@ devalsv(:,ik)=devalfv(:,1,ik)
   end do
 ! add densities from each process and redistribute
   if (np_mpi > 1) then
-    n=npmtmax*natmtot
-    call mpi_allreduce(mpi_in_place,drhomt,n,mpi_double_complex,mpi_sum, &
-     mpicom,ierror)
-    call mpi_allreduce(mpi_in_place,drhoir,ngtot,mpi_double_complex,mpi_sum, &
-     mpicom,ierror)
-    if (spinpol) then
-      n=npmtmax*natmtot*ndmag
-      call mpi_allreduce(mpi_in_place,dmagmt,n,mpi_double_complex,mpi_sum, &
-       mpicom,ierror)
-      n=ngtot*ndmag
-      call mpi_allreduce(mpi_in_place,dmagir,n,mpi_double_complex,mpi_sum, &
-       mpicom,ierror)
-    end if
+    n=size(drhmg)
+    call mpi_allreduce(mpi_in_place,drhmg,n,mpi_double_complex,mpi_sum,mpicom, &
+     ierror)
   end if
 ! synchronise MPI processes
   call mpi_barrier(mpicom,ierror)
@@ -271,7 +247,7 @@ devalsv(:,ik)=devalfv(:,1,ik)
 ! end the self-consistent loop
 end do
 write(*,*)
-write(*,'("Warning(phonon): failed to reach self-consistency after ",I4,&
+write(*,'("Warning(phonon): failed to reach self-consistency after ",I0,&
  &" loops")') maxscl
 20 continue
 ! close the RMSDDVS.OUT file
