@@ -18,7 +18,7 @@ use modmain
 ! !DESCRIPTION:
 !   Produces a 1D plot of the real functions contained in arrays {\tt rfmt} and
 !   {\tt rfir} along the lines connecting the vertices in the global array
-!   {\tt vvlp1d}. See routine {\tt rfplot}.
+!   {\tt vvlp1d}. See routine {\tt rfpts}.
 !
 ! !REVISION HISTORY:
 !   Created June 2003 (JKD)
@@ -35,7 +35,7 @@ real(8) fmin,fmax,t1
 real(8), allocatable :: fp(:,:)
 if ((nf < 1).or.(nf > 4)) then
   write(*,*)
-  write(*,'("Error(plot1d): invalid number of functions : ",I8)') nf
+  write(*,'("Error(plot1d): invalid number of functions : ",I0)') nf
   write(*,*)
   stop
 end if
@@ -43,8 +43,8 @@ allocate(fp(npp1d,nf))
 ! connect the 1D plotting vertices
 call plotpt1d(avec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
 do jf=1,nf
-! evaluate function at each point
-  call rfplot(npp1d,vplp1d,rfmt(:,:,jf),rfir(:,jf),fp(:,jf))
+! evaluate real function at each point
+  call rfpts(npp1d,vplp1d,rfmt(:,:,jf),rfir(:,jf),fp(:,jf))
 end do
 do ip=ip01d,npp1d
 ! write the point distances and function to file
