@@ -35,7 +35,7 @@ real(8) v1(3)
 real(8), allocatable :: vpl(:,:),fp(:,:)
 if ((nf < 1).or.(nf > 4)) then
   write(*,*)
-  write(*,'("Error(plot3d): invalid number of functions : ",I8)') nf
+  write(*,'("Error(plot3d): invalid number of functions : ",I0)') nf
   write(*,*)
   stop
 end if
@@ -45,9 +45,9 @@ np=np3d(1)*np3d(2)*np3d(3)
 allocate(vpl(3,np),fp(np,nf))
 ! generate the 3D plotting points
 call plotpt3d(vpl)
-! evaluate the functions at the grid points
+! evaluate the real functions at the grid points
 do jf=1,nf
-  call rfplot(np,vpl,rfmt(:,:,jf),rfir(:,jf),fp(:,jf))
+  call rfpts(np,vpl,rfmt(:,:,jf),rfir(:,jf),fp(:,jf))
 end do
 ! write functions to file
 write(fnum,'(3I6," : grid size")') np3d(:)
