@@ -44,13 +44,13 @@ real(8) dt,f,t1
 real(8), allocatable :: seg(:)
 if (nv < 1) then
   write(*,*)
-  write(*,'("Error(plotpt1d): nv < 1 : ",I8)') nv
+  write(*,'("Error(plotpt1d): nv < 1 : ",I0)') nv
   write(*,*)
   stop
 end if
 if (np < nv) then
   write(*,*)
-  write(*,'("Error(plotpt1d): np < nv : ",2I8)') np,nv
+  write(*,'("Error(plotpt1d): np < nv :",2(X,I0))') np,nv
   write(*,*)
   stop
 end if
