@@ -34,7 +34,7 @@ do jf=1,nf
 ! loop over real-complex FFT points
   do ifq=ifq0,nfqrz
 ! evaluate the complex function at all the plot points
-    call zfplot(np,vpl,zfmt(:,:,jf,ifq),zfir(:,jf,ifq),fpq(:,ifq))
+    call zfpts(np,vpl,zfmt(:,:,jf,ifq),zfir(:,jf,ifq),fpq(:,ifq))
   end do
   do ip=1,np
     sm=0.d0
