@@ -16,7 +16,7 @@ complex(8), external :: zfpole
 polefit=0.d0
 do iw=0,nwfm
   z1=zfm(iw)-zfpole(c,wfm(iw))
-  polefit=polefit+dble(z1)**2+aimag(z1)**2
+  polefit=polefit+z1%re**2+z1%im**2
 end do
 end function
 
