@@ -25,8 +25,7 @@ implicit none
 integer is,ias,nthd
 integer nr,nri,iro,i0,i1
 ! allocatable arrays
-complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
-complex(8), allocatable :: zvclmt(:,:),zvclir(:)
+complex(8), allocatable :: zrhomt(:,:),zrhoir(:),zvclmt(:,:),zvclir(:)
 allocate(zrhomt(npmtmax,natmtot))
 ! convert real muffin-tin charge density to complex spherical harmonic expansion
 call holdthd(natmtot,nthd)
