@@ -12,14 +12,14 @@ integer ir
 real(8) v0,v(3)
 ! allocatable arrays
 real(8), allocatable :: rfft(:)
-if (sum(abs(efielduc(:))) < epslat) return
+if (sum(abs(efieldcu(:))) < epslat) return
 allocate(rfft(nqpt))
 ! constant added to potential so that it is zero at the ultracell center
 v(:)=0.5d0*(avecu(:,1)+avecu(:,2)+avecu(:,3))
-v0=dot_product(efielduc(:),v(:))
+v0=dot_product(efieldcu(:),v(:))
 ! calculate the potential in real-space
 do ir=1,nqpt
-  rfft(ir)=v0-dot_product(efielduc(:),vrcu(:,ir))
+  rfft(ir)=v0-dot_product(efieldcu(:),vrcu(:,ir))
 end do
 ! Fourier transform to Q-space
 call rzfftifc(3,ngridq,-1,rfft,vclq)
