@@ -6,13 +6,11 @@
 subroutine potuinit
 use modmain
 use modulr
-use modrandom
 use modomp
 implicit none
 ! local variables
 integer ifq,idm,is,ias
 integer nrc,nrci,npc
-real(8) cb,t1
 ! automatic arrays
 real(8) rfmt(npcmtmax)
 ! set the Q=0 muffin-tin potential equal to that of the normal ground-state
@@ -56,34 +54,5 @@ end do
 ! repeat for the interstitial magnetic field
 bsqir(1:ngtot,1:ndmag,1)=bsir(1:ngtot,1:ndmag)
 bsqir(1:ngtot,1:ndmag,2:nfqrz)=0.d0
-! coupling constant of the external field (g_e/4c)
-cb=gfacte/(4.d0*solsc)
-! initialise the external magnetic fields
-if (abs(rndbfcu) > 0.d0) then
-  t1=cb*rndbfcu
-  do ifq=1,nfqrz
-    do idm=1,ndmag
-      bfcq(idm,ifq)=t1*cmplx(randomu()-0.5d0,randomu()-0.5d0,8)
-      do ias=1,natmtot
-        bfcmtq(ias,idm,ifq)=t1*cmplx(randomu()-0.5d0,randomu()-0.5d0,8)
-      end do
-    end do
-  end do
-  bfcq(1:ndmag,1)=dble(bfcq(1:ndmag,1))
-  bfcmtq(1:natmtot,1:ndmag,1)=dble(bfcmtq(1:natmtot,1:ndmag,1))
-else
-  bfcq(1:ndmag,1:nfqrz)=0.d0
-  bfcmtq(1:natmtot,1:ndmag,1:nfqrz)=0.d0
-end if
-! add the global external magnetic field
-do idm=1,ndmag
-  if (ncmag) then
-    t1=cb*bfielduc(idm)
-  else
-    t1=cb*bfielduc(3)
-  end if
-  bfcq(idm,1)=bfcq(idm,1)+t1
-  bfcmtq(1:natmtot,idm,1)=bfcmtq(1:natmtot,idm,1)+t1
-end do
 end subroutine
 
