@@ -46,7 +46,7 @@ if (spinpol) then
     allocate(gup2(n),gdn2(n),gupdn(n))
     allocate(dxdgu2(n),dxdgd2(n),dxdgud(n))
     allocate(dcdgu2(n),dcdgd2(n),dcdgud(n))
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     allocate(g2up(n),g2dn(n))
     allocate(gvup(n,3),gvdn(n,3))
     allocate(gup2(n),gdn2(n),gupdn(n))
@@ -64,7 +64,7 @@ else
   else if (xcgrad == 2) then
     allocate(g2rho(n),gvrho(n,3),grho2(n))
     allocate(dxdgr2(n),dcdgr2(n))
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     allocate(g2rho(n),gvrho(n,3),grho2(n))
     allocate(dxdgr2(n),dcdgr2(n))
     allocate(dxdg2r(n),dcdg2r(n))
@@ -104,14 +104,17 @@ if (spinpol) then
     end do
   end if
   if (xcgrad < 1) then
+! LSDA
     call xcifc(xctype_,n,tempa=swidth,rhoup=rhoup,rhodn=rhodn,ex=exir_, &
      ec=ecir_,vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn)
   else if (xcgrad == 1) then
+! GGA
     call ggair_sp_1(rhoup,rhodn,grho,gup,gdn,g2up,g2dn,g3rho,g3up,g3dn)
     call xcifc(xctype_,n,rhoup=rhoup,rhodn=rhodn,grho=grho,gup=gup,gdn=gdn, &
      g2up=g2up,g2dn=g2dn,g3rho=g3rho,g3up=g3up,g3dn=g3dn,ex=exir_,ec=ecir_, &
      vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn)
   else if (xcgrad == 2) then
+! GGA
     call ggair_sp_2a(rhoup,rhodn,g2up,g2dn,gvup,gvdn,gup2,gdn2,gupdn)
     call xcifc(xctype_,n,rhoup=rhoup,rhodn=rhodn,gup2=gup2,gdn2=gdn2, &
      gupdn=gupdn,ex=exir_,ec=ecir_,vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn, &
@@ -120,6 +123,7 @@ if (spinpol) then
     call ggair_sp_2b(g2up,g2dn,gvup,gvdn,vxup,vxdn,vcup,vcdn,dxdgu2,dxdgd2, &
      dxdgud,dcdgu2,dcdgd2,dcdgud)
   else if (any(xcgrad == [3,4,5])) then
+! meta-GGA with energy
     call ggair_sp_2a(rhoup,rhodn,g2up,g2dn,gvup,gvdn,gup2,gdn2,gupdn)
 ! enforce the von Weizsacker lower bound
     call k_vwlb(n,rhoup,gup2,tauir_(:,1))
@@ -133,7 +137,7 @@ if (spinpol) then
     call ggair_sp_2b(g2up,g2dn,gvup,gvdn,vxup,vxdn,vcup,vcdn,dxdgu2,dxdgd2, &
      dxdgud,dcdgu2,dcdgd2,dcdgud)
 ! determine δτ(r')/δρ(r) using an approximate kinetic energy density functional
-    if (xcgrad /= 3) then
+    if (any(xcgrad == [4,5])) then
       call xcifc(ktype,n,rhoup=rhoup,rhodn=rhodn,g2up=g2up,g2dn=g2dn,gup2=gup2,&
        gdn2=gdn2,tauup=tauir_(:,1),taudn=tauir_(:,2),dtdru=dtdru,dtdrd=dtdrd, &
        dtdgu2=dxdgu2,dtdgd2=dxdgd2,dtdg2u=dxdg2u,dtdg2d=dxdg2d,wxup=dcdgu2, &
@@ -146,6 +150,17 @@ if (spinpol) then
       end if
       wxcir_(1:n)=0.5d0*(wxup(1:n)+wxdn(1:n)+wcup(1:n)+wcdn(1:n))
     end if
+  else if (xcgrad == 6) then
+! potential-only meta-GGA
+    call ggair_sp_2a(rhoup,rhodn,g2up,g2dn,gvup,gvdn,gup2,gdn2,gupdn)
+    call xcifc(xctype_,n,c_tb09=c_tb09,rhoup=rhoup,rhodn=rhodn,g2up=g2up, &
+     g2dn=g2dn,gup2=gup2,gdn2=gdn2,gupdn=gupdn,tauup=tauir_(:,1), &
+     taudn=tauir_(:,2),vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn,dxdgu2=dxdgu2, &
+     dxdgd2=dxdgd2,dxdgud=dxdgud,dcdgu2=dcdgu2,dcdgd2=dcdgd2,dcdgud=dcdgud, &
+     dxdg2u=dxdg2u,dxdg2d=dxdg2d,dcdg2u=dcdg2u,dcdg2d=dcdg2d,wxup=wxup, &
+     wxdn=wxdn,wcup=wcup,wcdn=wcdn)
+    exir_(1:n)=0.d0; ecir_(1:n)=0.d0
+    wxcir_(1:n)=0.d0
   end if
 ! hybrid functionals
   if (hybrid) then
@@ -203,15 +218,22 @@ else
      dcdg2r=dcdg2r,wx=wx,wc=wc)
     call ggair_2b(g2rho,gvrho,vx,vc,dxdgr2,dcdgr2)
 ! determine δτ(r')/δρ(r) using an approximate kinetic energy density functional
-    if (xcgrad /= 3) then
+    if (any(xcgrad == [4,5])) then
       call xcifc(ktype,n,rho=rhoir_,g2rho=g2rho,grho2=grho2,tau=tauir_, &
        dtdr=dtdr,dtdgr2=dxdgr2,dtdg2r=dxdg2r,wx=dcdgr2)
       call ggair_4(gvrho,vx,vc,wx,wc,dtdr,dxdgr2)
       if (kgrad == 3) then
         call ggair_3(vx,vc,wx,wc,dxdg2r)
       end if
+      wxcir_(1:n)=wx(1:n)+wc(1:n)
     end if
-    wxcir_(1:n)=wx(1:n)+wc(1:n)
+  else if (xcgrad == 6) then
+    call ggair_2a(rhoir_,g2rho,gvrho,grho2)
+    call xcifc(xctype_,n,c_tb09=c_tb09,rho=rhoir_,g2rho=g2rho,grho2=grho2, &
+     tau=tauir_,vx=vx,vc=vc,dxdgr2=dxdgr2,dcdgr2=dcdgr2,dxdg2r=dxdg2r, &
+     dcdg2r=dcdg2r,wx=wx,wc=wc)
+    exir_(1:n)=0.d0; ecir_(1:n)=0.d0
+    wxcir_(1:n)=0.d0
   end if
 ! hybrid functionals
   if (hybrid) then
@@ -234,7 +256,7 @@ if (spinpol) then
     deallocate(gup2,gdn2,gupdn)
     deallocate(dxdgu2,dxdgd2,dxdgud)
     deallocate(dcdgu2,dcdgd2,dcdgud)
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     deallocate(g2up,g2dn)
     deallocate(gvup,gvdn)
     deallocate(gup2,gdn2,gupdn)
@@ -252,7 +274,7 @@ else
   else if (xcgrad == 2) then
     deallocate(g2rho,gvrho,grho2)
     deallocate(dxdgr2,dcdgr2)
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     deallocate(g2rho,gvrho,grho2)
     deallocate(dxdgr2,dcdgr2,dxdg2r,dcdg2r)
     deallocate(dtdr,wx,wc)
