@@ -42,7 +42,7 @@ is=idxis(ias)
 n=npmt(is)
 ! allocate local arrays
 allocate(rho(n),ex(n),ec(n),vxc(n))
-if (any(xcgrad == [3,4,5])) allocate(tau(n,nspinor))
+if (any(xcgrad == [3,4,5,6])) allocate(tau(n,nspinor))
 if (spinpol) then
   allocate(mag(n,3),bxc(n,3))
 end if
@@ -59,7 +59,7 @@ if (spinpol) then
     allocate(gup2(n),gdn2(n),gupdn(n))
     allocate(dxdgu2(n),dxdgd2(n),dxdgud(n))
     allocate(dcdgu2(n),dcdgd2(n),dcdgud(n))
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     allocate(g2up(n),g2dn(n))
     allocate(gvup(n,3),gvdn(n,3))
     allocate(gup2(n),gdn2(n),gupdn(n))
@@ -77,7 +77,7 @@ else
   else if (xcgrad == 2) then
     allocate(g2rho(n),gvrho(n,3),grho2(n))
     allocate(dxdgr2(n),dcdgr2(n))
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     allocate(g2rho(n),gvrho(n,3),grho2(n))
     allocate(dxdgr2(n),dcdgr2(n))
     allocate(dxdg2r(n),dcdg2r(n))
@@ -93,7 +93,7 @@ else
   rho(1:n)=rhomt_(1:n,ias)
 end if
 ! convert tau to spherical coordinates if required
-if (any(xcgrad == [3,4,5])) then
+if (any(xcgrad == [3,4,5,6])) then
   do ispn=1,nspinor
     if (tsh) then
       call rbsht(nr,nri,taumt_(:,ias,ispn),tau(:,ispn))
@@ -121,7 +121,7 @@ if (spinpol) then
     if (xcgrad == 0) then
 ! LSDA
       do i=1,n
-! compute rhoup=(rho+|m|)/2 and rhodn=(rho-|m|)/2
+! compute ρ↑=(ρ+|m|)/2 and ρ↓=(ρ-|m|)/2
         t0=rho(i)
         t1=sqrt(mag(i,1)**2+mag(i,2)**2+mag(i,3)**2)
         rhoup(i)=0.5d0*(t0+t1)
@@ -139,7 +139,7 @@ if (spinpol) then
   else
 ! collinear
     do i=1,n
-! compute rhoup=(rho+m_z)/2 and rhodn=(rho-m_z)/2
+! compute ρ↑=(rho+m_z)/2 and ρ↓=(rho-m_z)/2
       t0=rho(i)
       t1=mag(i,1)
       rhoup(i)=0.5d0*(t0+t1)
@@ -148,14 +148,17 @@ if (spinpol) then
   end if
 ! call the exchange-correlation interface routine
   if (xcgrad < 1) then
+! LSDA
     call xcifc(xctype_,n,tempa=swidth,rhoup=rhoup,rhodn=rhodn,ex=ex,ec=ec, &
      vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn)
   else if (xcgrad == 1) then
+! GGA
     call ggamt_sp_1(is,n,rhoup,rhodn,grho,gup,gdn,g2up,g2dn,g3rho,g3up,g3dn)
     call xcifc(xctype_,n,rhoup=rhoup,rhodn=rhodn,grho=grho,gup=gup,gdn=gdn, &
      g2up=g2up,g2dn=g2dn,g3rho=g3rho,g3up=g3up,g3dn=g3dn,ex=ex,ec=ec,vxup=vxup,&
      vxdn=vxdn,vcup=vcup,vcdn=vcdn)
   else if (xcgrad == 2) then
+! GGA
     call ggamt_sp_2a(is,n,rhoup,rhodn,g2up,g2dn,gvup,gvdn,gup2,gdn2,gupdn)
     call xcifc(xctype_,n,rhoup=rhoup,rhodn=rhodn,gup2=gup2,gdn2=gdn2, &
      gupdn=gupdn,ex=ex,ec=ec,vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn, &
@@ -164,6 +167,7 @@ if (spinpol) then
     call ggamt_sp_2b(is,n,g2up,g2dn,gvup,gvdn,vxup,vxdn,vcup,vcdn,dxdgu2, &
      dxdgd2,dxdgud,dcdgu2,dcdgd2,dcdgud)
   else if (any(xcgrad == [3,4,5])) then
+! meta-GGA with energy
     call ggamt_sp_2a(is,n,rhoup,rhodn,g2up,g2dn,gvup,gvdn,gup2,gdn2,gupdn)
 ! enforce the von Weizsacker lower bound
     call k_vwlb(n,rhoup,gup2,tau(:,1))
@@ -176,7 +180,7 @@ if (spinpol) then
     call ggamt_sp_2b(is,n,g2up,g2dn,gvup,gvdn,vxup,vxdn,vcup,vcdn,dxdgu2, &
      dxdgd2,dxdgud,dcdgu2,dcdgd2,dcdgud)
 ! determine δτ(r')/δρ(r) using an approximate kinetic energy functional
-    if (xcgrad /= 3) then
+    if (any(xcgrad == [4,5])) then
       call xcifc(ktype,n,rhoup=rhoup,rhodn=rhodn,g2up=g2up,g2dn=g2dn,gup2=gup2,&
        gdn2=gdn2,tauup=tau(:,1),taudn=tau(:,2),dtdru=dtdru,dtdrd=dtdrd, &
        dtdgu2=dxdgu2,dtdgd2=dxdgd2,dtdg2u=dxdg2u,dtdg2d=dxdg2d,wxup=dcdgu2, &
@@ -187,9 +191,20 @@ if (spinpol) then
         call ggamt_3(is,n,vxup,vcup,wxup,wcup,dxdg2u)
         call ggamt_3(is,n,vxdn,vcdn,wxdn,wcdn,dxdg2d)
       end if
+      wxcmt_(1:n,ias)=0.5d0*(wxup(1:n)+wxdn(1:n)+wcup(1:n)+wcdn(1:n))
+      if (tsh) call rfshtip(nr,nri,wxcmt_(:,ias))
     end if
-    wxcmt_(1:n,ias)=0.5d0*(wxup(1:n)+wxdn(1:n)+wcup(1:n)+wcdn(1:n))
-    if (tsh) call rfshtip(nr,nri,wxcmt_(:,ias))
+  else if (xcgrad == 6) then
+! potential-only meta-GGA
+    call ggamt_sp_2a(is,n,rhoup,rhodn,g2up,g2dn,gvup,gvdn,gup2,gdn2,gupdn)
+    call xcifc(xctype_,n,c_tb09=c_tb09,rhoup=rhoup,rhodn=rhodn,g2up=g2up, &
+     g2dn=g2dn,gup2=gup2,gdn2=gdn2,gupdn=gupdn,tauup=tau(:,1),taudn=tau(:,2), &
+     vxup=vxup,vxdn=vxdn,vcup=vcup,vcdn=vcdn,dxdgu2=dxdgu2,dxdgd2=dxdgd2, &
+     dxdgud=dxdgud,dcdgu2=dcdgu2,dcdgd2=dcdgd2,dcdgud=dcdgud,dxdg2u=dxdg2u, &
+     dxdg2d=dxdg2d,dcdg2u=dcdg2u,dcdg2d=dcdg2d,wxup=wxup,wxdn=wxdn,wcup=wcup, &
+     wcdn=wcdn)
+    ex(1:n)=0.d0; ec(1:n)=0.d0
+    wxcmt_(1:n,ias)=0.d0
   end if
 ! hybrid functionals
   if (hybrid) then
@@ -208,7 +223,7 @@ if (spinpol) then
       vxc(i)=0.5d0*(t1+t2)
 ! determine the exchange-correlation magnetic field
       t3=0.5d0*(t1-t2)
-! |m| = rhoup - rhodn
+! |m| = ρ↑ - ρ↓
       t4=rhoup(i)-rhodn(i)
       if (abs(t4) > 1.d-8) t4=t3/t4
       bxc(i,1:3)=mag(i,1:3)*t4
@@ -256,16 +271,23 @@ else
      wc=wc)
     call ggamt_2b(is,n,g2rho,gvrho,vx,vc,dxdgr2,dcdgr2)
 ! determine δτ(r')/δρ(r) using an approximate kinetic energy functional
-    if (xcgrad /= 3) then
+    if (any(xcgrad == [4,5])) then
       call xcifc(ktype,n,rho=rho,g2rho=g2rho,grho2=grho2,tau=tau,dtdr=dtdr, &
        dtdgr2=dxdgr2,dtdg2r=dxdg2r,wx=dcdgr2)
       call ggamt_4(is,n,gvrho,vx,vc,wx,wc,dtdr,dxdgr2)
       if (kgrad == 3) then
         call ggamt_3(is,n,vx,vc,wx,wc,dxdg2r)
       end if
+      wxcmt_(1:n,ias)=wx(1:n)+wc(1:n)
+      if (tsh) call rfshtip(nr,nri,wxcmt_(:,ias))
     end if
-    wxcmt_(1:n,ias)=wx(1:n)+wc(1:n)
-    if (tsh) call rfshtip(nr,nri,wxcmt_(:,ias))
+  else if (xcgrad == 6) then
+    call ggamt_2a(tsh,is,n,rhomt_(:,ias),g2rho,gvrho,grho2)
+    call xcifc(xctype_,n,c_tb09=c_tb09,rho=rho,g2rho=g2rho,grho2=grho2,tau=tau,&
+     vx=vx,vc=vc,dxdgr2=dxdgr2,dcdgr2=dcdgr2,dxdg2r=dxdg2r,dcdg2r=dcdg2r, &
+     wx=wx,wc=wc)
+    ex(1:n)=0.d0; ec(1:n)=0.d0
+    wxcmt_(1:n,ias)=0.d0
   end if
 ! hybrid functionals
   if (hybrid) then
@@ -290,7 +312,7 @@ else
   vxcmt_(1:n,ias)=vxc(1:n)
 end if
 deallocate(rho,ex,ec,vxc)
-if (any(xcgrad == [3,4,5])) deallocate(tau)
+if (any(xcgrad == [3,4,5,6])) deallocate(tau)
 if (spinpol) then
   deallocate(mag,bxc)
   deallocate(rhoup,rhodn,vxup,vxdn,vcup,vcdn)
@@ -302,7 +324,7 @@ if (spinpol) then
     deallocate(gup2,gdn2,gupdn)
     deallocate(dxdgu2,dxdgd2,dxdgud)
     deallocate(dcdgu2,dcdgd2,dcdgud)
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     deallocate(g2up,g2dn)
     deallocate(gvup,gvdn)
     deallocate(gup2,gdn2,gupdn)
@@ -320,7 +342,7 @@ else
   else if (xcgrad == 2) then
     deallocate(g2rho,gvrho,grho2)
     deallocate(dxdgr2,dcdgr2)
-  else if (any(xcgrad == [3,4,5])) then
+  else if (any(xcgrad == [3,4,5,6])) then
     deallocate(g2rho,gvrho,grho2)
     deallocate(dxdgr2,dcdgr2,dxdg2r,dcdg2r)
     deallocate(dtdr,wx,wc)
