@@ -19,8 +19,8 @@ allocate(grfmt(npmtmax,natmtot,3),grfir(ngtot,3))
 allocate(zrhomt(npmtmax,natmtot),zrhoir(ngtot))
 allocate(zvclmt(npmtmax,natmtot),zvclir(ngtot))
 ! compute the divergence of B_xc
-rfmt(:,:)=0.d0
-rfir(:)=0.d0
+rfmt(1:npmtmax,1:natmtot)=0.d0
+rfir(1:ngtot)=0.d0
 do idm=1,3
   call gradrf(bxcmt(:,:,idm),bxcir(:,idm),grfmt,grfir)
   do ias=1,natmtot
@@ -28,7 +28,7 @@ do idm=1,3
     np=npmt(is)
     rfmt(1:np,ias)=rfmt(1:np,ias)+grfmt(1:np,ias,idm)
   end do
-  rfir(:)=rfir(:)+grfir(:,idm)
+  rfir(1:ngtot)=rfir(1:ngtot)+grfir(1:ngtot,idm)
 end do
 ! convert real muffin-tin divergence to complex spherical harmonic expansion
 do ias=1,natmtot
@@ -36,10 +36,10 @@ do ias=1,natmtot
   call rtozfmt(nrmt(is),nrmti(is),rfmt(:,ias),zrhomt(:,ias))
 end do
 ! store real interstitial divergence in a complex array
-zrhoir(:)=rfir(:)
+zrhoir(1:ngtot)=rfir(1:ngtot)
 ! solve the complex Poisson's equation
 call genzvclmt(nrmt,nrmti,nrmtmax,rlmt,wprmt,npmtmax,zrhomt,zvclmt)
-call zpotcoul(nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg,ngvec, &
+call zpotcoul(0,nrmt,nrmti,npmt,nrmtmax,rlmt,ngridg,igfft,ngvec,gc,gclg,ngvec, &
  jlgrmt,ylmg,sfacg,zrhoir,npmtmax,zvclmt,zvclir)
 ! convert complex muffin-tin potential to real spherical harmonic expansion
 do ias=1,natmtot
@@ -47,7 +47,7 @@ do ias=1,natmtot
   call ztorfmt(nrmt(is),nrmti(is),zvclmt(:,ias),rfmt(:,ias))
 end do
 ! store complex interstitial potential in real array
-rfir(:)=dble(zvclir(:))
+rfir(1:ngtot)=dble(zvclir(1:ngtot))
 ! compute the gradient
 call gradrf(rfmt,rfir,grfmt,grfir)
 ! add gradient over 4π to existing B_xc
@@ -59,7 +59,7 @@ do idm=1,3
     bxcmt(1:np,ias,idm)=bxcmt(1:np,ias,idm)+t1*grfmt(1:np,ias,idm)
   end do
 end do
-bxcir(:,:)=bxcir(:,:)+t1*grfir(:,:)
+bxcir(1:ngtot,1:3)=bxcir(1:ngtot,1:3)+t1*grfir(1:ngtot,1:3)
 deallocate(rfmt,rfir,grfmt,grfir)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
 end subroutine
