@@ -5,6 +5,7 @@
 
 subroutine putepsinv(iq,epsi)
 use modmain
+use modramdisk
 implicit none
 ! arguments
 integer, intent(in) :: iq
@@ -14,9 +15,17 @@ integer recl
 ! determine the record length for EPSINV.OUT
 inquire(iolength=recl) vql(1:3,iq),ngrf,nwrf,epsi
 !$OMP CRITICAL(u245)
-open(245,file='EPSINV.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
-write(245,rec=iq) vql(1:3,iq),ngrf,nwrf,epsi
-close(245)
+! write to RAM disk if required
+if (ramdisk) then
+  call putrd('EPSINV.OUT',iq,v1=vql(1:3,iq),n1=ngrf,n2=nwrf, &
+   nzv=ngrf*ngrf*nwrf,zva=epsi)
+end if
+! write to disk if required
+if (wrtdsk) then
+  open(245,file='EPSINV.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
+  write(245,rec=iq) vql(1:3,iq),ngrf,nwrf,epsi
+  close(245)
+end if
 !$OMP END CRITICAL(u245)
 end subroutine
 
