@@ -3,20 +3,20 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine putevalsv(fext,ik,evalsvp)
+subroutine putevalsv(fext,ik,evalsv_)
 use modmain
 implicit none
 ! arguments
 character(*), intent(in) :: fext
 integer, intent(in) :: ik
-real(8), intent(in) :: evalsvp(nstsv)
+real(8), intent(in) :: evalsv_(nstsv)
 ! local variables
 integer recl
 ! find the record length
-inquire(iolength=recl) vkl(1:3,ik),nstsv,evalsvp
+inquire(iolength=recl) vkl(1:3,ik),nstsv,evalsv_
 !$OMP CRITICAL(u204)
 open(204,file='EVALSV'//trim(fext),form='UNFORMATTED',access='DIRECT',recl=recl)
-write(204,rec=ik) vkl(1:3,ik),nstsv,evalsvp
+write(204,rec=ik) vkl(1:3,ik),nstsv,evalsv_
 close(204)
 !$OMP END CRITICAL(u204)
 end subroutine
