@@ -16,7 +16,7 @@ integer is,ias,nthd
 complex(8), external :: rcfmtinp
 ! interstitial contribution
 rcfinp=sum((cfunir(1:ngtot)*rfir(1:ngtot))*cfir(1:ngtot))
-rcfinp=rcfinp*(omega/dble(ngtot))
+rcfinp=rcfinp*(omega/ngtot)
 ! muffin-tin contribution
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
