@@ -50,19 +50,19 @@ real(8) g1(nr),f1(nr),fr(nr)
 real(8), external :: splint
 if (k < 1) then
   write(*,*)
-  write(*,'("Error(rdirac): k < 1 : ",I8)') k
+  write(*,'("Error(rdirac): k < 1 : ",I0)') k
   write(*,*)
   stop
 end if
 if (k > n) then
   write(*,*)
-  write(*,'("Error(rdirac): incompatible n and k : ",2I8)') n,k
+  write(*,'("Error(rdirac): incompatible n and k :",2(X,I0))') n,k
   write(*,*)
   stop
 end if
 if ((k == n).and.(l /= k-1)) then
   write(*,*)
-  write(*,'("Error(rdirac): incompatible n, k and l : ",3I8)') n,k,l
+  write(*,'("Error(rdirac): incompatible n, k and l :",3(X,I0))') n,k,l
   write(*,*)
   stop
 end if
@@ -72,13 +72,13 @@ else if (k == l+1) then
   kpa=-k
 else
   write(*,*)
-  write(*,'("Error(rdirac): incompatible l and k : ",2I8)') l,k
+  write(*,'("Error(rdirac): incompatible l and k :",2(X,I0))') l,k
   write(*,*)
   stop
 end if
 if (nr < 4) then
   write(*,*)
-  write(*,'("Error(rdirac): nr < 4 : ",I8)') nr
+  write(*,'("Error(rdirac): nr < 4 : ",I0)') nr
   write(*,*)
   stop
 end if
