@@ -48,12 +48,9 @@ real(8), intent(in) :: e
 integer, intent(in) :: nr
 real(8), intent(in) :: r(nr),vr(nr)
 integer, intent(out) :: nn
-real(8), intent(out) :: g0(nr),g1(nr)
-real(8), intent(out) :: f0(nr),f1(nr)
+real(8), intent(out) :: g0(nr),g1(nr),f0(nr),f1(nr)
 ! local variables
-integer ir,ir0
-! rescaling limit
-real(8), parameter :: rsc=1.d100
+integer ir,ir0,i
 real(8) ci,e0,t1,t2,t3,t4
 ! inverse speed of light
 ci=1.d0/sol
@@ -65,36 +62,30 @@ t2=dble(kpa)/r(1)
 t3=ci*(t1-vr(1))
 t4=ci*(vr(1)-e)
 f0(1)=1.d0
-f1(1)=0.d0
-g0(1)=(f1(1)-t2*f0(1))/t4
-g1(1)=t3*f0(1)-t2*g0(1)
+g0(1)=-t2/t4
+g1(1)=t3-t2*g0(1)
 ! extrapolate to the first four points
 g1(2:4)=g1(1)
-f1(2:4)=f1(1)
+f1(1:4)=0.d0
 nn=0
 do ir=2,nr
   t2=dble(kpa)/r(ir)
   t3=ci*(t1-vr(ir))
   t4=ci*(vr(ir)-e)
-  ir0=ir-3
-  if (ir0 < 1) ir0=1
+  ir0=max(ir-3,1)
+! estimate the derivatives
   g1(ir)=poly3(r(ir0),g1(ir0),r(ir))
   f1(ir)=poly3(r(ir0),f1(ir0),r(ir))
+  do i=1,8
 ! integrate to find wavefunction
-  g0(ir)=poly4i(r(ir0),g1(ir0),r(ir))+g0(ir0)
-  f0(ir)=poly4i(r(ir0),f1(ir0),r(ir))+f0(ir0)
+    g0(ir)=poly4i(r(ir0),g1(ir0),r(ir))+g0(ir0)
+    f0(ir)=poly4i(r(ir0),f1(ir0),r(ir))+f0(ir0)
 ! compute the derivatives
-  g1(ir)=t3*f0(ir)-t2*g0(ir)
-  f1(ir)=t4*g0(ir)+t2*f0(ir)
-! integrate for correction
-  g0(ir)=poly4i(r(ir0),g1(ir0),r(ir))+g0(ir0)
-  f0(ir)=poly4i(r(ir0),f1(ir0),r(ir))+f0(ir0)
-! compute the derivatives again
-  g1(ir)=t3*f0(ir)-t2*g0(ir)
-  f1(ir)=t4*g0(ir)+t2*f0(ir)
+    g1(ir)=t3*f0(ir)-t2*g0(ir)
+    f1(ir)=t4*g0(ir)+t2*f0(ir)
+  end do
 ! check for overflow
-  if ((abs(g0(ir)) > rsc).or.(abs(g1(ir)) > rsc).or. &
-      (abs(f0(ir)) > rsc).or.(abs(f1(ir)) > rsc)) then
+  if (abs(g0(ir)) > 1.d100) then
 ! set the remaining points and return
     g0(ir+1:nr)=g0(ir); g1(ir+1:nr)=g1(ir)
     f0(ir+1:nr)=f0(ir); f1(ir+1:nr)=f1(ir)
@@ -103,7 +94,6 @@ do ir=2,nr
 ! check for node
   if (g0(ir-1)*g0(ir) < 0.d0) nn=nn+1
 end do
-return
 
 contains
 
