@@ -73,7 +73,7 @@ do ik=1,nkpt
     engyvcl=engyvcl+wo*dble(vclmat(ist,ist,ik))
 ! kinetic energy from valence states
     z1=zdotc(nstsv,evecsv(:,ist),1,dkdc(:,ist,ik),1)
-    engykn=engykn+wo*dble(z1)
+    engykn=engykn+wo*z1%re
   end do
 end do
 deallocate(evecsv)
