@@ -21,8 +21,8 @@ do is=1,nspecies
     if ((is /= is_).or.(ia /= ia_)) then
       write(*,*)
       write(*,'("Error(readatdvc): species or atom number mismatch")')
-      write(*,'(" internal  : ",2I4)') is,ia
-      write(*,'(" ATDVC.OUT : ",2I4)') is_,ia_
+      write(*,'(" internal  :",2(X,I0))') is,ia
+      write(*,'(" ATDVC.OUT :",2(X,I0))') is_,ia_
       write(*,*)
       stop
     end if
