@@ -24,7 +24,7 @@ do ik=1,nkpt
   t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
   if (t1 > epslat) then
     write(*,*)
-    write(*,'("Error(reademd): differing vectors for k-point ",I8)') ik
+    write(*,'("Error(reademd): differing vectors for k-point ",I0)') ik
     write(*,'(" current : ",3G18.10)') vkl(:,ik)
     write(*,'(" EMD.OUT : ",3G18.10)') vkl_
     write(*,*)
@@ -32,14 +32,14 @@ do ik=1,nkpt
   end if
   if (nhk(1,ik) /= nhk_) then
     write(*,*)
-    write(*,'("Error(reademd): differing nhk for k-point ",I8)') ik
-    write(*,'(" current : ",I8)') nhk(1,ik)
-    write(*,'(" EMD.OUT : ",I8)') nhk_
+    write(*,'("Error(reademd): differing nhk for k-point ",I0)') ik
+    write(*,'(" current : ",I0)') nhk(1,ik)
+    write(*,'(" EMD.OUT : ",I0)') nhk_
     write(*,*)
     stop
   end if
 ! store momentum density in single-precision array
-  emds(:,ik)=real(emd(:))
+  emds(1:nhk_,ik)=real(emd(1:nhk_))
 end do
 close(250)
 ! write the EMD of the last k-point to test file if required
