@@ -29,15 +29,15 @@ do its=1,ntimes-1,ntsforce
   if (its /= its_) then
     write(*,*)
     write(*,'("Error(readforcet): time step number mismatch")')
-    write(*,'(" internal        : ",I8)') its
-    write(*,'(" FORCETOT_TD.OUT : ",I8)') its_
+    write(*,'(" internal        : ",I0)') its
+    write(*,'(" FORCETOT_TD.OUT : ",I0)') its_
     write(*,*)
     stop
   end if
   t1=abs(times(its)-times_)
   if (t1 > 1.d-10) then
     write(*,*)
-    write(*,'("Error(readforcet): time step mismatch for step number ",I8)') its
+    write(*,'("Error(readforcet): time step mismatch for step number ",I0)') its
     write(*,'(" internal        : ",G18.10)') times(its)
     write(*,'(" FORCETOT_TD.OUT : ",G18.10)') times_
     stop
@@ -49,9 +49,9 @@ do its=1,ntimes-1,ntsforce
       if ((is /= is_).or.(ia /= ia_)) then
         write(*,*)
         write(*,'("Error(readforcet): species or atom number mismatch for time &
-         &step number ",I8)') its
-        write(*,'(" internal        : ",2I4)') is,ia
-        write(*,'(" FORCETOT_TD.OUT : ",2I4)') is_,ia_
+         &step number ",I0)') its
+        write(*,'(" internal        :",2(X,I0))') is,ia
+        write(*,'(" FORCETOT_TD.OUT :",2(X,I0))') is_,ia_
         write(*,*)
         stop
       end if
