@@ -107,6 +107,7 @@ amixpm(2)=1.d0
 mixsdb=5
 broydpm(1)=0.4d0
 broydpm(2)=0.15d0
+mixrho=.false.
 epspot=1.d-6
 epsengy=1.d-4
 epsforce=5.d-3
@@ -149,6 +150,8 @@ lmirep=.true.
 spinpol=.false.
 spinorb=.false.
 socscf=1.d0
+bforb=.false.
+bfdmag=.false.
 atpopt=1
 maxatpstp=200
 tau0atp=0.2d0
@@ -173,9 +176,10 @@ evaltol=-1.d0
 epsband=1.d-12
 demaxbnd=2.5d0
 autolinengy=.false.
+dlefe=-0.1d0
+autodlefe=.true.
 deapw=0.2d0
 delorb=0.05d0
-dlefe=-0.1d0
 bfieldc0(:)=0.d0
 dbfieldc0(:)=0.d0
 efieldc(:)=0.d0
@@ -186,8 +190,10 @@ afspc(:,:)=0.d0
 dafspc(:,:)=0.d0
 fsmtype=0
 momfix(:)=0.d0
+momfixm=0.d0
 dmomfix(:)=0.d0
 mommtfix(:,:,:)=1.d6
+mommtfixm(:,:)=-1.d0
 taufsm=0.01d0
 rmtdelta=0.05d0
 isgkmax=-1
@@ -234,14 +240,11 @@ reducebf=1.d0
 ptnucl=.true.
 tefvr=.true.
 tefvit=.false.
-minitefv=6
-maxitefv=4
-befvit=0.25d0
-epsefvit=1.d-5
+nefvit=2
 vecql(:)=0.d0
 mustar=0.15d0
-sqados(1:2)=0.d0
-sqados(3)=1.d0
+sqaxis(1:2)=0.d0
+sqaxis(3)=1.d0
 test=.false.
 spincore=.false.
 solscf=1.d0
@@ -257,6 +260,7 @@ hybridc=1.d0
 ecvcut=-3.5d0
 esccut=-0.4d0
 gmaxrf=3.d0
+mbwgrf=-1
 emaxrf=1.d6
 ntemp=40
 nvbse0=2
@@ -272,13 +276,15 @@ fxclrc(2)=0.d0
 rndatposc=0.d0
 rndbfcmt=0.d0
 rndavec=0.d0
+c_tb09=0.d0
+tc_tb09=.false.
 hmaxvr=20.d0
 hkmax=12.d0
 lorbcnd=.false.
 lorbordc=3
 nrmtscf=1.d0
 dnrmtscf=0.d0
-lmaxdos=3
+lmaxdb=3
 epsdev=0.0025d0
 npmae0=-1
 wrtvars=.false.
@@ -322,13 +328,14 @@ scu1=1.d0
 scu2=1.d0
 scu3=1.d0
 q0cut=0.d0
+ngridkpa(:)=-1
 rndbfcu=0.d0
-bfielduc(:)=0.d0
-efielduc(:)=0.d0
+bfieldcu(:)=0.d0
+efieldcu(:)=0.d0
 tplotq0=.true.
 trdvclr=.false.
+trdbfcr=.false.
 wmaxgw=-10.d0
-twdiag=.false.
 tsediag=.false.
 actype=10
 npole=3
@@ -376,7 +383,7 @@ pwxpsn=2
 ramdisk=.true.
 wrtdsk=.true.
 epsdmat=1.d-8
-tm3old=.false.
+tm3vdl=.false.
 batch=.false.
 tafspt=.false.
 tbaspat=.false.
@@ -516,7 +523,7 @@ case('ngridk')
   read(str,*,iostat=ios) ngridk(:),dngridk(:)
   if (any(ngridk(:) < 1)) then
     write(*,*)
-    write(*,'("Error(readinput): invalid ngridk : ",3I8)') ngridk
+    write(*,'("Error(readinput): invalid ngridk :",3(X,I0))') ngridk
     write(*,*)
     stop
   end if
@@ -536,7 +543,7 @@ case('ngridq')
   read(50,*,err=20) ngridq(:)
   if (any(ngridq(:) < 1)) then
     write(*,*)
-    write(*,'("Error(readinput): invalid ngridq : ",3I8)') ngridq
+    write(*,'("Error(readinput): invalid ngridq :",3(X,I0))') ngridq
     write(*,*)
     stop
   end if
@@ -562,13 +569,13 @@ case('lmaxapw')
   read(str,*,iostat=ios) lmaxapw,dlmaxapw
   if (lmaxapw < 0) then
     write(*,*)
-    write(*,'("Error(readinput): lmaxapw < 0 : ",I8)') lmaxapw
+    write(*,'("Error(readinput): lmaxapw < 0 : ",I0)') lmaxapw
     write(*,*)
     stop
   end if
   if (lmaxapw >= maxlapw) then
     write(*,*)
-    write(*,'("Error(readinput): lmaxapw too large : ",I8)') lmaxapw
+    write(*,'("Error(readinput): lmaxapw too large : ",I0)') lmaxapw
     write(*,'("Adjust maxlapw in modmain and recompile code")')
     write(*,*)
     stop
@@ -579,7 +586,7 @@ case('lmaxo','lmaxvr')
   read(str,*,iostat=ios) lmaxo,dlmaxo
   if (lmaxo < 3) then
     write(*,*)
-    write(*,'("Error(readinput): lmaxo < 3 : ",I8)') lmaxo
+    write(*,'("Error(readinput): lmaxo < 3 : ",I0)') lmaxo
     write(*,*)
     stop
   end if
@@ -587,7 +594,7 @@ case('lmaxi','lmaxinr')
   read(50,*,err=20) lmaxi
   if (lmaxi < 1) then
     write(*,*)
-    write(*,'("Error(readinput): lmaxi < 1 : ",I8)') lmaxi
+    write(*,'("Error(readinput): lmaxi < 1 : ",I0)') lmaxi
     write(*,*)
     stop
   end if
@@ -610,6 +617,10 @@ case('socscf')
     write(*,*)
     stop
   end if
+case('bforb')
+  read(50,*,err=20) bforb
+case('bfdmag')
+  read(50,*,err=20) bfdmag
 case('xctype')
   read(50,'(A)',err=20) str
   str=trim(str)//' 0 0'
@@ -624,7 +635,7 @@ case('ktype')
   read(str,*,err=20) ktype(:)
   if (ktype(3) /= 0) then
     write(*,*)
-    write(*,'("Error(readinput): ktype(3) should be zero : ",I8)') ktype(3)
+    write(*,'("Error(readinput): ktype(3) should be zero : ",I0)') ktype(3)
     write(*,*)
     stop
   end if
@@ -704,7 +715,7 @@ case('mixsdb')
   read(50,*,err=20) mixsdb
   if (mixsdb < 2) then
     write(*,*)
-    write(*,'("Error(readinput): mixsdb < 2 : ",I8)') mixsdb
+    write(*,'("Error(readinput): mixsdb < 2 : ",I0)') mixsdb
     write(*,*)
     stop
   end if
@@ -718,11 +729,13 @@ case('broydpm')
     write(*,*)
     stop
   end if
+case('mixrho')
+  read(50,*,err=20) mixrho
 case('maxscl')
   read(50,*,err=20) maxscl
   if (maxscl < 0) then
     write(*,*)
-    write(*,'("Error(readinput): maxscl < 0 : ",I8)') maxscl
+    write(*,'("Error(readinput): maxscl < 0 : ",I0)') maxscl
     write(*,*)
     stop
   end if
@@ -745,13 +758,13 @@ case('atoms')
   read(50,*,err=20) nspecies
   if (nspecies < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nspecies < 1 : ",I8)') nspecies
+    write(*,'("Error(readinput): nspecies < 1 : ",I0)') nspecies
     write(*,*)
     stop
   end if
   if (nspecies > maxspecies) then
     write(*,*)
-    write(*,'("Error(readinput): nspecies too large : ",I8)') nspecies
+    write(*,'("Error(readinput): nspecies too large : ",I0)') nspecies
     write(*,'("Adjust maxspecies in modmain and recompile code")')
     write(*,*)
     stop
@@ -762,15 +775,15 @@ case('atoms')
     read(50,*,err=20) natoms(is)
     if (natoms(is) < 1) then
       write(*,*)
-      write(*,'("Error(readinput): natoms < 1 : ",I8)') natoms(is)
-      write(*,'(" for species ",I4)') is
+      write(*,'("Error(readinput): natoms < 1 : ",I0)') natoms(is)
+      write(*,'(" for species ",I0)') is
       write(*,*)
       stop
     end if
     if (natoms(is) > maxatoms) then
       write(*,*)
-      write(*,'("Error(readinput): natoms too large : ",I8)') natoms(is)
-      write(*,'(" for species ",I4)') is
+      write(*,'("Error(readinput): natoms too large : ",I0)') natoms(is)
+      write(*,'(" for species ",I0)') is
       write(*,'("Adjust maxatoms in modmain and recompile code")')
       write(*,*)
       stop
@@ -785,13 +798,13 @@ case('plot1d')
   read(50,*,err=20) nvp1d,npp1d
   if (nvp1d < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nvp1d < 1 : ",I8)') nvp1d
+    write(*,'("Error(readinput): nvp1d < 1 : ",I0)') nvp1d
     write(*,*)
     stop
   end if
   if (npp1d < nvp1d) then
     write(*,*)
-    write(*,'("Error(readinput): npp1d < nvp1d : ",2I8)') npp1d,nvp1d
+    write(*,'("Error(readinput): npp1d < nvp1d :",2(X,I0))') npp1d,nvp1d
     write(*,*)
     stop
   end if
@@ -804,7 +817,7 @@ case('ip01d')
   read(50,*,err=20) ip01d
   if (ip01d < 1) then
     write(*,*)
-    write(*,'("Error(readinput): ip01d < 1 : ",I8)') ip01d
+    write(*,'("Error(readinput): ip01d < 1 : ",I0)') ip01d
     write(*,*)
     stop
   end if
@@ -815,7 +828,7 @@ case('plot2d')
   read(50,*,err=20) np2d(:)
   if ((np2d(1) < 1).or.(np2d(2) < 1)) then
     write(*,*)
-    write(*,'("Error(readinput): np2d < 1 : ",2I8)') np2d
+    write(*,'("Error(readinput): np2d < 1 :",2(X,I0))') np2d
     write(*,*)
     stop
   end if
@@ -827,7 +840,7 @@ case('plot3d')
   read(50,*,err=20) np3d(:)
   if ((np3d(1) < 1).or.(np3d(2) < 1).or.(np3d(3) < 1)) then
     write(*,*)
-    write(*,'("Error(readinput): np3d < 1 : ",3I8)') np3d
+    write(*,'("Error(readinput): np3d < 1 :",3(X,I0))') np3d
     write(*,*)
     stop
   end if
@@ -835,19 +848,19 @@ case('wplot','dos')
   read(50,*,err=20) nwplot,ngrkf,nswplot
   if (nwplot < 2) then
     write(*,*)
-    write(*,'("Error(readinput): nwplot < 2 : ",I8)') nwplot
+    write(*,'("Error(readinput): nwplot < 2 : ",I0)') nwplot
     write(*,*)
     stop
   end if
   if (ngrkf < 1) then
     write(*,*)
-    write(*,'("Error(readinput): ngrkf < 1 : ",I8)') ngrkf
+    write(*,'("Error(readinput): ngrkf < 1 : ",I0)') ngrkf
     write(*,*)
     stop
   end if
   if (nswplot < 0) then
     write(*,*)
-    write(*,'("Error(readinput): nswplot < 0 : ",I8)') nswplot
+    write(*,'("Error(readinput): nswplot < 0 : ",I0)') nswplot
     write(*,*)
     stop
   end if
@@ -874,7 +887,7 @@ case('maxatpstp','maxatmstp')
   read(50,*,err=20) maxatpstp
   if (maxatpstp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): maxatpstp < 1 : ",I8)') maxatpstp
+    write(*,'("Error(readinput): maxatpstp < 1 : ",I0)') maxatpstp
     write(*,*)
     stop
   end if
@@ -898,7 +911,7 @@ case('maxlatvstp')
   read(50,*,err=20) maxlatvstp
   if (maxlatvstp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): maxlatvstp < 1 : ",I8)') maxlatvstp
+    write(*,'("Error(readinput): maxlatvstp < 1 : ",I0)') maxlatvstp
     write(*,*)
     stop
   end if
@@ -911,7 +924,7 @@ case('lradstp')
   read(50,*,err=20) lradstp
   if (lradstp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): lradstp < 1 : ",I8)') lradstp
+    write(*,'("Error(readinput): lradstp < 1 : ",I0)') lradstp
     write(*,*)
     stop
   end if
@@ -928,7 +941,7 @@ case('noptcomp')
   read(50,*,err=20) noptcomp
   if ((noptcomp < 1).or.(noptcomp > 27)) then
     write(*,*)
-    write(*,'("Error(readinput): noptcomp should be from 1 to 27 : ",I8)') &
+    write(*,'("Error(readinput): noptcomp should be from 1 to 27 : ",I0)') &
      noptcomp
     write(*,*)
     stop
@@ -957,7 +970,7 @@ case('optcomp')
     end if
     if (any(optcomp(:,i) < 1).or.any(optcomp(:,i) > 3)) then
       write(*,*)
-      write(*,'("Error(readinput): invalid optcomp : ",3I8)') optcomp(:,i)
+      write(*,'("Error(readinput): invalid optcomp :",3(X,I0))') optcomp(:,i)
       write(*,*)
       stop
     end if
@@ -991,6 +1004,10 @@ case('demaxbnd')
   end if
 case('autolinengy')
   read(50,*,err=20) autolinengy
+case('dlefe')
+  read(50,*,err=20) dlefe
+case('autodlefe')
+  read(50,*,err=20) autodlefe
 case('deapw')
   read(50,*,err=20) deapw
   if (abs(deapw) < 1.d-8) then
@@ -1007,8 +1024,6 @@ case('delorb')
     write(*,*)
     stop
   end if
-case('dlefe')
-  read(50,*,err=20) dlefe
 case('bfieldc')
   read(50,'(A)',err=20) str
   read(str,*,err=20) bfieldc0(:)
@@ -1039,6 +1054,14 @@ case('momfix')
   read(50,'(A)',err=20) str
   read(str,*,err=20) momfix(:)
   read(str,*,iostat=ios) momfix(:),dmomfix(:)
+case('momfixm')
+  read(50,*,err=20) momfixm
+  if (momfixm < 0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): momfixm < 0 : ",G18.10)') momfixm
+    write(*,*)
+    stop
+  end if
 case('mommtfix')
   do ias=1,maxspecies*maxatoms
     read(50,'(A)',err=20) str
@@ -1048,7 +1071,21 @@ case('mommtfix')
       write(*,*)
       write(*,'("Error(readinput): error reading muffin-tin fixed spin &
        &moments")')
-      write(*,'("(blank line required after mommtfix block")')
+      write(*,'("(blank line required after mommtfix block)")')
+      write(*,*)
+      stop
+    end if
+  end do
+case('mommtfixm')
+  do ias=1,maxspecies*maxatoms
+    read(50,'(A)',err=20) str
+    if (trim(str) == '') goto 10
+    read(str,*,iostat=ios) is,ia,mommtfixm(ia,is)
+    if (ios /= 0) then
+      write(*,*)
+      write(*,'("Error(readinput): error reading muffin-tin fixed spin &
+       &moment magnitudes")')
+      write(*,'("(blank line required after mommtfixm block)")')
       write(*,*)
       stop
     end if
@@ -1079,7 +1116,7 @@ case('symtype')
   read(50,*,err=20) symtype
   if ((symtype < 0).or.(symtype > 2)) then
     write(*,*)
-    write(*,'("Error(readinput): symtype not defined : ",I8)') symtype
+    write(*,'("Error(readinput): symtype not defined : ",I0)') symtype
     write(*,*)
     stop
   end if
@@ -1095,7 +1132,7 @@ case('phwrite')
   read(50,*,err=20) nphwrt
   if (nphwrt < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nphwrt < 1 : ",I8)') nphwrt
+    write(*,'("Error(readinput): nphwrt < 1 : ",I0)') nphwrt
     write(*,*)
     stop
   end if
@@ -1123,7 +1160,7 @@ case('maxitoep')
   read(50,*,err=20) maxitoep
   if (maxitoep < 1) then
     write(*,*)
-    write(*,'("Error(readinput): maxitoep < 1 : ",I8)') maxitoep
+    write(*,'("Error(readinput): maxitoep < 1 : ",I0)') maxitoep
     write(*,*)
     stop
   end if
@@ -1179,7 +1216,7 @@ case('ndspem')
   read(50,*,err=20) ndspem
   if ((ndspem < 1).or.(ndspem > 4)) then
     write(*,*)
-    write(*,'("Error(readinput): ndspem out of range : ",I8)') ndspem
+    write(*,'("Error(readinput): ndspem out of range : ",I0)') ndspem
     write(*,*)
     stop
   end if
@@ -1217,7 +1254,7 @@ case('DFT+U','dft+u','lda+u')
       read(str,*,iostat=ios) is,l,udufix(i)
     case default
       write(*,*)
-      write(*,'("Error(readinput): invalid inpdftu : ",I8)') inpdftu
+      write(*,'("Error(readinput): invalid inpdftu : ",I0)') inpdftu
       write(*,*)
       stop
     end select
@@ -1231,19 +1268,20 @@ case('DFT+U','dft+u','lda+u')
     if ((is < 1).or.(is >= maxspecies)) then
       write(*,*)
       write(*,'("Error(readinput): invalid species number in dft+u block : ", &
-       &I8)') is
+       &I0)') is
       write(*,*)
       stop
     end if
     if (l < 0) then
       write(*,*)
-      write(*,'("Error(readinput): l < 0 in dft+u block : ",I8)') l
+      write(*,'("Error(readinput): l < 0 in dft+u block : ",I0)') l
       write(*,*)
       stop
     end if
     if (l > lmaxdm) then
       write(*,*)
-      write(*,'("Error(readinput): l > lmaxdm in dft+u block : ",2I8)') l,lmaxdm
+      write(*,'("Error(readinput): l > lmaxdm in dft+u block :",2(X,I0))') l, &
+       lmaxdm
       write(*,*)
       stop
     end if
@@ -1275,7 +1313,7 @@ case('rdmmaxscl')
   read(50,*,err=20) rdmmaxscl
   if (rdmmaxscl < 0) then
     write(*,*)
-    write(*,'("Error(readinput): rdmmaxscl < 0 : ",I8)') rdmmaxscl
+    write(*,'("Error(readinput): rdmmaxscl < 0 : ",I0)') rdmmaxscl
     write(*,*)
   end if
 case('maxitn')
@@ -1316,7 +1354,7 @@ case('rdmtemp')
   end if
 case('reducebf')
   read(50,*,err=20) reducebf
-  if ((reducebf < 0.49d0).or.(reducebf > 1.d0)) then
+  if ((reducebf < 0.5d0).or.(reducebf > 1.d0)) then
     write(*,*)
     write(*,'("Error(readinput): reducebf not in [0.5,1] : ",G18.10)') reducebf
     write(*,*)
@@ -1329,40 +1367,22 @@ case('tefvr','tseqr')
 case('tefvit','tseqit')
   read(50,*,err=20) tefvit
 case('minitefv','minseqit')
-  read(50,*,err=20) minitefv
-  if (minitefv < 1) then
+  read(50,*,err=20)
+  write(*,'("Info(readinput): variable ''minitefv'' is no longer used")')
+case('nefvit','maxitefv','maxseqit','nseqit')
+  read(50,*,err=20) nefvit
+  if (nefvit < 1) then
     write(*,*)
-    write(*,'("Error(readinput): minitefv < 1 : ",I8)') minitefv
-    write(*,*)
-    stop
-  end if
-case('maxitefv','maxseqit')
-  read(50,*,err=20) maxitefv
-  if (maxitefv < 1) then
-    write(*,*)
-    write(*,'("Error(readinput): maxitefv < 1 : ",I8)') maxitefv
+    write(*,'("Error(readinput): nefvit < 1 : ",I0)') nefvit
     write(*,*)
     stop
   end if
 case('befvit','bseqit')
-  read(50,*,err=20) befvit
-  if (befvit <= 0.d0) then
-    write(*,*)
-    write(*,'("Error(readinput): befvit <= 0 : ",G18.10)') befvit
-    write(*,*)
-    stop
-  end if
-case('epsefvit','epsseqit')
-  read(50,*,err=20) epsefvit
-  if (epsefvit < 0.d0) then
-    write(*,*)
-    write(*,'("Error(readinput): epsefvit < 0 : ",G18.10)') epsefvit
-    write(*,*)
-    stop
-  end if
-case('nseqit')
   read(50,*,err=20)
-  write(*,'("Info(readinput): variable ''nseqit'' is no longer used")')
+  write(*,'("Info(readinput): variable ''befvit'' is no longer used")')
+case('epsefvit','epsseqit')
+  read(50,*,err=20)
+  write(*,'("Info(readinput): variable ''epsefvit'' is no longer used")')
 case('tauseq')
   read(50,*,err=20)
   write(*,'("Info(readinput): variable ''tauseq'' is no longer used")')
@@ -1370,8 +1390,8 @@ case('vecql')
   read(50,*,err=20) vecql(:)
 case('mustar')
   read(50,*,err=20) mustar
-case('sqados')
-  read(50,*,err=20) sqados(:)
+case('sqaxis','sqados')
+  read(50,*,err=20) sqaxis(:)
 case('test')
   read(50,*,err=20) test
 case('frozencr')
@@ -1415,7 +1435,7 @@ case('nvbse')
   read(50,*,err=20) nvbse0
   if (nvbse0 < 0) then
     write(*,*)
-    write(*,'("Error(readinput): nvbse < 0 : ",I8)') nvbse0
+    write(*,'("Error(readinput): nvbse < 0 : ",I0)') nvbse0
     write(*,*)
     stop
   end if
@@ -1423,7 +1443,7 @@ case('ncbse')
   read(50,*,err=20) ncbse0
   if (ncbse0 < 0) then
     write(*,*)
-    write(*,'("Error(readinput): ncbse < 0 : ",I8)') ncbse0
+    write(*,'("Error(readinput): ncbse < 0 : ",I0)') ncbse0
     write(*,*)
     stop
   end if
@@ -1493,6 +1513,8 @@ case('gmaxrf','gmaxrpa')
     write(*,*)
     stop
   end if
+case('mbwgrf')
+  read(50,*,err=20) mbwgrf
 case('emaxrf')
   read(50,*,err=20) emaxrf
   if (emaxrf < 0.d0) then
@@ -1513,7 +1535,7 @@ case('ntemp')
   read(50,*,err=20) ntemp
   if (ntemp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): ntemp < 1 : ",I8)') ntemp
+    write(*,'("Error(readinput): ntemp < 1 : ",I0)') ntemp
     write(*,*)
     stop
   end if
@@ -1530,8 +1552,9 @@ case('rndbfcmt')
 case('rndavec')
   read(50,*,err=20) rndavec
 case('c_tb09')
-  read(50,*,err=20)
-  write(*,'("Info(readinput): variable ''c_tb09'' is no longer used")')
+  read(50,*,err=20) c_tb09
+! set flag to indicate Tran-Blaha constant has been read in
+  tc_tb09=.true.
 case('lowq','highq','vhighq','uhighq')
   read(50,*,err=20) lv
   if (lv) then
@@ -1577,7 +1600,7 @@ case('lowq','highq','vhighq','uhighq')
       rgkmax=max(rgkmax,9.d0)
       gmaxvr=max(gmaxvr,18.d0)
       lmaxapw=max(lmaxapw,11)
-      lmaxo=max(lmaxo,8)
+      lmaxo=max(lmaxo,9)
       nrmtscf=max(nrmtscf,2.d0)
       nxlo=max(nxlo,3)
       lorbcnd=.true.
@@ -1616,10 +1639,10 @@ case('lowq','highq','vhighq','uhighq')
       write(*,'("Info(readinput): parameters set by ",A," option")') trim(block)
       write(*,'(" rgkmax : ",G18.10)') rgkmax
       write(*,'(" gmaxvr : ",G18.10)') gmaxvr
-      write(*,'(" lmaxapw : ",I4)') lmaxapw
-      write(*,'(" lmaxo : ",I4)') lmaxo
+      write(*,'(" lmaxapw : ",I0)') lmaxapw
+      write(*,'(" lmaxo : ",I0)') lmaxo
       write(*,'(" nrmtscf : ",G18.10)') nrmtscf
-      write(*,'(" nxlo : ",I4)') nxlo
+      write(*,'(" nxlo : ",I0)') nxlo
       write(*,'(" lorbcnd : ",L1)') lorbcnd
       write(*,'(" radkpt : ",G18.10)') radkpt
       write(*,'(" autokpt : ",L1)') autokpt
@@ -1632,7 +1655,7 @@ case('lowq','highq','vhighq','uhighq')
       write(*,'(" autolinengy : ",L1)') autolinengy
       write(*,'(" gmaxrf : ",G18.10)') gmaxrf
       if (trim(block) == 'lowq') then
-        write(*,'(" lradstp : ",I4)') lradstp
+        write(*,'(" lradstp : ",I0)') lradstp
       end if
     end if
   end if
@@ -1658,13 +1681,13 @@ case('lorbordc')
   read(50,*,err=20) lorbordc
   if (lorbordc < 2) then
     write(*,*)
-    write(*,'("Error(readinput): lorbordc < 2 : ",I8)') lorbordc
+    write(*,'("Error(readinput): lorbordc < 2 : ",I0)') lorbordc
     write(*,*)
     stop
   end if
   if (lorbordc > maxlorbord) then
     write(*,*)
-    write(*,'("Error(readinput): lorbordc too large : ",I8)') lorbordc
+    write(*,'("Error(readinput): lorbordc too large : ",I0)') lorbordc
     write(*,'("Adjust maxlorbord in modmain and recompile code")')
     write(*,*)
     stop
@@ -1679,11 +1702,11 @@ case('nrmtscf')
     write(*,*)
     stop
   end if
-case('lmaxdos')
-  read(50,*,err=20) lmaxdos
-  if (lmaxdos < 0) then
+case('lmaxdb','lmaxdos')
+  read(50,*,err=20) lmaxdb
+  if (lmaxdb < 0) then
     write(*,*)
-    write(*,'("Error(readinput): lmaxdos < 0 : ",I8)') lmaxdos
+    write(*,'("Error(readinput): lmaxdb < 0 : ",I0)') lmaxdb
     write(*,*)
     stop
   end if
@@ -1714,7 +1737,7 @@ case('tm3fix')
   read(50,*,err=20) ntmfix
   if (ntmfix < 1) then
     write(*,*)
-    write(*,'("Error(readinput): ntmfix < 1 : ",I8)') ntmfix
+    write(*,'("Error(readinput): ntmfix < 1 : ",I0)') ntmfix
     write(*,*)
     stop
   end if
@@ -1726,8 +1749,8 @@ case('tm3fix')
     read(50,*,err=20) is,ia,l
     if ((is < 1).or.(ia < 1).or.(l < 0)) then
       write(*,*)
-      write(*,'("Error(readinput): invalid is, ia or l in tm3fix block : ",&
-       &3I8)') is,ia,l
+      write(*,'("Error(readinput): invalid is, ia or l in tm3fix block :",&
+       &3(X,I0))') is,ia,l
       write(*,*)
       stop
     end if
@@ -1774,7 +1797,7 @@ case('pulse')
   read(50,*,err=20) npulse
   if (npulse < 1) then
     write(*,*)
-    write(*,'("Error(readinput): npulse < 1 : ",I8)') npulse
+    write(*,'("Error(readinput): npulse < 1 : ",I0)') npulse
     write(*,*)
     stop
   end if
@@ -1789,7 +1812,7 @@ case('ramp')
   read(50,*,err=20) nramp
   if (nramp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nramp < 1 : ",I8)') nramp
+    write(*,'("Error(readinput): nramp < 1 : ",I0)') nramp
     write(*,*)
     stop
   end if
@@ -1804,7 +1827,7 @@ case('step')
   read(50,*,err=20) nstep
   if (nstep < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nstep < 1 : ",I8)') nstep
+    write(*,'("Error(readinput): nstep < 1 : ",I0)') nstep
     write(*,*)
     stop
   end if
@@ -1834,7 +1857,7 @@ case('nxoapwlo','nxapwlo')
   read(50,*,err=20) nxoapwlo
   if (nxoapwlo < 0) then
     write(*,*)
-    write(*,'("Error(readinput): nxoapwlo < 0 : ",I8)') nxoapwlo
+    write(*,'("Error(readinput): nxoapwlo < 0 : ",I0)') nxoapwlo
     write(*,*)
     stop
   end if
@@ -1842,7 +1865,7 @@ case('nxlo')
   read(50,*,err=20) nxlo
   if (nxlo < 0) then
     write(*,*)
-    write(*,'("Error(readinput): nxlo < 0 : ",I8)') nxlo
+    write(*,'("Error(readinput): nxlo < 0 : ",I0)') nxlo
     write(*,*)
     stop
   end if
@@ -1907,29 +1930,28 @@ case('scaleu3')
   read(50,*,err=20) scu3
 case('q0cut')
   read(50,*,err=20) q0cut
-  if (q0cut < 0.d0) then
-    write(*,*)
-    write(*,'("Error(readinput): q0cut < 0 : ",G18.10)') q0cut
-    write(*,*)
-    stop
-  end if
+case('ngridkpa')
+  read(50,*,err=20) ngridkpa
 case('rndbfcu')
   read(50,*,err=20) rndbfcu
-case('bfielduc')
-  read(50,*,err=20) bfielduc
-case('efielduc')
-  read(50,*,err=20) efielduc
+case('bfieldcu','bfielduc')
+  read(50,*,err=20) bfieldcu
+case('efieldcu','efielduc')
+  read(50,*,err=20) efieldcu
 case('tplotq0')
   read(50,*,err=20) tplotq0
 case('trdvclr')
   read(50,*,err=20) trdvclr
+case('trdbfcr')
+  read(50,*,err=20) trdbfcr
 case('evtype')
   read(50,*,err=20)
   write(*,'("Info(readinput): variable ''evtype'' is no longer used")')
 case('wmaxgw')
   read(50,*,err=20) wmaxgw
 case('twdiag')
-  read(50,*,err=20) twdiag
+  read(50,*,err=20)
+  write(*,'("Info(readinput): variable ''twdiag'' is no longer used")')
 case('tsediag')
   read(50,*,err=20) tsediag
 case('actype')
@@ -1938,7 +1960,7 @@ case('npole')
   read(50,*,err=20) npole
   if (npole < 1) then
     write(*,*)
-    write(*,'("Error(readinput): npole < 1 : ",I8)') npole
+    write(*,'("Error(readinput): npole < 1 : ",I0)') npole
     write(*,*)
     stop
   end if
@@ -1946,7 +1968,7 @@ case('nspade')
   read(50,*,err=20) nspade
   if (nspade < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nspade < 1 : ",I8)') nspade
+    write(*,'("Error(readinput): nspade < 1 : ",I0)') nspade
     write(*,*)
     stop
   end if
@@ -1974,7 +1996,7 @@ case('maxlvl','omp_max_active_levels','OMP_MAX_ACTIVE_LEVELS')
   read(50,*,err=20) maxlvl
   if (maxlvl < 1) then
     write(*,*)
-    write(*,'("Error(readinput): maxlvl < 1 : ",I8)') maxlvl
+    write(*,'("Error(readinput): maxlvl < 1 : ",I0)') maxlvl
     write(*,*)
     stop
   end if
@@ -1990,10 +2012,10 @@ case('stable')
       write(*,*)
       write(*,'("Info(readinput): parameters set by stable option")')
       write(*,'(" autolinengy : ",L1)') autolinengy
-      write(*,'(" mrmtav : ",I4)') mrmtav
-      write(*,'(" lmaxapw : ",I4)') lmaxapw
+      write(*,'(" mrmtav : ",I0)') mrmtav
+      write(*,'(" lmaxapw : ",I0)') lmaxapw
       write(*,'(" gmaxvr : ",G18.10)') gmaxvr
-      write(*,'(" msmgmt : ",I4)') msmgmt
+      write(*,'(" msmgmt : ",I0)') msmgmt
     end if
   end if
 case('metagga')
@@ -2008,10 +2030,10 @@ case('metagga')
     if (mp_mpi) then
       write(*,*)
       write(*,'("Info(readinput): parameters set by metagga option")')
-      write(*,'(" lmaxi : ",I4)') lmaxi
+      write(*,'(" lmaxi : ",I0)') lmaxi
       write(*,'(" gmaxvr : ",G18.10)') gmaxvr
       write(*,'(" nrmtscf : ",G18.10)') nrmtscf
-      write(*,'(" msmgmt : ",I4)') msmgmt
+      write(*,'(" msmgmt : ",I0)') msmgmt
       write(*,'(" epspot : ",G18.10)') epspot
       write(*,'(" epsengy : ",G18.10)') epsengy
     end if
@@ -2087,7 +2109,7 @@ case('nkspolar')
   read(50,*,err=20) nkspolar
   if (nkspolar < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nkspolar < 1 : ",I8)') nkspolar
+    write(*,'("Error(readinput): nkspolar < 1 : ",I0)') nkspolar
     write(*,*)
     stop
   end if
@@ -2095,7 +2117,7 @@ case('ntsforce')
   read(50,*,err=20) ntsforce
   if (ntsforce < 1) then
     write(*,*)
-    write(*,'("Error(readinput): ntsforce < 1 : ",I8)') ntsforce
+    write(*,'("Error(readinput): ntsforce < 1 : ",I0)') ntsforce
     write(*,*)
     stop
   end if
@@ -2129,7 +2151,7 @@ case('pwxpsn')
   read(50,*,err=20) pwxpsn
   if (pwxpsn < 1) then
     write(*,*)
-    write(*,'("Error(readinput): pwxpsn < 1 : ",I8)') pwxpsn
+    write(*,'("Error(readinput): pwxpsn < 1 : ",I0)') pwxpsn
     write(*,*)
     stop
   end if
@@ -2139,8 +2161,8 @@ case('wrtdsk')
   read(50,*,err=20) wrtdsk
 case('epsdmat')
   read(50,*,err=20) epsdmat
-case('tm3old')
-  read(50,*,err=20) tm3old
+case('tm3vdl','tm3old')
+  read(50,*,err=20) tm3vdl
 case('batch')
   read(50,*,err=20) batch
 case('tafspt')
