@@ -29,7 +29,7 @@ do is=1,nspecies
   if (rminsp(is) <= 0.d0) then
     write(*,*)
     write(*,'("Error(readspecies): rminsp <= 0 : ",G18.10)') rminsp(is)
-    write(*,'(" for species ",I4)') is
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
@@ -37,7 +37,7 @@ do is=1,nspecies
     write(*,*)
     write(*,'("Error(readspecies): rmt <= rminsp : ",2G18.10)') rmt(is), &
      rminsp(is)
-    write(*,'(" for species ",I4)') is
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
@@ -50,8 +50,8 @@ do is=1,nspecies
   end if
   if (nrmt(is) < 20) then
     write(*,*)
-    write(*,'("Error(readspecies): nrmt too small : ",I8)') nrmt(is)
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): nrmt too small : ",I0)') nrmt(is)
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
@@ -62,8 +62,8 @@ do is=1,nspecies
   read(50,*) nstsp(is)
   if ((nstsp(is) < 1).or.(nstsp(is) > maxstsp)) then
     write(*,*)
-    write(*,'("Error(readspecies): nstsp out of range : ",I8)') nstsp(is)
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): nstsp out of range : ",I0)') nstsp(is)
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
@@ -71,33 +71,33 @@ do is=1,nspecies
     read(50,*) nsp(ist,is),lsp(ist,is),ksp(ist,is),occsp(ist,is),spcore(ist,is)
     if (nsp(ist,is) < 1) then
       write(*,*)
-      write(*,'("Error(readspecies): nsp < 1 : ",I8)') nsp(ist,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and state ",I4)') ist
+      write(*,'("Error(readspecies): nsp < 1 : ",I0)') nsp(ist,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and state ",I0)') ist
       write(*,*)
       stop
     end if
     if (lsp(ist,is) < 0) then
       write(*,*)
-      write(*,'("Error(readspecies): lsp < 0 : ",I8)') lsp(ist,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and state ",I4)') ist
+      write(*,'("Error(readspecies): lsp < 0 : ",I0)') lsp(ist,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and state ",I0)') ist
       write(*,*)
       stop
     end if
     if (ksp(ist,is) < 1) then
       write(*,*)
-      write(*,'("Error(readspecies): ksp < 1 : ",I8)') ksp(ist,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and state ",I4)') ist
+      write(*,'("Error(readspecies): ksp < 1 : ",I0)') ksp(ist,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and state ",I0)') ist
       write(*,*)
       stop
     end if
     if (occsp(ist,is) < 0.d0) then
       write(*,*)
       write(*,'("Error(readspecies): occsp < 0 : ",G18.10)') occsp(ist,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and state ",I4)') ist
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and state ",I0)') ist
       write(*,*)
       stop
     end if
@@ -105,15 +105,15 @@ do is=1,nspecies
   read(50,*) apword(0,is)
   if (apword(0,is) < 1) then
     write(*,*)
-    write(*,'("Error(readspecies): apword < 1 : ",I8)') apword(0,is)
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): apword < 1 : ",I0)') apword(0,is)
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
   if (apword(0,is) > maxapword) then
     write(*,*)
-    write(*,'("Error(readspecies): apword too large : ",I8)') apword(0,is)
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): apword too large : ",I0)') apword(0,is)
+    write(*,'(" for species ",I0)') is
     write(*,'("Adjust maxapword in modmain and recompile code")')
     write(*,*)
     stop
@@ -124,9 +124,9 @@ do is=1,nspecies
     read(50,*) apwe0(io,0,is),apwdm(io,0,is),apwve(io,0,is)
     if (apwdm(io,0,is) < 0) then
       write(*,*)
-      write(*,'("Error(readspecies): apwdm < 0 : ",I8)') apwdm(io,0,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and order ",I4)') io
+      write(*,'("Error(readspecies): apwdm < 0 : ",I0)') apwdm(io,0,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and order ",I0)') io
       write(*,*)
       stop
     end if
@@ -139,8 +139,8 @@ do is=1,nspecies
   read(50,*) nlx
   if (nlx < 0) then
     write(*,*)
-    write(*,'("Error(readspecies): nlx < 0 : ",I8)') nlx
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): nlx < 0 : ",I0)') nlx
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
@@ -148,34 +148,34 @@ do is=1,nspecies
     read(50,*) lx,io
     if (lx < 0) then
       write(*,*)
-      write(*,'("Error(readspecies): lx < 0 : ",I8)') lx
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and exception number ",I4)') ilx
+      write(*,'("Error(readspecies): lx < 0 : ",I0)') lx
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and exception number ",I0)') ilx
       write(*,*)
       stop
     end if
     if (lx > lmaxapw) then
       write(*,*)
-      write(*,'("Error(readspecies): lx > lmaxapw : ",I8)') lx
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and exception number ",I4)') ilx
+      write(*,'("Error(readspecies): lx > lmaxapw : ",I0)') lx
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and exception number ",I0)') ilx
       write(*,*)
       stop
     end if
     apword(lx,is)=io
     if (apword(lx,is) < 1) then
       write(*,*)
-      write(*,'("Error(readspecies): apword < 1 : ",I8)') apword(lx,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and exception number ",I4)') ilx
+      write(*,'("Error(readspecies): apword < 1 : ",I0)') apword(lx,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and exception number ",I0)') ilx
       write(*,*)
       stop
     end if
     if (apword(lx,is) > maxapword) then
       write(*,*)
-      write(*,'("Error(readspecies): apword too large : ",I8)') apword(lx,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and exception number ",I4)') ilx
+      write(*,'("Error(readspecies): apword too large : ",I0)') apword(lx,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and exception number ",I0)') ilx
       write(*,'("Adjust maxapword in modmain and recompile code")')
       write(*,*)
       stop
@@ -184,10 +184,10 @@ do is=1,nspecies
       read(50,*) apwe0(io,lx,is),apwdm(io,lx,is),apwve(io,lx,is)
       if (apwdm(io,lx,is) < 0) then
         write(*,*)
-        write(*,'("Error(readspecies): apwdm < 0 : ",I8)') apwdm(io,lx,is)
-        write(*,'(" for species ",I4)') is
-        write(*,'(" exception number ",I4)') ilx
-        write(*,'(" and order ",I4)') io
+        write(*,'("Error(readspecies): apwdm < 0 : ",I0)') apwdm(io,lx,is)
+        write(*,'(" for species ",I0)') is
+        write(*,'(" exception number ",I0)') ilx
+        write(*,'(" and order ",I0)') io
         write(*,*)
         stop
       end if
@@ -213,15 +213,15 @@ do is=1,nspecies
   read(50,*) nlorb(is)
   if (nlorb(is) < 0) then
     write(*,*)
-    write(*,'("Error(readspecies): nlorb < 0 : ",I8)') nlorb(is)
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): nlorb < 0 : ",I0)') nlorb(is)
+    write(*,'(" for species ",I0)') is
     write(*,*)
     stop
   end if
   if (nlorb(is) > maxlorb) then
     write(*,*)
-    write(*,'("Error(readspecies): nlorb too large : ",I8)') nlorb(is)
-    write(*,'(" for species ",I4)') is
+    write(*,'("Error(readspecies): nlorb too large : ",I0)') nlorb(is)
+    write(*,'(" for species ",I0)') is
     write(*,'("Adjust maxlorb in modmain and recompile code")')
     write(*,*)
     stop
@@ -230,34 +230,34 @@ do is=1,nspecies
     read(50,*) lorbl(ilo,is),lorbord(ilo,is)
     if (lorbl(ilo,is) < 0) then
       write(*,*)
-      write(*,'("Error(readspecies): lorbl < 0 : ",I8)') lorbl(ilo,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and local-orbital ",I4)') ilo
+      write(*,'("Error(readspecies): lorbl < 0 : ",I0)') lorbl(ilo,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and local-orbital ",I0)') ilo
       write(*,*)
       stop
     end if
     if (lorbl(ilo,is) > lmaxo) then
       write(*,*)
-      write(*,'("Error(readspecies): lorbl > lmaxo : ",2I8)') lorbl(ilo,is), &
+      write(*,'("Error(readspecies): lorbl > lmaxo :",2(X,I0))') lorbl(ilo,is),&
        lmaxo
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and local-orbital ",I4)') ilo
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and local-orbital ",I0)') ilo
       write(*,*)
       stop
     end if
     if (lorbord(ilo,is) < 2) then
       write(*,*)
-      write(*,'("Error(readspecies): lorbord < 2 : ",I8)') lorbord(ilo,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and local-orbital ",I4)') ilo
+      write(*,'("Error(readspecies): lorbord < 2 : ",I0)') lorbord(ilo,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and local-orbital ",I0)') ilo
       write(*,*)
       stop
     end if
     if (lorbord(ilo,is) > maxlorbord) then
       write(*,*)
-      write(*,'("Error(readspecies): lorbord too large : ",I8)') lorbord(ilo,is)
-      write(*,'(" for species ",I4)') is
-      write(*,'(" and local-orbital ",I4)') ilo
+      write(*,'("Error(readspecies): lorbord too large : ",I0)') lorbord(ilo,is)
+      write(*,'(" for species ",I0)') is
+      write(*,'(" and local-orbital ",I0)') ilo
       write(*,'("Adjust maxlorbord in modmain and recompile code")')
       write(*,*)
       stop
@@ -266,10 +266,10 @@ do is=1,nspecies
       read(50,*) lorbe0(io,ilo,is),lorbdm(io,ilo,is),lorbve(io,ilo,is)
       if (lorbdm(io,ilo,is) < 0) then
         write(*,*)
-        write(*,'("Error(readspecies): lorbdm < 0 : ",I8)') lorbdm(io,ilo,is)
-        write(*,'(" for species ",I4)') is
-        write(*,'(" local-orbital ",I4)') ilo
-        write(*,'(" and order ",I4)') io
+        write(*,'("Error(readspecies): lorbdm < 0 : ",I0)') lorbdm(io,ilo,is)
+        write(*,'(" for species ",I0)') is
+        write(*,'(" local-orbital ",I0)') ilo
+        write(*,'(" and order ",I0)') io
         write(*,*)
         stop
       end if
@@ -342,6 +342,10 @@ end if
 rmt0(1:nspecies)=rmt(1:nspecies)
 ! add conduction state local-orbitals if required
 if (lorbcnd) call addlorbcnd
+! maximum number of local-orbitals over all species
+nlomax=maxval(nlorb(1:nspecies))
+! generate the index which arranges the local-orbitals in ascending energy
+call genidxelo
 ! subtract 2 Hartree from the minimum energy
 e0min=e0min-2.d0
 end subroutine
