@@ -69,8 +69,8 @@ read(100) nspecies_
 if (nspecies /= nspecies_) then
   write(*,*)
   write(*,'("Error(readstate): differing nspecies")')
-  write(*,'(" current   : ",I4)') nspecies
-  write(*,'(" STATE.OUT : ",I4)') nspecies_
+  write(*,'(" current   : ",I0)') nspecies
+  write(*,'(" STATE.OUT : ",I0)') nspecies_
   write(*,*)
   stop
 end if
@@ -84,9 +84,9 @@ do is=1,nspecies
   read(100) natoms_
   if (natoms(is) /= natoms_) then
     write(*,*)
-    write(*,'("Error(readstate): differing natoms for species ",I4)') is
-    write(*,'(" current   : ",I4)') natoms(is)
-    write(*,'(" STATE.OUT : ",I4)') natoms_
+    write(*,'("Error(readstate): differing natoms for species ",I0)') is
+    write(*,'(" current   : ",I0)') natoms(is)
+    write(*,'(" STATE.OUT : ",I0)') natoms_
     write(*,*)
     stop
   end if
@@ -98,30 +98,33 @@ end do
 read(100) ngridg_
 read(100) ngvec_
 read(100) ndmag_
-if ((spinpol_).and.(ndmag_ /= 1).and.(ndmag_ /= 3)) then
+if (spinpol_.and.(ndmag_ /= 1).and.(ndmag_ /= 3)) then
   write(*,*)
-  write(*,'("Error(readstate): invalid ndmag in STATE.OUT : ",I8)') ndmag_
+  write(*,'("Error(readstate): invalid ndmag in STATE.OUT : ",I0)') ndmag_
   write(*,*)
   stop
 end if
 read(100) nspinor_
 read(100) fsmtype_
-if ((version_(1) > 2).or.(version_(2) >= 3)) then
+if (version_(1) > 2) then
   read(100) ftmtype_
 else
   ftmtype_=0
 end if
 read(100) dftu_
 read(100) lmmaxdm_
-if ((version_(1) > 5).or.((version_(1) == 5).and.(version_(2) >= 1))) then
+if ((version_(1) > 5).or.((version_(1) == 5).and.(version_(2) > 0))) then
   read(100) xcgrad_
 else
   xcgrad_=0
 end if
-if ((version_(1) >= 10).or.((version_(1) == 9).and.(version_(2) >= 6))) then
+if ((version_(1) > 9).or.((version_(1) == 9).and.(version_(2) > 5))) then
   read(100) efermi
 else
-  call readfermi
+  call readefm
+end if
+if ((version_(1) > 10).or.((version_(1) == 10).and.(version_(2) > 6))) then
+  read(100) dlefe
 end if
 ngtot_=ngridg_(1)*ngridg_(2)*ngridg_(3)
 ! map from old interstitial grid to new
@@ -167,7 +170,7 @@ read(100) rfmt_,rfir_
 call rgfmt(vxcmt)
 vxcir(1:ngtot)=rfir_(mapir(1:ngtot))
 ! read the Kohn-Sham effective potential, regrid and pack
-if ((version_(1) > 2).or.(version_(2) >= 2)) then
+if (version_(1) > 2) then
   read(100) rfmt_,rfir_
 else
   allocate(vsig_(ngvec_))
@@ -231,8 +234,8 @@ if (spinpol_) then
     deallocate(bfsmcmt_)
   end if
 end if
-if (any(xcgrad == [3,4,5])) then
-  if (any(xcgrad_ == [3,4,5])) then
+if (any(xcgrad == [3,4,5,6])) then
+  if (any(xcgrad_ == [3,4,5,6])) then
     read(100) rfmt_,rfir_
     call rgfmt(wxcmt)
     wxcir(1:ngtot)=rfir_(mapir(1:ngtot))
@@ -278,7 +281,6 @@ if ((ftmtype /= 0).and.(ftmtype_ /= 0)) then
   deallocate(vmftm_)
 end if
 close(100)
-return
 
 contains
 
