@@ -18,8 +18,8 @@ read(50,*) ngridq_(1:3)
 if (any(ngridq(1:3) /= ngridq_(1:3))) then
   write(*,*)
   write(*,'("Error(readvclr): differing ngridq")')
-  write(*,'(" current  : ",3I6)') ngridq
-  write(*,'(" VCLR.OUT : ",3I6)') ngridq_
+  write(*,'(" current  :",3(X,I0))') ngridq
+  write(*,'(" VCLR.OUT :",3(X,I0))') ngridq_
   write(*,*)
   stop
 end if
@@ -32,8 +32,8 @@ do i3=1,ngridq(3)
       if ((i1 /= i1_).or.(i2 /= i2_).or.(i3 /= i3_)) then
         write(*,*)
         write(*,'("Error(readvclr): differing i1, i2 or i3")')
-        write(*,'(" current  : ",3I6)') i1,i2,i3
-        write(*,'(" VCLR.OUT : ",3I6)') i1_,i2_,i3_
+        write(*,'(" current  :",3(X,I0))') i1,i2,i3
+        write(*,'(" VCLR.OUT :",3(X,I0))') i1_,i2_,i3_
         write(*,*)
         stop
       end if
