@@ -53,7 +53,7 @@ end do
 ! interstitial contribution
 !$OMP SINGLE
 t1=sum(rfir1(1:ngtot)*rfir2(1:ngtot)*cfunir(1:ngtot))
-rfinp=rfinp+t1*omega/dble(ngtot)
+rfinp=rfinp+t1*(omega/ngtot)
 !$OMP END SINGLE
 !$OMP END PARALLEL
 call freethd(nthd)
