@@ -17,7 +17,7 @@ integer is,ias,nthd
 real(8), external :: rfmtinp
 ! interstitial contribution
 rfinpc=sum(rfir1(1:ngtot)*rfir2(1:ngtot)*cfunir(1:ngtot))
-rfinpc=rfinpc*omega/dble(ngtot)
+rfinpc=rfinpc*(omega/ngtot)
 ! muffin-tin contribution
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
