@@ -14,7 +14,7 @@ integer is,ias
 real(8), external :: rfmtint
 ! interstitial contribution
 rfint=dot_product(rfir(1:ngtot),cfunir(1:ngtot))
-rfint=rfint*omega/dble(ngtot)
+rfint=rfint*(omega/ngtot)
 ! muffin-tin contribution
 do ias=1,natmtot
   is=idxis(ias)
