@@ -14,7 +14,7 @@ integer nro,iro,lm
 integer i1,j0,j1
 ! automatic arrays
 real(8) fr(nr)
-if (m <= 0) return
+if (m < 1) return
 nro=nr-nri
 iro=nri+1
 do lm=1,lmmaxi
