@@ -41,8 +41,7 @@ do ias=1,natmtot
     i1=lmmaxo*(nr-iro)+i0
     rhomt(i0:i1:lmmaxo,ias)=rhomt(i0:i1:lmmaxo,ias)+rhocr(iro:nr,ias,ispn)
 ! compute the core charge inside the muffin-tins
-    t1=sum(wr2mt(1:nr,is)*rhocr(1:nr,ias,ispn))
-    sm=sm+fourpi*y00*t1
+    sm=sm+fourpi*y00*sum(wr2mt(1:nr,is)*rhocr(1:nr,ias,ispn))
   end do
 ! core leakage charge
   chgcrlk(ias)=chgcr(is)-sm
@@ -58,19 +57,21 @@ do ias=1,natmtot
     else
       t1=abs(v(1))
     end if
-    if (t1 > 1.d-10) v(1:ndmag)=v(1:ndmag)/t1
 ! add the core magnetisation to the total
-    i=1
-    do ir=1,nri
-      t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
-      magmt(i,ias,1:ndmag)=magmt(i,ias,1:ndmag)+t1*v(1:ndmag)
-      i=i+lmmaxi
-    end do
-    do ir=iro,nr
-      t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
-      magmt(i,ias,1:ndmag)=magmt(i,ias,1:ndmag)+t1*v(1:ndmag)
-      i=i+lmmaxo
-    end do
+    if (t1 > 1.d-10) then
+      v(1:ndmag)=v(1:ndmag)/t1
+      i=1
+      do ir=1,nri
+        t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
+        magmt(i,ias,1:ndmag)=magmt(i,ias,1:ndmag)+t1*v(1:ndmag)
+        i=i+lmmaxi
+      end do
+      do ir=iro,nr
+        t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
+        magmt(i,ias,1:ndmag)=magmt(i,ias,1:ndmag)+t1*v(1:ndmag)
+        i=i+lmmaxo
+      end do
+    end if
   end if
 end do
 end subroutine
