@@ -6,20 +6,24 @@
 !BOP
 ! !ROUTINE: rhomagk
 ! !INTERFACE:
-subroutine rhomagk(ngp,igpig,lock,wppt,occsvp,apwalm,evecfv,evecsv)
+subroutine rhomagk(ngp,igpig,wppt,occsvp,apwalm,evecfv,evecsv,rhomt_,rhoir_, &
+ magmt_,magir_)
 ! !USES:
 use modmain
 use modomp
 ! !INPUT/OUTPUT PARAMETERS:
 !   ngp    : number of G+p-vectors (in,integer(nspnfv))
 !   igpig  : index from G+p-vectors to G-vectors (in,integer(ngkmax,nspnfv))
-!   lock   : OpenMP lock for each atom (in,integer(natmtot))
 !   wppt   : weight of input p-point (in,real)
 !   occsvp : occupation number for each state (in,real(nstsv))
 !   apwalm : APW matching coefficients
 !            (in,complex(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 !   evecfv : first-variational eigenvectors (in,complex(nmatmax,nstfv,nspnfv))
 !   evecsv : second-variational eigenvectors (in,complex(nstsv,nstsv))
+!   rhomt_ : muffin-tin density (inout,real(npcmtmax,natmtot))
+!   rhoir_ : interstitial density (inout,real(ngtc))
+!   magmt_ : muffin-tin magnetisation (inout,real(npcmtmax,natmtot,ndmag))
+!   magir_ : interstitial magnetisation (inout,real(ngtc,ndmag))
 ! !DESCRIPTION:
 !   Generates the partial valence charge density and magnetisation from the
 !   eigenvectors at a particular $k$-point. In the muffin-tin region, the
@@ -42,13 +46,14 @@ use modomp
 implicit none
 ! arguments
 integer, intent(in) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
-integer(omp_lock_kind), intent(inout) :: lock(natmtot)
 real(8), intent(in) :: wppt,occsvp(nstsv)
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv)
+real(8), intent(inout) :: rhomt_(npcmtmax,natmtot),rhoir_(ngtc)
+real(8), intent(inout) :: magmt_(npcmtmax,natmtot,ndmag),magir_(ngtc,ndmag)
 ! local variables
 integer ispn,jspn,nst,ist
-integer is,ias,npc,i,j,k
+integer is,ias,npc,j,k
 integer n,igp,nthd
 real(8) wo,ts0,ts1
 complex(8) z1
@@ -65,52 +70,48 @@ do ist=1,nstsv
   nst=nst+1
   idx(nst)=ist
 end do
-allocate(wfmt(npcmtmax,nspinor,nst))
-call holdthd(nst,nthd)
 !----------------------------------------------!
 !     muffin-tin density and magnetisation     !
 !----------------------------------------------!
+call holdthd(max(natmtot,nst),nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfir,wfgp,ias,is) &
-!$OMP PRIVATE(npc,i,j,k,wo) &
-!$OMP PRIVATE(ispn,jspn,n,ist) &
-!$OMP PRIVATE(z1,igp) &
+!$OMP PRIVATE(wfmt,wfir,wfgp) &
+!$OMP PRIVATE(ias,is,npc,j,k,wo) &
+!$OMP PRIVATE(ispn,jspn,n,ist,z1,igp) &
 !$OMP NUM_THREADS(nthd)
+allocate(wfmt(npcmtmax,nspinor,nst))
+!$OMP DO SCHEDULE(DYNAMIC)
 do ias=1,natmtot
   is=idxis(ias)
   npc=npcmt(is)
-!$OMP SINGLE
   call wfmtsv(.false.,lradstp,is,ias,nst,idx,ngp,apwalm,evecfv,evecsv,npcmtmax,&
    wfmt)
-!$OMP END SINGLE
-!$OMP DO SCHEDULE(DYNAMIC)
   do j=1,nst
     k=idx(j)
     wo=occsvp(k)*wppt
 ! add to density and magnetisation
-    call omp_set_lock(lock(ias))
     if (spinpol) then
 ! spin-polarised
       if (ncmag) then
 ! non-collinear
-        call rmk1(npc,wo,wfmt(:,1,j),wfmt(:,2,j),rhomt(:,ias),magmt(:,ias,1), &
-         magmt(:,ias,2),magmt(:,ias,3))
+        call rmk1(npc,wo,wfmt(:,1,j),wfmt(:,2,j),rhomt_(:,ias),magmt_(:,ias,1),&
+         magmt_(:,ias,2),magmt_(:,ias,3))
       else
 ! collinear
-        call rmk2(npc,wo,wfmt(:,1,j),wfmt(:,2,j),rhomt(:,ias),magmt(:,ias,1))
+        call rmk2(npc,wo,wfmt(:,1,j),wfmt(:,2,j),rhomt_(:,ias),magmt_(:,ias,1))
       end if
     else
 ! spin-unpolarised
-      call rmk3(npc,wo,wfmt(:,1,j),rhomt(:,ias))
+      call rmk3(npc,wo,wfmt(:,1,j),rhomt_(:,ias))
     end if
-    call omp_unset_lock(lock(ias))
   end do
-!$OMP END DO
 end do
+!$OMP END DO NOWAIT
+deallocate(wfmt)
 !------------------------------------------------!
 !     interstitial density and magnetisation     !
 !------------------------------------------------!
-!$OMP DO SCHEDULE(DYNAMIC)
+!$OMP DO ORDERED SCHEDULE(DYNAMIC)
 do j=1,nst
   k=idx(j)
   wo=occsvp(k)*wppt/omega
@@ -121,9 +122,8 @@ do j=1,nst
       n=ngp(jspn)
       wfgp(1:n)=0.d0
       do ist=1,nstfv
-        i=(ispn-1)*nstfv+ist
-        z1=evecsv(i,k)
-        if (abs(dble(z1))+abs(aimag(z1)) > 1.d-10) then
+        z1=evecsv((ispn-1)*nstfv+ist,k)
+        if (abs(z1%re)+abs(z1%im) > epswf) then
           wfgp(1:n)=wfgp(1:n)+z1*evecfv(1:n,ist,jspn)
         end if
       end do
@@ -143,30 +143,28 @@ do j=1,nst
     call zfftifc(3,ngdgc,1,wfir)
   end if
 ! add to density and magnetisation
-!$OMP CRITICAL(rhomagk_)
+!$OMP ORDERED
   if (spinpol) then
 ! spin-polarised
     if (ncmag) then
 ! non-collinear
-      call rmk1(ngtc,wo,wfir,wfir(:,2),rhoir,magir,magir(:,2),magir(:,3))
+      call rmk1(ngtc,wo,wfir,wfir(:,2),rhoir_,magir_,magir_(:,2),magir_(:,3))
     else
 ! collinear
-      call rmk2(ngtc,wo,wfir,wfir(:,2),rhoir,magir)
+      call rmk2(ngtc,wo,wfir,wfir(:,2),rhoir_,magir_)
     end if
   else
 ! spin-unpolarised
-    call rmk3(ngtc,wo,wfir,rhoir)
+    call rmk3(ngtc,wo,wfir,rhoir_)
   end if
-!$OMP END CRITICAL(rhomagk_)
+!$OMP END ORDERED
 end do
 !$OMP END DO
 !$OMP END PARALLEL
 call freethd(nthd)
-deallocate(wfmt)
 call timesec(ts1)
 !$OMP ATOMIC
 timerho=timerho+ts1-ts0
-return
 
 contains
 
