@@ -50,6 +50,7 @@ allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfir(ngtc,nspinor,nstsv))
 ! loop over long-range states in subsets of size nstsv
 do jkpa=1,nkpa
 ! number of and index to occupied states in subset
+!$OMP BARRIER
 !$OMP SINGLE
   nst=0
   do jst=1,nstsv
@@ -80,10 +81,10 @@ do jkpa=1,nkpa
 !$OMP DO SCHEDULE(DYNAMIC)
   do ir=1,nqpt
 ! convert third-variational states to second-variational states
-    call zgemm('N','N',nstsv,nstsv,nstsv,zone,evecsv,nstsv,evectv(:,:,ir), &
+    call zgemm('N','N',nstsv,nst,nstsv,zone,evecsv,nstsv,evectv(:,:,ir), &
      nstsv,zzero,evecsvt,nstsv)
 ! generate the wavefunctions in single-precision
-    call genwfsv_sp(.false.,.false.,nst,idx,ngdgc,igfc,ngk0,igkig(:,1,ik), &
+    call genwfsv_sp(.false.,.false.,nst,[0],ngdgc,igfc,ngk0,igkig(:,1,ik), &
      apwalm,evecfv,evecsvt,wfmt,ngtc,wfir)
 ! loop over second-variational states
     do jst=1,nst
@@ -133,7 +134,6 @@ deallocate(apwalm,evecfv,evecsv,evectv)
 call timesec(ts1)
 !$OMP ATOMIC
 timerho=timerho+ts1-ts0
-return
 
 contains
 
@@ -146,8 +146,7 @@ complex(4), intent(in) :: wf1(n),wf2(n)
 real(8), intent(inout) :: rho(n),mag1(n),mag2(n),mag3(n)
 ! local variables
 integer i
-real(4) wo2,t1,t2
-real(4) a1,b1,a2,b2
+real(4) wo2,a1,b1,a2,b2,t1,t2
 wo2=2.e0*wo
 !$OMP SIMD PRIVATE(a1,b1,a2,b2,t1,t2) SIMDLEN(8)
 do i=1,n
