@@ -11,34 +11,28 @@ implicit none
 ! local variables
 integer ik,ispn,idm
 integer is,ias,n,nthd
-! automatic arrays
-integer(omp_lock_kind) lock(natmtot)
 ! allocatable arrays
+real(8), allocatable :: rhomt_(:,:),rhoir_(:),magmt_(:,:,:),magir_(:,:)
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
 ! set the charge density and magnetisation to zero
-do ias=1,natmtot
-  is=idxis(ias)
-  rhomt(1:npcmt(is),ias)=0.d0
-end do
-rhoir(1:ngtc)=0.d0
-do idm=1,ndmag
-  do ias=1,natmtot
-    is=idxis(ias)
-    magmt(1:npcmt(is),ias,idm)=0.d0
-  end do
-  magir(1:ngtc,idm)=0.d0
-end do
-! initialise the OpenMP locks
-do ias=1,natmtot
-  call omp_init_lock(lock(ias))
-end do
+allocate(rhomt_(npcmtmax,natmtot),rhoir_(ngtc))
+rhomt_(:,:)=0.d0
+rhoir_(:)=0.d0
+if (spinpol) then
+  allocate(magmt_(npcmtmax,natmtot,ndmag),magir_(ngtc,ndmag))
+else
+  allocate(magmt_(1,1,1),magir_(1,1))
+end if
+magmt_(:,:,:)=0.d0
+magir_(:,:)=0.d0
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(apwalm,evecfv,evecsv,ispn) &
+!$OMP REDUCTION(+:rhomt_,rhoir_,magmt_,magir_) &
 !$OMP NUM_THREADS(nthd)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
-!$OMP DO SCHEDULE(DYNAMIC)
+!$OMP DO SCHEDULE(STATIC)
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
@@ -51,17 +45,45 @@ do ik=1,nkpt
      sfacgk(:,:,ispn,ik),apwalm(:,:,:,:,ispn))
   end do
 ! add to the density and magnetisation
-  call rhomagk(ngk(:,ik),igkig(:,:,ik),lock,wkpt(ik),occsv(:,ik),apwalm, &
-   evecfv,evecsv)
+  call rhomagk(ngk(:,ik),igkig(:,:,ik),wkpt(ik),occsv(:,ik),apwalm,evecfv, &
+   evecsv,rhomt_,rhoir_,magmt_,magir_)
 end do
 !$OMP END DO
 deallocate(apwalm,evecfv,evecsv)
 !$OMP END PARALLEL
 call freethd(nthd)
-! destroy the OpenMP locks
+! add density from each process and redistribute
+if (np_mpi > 1) then
+  n=npcmtmax*natmtot
+  call mpi_allreduce(mpi_in_place,rhomt_,n,mpi_double_precision,mpi_sum,mpicom,&
+   ierror)
+  call mpi_allreduce(mpi_in_place,rhoir_,ngtc,mpi_double_precision,mpi_sum, &
+   mpicom,ierror)
+  if (spinpol) then
+    n=n*ndmag
+    call mpi_allreduce(mpi_in_place,magmt_,n,mpi_double_precision,mpi_sum, &
+     mpicom,ierror)
+    n=ngtc*ndmag
+    call mpi_allreduce(mpi_in_place,magir_,n,mpi_double_precision,mpi_sum, &
+     mpicom,ierror)
+  end if
+end if
+! copy density to the global arrays
 do ias=1,natmtot
-  call omp_destroy_lock(lock(ias))
+  is=idxis(ias)
+  rhomt(1:npcmt(is),ias)=rhomt_(1:npcmt(is),ias)
 end do
+rhoir(1:ngtc)=rhoir_(1:ngtc)
+if (spinpol) then
+  do idm=1,ndmag
+    do ias=1,natmtot
+      is=idxis(ias)
+      magmt(1:npcmt(is),ias,idm)=magmt_(1:npcmt(is),ias,idm)
+    end do
+    magir(1:ngtc,idm)=magir_(1:ngtc,idm)
+  end do
+end if
+deallocate(rhomt_,rhoir_,magmt_,magir_)
 ! convert muffin-tin density/magnetisation to spherical harmonics
 call rhomagsh
 call holdthd(2,nthd)
@@ -92,21 +114,5 @@ if (spinpol) then
 end if
 !$OMP END PARALLEL SECTIONS
 call freethd(nthd)
-! add densities from each process and redistribute
-if (np_mpi > 1) then
-  n=npmtmax*natmtot
-  call mpi_allreduce(mpi_in_place,rhomt,n,mpi_double_precision,mpi_sum,mpicom, &
-   ierror)
-  call mpi_allreduce(mpi_in_place,rhoir,ngtot,mpi_double_precision,mpi_sum, &
-   mpicom,ierror)
-  if (spinpol) then
-    n=n*ndmag
-    call mpi_allreduce(mpi_in_place,magmt,n,mpi_double_precision,mpi_sum, &
-     mpicom,ierror)
-    n=ngtot*ndmag
-    call mpi_allreduce(mpi_in_place,magir,n,mpi_double_precision,mpi_sum, &
-     mpicom,ierror)
-  end if
-end if
 end subroutine
 
