@@ -7,16 +7,14 @@ subroutine rmtavrg
 use modmain
 implicit none
 ! local variables
-integer is,i
+integer i
 real(8) ra
 if (nspecies <= 1) return
 do i=1,mrmtav
 ! average muffin-tin radius
   ra=sum(rmt(1:nspecies))/nspecies
 ! replace each muffin-tin radius with half itself plus the average
-  do is=1,nspecies
-    rmt(is)=0.5d0*(rmt(is)+ra)
-  end do
+  rmt(1:nspecies)=0.5d0*(rmt(1:nspecies)+ra)
 end do
 end subroutine
 
