@@ -13,7 +13,7 @@ complex(8), intent(inout) :: evecsv(nstsv,nstsv)
 ! local variables
 integer ist,jst
 real(8) a,b
-if (abs(rndm).lt.1.d-8) return
+if (abs(rndm) < 1.d-8) return
 ! add complex random numbers to each eigenvector
 do ist=1,nstsv
   do jst=1,nstsv
