@@ -43,19 +43,19 @@ real(8), intent(out) :: det,v(3),th
 ! local variables
 real(8), parameter :: pi=3.1415926535897932385d0
 real(8) rotp(3,3),t1,t2
-! find the determinant
+! find the determinant and proper rotation matrix
 det=rot(1,1)*(rot(2,2)*rot(3,3)-rot(3,2)*rot(2,3)) &
    +rot(2,1)*(rot(3,2)*rot(1,3)-rot(1,2)*rot(3,3)) &
    +rot(3,1)*(rot(1,2)*rot(2,3)-rot(2,2)*rot(1,3))
 if (abs(det-1.d0) < eps) then
   det=1.d0
+  rotp(1:3,1:3)=rot(1:3,1:3)
 else if (abs(det+1.d0) < eps) then
   det=-1.d0
+  rotp(1:3,1:3)=-rot(1:3,1:3)
 else
   goto 10
 end if
-! proper rotation matrix
-rotp(1:3,1:3)=det*rot(1:3,1:3)
 v(1)=0.5d0*(rotp(2,3)-rotp(3,2))
 v(2)=0.5d0*(rotp(3,1)-rotp(1,3))
 v(3)=0.5d0*(rotp(1,2)-rotp(2,1))
@@ -70,7 +70,7 @@ else
   if (t2 > 0.d0) then
 ! zero angle: axis arbitrary
     th=0.d0
-    v(1:3)=1.d0/sqrt(3.d0)
+    v(1)=0.d0; v(2)=0.d0; v(3)=1.d0
   else
 ! rotation by pi
     th=pi
