@@ -8,21 +8,17 @@ use modomp
 implicit none
 ! arguments
 integer, intent(in) :: l,n
-! pass in complex arrays as real
-real(8), intent(in) :: a(2*l,n),b(2*l,n)
+complex(8), intent(in) :: a(l,n),b(l,n)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: c(ld,*)
 ! local variables
-integer i,j,nthd
+integer j,nthd
 call holdthd(n,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(i) &
 !$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do j=1,n
-  do i=1,j
-    c(i,j)=c(i,j)+dot_product(a(:,i),b(:,j))
-  end do
+  call dgemv('T',2*l,j,1.d0,a,2*l,b(1,j),1,1.d0,c(1,j),2)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
