@@ -24,6 +24,7 @@ integer(omp_lock_kind), allocatable :: lock(:)
 real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqr(:,:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:)
 complex(8), allocatable :: vchi0(:,:,:),vfxc(:,:,:)
+complex(4), allocatable :: vchi0_sp(:,:,:)
 complex(8), allocatable :: eps0(:,:,:),epsi(:,:,:),epsm(:,:,:)
 complex(8), allocatable :: zw(:),a(:,:)
 ! initialise global variables
@@ -37,7 +38,7 @@ v(1:3)=abs(v(1:3)-nint(v(1:3)))
 if ((v(1) > epslat).or.(v(2) > epslat).or.(v(3) > epslat)) then
   write(*,*)
   write(*,'("Error(tddftlr): q-vector incommensurate with k-point grid")')
-  write(*,'(" ngridk : ",3I6)') ngridk
+  write(*,'(" ngridk :",3(X,I0))') ngridk
   write(*,'(" vecql : ",3G18.10)') vecql
   write(*,*)
   stop
@@ -77,16 +78,14 @@ else
 ! otherwise the head is just G = G' = 0 and finite q
   nm=ngrf
 end if
-! allocate local arrays
-allocate(vchi0(nm,nm,nwrf),vfxc(nm,nm,nwrf))
-allocate(eps0(nm,nm,nwrf),epsi(nm,nm,nwrf))
 ! initialise the OpenMP locks
 allocate(lock(nwrf))
 do iw=1,nwrf
   call omp_init_lock(lock(iw))
 end do
-! compute v¹⸍² χ₀ v¹⸍² (the symmetric version of v χ₀)
-vchi0(1:nm,1:nm,1:nwrf)=0.d0
+! compute v¹⸍² χ₀ v¹⸍² (the symmetric version of v χ₀) in single-precision
+allocate(vchi0_sp(nm,nm,nwrf))
+vchi0_sp(1:nm,1:nm,1:nwrf)=0.e0
 call holdthd(nkptnr/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP SCHEDULE(DYNAMIC) &
@@ -95,10 +94,10 @@ do ik=1,nkptnr
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(tddftlr_)
-  write(*,'("Info(tddftlr): ",I6," of ",I6," k-points")') ik,nkptnr
+  write(*,'("Info(tddftlr): ",I0," of ",I0," k-points")') ik,nkptnr
 !$OMP END CRITICAL(tddftlr_)
 ! add to v¹⸍² χ₀ v¹⸍²
-  call genvchi0(.true.,ik,lock,vecql,gclgq,jlgqr,ylmgq,sfacgq,nm,vchi0)
+  call genvchi0(.true.,ik,lock,vecql,gclgq,jlgqr,ylmgq,sfacgq,nm,vchi0_sp)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
@@ -110,9 +109,13 @@ deallocate(lock)
 ! add vchi0 from each process and redistribute
 if (np_mpi > 1) then
   n=nm*nm*nwrf
-  call mpi_allreduce(mpi_in_place,vchi0,n,mpi_double_complex,mpi_sum,mpicom, &
-   ierror)
+  call mpi_allreduce(mpi_in_place,vchi0_sp,n,mpi_complex,mpi_sum,mpicom,ierror)
 end if
+! copy to double-precision array
+allocate(vchi0(nm,nm,nwrf))
+vchi0(1:nm,1:nm,1:nwrf)=vchi0_sp(1:nm,1:nm,1:nwrf)
+deallocate(vchi0_sp)
+allocate(vfxc(nm,nm,nwrf),eps0(nm,nm,nwrf),epsi(nm,nm,nwrf))
 ! calculate symmetric ϵ_0 = 1 - v¹⸍² χ₀ v¹⸍²
 eps0(1:nm,1:nm,1:nwrf)=-vchi0(1:nm,1:nm,1:nwrf)
 do i=1,nm
@@ -155,7 +158,7 @@ if (fxctype(1) == 210) then
   end if
   if (mp_mpi) then
     if (mod(it,10) == 0) then
-      write(*,'("Info(tddftlr): done ",I4," bootstrap iterations")') it
+      write(*,'("Info(tddftlr): done ",I0," bootstrap iterations")') it
       t1=dble(vfxc(1,1,1))
       write(*,'(" head of matrix v⁻¹⸍² f_xc v⁻¹⸍² : ",G18.10)') t1
       write(*,'("  multiplied by -4π gives α : ",G18.10)') -fourpi*t1
@@ -170,9 +173,7 @@ else if (fxctype(1) == 211) then
   it=it+1
   if (it <= 1) goto 10
 end if
-deallocate(gclgq,jlgqr)
-deallocate(ylmgq,sfacgq)
-deallocate(vchi0,vfxc)
+deallocate(gclgq,jlgqr,ylmgq,sfacgq,vchi0,vfxc)
 ! invert ϵ⁻¹ to find ϵ and store in array eps0
 do iw=1,nwrf
   eps0(1:nm,1:nm,iw)=epsi(1:nm,1:nm,iw)
