@@ -39,7 +39,7 @@ v(1:3)=abs(v(1:3)-nint(v(1:3)))
 if ((v(1) > epslat).or.(v(2) > epslat).or.(v(3) > epslat)) then
   write(*,*)
   write(*,'("Error(tddftsplr): q-vector incommensurate with k-point grid")')
-  write(*,'(" ngridk : ",3I6)') ngridk
+  write(*,'(" ngridk :",3(X,I0))') ngridk
   write(*,'(" vecql : ",3G18.10)') vecql
   write(*,*)
   stop
@@ -80,7 +80,7 @@ do ik=1,nkptnr
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(tddftsplr_)
-  write(*,'("Info(tddftsplr): ",I6," of ",I6," k-points")') ik,nkptnr
+  write(*,'("Info(tddftsplr): ",I0," of ",I0," k-points")') ik,nkptnr
 !$OMP END CRITICAL(tddftsplr_)
   call genspchi0(ik,lock,vecql,jlgqr,ylmgq,sfacgq,chi)
 end do
@@ -257,7 +257,6 @@ end if
 call writetest(330,'transverse response function',nv=nwrf,tol=1.d-2,zva=chit)
 deallocate(gqc,ylmgq,sfacgq,chi,fxc)
 if (.not.ncmag) deallocate(chit)
-return
 
 contains
 
@@ -268,17 +267,19 @@ complex(8), intent(in) :: a(4,4)
 complex(8), intent(out) :: b(4,4)
 ! local variables
 integer i,j
-complex(8) c(4,4)
+complex(8) c(4,4),z1
 do i=1,4
   c(i,1)=a(i,1)+a(i,4)
   c(i,2)=a(i,2)+a(i,3)
-  c(i,3)=zmi*(a(i,2)-a(i,3))
+  z1=a(i,2)-a(i,3)
+  c(i,3)=cmplx(z1%im,-z1%re,8)
   c(i,4)=a(i,1)-a(i,4)
 end do
 do j=1,4
   b(1,j)=c(1,j)+c(4,j)
   b(2,j)=c(2,j)+c(3,j)
-  b(3,j)=zi*(c(2,j)-c(3,j))
+  z1=c(2,j)-c(3,j)
+  b(3,j)=cmplx(-z1%im,z1%re,8)
   b(4,j)=c(1,j)-c(4,j)
 end do
 end subroutine
@@ -294,15 +295,17 @@ complex(8) c(4,4),z1
 do i=1,4
   c(i,1)=a(i,1)
   z1=a(i,3)
-  c(i,2)=a(i,2)+zmi*z1
-  c(i,3)=a(i,2)+zi*z1
+  z1=cmplx(-z1%im,z1%re,8)
+  c(i,2)=a(i,2)-z1
+  c(i,3)=a(i,2)+z1
   c(i,4)=a(i,4)
 end do
 do j=1,4
   b(1,j)=c(1,j)
   z1=c(3,j)
-  b(2,j)=c(2,j)+zi*z1
-  b(3,j)=c(2,j)+zmi*z1
+  z1=cmplx(-z1%im,z1%re,8)
+  b(2,j)=c(2,j)+z1
+  b(3,j)=c(2,j)-z1
   b(4,j)=c(4,j)
 end do
 end subroutine
