@@ -5,6 +5,7 @@
 
 subroutine tdhfc
 use modmain
+use modtddft
 use modtdhfc
 implicit none
 ! initialise global variables
@@ -21,7 +22,8 @@ call readevalsv
 call readoccsv
 ! find the number of and index to the states within the energy window
 call genidxthc
-
-
+! loop over time steps
+do itimes=1,ntimes-1
+end do
 end subroutine
 
