@@ -22,13 +22,15 @@ complex(8), allocatable :: kmat(:,:),pmat(:,:,:)
 complex(8), allocatable :: a(:,:),b(:,:),c(:,:)
 if (itimes >= ntimes) then
   write(*,*)
-  write(*,'("Error(timestep): itimes >= ntimes : ",2I8)') itimes,ntimes
+  write(*,'("Error(timestep): itimes >= ntimes :",2(X,I0))') itimes,ntimes
   write(*,*)
   stop
 end if
 allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (spinpol) then
   allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
+else
+  allocate(bmt(1,1,1),bir(1,1))
 end if
 ! generate the Kohn-Sham potential and magnetic field in spherical coordinates
 ! and multiply by the radial integration weights; also multiply the interstitial
@@ -115,8 +117,7 @@ deallocate(evecsv,evectv,evecsvt)
 deallocate(kmat,pmat,a,b,c)
 !$OMP END PARALLEL
 call freethd(nthd)
-deallocate(vmt,vir)
-if (spinpol) deallocate(bmt,bir)
+deallocate(vmt,vir,bmt,bir)
 ! add the kinetic energy and total current from each process and redistribute
 if (np_mpi > 1) then
   call mpi_allreduce(mpi_in_place,engykn,1,mpi_double_precision,mpi_sum,mpicom,&
