@@ -55,25 +55,25 @@ real(8) dlm(2*l+1,2*l+1,-k:k),dsp(2,2,-p:p)
 real(8), external :: wigner3j,wigner3jf
 if (l < 0) then
   write(*,*)
-  write(*,'("Error(tm2todm): l < 0 : ",I8)') l
+  write(*,'("Error(tm2todm): l < 0 : ",I0)') l
   write(*,*)
   stop
 end if
 if (k < 0) then
   write(*,*)
-  write(*,'("Error(tm2todm): k < 0 : ",I8)') k
+  write(*,'("Error(tm2todm): k < 0 : ",I0)') k
   write(*,*)
   stop
 end if
 if (k > 2*l) then
   write(*,*)
-  write(*,'("Error(tm2todm): k > 2*l : ",2I8)') k,2*l
+  write(*,'("Error(tm2todm): k > 2*l :",2(X,I0))') k,2*l
   write(*,*)
   stop
 end if
 if ((p < 0).or.(p > 1)) then
   write(*,*)
-  write(*,'("Error(tm2todm): p should be 0 or 1 : ",I8)') p
+  write(*,'("Error(tm2todm): p should be 0 or 1 : ",I0)') p
   write(*,*)
   stop
 end if
