@@ -44,9 +44,11 @@ subroutine tm3todm(l,k,p,r,ld,wkpr,dm)
 !   where the subscripts S and A refer to the symmetric and antisymmetric parts
 !   of the matrix, respectively. This routine generates the Hermitian density
 !   matrix $D$ as described above from the real tensor moments $w_t^{kpr}$. For
-!   a detailed derivation see {\it Phys. Rev. B} {\bf 80}, 035121 (2009) and
-!   {\it J. Phys.: Condens. Matter} {\bf 7}, 9947 (1995). See also the routines
-!   {\tt tm2todm} and {\tt tm3rtoz}.
+!   a detailed derivation see {\it Phys. Rev. B} {\bf 80}, 035121 (2009),
+!   {\it J. Phys.: Condens. Matter} {\bf 7}, 9947 (1995) and G. van der Laan in
+!   {\it Spin-Orbit-Influenced Spectroscopies of Magnetic Solids. Lecture Notes
+!   in Physics}, {\bf 466} (1996). See also the routines {\tt tm2todm} and
+!   {\tt tm3rtoz}.
 !
 ! !REVISION HISTORY:
 !   Created 2007 (Francesco Cricchio and Lars Nordstrom)
@@ -68,37 +70,37 @@ real(8) wkp(-ld:ld,-1:1),dmr(ld,2,ld,2)
 real(8), external :: wigner3j
 if (l < 0) then
   write(*,*)
-  write(*,'("Error(tm3todm): l < 0 : ",I8)') l
+  write(*,'("Error(tm3todm): l < 0 : ",I0)') l
   write(*,*)
   stop
 end if
 if (k < 0) then
   write(*,*)
-  write(*,'("Error(tm3todm): k < 0 : ",I8)') k
+  write(*,'("Error(tm3todm): k < 0 : ",I0)') k
   write(*,*)
   stop
 end if
 if (k > 2*l) then
   write(*,*)
-  write(*,'("Error(tm3todm): k > 2*l : ",2I8)') k,2*l
+  write(*,'("Error(tm3todm): k > 2*l :",2(X,I0))') k,2*l
   write(*,*)
   stop
 end if
 if ((p < 0).or.(p > 1)) then
   write(*,*)
-  write(*,'("Error(tm3todm): p should be 0 or 1 : ",I8)') p
+  write(*,'("Error(tm3todm): p should be 0 or 1 : ",I0)') p
   write(*,*)
   stop
 end if
 if (r < abs(k-p)) then
   write(*,*)
-  write(*,'("Error(tm3todm): r < |k-p| : ",2I8)') r,abs(k-p)
+  write(*,'("Error(tm3todm): r < |k-p| :",2(X,I0))') r,abs(k-p)
   write(*,*)
   stop
 end if
 if (r > (k+p)) then
   write(*,*)
-  write(*,'("Error(tm3todm): r > k+p : ",2I8)') r,k+p
+  write(*,'("Error(tm3todm): r > k+p :",2(X,I0))') r,k+p
   write(*,*)
   stop
 end if
@@ -119,7 +121,6 @@ end do
 call tm2todm(l,k,p,ld,wkp,dmr)
 ! convert to complex Hermitian matrix
 call dmrtoz(ld*2,dmr,dm)
-return
 
 contains
 
