@@ -16,7 +16,7 @@ integer, intent(in) :: ld
 complex(4), intent(out) :: wfir(ld,nspinor,nst)
 ! local variables
 integer ist,ispn,jspn
-integer n,igp,i,j,k,nthd
+integer n,igp,j,k,nthd
 real(8) t0
 complex(8) z1
 ! automatic arrays
@@ -25,7 +25,7 @@ t0=1.d0/sqrt(omega)
 call holdthd(nst,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(wfgp,k,ispn,jspn) &
-!$OMP PRIVATE(n,ist,i,z1,igp) &
+!$OMP PRIVATE(n,ist,z1,igp) &
 !$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do j=1,nst
@@ -42,9 +42,8 @@ do j=1,nst
         wfgp(1:n)=0.e0
       end if
       do ist=1,nstfv
-        i=(ispn-1)*nstfv+ist
-        z1=evecsv(i,k)
-        if (abs(dble(z1))+abs(aimag(z1)) < epsocc) cycle
+        z1=evecsv((ispn-1)*nstfv+ist,k)
+        if (abs(z1%re)+abs(z1%im) < epswf) cycle
         if (tgp) then
 ! wavefunction in G+p-space
           wfir(1:n,ispn,j)=wfir(1:n,ispn,j)+z1*evecfv(1:n,ist,jspn)
