@@ -25,19 +25,19 @@ call genapwfr
 ! generate the local-orbital radial functions
 call genlofr
 ! set the occupation numbers
-if ((task == 61).or.(task == 62).or.(task == 63)) then
+if (any(task == [61,62,63])) then
 ! plot of wavefunction modulus squared
   ik=kstlist(1,1)
   ist=kstlist(2,1)
   if ((ik < 1).or.(ik > nkpt)) then
     write(*,*)
-    write(*,'("Error(wfplot): k-point out of range : ",I8)') ik
+    write(*,'("Error(wfplot): k-point out of range : ",I0)') ik
     write(*,*)
     stop
   end if
   if ((ist < 1).or.(ist > nstsv)) then
     write(*,*)
-    write(*,'("Error(wfplot): state out of range : ",I8)') ist
+    write(*,'("Error(wfplot): state out of range : ",I0)') ist
     write(*,*)
     stop
   end if
@@ -46,6 +46,7 @@ if ((task == 61).or.(task == 62).or.(task == 63)) then
   occsv(ist,ik)=1.d0/wkpt(ik)
 ! no symmetrisation required
   nsymcrys=1
+  eqatoms(:,:,:)=.false.
 else
 ! plotting an STM image by setting occupation numbers to be a delta function at
 ! the Fermi energy
@@ -97,7 +98,7 @@ if (mp_mpi) then
     write(*,'(" 3D wavefunction modulus squared written to WF3D.OUT")')
   end select
   if (task /= 162) then
-    write(*,'(" for k-point ",I8," and state ",I6)') kstlist(1,1),kstlist(2,1)
+    write(*,'(" for k-point ",I0," and state ",I0)') kstlist(1,1),kstlist(2,1)
   end if
 end if
 end subroutine
