@@ -42,8 +42,8 @@ if ((j1 < 0).or.(j2 < 0).or.(j3 < 0).or.(abs(m1) > j1).or.(abs(m2) > j2) &
  .or.(abs(m3) > j3)) then
   write(*,*)
   write(*,'("Error(wigner3j): invalid arguments :")')
-  write(*,'("j1 = ",I8," j2 = ",I8," j3 = ",I8)') j1,j2,j3
-  write(*,'("m1 = ",I8," m2 = ",I8," m3 = ",I8)') m1,m2,m3
+  write(*,'("j1 = ",I0," j2 = ",I0," j3 = ",I0)') j1,j2,j3
+  write(*,'("m1 = ",I0," m2 = ",I0," m3 = ",I0)') m1,m2,m3
   write(*,*)
   stop
 end if
@@ -53,7 +53,8 @@ if ((j1 == 0).and.(j2 == 0).and.(j3 == 0)) then
 end if
 if ((j1 > 50).or.(j2 > 50).or.(j3 > 50)) then
   write(*,*)
-  write(*,'("Error(wigner3j): angular momenta out of range : ",3I8)') j1,j2,j3
+  write(*,'("Error(wigner3j): angular momenta out of range :",3(X,I0))') &
+   j1,j2,j3
   write(*,*)
   stop
 end if
