@@ -36,11 +36,11 @@ if (tpdos) then
     write(*,'(" PDOS summed over spin")')
   end if
   write(*,*)
-  write(*,'(" Spin-quantisation axis : ",3G18.10)') sqados(:)
+  write(*,'(" Spin-quantisation axis : ",3G18.10)') sqaxis(:)
   if (lmirep) then
     write(*,*)
-    write(*,'(" Eigenvalues of a random matrix in the Yₗₘ basis symmetrised")')
-    write(*,'(" with the site symmetries written to ELMIREP.OUT for all")')
+    write(*,'(" Eigenvalues of a random matrix symmetrised with the site")')
+    write(*,'(" symmetries in the Yₗₘ basis written to ELMIREP.OUT for all")')
     write(*,'(" species and atoms. Degenerate eigenvalues correspond to")')
     write(*,'(" irreducible representations of each site symmetry group")')
   end if
