@@ -14,22 +14,21 @@ integer is,ias
 ! allocatable arrays
 complex(8), allocatable :: zfmt(:,:,:)
 allocate(zfmt(lmmaxo,nrmtmax,natmtot))
-open(50,file='DVS'//trim(fext),form='UNFORMATTED')
-write(50) version
-write(50) nspecies
-write(50) lmmaxo
+open(150,file='DVS'//trim(fext),form='UNFORMATTED',action='WRITE')
+write(150) version
+write(150) nspecies
+write(150) lmmaxo
 do is=1,nspecies
-  write(50) natoms(is)
-  write(50) nrmt(is)
+  write(150) natoms(is)
+  write(150) nrmt(is)
 end do
-write(50) ngridg
+write(150) ngridg
 do ias=1,natmtot
   is=idxis(ias)
   call zfmtpack(.false.,nrmt(is),nrmti(is),dvsmt(:,ias),zfmt(:,:,ias))
 end do
-write(50) zfmt,dvsir
-close(50)
+write(150) zfmt,dvsir
+close(150)
 deallocate(zfmt)
-return
 end subroutine
 
