@@ -37,8 +37,8 @@ real(8) w(3),work(lwork)
 real(8), allocatable :: rfmt(:),grfmt1(:,:),grfmt2(:,:)
 if (lmaxi < 2) then
   write(*,*)
-  write(*,'("Error(writeefg): lmaxi too small for calculating the EFG : ",&
-   &I4)') lmaxi
+  write(*,'("Error(writeefg): lmaxi too small for calculating the EFG : ",I0)')&
+   lmaxi
   write(*,'(" Run the ground-state calculation again with lmaxi >= 2")')
   write(*,*)
   stop
