@@ -5,12 +5,12 @@
 
 subroutine writeengyu(fnum)
 use modmain
-use modulr
 implicit none
 ! arguments
 integer, intent(in) :: fnum
 write(fnum,*)
-write(fnum,'("Energies :")')
-write(fnum,'(" Fermi",T30,": ",G22.12)') efermi
+write(fnum,'("Energies per unit cell:")')
+write(fnum,'(" Fermi",T30,": ",G24.14)') efermi
+write(fnum,'(" sum of eigenvalues",T30,": ",G24.14)') evalsum
 end subroutine
 
