@@ -20,7 +20,7 @@ do ik=1,nkpt
   write(50,'(" (state, eigenvalue, V-norm below)")')
   do ist=1,nstsv
     e=evaluv(ist,ik)
-    if (vnorm(ist,ik).gt.0.5d0) e=-e
+    if (vnorm(ist,ik) > 0.5d0) e=-e
     write(50,'(I6,2G18.10)') ist,e,vnorm(ist,ik)
   end do
   write(50,*)
