@@ -15,7 +15,7 @@ complex(8), allocatable :: w(:)
 call init0
 call init1
 ! read Fermi energy from a file
-call readfermi
+call readefm
 ! get the eigenvalues from file
 do ik=1,nkpt
   call getevalsv(filext,ik,vkl(:,ik),evalsv(:,ik))
@@ -40,8 +40,8 @@ read(140) nmbse_
 if (nmbse /= nmbse_) then
   write(*,*)
   write(*,'("Error(writeevbse): differing nmbse")')
-  write(*,'(" current    : ",I6)') nmbse
-  write(*,'(" HMLBSE.OUT : ",I6)') nmbse_
+  write(*,'(" current    : ",I0)') nmbse
+  write(*,'(" HMLBSE.OUT : ",I0)') nmbse_
   write(*,*)
   stop
 end if
