@@ -11,10 +11,10 @@ integer, intent(in) :: fnum
 ! local variables
 integer is,ia,ias
 write(fnum,*)
-if ((abs(fsmtype) == 1).or.(abs(fsmtype) == 3)) then
+if (any(abs(fsmtype) == [1,3,4,6])) then
   write(fnum,'("FSM global effective field",T30,": ",3G18.10)') bfsmc(1:ndmag)
 end if
-if ((abs(fsmtype) == 2).or.(abs(fsmtype) == 3)) then
+if (any(abs(fsmtype) == [2,3,5,6])) then
   write(fnum,'("FSM local muffin-tin effective fields :")')
   do is=1,nspecies
     write(fnum,'(" species : ",I4," (",A,")")') is,trim(spsymb(is))
