@@ -11,7 +11,7 @@ implicit none
 real(8), intent(in) :: gq(nbph,nqpt)
 ! local variables
 integer iq,i
-open(50,file='GAMMAQ.OUT',form='FORMATTED')
+open(50,file='GAMMAQ.OUT',form='FORMATTED',action='WRITE')
 write(50,*)
 write(50,'(I4," : total number of atoms")') natmtot
 write(50,'(I6," : number of q-points")') nqpt
@@ -29,6 +29,5 @@ close(50)
 write(*,*)
 write(*,'("Info(writegamma):")')
 write(*,'(" wrote phonon linewidths for all q-points to GAMMAQ.OUT")')
-return
 end subroutine
 
