@@ -43,7 +43,7 @@ write(fnum,'("Time (hh:mm:ss)   : ",A2,":",A2,":",A2)') tim(1:2),tim(3:4), &
  tim(5:6)
 if (np_mpi > 1) then
   write(fnum,*)
-  write(fnum,'("Using MPI, number of processes : ",I8)') np_mpi
+  write(fnum,'("Using MPI, number of processes : ",I0)') np_mpi
 end if
 if (notelns > 0) then
   write(fnum,*)
@@ -184,7 +184,7 @@ if (tefield) then
   write(fnum,*)
   write(fnum,'("Constant electric field applied across unit cell")')
   write(fnum,'(" field strength : ",3G18.10)') efieldc
-  t1=norm2(efieldc(:))
+  t1=norm2(efieldc(1:3))
   write(fnum,'("  magnitude : ",G18.10)') t1
   write(fnum,'("   volts/nanometer : ",G18.10)') t1*ef_si/1.d9
   write(fnum,'(" maximum distance from center over which E-field is &
@@ -224,7 +224,7 @@ else if (reducek == 2) then
   write(fnum,'("k-point set is reduced with symmorphic symmetries only")')
 else
   write(*,*)
-  write(*,'("Error(writeinfo): undefined k-point reduction type : ",I8)') &
+  write(*,'("Error(writeinfo): undefined k-point reduction type : ",I0)') &
    reducek
   write(*,*)
   stop
@@ -247,7 +247,8 @@ case(1:)
      trim(spsymb(isgkmax))
   else
     write(*,*)
-    write(*,'("Error(writeinfo): isgkmax > nspecies : ",2I8)') isgkmax,nspecies
+    write(*,'("Error(writeinfo): isgkmax > nspecies :",2(X,I0))') isgkmax, &
+     nspecies
     write(*,*)
     stop
   end if
@@ -262,9 +263,9 @@ write(fnum,'("G-vector grid sizes : ",3I6)') ngridg(:)
 write(fnum,'("Number of G-vectors : ",I8)') ngvec
 write(fnum,*)
 write(fnum,'("Maximum angular momentum used for")')
-write(fnum,'(" APW functions                      : ",I4)') lmaxapw
-write(fnum,'(" outer part of muffin-tin           : ",I4)') lmaxo
-write(fnum,'(" inner part of muffin-tin           : ",I4)') lmaxi
+write(fnum,'(" APW functions            : ",I4)') lmaxapw
+write(fnum,'(" outer part of muffin-tin : ",I4)') lmaxo
+write(fnum,'(" inner part of muffin-tin : ",I4)') lmaxi
 write(fnum,*)
 write(fnum,'("Total nuclear charge    : ",G18.10)') chgzn
 write(fnum,'("Total core charge       : ",G18.10)') chgcrtot
@@ -311,17 +312,19 @@ if (xcgrad == 0) then
   write(fnum,'(" local density approximation (LDA)")')
 else if ((xcgrad == 1).or.(xcgrad == 2)) then
   write(fnum,'(" generalised gradient approximation (GGA)")')
-else if (any(xcgrad == [3,4,5])) then
+else if (any(xcgrad == [3,4,5,6])) then
   write(fnum,'(" meta-GGA")')
-  if (xcgrad /= 3) then
+  if (xcgrad == 3) then
+    write(fnum,'(" fully deorbitalised functional")')
+  else if (xcgrad == 6) then
+    write(fnum,'(" potential-only functional")')
+  else
     write(fnum,'(" partially deorbitalised functional")')
     write(fnum,'(" using Kohn-Sham orbital kinetic energy density τ(r)")')
     write(fnum,'(" kinetic energy functional used for δτ(r'')/δρ(r) : ",3I6)') &
      ktype(:)
     write(fnum,'("  ",A)') trim(kdescr)
     write(fnum,'("  gradient requirement : ",I4)') kgrad
-  else
-    write(fnum,'(" fully deorbitalised functional")')
   end if
 end if
 if (ksgwrho) then
@@ -339,7 +342,7 @@ if (dftu /= 0) then
     write(fnum,'(" see Phys. Rev. B 49, 14211 (1994)")')
   else
     write(*,*)
-    write(*,'("Error(writeinfo): dftu not defined : ",I8)') dftu
+    write(*,'("Error(writeinfo): dftu not defined : ",I0)') dftu
     write(*,*)
     stop
   end if
