@@ -10,7 +10,7 @@ implicit none
 ! local variables
 integer ikpa
 open(50,file='KAPPA.OUT',form='FORMATTED')
-write(50,'(I6," : nkpa; kappa-point, vector in unit cell reciprocal lattice &
+write(50,'(I6," : nkpa; κ-point, vector in unit cell reciprocal lattice &
  &coordinates below")') nkpa
 do ikpa=1,nkpa
   write(50,'(I6,3G18.10)') ikpa,vql(:,ikpa)
