@@ -48,6 +48,7 @@ write(100) dftu
 write(100) lmmaxdm
 write(100) xcgrad
 write(100) efermi
+write(100) dlefe
 ! muffin-tin functions are unpacked to maintain backward compatibility
 allocate(rfmt(lmmaxo,nrmtmax,natmtot))
 if (spinpol) then
@@ -111,7 +112,7 @@ if (spinpol) then
   end if
 end if
 ! write the meta-GGA exchange-correlation potential
-if (any(xcgrad == [3,4,5])) then
+if (any(xcgrad == [3,4,5,6])) then
   do ias=1,natmtot
     is=idxis(ias)
     call rfmtpack(.false.,nrmt(is),nrmti(is),wxcmt(:,ias),rfmt(:,:,ias))
