@@ -103,7 +103,7 @@ if (tdrho3d) then
   close(50)
 end if
 ! magnetisation in 1D, 2D or 3D
-if ((tdmag1d.or.tdmag2d.or.tdmag3d).and.(spinpol)) then
+if ((tdmag1d.or.tdmag2d.or.tdmag3d).and.spinpol) then
   allocate(rvfmt(npmtmax,natmtot,3),rvfir(ngtot,3))
   if (ncmag) then
 ! non-collinear
