@@ -54,7 +54,7 @@ do ik=1,nkpt
       t1=occsv(jst,ik)
       if (abs(t1) < epsocc) cycle
       z1=zdotc(nstsv,evecsv(:,ist),1,evecsvt(:,jst),1)
-      sm=sm+t1*(dble(z1)**2+aimag(z1)**2)
+      sm=sm+t1*(z1%re**2+z1%im**2)
     end do
     occsvp(ist,ik)=sm
   end do
