@@ -55,7 +55,7 @@ do ik=1,nkpt
       t2=occsv(ist,ik)
       if (abs(t2) > epsocc) then
         z1=zdotc(nstsv,evecsvt(:,ist),1,a(:,ist),1)
-        jtk(l,ik)=jtk(l,ik)+t2*(dble(z1)+t1)
+        jtk(l,ik)=jtk(l,ik)+t2*(z1%re+t1)
       end if
     end do
   end do
