@@ -9,9 +9,8 @@ use modulr
 implicit none
 ! local variables
 integer i1,i2,i3,ir
-! allocatable arrays
-real(8), allocatable :: vclr(:)
-allocate(vclr(nqpt))
+! automatic arrays
+real(8) vclr(nqpt)
 ! Fourier transform external Coulomb potential from Q-space to real-space
 call rzfftifc(3,ngridq,1,vclr,vclq)
 ! write the real-space potential to file
@@ -27,6 +26,5 @@ do i3=1,ngridq(3)
   end do
 end do
 close(50)
-deallocate(vclr)
 end subroutine
 
