@@ -11,7 +11,7 @@ implicit none
 ! local variables
 integer ispn,ik,ist,nthd
 integer is,ias,nrc,nrci,npc
-integer np,ngp,iu,i
+integer np,ngp(nspnfv),iu,i
 real(8) vc(3),kc
 character(256) fname
 ! automatic arrays
@@ -19,10 +19,8 @@ complex(8) ylmk(lmmaxo),sfack(natmtot)
 ! allocatable arrays
 integer, allocatable :: igpig(:,:)
 real(8), allocatable :: vpl(:,:),jlkr(:,:)
-real(8), allocatable :: wfmta(:,:),wfmtb(:,:)
-real(8), allocatable :: wfira(:),wfirb(:)
-real(8), allocatable :: wfa(:,:,:),wfb(:,:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:),expmt(:,:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
+complex(8), allocatable :: expmt(:,:),wf(:,:,:)
 ! total number of plot points
 np=np3d(1)*np3d(2)*np3d(3)
 ! generate the 3D plotting points
@@ -31,24 +29,21 @@ call plotpt3d(vpl)
 ! parallel loop over non-reduced k-points
 call holdthd(nkptnr,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(igpig,jlkr,wfmta,wfmtb) &
-!$OMP PRIVATE(wfira,wfirb,wfa,wfb) &
-!$OMP PRIVATE(wfmt,wfir,ylmk,sfack,expmt) &
+!$OMP PRIVATE(igpig,jlkr,wfmt,wfir) &
+!$OMP PRIVATE(wf,expmt,ylmk,sfack) &
 !$OMP PRIVATE(ngp,vc,kc,ist,ispn,ias,is) &
 !$OMP PRIVATE(nrc,nrci,npc,fname,iu,i) &
 !$OMP NUM_THREADS(nthd)
 allocate(igpig(ngkmax,nspnfv))
 allocate(jlkr(njcmax,nspecies))
-allocate(wfmta(npmtmax,natmtot),wfmtb(npmtmax,natmtot))
-allocate(wfira(ngtot),wfirb(ngtot))
-allocate(wfa(np,nspinor,num_bands),wfb(np,nspinor,num_bands))
 allocate(wfmt(npcmtmax,natmtot,nspinor,num_bands))
 allocate(wfir(ngtot,nspinor,num_bands))
+allocate(wf(np,nspinor,num_bands))
 allocate(expmt(npcmtmax,natmtot))
 !$OMP DO SCHEDULE(DYNAMIC)
 do ik=1,nkptnr
 !$OMP CRITICAL(writew90unk_)
-  write(*,'("Info(writew90unk): ",I6," of ",I6," k-points")') ik,nkptnr
+  write(*,'("Info(writew90unk): ",I0," of ",I0," k-points")') ik,nkptnr
 !$OMP END CRITICAL(writew90unk_)
 ! generate the second-variational wavefunctions
   call genwfsvp(.false.,.false.,num_bands,idxw90,ngridg,igfft,vkl(:,ik),ngp, &
@@ -70,18 +65,10 @@ do ik=1,nkptnr
         npc=npcmt(is)
 ! remove the explicit phase exp(ik.r) from the muffin-tin wavefunction
         wfmt(1:npc,ias,ispn,ist)=wfmt(1:npc,ias,ispn,ist)*expmt(1:npc,ias)
-        wfmta(1:npc,ias)=dble(wfmt(1:npc,ias,ispn,ist))
-        call rfshtip(nrc,nrci,wfmta(:,ias))
-        wfmtb(1:npc,ias)=aimag(wfmt(1:npc,ias,ispn,ist))
-        call rfshtip(nrc,nrci,wfmtb(:,ias))
+        call zfshtip(nrc,nrci,wfmt(:,ias,ispn,ist))
       end do
-      call rfmtctof(wfmta)
-      call rfmtctof(wfmtb)
-      wfira(:)=dble(wfir(:,ispn,ist))
-      wfirb(:)=aimag(wfir(:,ispn,ist))
 ! generate the wavefunctions on a regular grid
-      call rfplot(np,vpl,wfmta,wfira,wfa(:,ispn,ist))
-      call rfplot(np,vpl,wfmtb,wfirb,wfb(:,ispn,ist))
+      call zfpts(np,vpl,wfmt(:,:,ispn,ist),wfir(:,ispn,ist),wf(:,ispn,ist))
     end do
   end do
   if (spinpol) then
@@ -92,17 +79,15 @@ do ik=1,nkptnr
   open(newunit=iu,file=trim(fname),form='UNFORMATTED',action='WRITE')
   write(iu) np3d(1),np3d(2),np3d(3),ik,num_bands
   do ist=1,num_bands
-    write(iu) (cmplx(wfa(i,1,ist),wfb(i,1,ist),8),i=1,np)
+    write(iu) (wf(i,1,ist),i=1,np)
     if (spinpol) then
-      write(iu) (cmplx(wfa(i,2,ist),wfb(i,2,ist),8),i=1,np)
+      write(iu) (wf(i,2,ist),i=1,np)
     end if
   end do
   close(iu)
 end do
 !$OMP END DO
-deallocate(igpig,jlkr)
-deallocate(wfmta,wfmtb,wfira,wfirb)
-deallocate(wfa,wfb,wfmt,wfir,expmt)
+deallocate(igpig,jlkr,wfmt,wfir,wf,expmt)
 !$OMP END PARALLEL
 call freethd(nthd)
 write(*,*)
