@@ -8,7 +8,7 @@ use modmain
 implicit none
 ! initialise universal variables
 call init0
-if (all(xcgrad /= [3,4,5])) then
+if (all(xcgrad /= [3,4,5,6])) then
   write(*,*)
   write(*,'("Error(wxcplot): meta-GGA not in use")')
   write(*,*)
