@@ -15,36 +15,31 @@ real(8) t1
 ! allocatable arrays
 real(8), allocatable :: grfmt(:,:,:),grfir(:,:)
 real(8), allocatable :: rfmt(:,:),rfir(:)
-real(8), allocatable :: rfmt1(:),rfmt2(:,:)
 ! external functions
 real(8), external :: rfint
-! check that the Tran-Blaha functional is being used (A. Shyichuk)
-if (xctype(2).ne.XC_MGGA_X_TB09) return
-! if Tran-Blaha constant has been read in return
-if (tc_tb09) return
 ! compute the gradient of the density
 allocate(grfmt(npmtmax,natmtot,3),grfir(ngtot,3))
 call gradrf(rhomt,rhoir,grfmt,grfir)
-allocate(rfmt(npmtmax,natmtot),rfmt1(npmtmax),rfmt2(npmtmax,3))
+allocate(rfmt(npmtmax,natmtot))
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
 ! convert muffin-tin density to spherical coordinates
-  call rbsht(nr,nri,rhomt(:,ias),rfmt1)
+  call rbsht(nr,nri,rhomt(:,ias),rfmt(:,ias))
 ! convert muffin-tin gradient to spherical coordinates
   do i=1,3
-    call rbsht(nr,nri,grfmt(:,ias,i),rfmt2(:,i))
+    call rbshtip(nr,nri,grfmt(:,ias,i))
   end do
 ! integrand in muffin-tin
   do i=1,npmt(is)
-    t1=sqrt(rfmt2(i,1)**2+rfmt2(i,2)**2+rfmt2(i,3)**2)
-    rfmt1(i)=t1/rfmt1(i)
+    t1=sqrt(grfmt(i,ias,1)**2+grfmt(i,ias,2)**2+grfmt(i,ias,3)**2)
+    rfmt(i,ias)=t1/rfmt(i,ias)
   end do
 ! convert to spherical harmonics
-  call rfsht(nr,nri,rfmt1,rfmt(:,ias))
+  call rfshtip(nr,nri,rfmt(:,ias))
 end do
-deallocate(grfmt,rfmt1,rfmt2)
+deallocate(grfmt)
 ! integrand in interstitial
 allocate(rfir(ngtot))
 do ir=1,ngtot
