@@ -16,19 +16,19 @@ integer n,ir,i
 i=1
 if (lmaxi == 1) then
   do ir=1,nri
-    cfmt(i:i+3)=cmplx(wr(ir)*zfmt(i:i+3))
+    cfmt(i:i+3)=wr(ir)*zfmt(i:i+3)
     i=i+4
   end do
 else
   n=lmmaxi-1
   do ir=1,nri
-    cfmt(i:i+n)=cmplx(wr(ir)*zfmt(i:i+n))
+    cfmt(i:i+n)=wr(ir)*zfmt(i:i+n)
     i=i+lmmaxi
   end do
 end if
 n=lmmaxo-1
 do ir=nri+1,nr
-  cfmt(i:i+n)=cmplx(wr(ir)*zfmt(i:i+n))
+  cfmt(i:i+n)=wr(ir)*zfmt(i:i+n)
   i=i+lmmaxo
 end do
 end subroutine
