@@ -9,16 +9,14 @@ implicit none
 ! arguments
 complex(8), intent(in) :: c(*),z
 ! local variables
-integer i,j
-real(8) t1
+integer i
 complex(8) z1
 zfpole=c(1)
-i=2
-do j=1,npole
+do i=2,2*npole,2
   z1=c(i)+z
-  t1=abs(dble(z1))+abs(aimag(z1))
-  if (t1 > 1.d-8) zfpole=zfpole+c(i+1)/z1
-  i=i+2
+  if (abs(z1%re)+abs(z1%im) > 1.d-8) then
+    zfpole=zfpole+c(i+1)/z1
+  end if
 end do
 end function
 
