@@ -9,6 +9,7 @@ implicit none
 ! arguments
 integer, intent(in) :: ngp
 real(8), intent(in) :: jlgpr(njcmax,nspecies,ngp)
+! note the Yₗₘ include a prefactor of 4π (-i)ˡ
 complex(8), intent(in) :: ylmgp(lmmaxo,ngp)
 integer, intent(in) :: ld
 complex(8), intent(in) :: sfacgp(ld,natmtot)
@@ -21,7 +22,7 @@ integer l,lm,n,i,j
 real(8) t0,y0
 complex(8) zsm,z1
 ! automatic arrays
-complex(4) ylm(lmmaxo),cfft(ngtc)
+complex(4) ylm(2:lmmaxo),cfft(ngtc)
 !-----------------------------------!
 !     interstitial contribution     !
 !-----------------------------------!
@@ -36,7 +37,7 @@ zfgp(1:ngp)=cfft(igfc(1:ngp))
 t0=1.d0/omega
 y0=t0*fourpi*y00
 do ig=1,ngp
-  ylm(1:lmmaxo)=t0*ylmgp(1:lmmaxo,ig)
+  ylm(2:lmmaxo)=t0*ylmgp(2:lmmaxo,ig)
   do is=1,nspecies
     nrc=nrcmt(is)
     nrci=nrcmti(is)
