@@ -18,10 +18,11 @@ complex(8), external :: zdotc
 call holdthd(n,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(i) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do j=1,n
   do i=1,m
-    c(i,j)=c(i,j)+zdotc(l,a(:,i),1,b(:,j),1)
+    c(i,j)=c(i,j)+zdotc(l,a(1,i),1,b(1,j),1)
   end do
 end do
 !$OMP END PARALLEL DO
