@@ -8,23 +8,24 @@ use modomp
 implicit none
 ! arguments
 integer, intent(in) :: l,n
-complex(8), intent(in) :: a(l,n),b(l,n)
+! pass in complex arrays as real
+real(8), intent(in) :: a(2*l,n),b(2*l,n)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: c(ld,*)
 ! local variables
 integer i,j,nthd
 ! external functions
-real(8), external :: ddot
 complex(8), external :: zdotc
 call holdthd(n,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(i) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do j=1,n
   do i=1,j-1
     c(i,j)=c(i,j)+zdotc(l,a(1,i),1,b(1,j),1)
   end do
-  c(j,j)=c(j,j)+ddot(2*l,a(1,j),1,b(1,j),1)
+  c(j,j)=c(j,j)+dot_product(a(:,j),b(:,j))
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
