@@ -23,7 +23,7 @@ use modmain
 !   spherical harmonic expansion of the Coulomb potential, $V_{lm}$, is obtained
 !   from the density expansion, $\rho_{lm}$, by
 !   $$ V_{lm}(r)=\frac{4\pi}{2l+1}\left(\frac{1}{r^{l+1}}\int_0^r\rho_{lm}(r')
-!      {r'}^{l+2}dr'+r^l\int_r^R\frac{\rho_{lm}(r')}{{r'}^{l-1}}dr'\right) $$
+!    {r'}^{l+2}dr'+r^l\int_r^R\frac{\rho_{lm}(r')}{{r'}^{l-1}}dr'\right), $$
 !   where $R$ is the muffin-tin radius.
 !
 ! !REVISION HISTORY:
@@ -98,7 +98,6 @@ do l=lmaxi+1,lmaxo
     end do
   end do
 end do
-return
 
 contains
 
